@@ -232,6 +232,14 @@ enum cxd56_audio_dma_path_e
 
   CXD56_AUDIO_DMA_PATH_MIC_TO_MEM = 0,
 
+  /* I2S0 to memory */
+
+  CXD56_AUDIO_DMA_PATH_I2S0_TO_MEM,
+
+  /* I2S1 to memory */
+
+  CXD56_AUDIO_DMA_PATH_I2S1_TO_MEM,
+
   /* Memory to BUS I/F1 */
 
   CXD56_AUDIO_DMA_PATH_MEM_TO_BUSIF1,
@@ -294,11 +302,19 @@ enum cxd56_audio_dma_e
 
   CXD56_AUDIO_DMAC_MIC = 0,
 
-  /* I2S_OUT */
+  /* I2S1 Input */
+
+  CXD56_AUDIO_DMAC_I2S0_UP,
+
+  /* I2S1 Output */
 
   CXD56_AUDIO_DMAC_I2S0_DOWN,
 
-  /* I2S2_OUT */
+  /* I2S2 Input */
+
+  CXD56_AUDIO_DMAC_I2S1_UP,
+
+  /* I2S2 Output */
 
   CXD56_AUDIO_DMAC_I2S1_DOWN
 };
