@@ -22,8 +22,8 @@
  * only indirectly through nuttx/irq.h
  */
 
-#ifndef __ARCH_ARM_INCLUDE_MAX326_IRQ_H
-#define __ARCH_ARM_INCLUDE_MAX326_IRQ_H
+#ifndef __ARCH_ARM_INCLUDE_MAX326XX_IRQ_H
+#define __ARCH_ARM_INCLUDE_MAX326XX_IRQ_H
 
 /****************************************************************************
  * Included Files
@@ -99,4 +99,4 @@ extern "C"
 #endif
 #endif
 
-#endif /* __ARCH_ARM_INCLUDE_MAX326_IRQ_H */
+#endif /* __ARCH_ARM_INCLUDE_MAX326XX_IRQ_H */
