@@ -31,7 +31,7 @@
 #include <nuttx/arch.h>
 #include <nuttx/can/can.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "hardware/am335x_pinmux.h"
 #include "hardware/am335x_prcm.h"
 #include "hardware/am335x_dcan.h"
