@@ -29,8 +29,7 @@
 
 #include <nuttx/irq.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "nvic.h"
 
 #ifdef CONFIG_DEBUG_FEATURES
