@@ -25,7 +25,8 @@
 #include <nuttx/config.h>
 #include <nuttx/arch.h>
 
-#include "svcall.h"
+#include <arch/syscall.h>
+
 #include "arm_internal.h"
 
 #if !defined(CONFIG_BUILD_FLAT) && defined(__KERNEL__)
