@@ -26,14 +26,12 @@
 
 #include <stdint.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "cp15_cacheops.h"
 #include "barriers.h"
 #include "sctlr.h"
 #include "scu.h"
 
-#ifdef CONFIG_SMP
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -208,5 +206,3 @@ void arm_enable_smp(int cpu)
   regval |= SCTLR_C;
   arm_set_sctlr(regval);
 }
-
-#endif
