@@ -34,7 +34,6 @@
 #include "arm.h"
 #include "sched/sched.h"
 #include "arm_internal.h"
-#include "arm_arch.h"
 
 /****************************************************************************
  * Public Functions
@@ -131,7 +130,7 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
                */
 
               CURRENT_REGS[REG_PC]      = (uint32_t)arm_sigdeliver;
-              CURRENT_REGS[REG_CPSR]    = (PSR_MODE_SVC | PSR_I_BIT |
+              CURRENT_REGS[REG_CPSR]    = (PSR_MODE_SYS | PSR_I_BIT |
                                            PSR_F_BIT);
 
 #ifdef CONFIG_ENDIAN_BIG
@@ -167,7 +166,7 @@ void up_schedule_sigaction(struct tcb_s *tcb, sig_deliver_t sigdeliver)
            */
 
           tcb->xcp.regs[REG_PC]      = (uint32_t)arm_sigdeliver;
-          tcb->xcp.regs[REG_CPSR]    = (PSR_MODE_SVC | PSR_I_BIT |
+          tcb->xcp.regs[REG_CPSR]    = (PSR_MODE_SYS | PSR_I_BIT |
                                         PSR_F_BIT);
 
 #ifdef CONFIG_ENDIAN_BIG
