@@ -33,7 +33,7 @@
 #include "itm.h"
 #include "tpi.h"
 #include "dwt.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "itm_syslog.h"
 
 #ifdef CONFIG_ARMV8M_ITMSYSLOG
