@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_COMMON_ARMV8_M_BARRIERS_H
-#define __ARCH_ARM_SRC_COMMON_ARMV8_M_BARRIERS_H
+#ifndef __ARCH_ARM_SRC_ARMV8_M_BARRIERS_H
+#define __ARCH_ARM_SRC_ARMV8_M_BARRIERS_H
 
 /****************************************************************************
  * Included Files
@@ -39,4 +39,4 @@
 #define ARM_ISB()  arm_isb(15)
 #define ARM_DMB()  arm_dmb(15)
 
-#endif /* __ARCH_ARM_SRC_COMMON_ARMV8_M_BARRIERS_H */
+#endif /* __ARCH_ARM_SRC_ARMV8_M_BARRIERS_H */
