@@ -38,16 +38,6 @@
 #include "arm_vfork.h"
 #include "sched/sched.h"
 
-/****************************************************************************
- * Pre-processor Definitions
- ****************************************************************************/
-
-/* For use with EABI and floating point, the stack must be aligned to 8-byte
- * addresses.
- */
-
-#define CONFIG_STACK_ALIGNMENT 8
-
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
