@@ -41,7 +41,7 @@
 #include <arch/chip/adc.h>
 
 #include "chip.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "hardware/cxd56_adc.h"
 #include "hardware/cxd56_scuseq.h"
 #include "cxd56_clock.h"
@@ -202,11 +202,12 @@ static const struct file_operations g_adcops =
   cxd56_adc_open,            /* open */
   cxd56_adc_close,           /* close */
   cxd56_adc_read,            /* read */
-  0,                         /* write */
-  0,                         /* seek */
+  NULL,                      /* write */
+  NULL,                      /* seek */
   cxd56_adc_ioctl,           /* ioctl */
-#ifndef CONFIG_DISABLE_POLL
-  0,                         /* poll */
+  NULL                       /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL                     /* unlink */
 #endif
 };
 
