@@ -32,8 +32,7 @@
 
 #include <arch/chip/pm.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "chip.h"
 #include "hardware/cxd56_crg.h"
 #include "hardware/cxd5602_backupmem.h"
