@@ -39,7 +39,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "cxd56_clock.h"
 #include "cxd56_emmc.h"
 #include "hardware/cxd56_emmc.h"
