@@ -41,7 +41,7 @@
 #include <arch/board/board.h>
 
 #include "clock/clock.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "cxd56_rtc.h"
 
 #include "hardware/cxd5602_topreg.h"
