@@ -40,8 +40,7 @@
 #include <arch/chip/scu.h>
 
 #include "chip.h"
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "cxd56_scufifo.h"
 #include "cxd56_clock.h"
 #include "cxd56_adc.h"
