@@ -29,8 +29,7 @@
 
 #include "hardware/cxd56_sph.h"
 #include "cxd56_sph.h"
-
-#include "arm_arch.h"
+#include "arm_internal.h"
 
 /****************************************************************************
  * Pre-processor Definitions
