@@ -25,7 +25,7 @@
 #include <nuttx/config.h>
 
 #include "chip.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "cxd56_uid.h"
 #include "hardware/cxd5602_topreg.h"
 
