@@ -58,8 +58,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "efm32_gpio.h"
 #include "hardware/efm32_cmu.h"
 #include "hardware/efm32_i2c.h"
