@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_EFM32_EFM32_OTGFS_H
-#define __ARCH_ARM_SRC_EFM32_EFM32_OTGFS_H
+#ifndef __ARCH_ARM_SRC_EFM32_EFM32_USB_H
+#define __ARCH_ARM_SRC_EFM32_EFM32_USB_H
 
 /****************************************************************************
  * Included Files
@@ -200,4 +200,4 @@ void efm32_usbsuspend(FAR struct usbdev_s *dev, bool resume);
 
 #endif /* __ASSEMBLY__ */
 #endif /* CONFIG_EFM32_OTGFS */
-#endif /* __ARCH_ARM_SRC_EFM32_EFM32_OTGFS_H */
+#endif /* __ARCH_ARM_SRC_EFM32_EFM32_USB_H */
