@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_IMX_RTC_H
-#define __ARCH_ARM_IMX_RTC_H
+#ifndef __ARCH_ARM_SRC_IMX1_IMX_RTC_H
+#define __ARCH_ARM_SRC_IMX1_IMX_RTC_H
 
 /****************************************************************************
  * Included Files
@@ -67,4 +67,4 @@
  * Inline Functions
  ****************************************************************************/
 
-#endif /* __ARCH_ARM_IMX_RTC_H */
+#endif /* __ARCH_ARM_SRC_IMX1_IMX_RTC_H */
