@@ -31,7 +31,7 @@
 #include <nuttx/irq.h>
 
 #include "chip.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "imx_iomuxc.h"
 #include "imx_gpio.h"
 
