@@ -28,8 +28,6 @@
 #include <fixedmath.h>
 #include <assert.h>
 
-#include "arm_arch.h"
-
 #include "hardware/imx_iomuxc.h"
 #include "hardware/imx_ccm.h"
 #include "hardware/imx_uart.h"
@@ -37,9 +35,7 @@
 #include "imx_iomuxc.h"
 #include "imx_gpio.h"
 #include "imx_lowputc.h"
-
 #include "arm_internal.h"
-
 #include "hardware/imx_pinmux.h"
 #include <arch/board/board.h> /* Include last:  has dependencies */
 
@@ -571,7 +567,7 @@ int imx_uart_configure(uint32_t base, FAR const struct uart_config_s *config)
  *
  ****************************************************************************/
 
-#if defined(IMX_HAVE_UART) && defined(CONFIG_DEBUG_FEATURES)
+#ifdef IMX_HAVE_UART
 void imx_lowputc(int ch)
 {
   /* Poll the TX fifo trigger level bit of the UART status register. When the
@@ -585,29 +581,8 @@ void imx_lowputc(int ch)
    * return
    */
 
-  if (ch == '\n')
-    {
-      /* Send the carrage return by writing it into the UART_TXD register. */
-
-      putreg32((uint32_t)'\r', IMX_CONSOLE_VBASE + UART_TXD_OFFSET);
-
-      /* Wait for the tranmsit register to be emptied. When the TXFE bit is
-       * non-zero, the TX Buffer FIFO is empty.
-       */
-
-      while ((getreg32(IMX_CONSOLE_VBASE + UART_USR2_OFFSET) &
-              UART_USR2_TXFE) == 0);
-    }
-
   /* Send the character by writing it into the UART_TXD register. */
 
   putreg32((uint32_t)ch, IMX_CONSOLE_VBASE + UART_TXD_OFFSET);
-
-  /* Wait for the tranmsit register to be emptied. When the TXFE bit is
-   * non-zero, the TX Buffer FIFO is empty.
-   */
-
-  while ((getreg32(IMX_CONSOLE_VBASE + UART_USR2_OFFSET) &
-          UART_USR2_TXFE) == 0);
 }
 #endif
