@@ -51,7 +51,7 @@
 
 #include <nuttx/video/fb.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 
 #include <nuttx/board.h>
 
