@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_IMXRT_LOWPUTC_H
-#define __ARCH_ARM_SRC_IMXRT_LOWPUTC_H
+#ifndef __ARCH_ARM_SRC_IMXRT_IMXRT_LOWPUTC_H
+#define __ARCH_ARM_SRC_IMXRT_IMXRT_LOWPUTC_H
 
 /****************************************************************************
  * Included Files
@@ -96,10 +96,10 @@ int imxrt_lpuart_configure(uint32_t base,
  *
  ****************************************************************************/
 
-#if defined(HAVE_LPUART_DEVICE) && defined(CONFIG_DEBUG_FEATURES)
+#if defined(HAVE_LPUART_DEVICE)
 void imxrt_lowputc(int ch);
 #else
 #  define imxrt_lowputc(ch)
 #endif
 
-#endif /* __ARCH_ARM_SRC_IMXRT_LOWPUTC_H */
+#endif /* __ARCH_ARM_SRC_IMXRT_IMXRT_LOWPUTC_H */
