@@ -26,7 +26,7 @@
 
 #include <stdint.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "imxrt_periphclks.h"
 
 /****************************************************************************
