@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_IMXRT_IMX_USDHC_H
-#define __ARCH_ARM_SRC_IMXRT_IMX_USDHC_H
+#ifndef __ARCH_ARM_SRC_IMXRT_IMXRT_USDHC_H
+#define __ARCH_ARM_SRC_IMXRT_IMXRT_USDHC_H
 
 /****************************************************************************
  * Included Files
@@ -72,4 +72,4 @@ void imxrt_usdhc_set_sdio_card_isr(FAR struct sdio_dev_s *dev,
 
 FAR struct sdio_dev_s *imxrt_usdhc_initialize(int slotno);
 
-#endif /* __ARCH_ARM_SRC_IMXRT_IMX_USDHC_H */
+#endif /* __ARCH_ARM_SRC_IMXRT_IMXRT_USDHC_H */
