@@ -37,8 +37,6 @@
 #include <arch/board/board.h>
 
 #include "arm_internal.h"
-#include "arm_arch.h"
-
 #include "chip.h"
 
 #include "kinetis.h"
@@ -712,6 +710,7 @@ static int pwm_stop(FAR struct pwm_lowerhalf_s *dev)
 
       default:
         pwmerr("ERROR: No such channel: %d\n", priv->channel);
+        leave_critical_section(flags);
         return -EINVAL;
     }
 
