@@ -64,8 +64,7 @@
 #include <arch/irq.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "kinetis.h"
 #include "kinetis_edma.h"
 #include "kinetis_spi.h"
