@@ -31,8 +31,7 @@
 #include <nuttx/irq.h>
 #include <nuttx/arch.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/kl_port.h"
 #include "kl_gpio.h"
 
