@@ -32,7 +32,7 @@
 #include <errno.h>
 #include <debug.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "lc823450_gpio.h"
 #include "lc823450_syscontrol.h"
 
