@@ -44,8 +44,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "lc823450_syscontrol.h"
 #include "lc823450_clockconfig.h"
 #include "lc823450_i2c.h"
