@@ -55,8 +55,7 @@
 #include <string.h>
 
 #include "chip.h"
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "lc823450_sddrv_if.h"
 #include "lc823450_sdc.h"
 #include "lc823450_syscontrol.h"
@@ -201,7 +200,7 @@ int lc823450_sdc_clearcardinfo(uint32_t ch)
 {
   int ret;
 
-  mcinfo("++++ start \n");
+  mcinfo("++++ start\n");
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret < 0)
@@ -220,7 +219,7 @@ int lc823450_sdc_clearcardinfo(uint32_t ch)
 #endif
 
   _sdc_semgive(&_sdc_sem[ch]);
-  mcinfo("---- end ret=%d \n", ret);
+  mcinfo("---- end ret=%d\n", ret);
   return ret;
 }
 
@@ -276,14 +275,14 @@ int lc823450_sdc_initialize(uint32_t ch)
         DEBUGASSERT(false);
     }
 
-  mcinfo("++++ start \n");
+  mcinfo("++++ start\n");
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
       ret = sddr_initialize(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("---- end ret=%d \n", ret);
+      mcinfo("---- end ret=%d\n", ret);
     }
 
   return ret;
@@ -297,14 +296,14 @@ int lc823450_sdc_finalize(uint32_t ch)
 {
   int ret;
 
-  mcinfo("++++ start ch=%ld \n", ch);
+  mcinfo("++++ start ch=%ld\n", ch);
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
       ret = sddr_finalize(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("---- end ret=%d \n", ret);
+      mcinfo("---- end ret=%d\n", ret);
     }
 
   return ret;
@@ -318,7 +317,7 @@ int lc823450_sdc_identifycard(uint32_t ch)
 {
   int ret;
 
-  mcinfo("++++ start \n");
+  mcinfo("++++ start\n");
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret < 0)
@@ -337,7 +336,7 @@ int lc823450_sdc_identifycard(uint32_t ch)
 #endif
 
   _sdc_semgive(&_sdc_sem[ch]);
-  mcinfo("---- end ret=%d \n", ret);
+  mcinfo("---- end ret=%d\n", ret);
   return ret;
 }
 
@@ -357,7 +356,7 @@ int lc823450_sdc_setclock(uint32_t ch, uint32_t limitclk, uint32_t sysclk)
     {
       ret = sddr_setclock(limitclk, sysclk, _cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("---- end ret=%d \n", ret);
+      mcinfo("---- end ret=%d\n", ret);
     }
 
   return ret;
@@ -375,14 +374,14 @@ int lc823450_sdc_refmediatype(uint32_t ch)
 {
   int ret;
 
-  mcinfo("++++ start \n");
+  mcinfo("++++ start\n");
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
       ret = sddr_refmediatype(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("---- end ret=%d \n", ret);
+      mcinfo("---- end ret=%d\n", ret);
     }
 
   return ret;
@@ -397,7 +396,7 @@ int lc823450_sdc_getcardsize(uint32_t ch,
 {
   int ret;
 
-  mcinfo("++++ start \n");
+  mcinfo("++++ start\n");
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
@@ -405,7 +404,7 @@ int lc823450_sdc_getcardsize(uint32_t ch,
       ret = sddr_getcardsize(psecnum, psecsize, _cfg[ch]);
 
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("---- end ret=%d \n", ret);
+      mcinfo("---- end ret=%d\n", ret);
     }
 
   return ret;
@@ -429,7 +428,7 @@ int lc823450_sdc_readsector(uint32_t ch,
     }
 
 #ifdef CONFIG_LC823450_SDC_LOG
-  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d \n", ch, addr, cnt);
+  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d\n", ch, addr, cnt);
 #endif
 
 #ifdef CONFIG_LC823450_SDC_CACHE
@@ -458,7 +457,7 @@ int lc823450_sdc_readsector(uint32_t ch,
           break;
         }
 
-      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d i=%d \n",
+      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d i=%d\n",
              ret, ch, addr, cnt, i);
     }
 
@@ -470,7 +469,7 @@ int lc823450_sdc_readsector(uint32_t ch,
           uint8_t *p = (pbuf + 0x1c2); /* partition id */
           if (0x7 == *p)
             {
-              mcinfo("exFAT (NTFS) detected \n");
+              mcinfo("exFAT (NTFS) detected\n");
               _sec_cache_enabled = 1;
             }
         }
@@ -493,7 +492,7 @@ errout_with_semaphore:
 #endif
   _sdc_semgive(&_sdc_sem[ch]);
 
-  mcinfo("----  end ret=%d \n", ret);
+  mcinfo("----  end ret=%d\n", ret);
   return ret;
 }
 
@@ -514,7 +513,7 @@ int lc823450_sdc_writesector(uint32_t ch,
     }
 
 #ifdef CONFIG_LC823450_SDC_LOG
-  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d \n", ch, addr, cnt);
+  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d\n", ch, addr, cnt);
 #endif
 
 #ifdef CONFIG_LC823450_SDC_CACHE
@@ -534,12 +533,12 @@ int lc823450_sdc_writesector(uint32_t ch,
 
   if (0 > ret)
     {
-      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d \n", ret, ch, addr, cnt);
+      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d\n", ret, ch, addr, cnt);
     }
 
   _sdc_semgive(&_sdc_sem[ch]);
 
-  mcinfo("----  end ret=%d \n", ret);
+  mcinfo("----  end ret=%d\n", ret);
   return ret;
 }
 
@@ -568,7 +567,7 @@ int lc823450_sdc_trimsector(uint32_t ch, unsigned long addr,
     }
 
 #ifdef CONFIG_LC823450_SDC_LOG
-  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d \n", ch, addr, cnt);
+  mcinfo("++++ start ch=%d, addr=%ld, cnt=%d\n", ch, addr, cnt);
 #endif
 
   lc823450_sdc_access_led(ch, addr);
@@ -580,12 +579,12 @@ int lc823450_sdc_trimsector(uint32_t ch, unsigned long addr,
   ret = sddr_eraseseq(0x00000001, addr, cnt, _cfg[ch]);
   if (0 > ret)
     {
-      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d \n", ret, ch, addr, cnt);
+      mcinfo("ret=%d ch=%" PRId32 " add=%ld cnt=%d\n", ret, ch, addr, cnt);
     }
 
   _sdc_semgive(&_sdc_sem[ch]);
 
-  mcinfo("----  end ret=%d \n", ret);
+  mcinfo("----  end ret=%d\n", ret);
   return ret;
 }
 
@@ -597,7 +596,7 @@ int lc823450_sdc_cachectl(uint32_t ch, int ctrl)
 {
   int ret;
 
-  mcinfo("++++ ch=%" PRId32 ", ctrl=%d \n", ch, ctrl);
+  mcinfo("++++ ch=%" PRId32 ", ctrl=%d\n", ch, ctrl);
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
@@ -605,7 +604,7 @@ int lc823450_sdc_cachectl(uint32_t ch, int ctrl)
       ret = sddr_cachectrl(ctrl, _cfg[ch]);
 
       _sdc_semgive(&_sdc_sem[ch]);
-      mcinfo("----  end ret=%d \n", ret);
+      mcinfo("----  end ret=%d\n", ret);
     }
 
   return ret;
@@ -619,7 +618,7 @@ int lc823450_sdc_changespeedmode(uint32_t ch, int mode)
 {
   int ret;
 
-  mcinfo("++++ ch=%" PRId32 ", mode=%d \n", ch, mode);
+  mcinfo("++++ ch=%" PRId32 ", mode=%d\n", ch, mode);
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret < 0)
@@ -648,7 +647,7 @@ int lc823450_sdc_changespeedmode(uint32_t ch, int mode)
     }
 
   _sdc_semgive(&_sdc_sem[ch]);
-  mcinfo("----  end ret=%d \n", ret);
+  mcinfo("----  end ret=%d\n", ret);
   return ret;
 }
 
@@ -661,7 +660,7 @@ int lc823450_sdc_getcid(uint32_t ch, char *cidstr, int length)
   uint8_t cid[16];
   int ret;
 
-  mcinfo("++++ ch=%" PRId32 " \n", ch);
+  mcinfo("++++ ch=%" PRId32 "\n", ch);
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret < 0)
@@ -685,7 +684,7 @@ int lc823450_sdc_getcid(uint32_t ch, char *cidstr, int length)
     }
 
   _sdc_semgive(&_sdc_sem[ch]);
-  mcinfo("----  end ret=%d \n", ret);
+  mcinfo("----  end ret=%d\n", ret);
   return ret;
 }
 
