@@ -40,7 +40,7 @@
 #include <nuttx/clock.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "lc823450_syscontrol.h"
 #include "lc823450_wdt.h"
