@@ -67,9 +67,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
 #include "arm_internal.h"
-
 #include "chip.h"
 #include "hardware/lpc17_40_syscon.h"
 #include "lpc17_40_gpio.h"
@@ -610,6 +608,7 @@ struct i2c_master_s *lpc17_40_i2cbus_initialize(int port)
 #endif
     {
       i2cerr("ERROR: LPC I2C Only supports ports 0, 1 and 2\n");
+      leave_critical_section(flags);
       return NULL;
     }
 
