@@ -30,7 +30,7 @@
 #include <nuttx/config.h>
 #include <stdint.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "lpc31_cgudrvr.h"
 
 /****************************************************************************
