@@ -1,6 +1,21 @@
 /****************************************************************************
  * arch/arm/src/lpc43xx/lpc43_emc.c
  *
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ *
  ****************************************************************************/
 
 /****************************************************************************
@@ -24,7 +39,6 @@
 #include <nuttx/wdog.h>
 
 #include "arm_internal.h"
-
 #include "chip.h"
 #include "lpc43_pinconfig.h"
 #include "lpc43_emc.h"
@@ -33,7 +47,7 @@
 #include "hardware/lpc43_ccu.h"
 #include "lpc43_rgu.h"
 #include "lpc43_gpio.h"
-#include "arm_arch.h"
+
 #include <arch/board/board.h>
 
 /****************************************************************************
