@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_LPC43XX_CHIP_LPC43_WDT_H
-#define __ARCH_ARM_SRC_LPC43XX_CHIP_LPC43_WDT_H
+#ifndef __ARCH_ARM_SRC_LPC43XX_LPC43_WDT_H
+#define __ARCH_ARM_SRC_LPC43XX_LPC43_WDT_H
 
 /****************************************************************************
  * Included Files
@@ -79,4 +79,4 @@ void lpc43_wwdtinitialize(FAR const char *devpath);
 
 #endif /* __ASSEMBLY__ */
 #endif /* CONFIG_WATCHDOG */
-#endif /* __ARCH_ARM_SRC_LPC43XX_CHIP_LPC43_WDT_H */
+#endif /* __ARCH_ARM_SRC_LPC43XX_LPC43_WDT_H */
