@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC548X_IOCON_H
-#define __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC548X_IOCON_H
+#ifndef __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC54_IOCON_H
+#define __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC54_IOCON_H
 
 /****************************************************************************
  * Included Files
@@ -361,4 +361,4 @@
 #define IOCON_PIO4_TYPEA_MASK (0x00000000) /* None */
 #define IOCON_PIO5_TYPEA_MASK (0x00000000) /* None */
 
-#endif /* __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC548X_IOCON_H */
+#endif /* __ARCH_ARM_SRC_LPC54XX_HARDWARE_LPC54_IOCON_H */
