@@ -29,8 +29,7 @@
 
 #include <nuttx/irq.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/max326_gcr.h"
 #include "hardware/max326_pwrseq.h"
 #include "hardware/max326_flc.h"
