@@ -38,8 +38,7 @@
 #include <nuttx/clock.h>
 #include <nuttx/timers/rtc.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/max326_rtc.h"
 #include "max326_rtc.h"
 
