@@ -52,9 +52,7 @@
 #include <nuttx/progmem.h>
 
 #include "chip.h"
-
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/nrf52_ficr.h"
 #include "hardware/nrf52_nvmc.h"
 #include "nrf52_nvmc.h"
