@@ -36,9 +36,14 @@
 #include <arch/nrf52/nrf52_irq.h>
 #include <nuttx/wqueue.h>
 
+#if defined(CONFIG_UART_BTH4)
+#  include <nuttx/serial/uart_bth4.h>
+#endif
+
 #include "arm_internal.h"
 #include "ram_vectors.h"
-#include "arm_arch.h"
+
+#include "hardware/nrf52_ficr.h"
 
 #include <mpsl.h>
 #include <sdc.h>
@@ -75,6 +80,19 @@
 #define MEMPOOL_SIZE  ((CONFIG_NRF52_SDC_SLAVE_COUNT * SLAVE_MEM_SIZE) + \
                        (SDC_MASTER_COUNT * MASTER_MEM_SIZE))
 
+#if (CONFIG_NRF52_SDC_PUB_ADDR > 0) ||          \
+  defined(CONFIG_NRF52_SDC_FICR_STATIC_ADDR)
+#  define HAVE_BTADDR_CONFIGURE
+#endif
+
+/* Calls to sdc */
+
+#define SDC_RNG_IRQHANDLER      sdc_RNG_IRQHandler
+#define MPSL_IRQ_CLOCK_HANDLER  MPSL_IRQ_CLOCK_Handler
+#define MPSL_IRQ_RTC0_HANDLER   MPSL_IRQ_RTC0_Handler
+#define MPSL_IRQ_TIMER0_HANDLER MPSL_IRQ_TIMER0_Handler
+#define MPSL_IRQ_RADIO_HANDLER  MPSL_IRQ_RADIO_Handler
+
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -88,6 +106,25 @@ struct nrf52_sdc_dev_s
   struct work_s work;
 };
 
+begin_packed_struct struct sdc_hci_cmd_vs_zephyr_write_bd_addr_s
+{
+  uint8_t bd_addr[6];
+} end_packed_struct;
+
+begin_packed_struct struct sdc_hci_cmd_le_set_random_address_s
+{
+  uint8_t bd_addr[6];
+} end_packed_struct;
+
+/****************************************************************************
+ * External Function Prototypes
+ ****************************************************************************/
+
+uint8_t sdc_hci_cmd_vs_zephyr_write_bd_addr(
+  FAR const struct sdc_hci_cmd_vs_zephyr_write_bd_addr_s *p_params);
+uint8_t sdc_hci_cmd_le_set_random_address(
+  FAR const struct sdc_hci_cmd_le_set_random_address_s *p_params);
+
 /****************************************************************************
  * Private Function Prototypes
  ****************************************************************************/
@@ -275,10 +312,10 @@ static void on_hci(void)
               struct hci_evt_cmd_complete_s *cmd_complete =
                   (struct hci_evt_cmd_complete_s *)
                       (g_sdc_dev.msg_buffer + sizeof(*hdr));
-              uint8_t *status = (uint8_t *)cmd_complete + 1;
+              uint8_t *status = (uint8_t *)cmd_complete + 3;
 
               wlinfo("received CMD_COMPLETE from softdevice "
-                     "(opcode: %d, status: 0x%x)\n",
+                     "(opcode: 0x%x, status: 0x%x)\n",
                      cmd_complete->opcode, *status);
             }
           else
@@ -332,7 +369,7 @@ static int swi_isr(int irq, FAR void *context, FAR void *arg)
 
 static void rng_handler(void)
 {
-  sdc_RNG_IRQHandler();
+  SDC_RNG_IRQHANDLER();
 }
 
 /****************************************************************************
@@ -341,7 +378,7 @@ static void rng_handler(void)
 
 static int power_clock_isr(int irq, FAR void *context, FAR void *arg)
 {
-  MPSL_IRQ_CLOCK_Handler();
+  MPSL_IRQ_CLOCK_HANDLER();
 
   return 0;
 }
@@ -352,7 +389,7 @@ static int power_clock_isr(int irq, FAR void *context, FAR void *arg)
 
 static void rtc0_handler(void)
 {
-  MPSL_IRQ_RTC0_Handler();
+  MPSL_IRQ_RTC0_HANDLER();
 }
 
 /****************************************************************************
@@ -361,7 +398,7 @@ static void rtc0_handler(void)
 
 static void timer0_handler(void)
 {
-  MPSL_IRQ_TIMER0_Handler();
+  MPSL_IRQ_TIMER0_HANDLER();
 }
 
 /****************************************************************************
@@ -370,9 +407,88 @@ static void timer0_handler(void)
 
 static void radio_handler(void)
 {
-  MPSL_IRQ_RADIO_Handler();
+  MPSL_IRQ_RADIO_HANDLER();
 }
 
+#ifdef HAVE_BTADDR_CONFIGURE
+/****************************************************************************
+ * Name: nrf52_sdc_btaddr_configure
+ ****************************************************************************/
+
+static int nrf52_sdc_btaddr_configure(void)
+{
+#ifdef CONFIG_NRF52_SDC_FICR_STATIC_ADDR
+  struct sdc_hci_cmd_le_set_random_address_s   rand_addr;
+#endif
+#if CONFIG_NRF52_SDC_PUB_ADDR > 0
+  struct sdc_hci_cmd_vs_zephyr_write_bd_addr_s pub_addr;
+#endif
+#ifdef CONFIG_NRF52_SDC_FICR_STATIC_ADDR
+  uint32_t                              regval   = 0;
+  uint32_t                              addr[2];
+  uint32_t                              addrtype = 0;
+#endif
+  int                                   ret      = OK;
+
+#ifdef CONFIG_NRF52_SDC_FICR_STATIC_ADDR
+  /* Get device address type */
+
+  addrtype = getreg32(NRF52_FICR_DEVICEADDRTYPE);
+
+  /* Get device addr from FICR */
+
+  addr[0] = getreg32(NRF52_FICR_DEVICEADDR0);
+  addr[1] = getreg32(NRF52_FICR_DEVICEADDR1);
+
+  if ((addrtype & 0x01) == FICR_DEVICEADDRTYPE_RANDOM)
+    {
+      /* Configure static random address */
+
+      memcpy(&rand_addr.bd_addr[0], &addr[0], 4);
+      memcpy(&rand_addr.bd_addr[4], &addr[1], 2);
+
+      /* The two most significant bits of the address shall be set */
+
+      rand_addr.bd_addr[4] |= 0x0c;
+
+      ret = sdc_hci_cmd_le_set_random_address(&rand_addr);
+      if (ret < 0)
+        {
+          wlerr("sdc_hci_cmd_le_set_random_address failed: %d\n", ret);
+          goto errout;
+        }
+    }
+  else
+    {
+      wlerr("Static random address not available\n");
+      ret = -EINVAL;
+      goto errout;
+    }
+#endif
+
+#if CONFIG_NRF52_SDC_PUB_ADDR > 0
+  /* Configure public address if available */
+
+  pub_addr.bd_addr[0] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 5)) & 0xff;
+  pub_addr.bd_addr[1] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 4)) & 0xff;
+  pub_addr.bd_addr[2] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 3)) & 0xff;
+  pub_addr.bd_addr[3] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 2)) & 0xff;
+  pub_addr.bd_addr[4] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 1)) & 0xff;
+  pub_addr.bd_addr[5] = (CONFIG_NRF52_SDC_PUB_ADDR >> (8 * 0)) & 0xff;
+
+  ret = sdc_hci_cmd_vs_zephyr_write_bd_addr(&pub_addr);
+  if (ret < 0)
+    {
+      wlerr("sdc_hci_cmd_vs_zephyr_write_bd_addr failed: %d\n", ret);
+      goto errout;
+    }
+#endif
+
+errout:
+  return ret;
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -429,7 +545,6 @@ int nrf52_sdc_initialize(void)
 
   ret = mpsl_init(&g_clock_config, NRF52_IRQ_SWI5_EGU5 - NRF52_IRQ_EXTINT,
                   &mpsl_assert_handler);
-
   if (ret < 0)
     {
       wlerr("mpsl init failed: %d\n", ret);
@@ -439,7 +554,6 @@ int nrf52_sdc_initialize(void)
   /* Initialize SDC */
 
   ret = sdc_init(&sdc_fault_handler);
-
   if (ret < 0)
     {
       wlerr("mpsl init failed: %d\n", ret);
@@ -451,7 +565,6 @@ int nrf52_sdc_initialize(void)
   cfg.master_count.count = SDC_MASTER_COUNT;
   ret = sdc_cfg_set(SDC_DEFAULT_RESOURCE_CFG_TAG,
                     SDC_CFG_TYPE_MASTER_COUNT, &cfg);
-
   if (ret < 0)
     {
       wlerr("Failed to set master role count: %d\n", ret);
@@ -461,7 +574,6 @@ int nrf52_sdc_initialize(void)
   cfg.slave_count.count = CONFIG_NRF52_SDC_SLAVE_COUNT;
   ret = sdc_cfg_set(SDC_DEFAULT_RESOURCE_CFG_TAG,
                     SDC_CFG_TYPE_SLAVE_COUNT, &cfg);
-
   if (ret < 0)
     {
       wlerr("Failed to set slave role count: %d\n", ret);
@@ -491,7 +603,6 @@ int nrf52_sdc_initialize(void)
 
 #ifdef CONFIG_NRF52_SDC_ADVERTISING
   ret = sdc_support_adv();
-
   if (ret < 0)
     {
       wlerr("Could not enable advertising feature: %d\n", ret);
@@ -501,7 +612,6 @@ int nrf52_sdc_initialize(void)
 
 #ifdef CONFIG_NRF52_SDC_SCANNING
   ret = sdc_support_scan();
-
   if (ret < 0)
     {
       wlerr("Could not enable scanning feature: %d\n", ret);
@@ -511,7 +621,6 @@ int nrf52_sdc_initialize(void)
 
 #if SDC_MASTER_COUNT > 0
   ret = sdc_support_master();
-
   if (ret < 0)
     {
       wlerr("Could not enable master feature: %d\n", ret);
@@ -521,7 +630,6 @@ int nrf52_sdc_initialize(void)
 
 #if CONFIG_NRF52_SDC_SLAVE_COUNT > 0
   ret = sdc_support_slave();
-
   if (ret < 0)
     {
       wlerr("Could not enable slave feature: %d\n", ret);
@@ -531,7 +639,6 @@ int nrf52_sdc_initialize(void)
 
 #ifdef CONFIG_NRF52_SDC_DLE
   ret = sdc_support_dle();
-
   if (ret < 0)
     {
       wlerr("Could not enable DLE feature: %d\n", ret);
@@ -541,7 +648,6 @@ int nrf52_sdc_initialize(void)
 
 #ifdef CONFIG_NRF52_SDC_LE_2M_PHY
   ret = sdc_support_le_2m_phy();
-
   if (ret < 0)
     {
       wlerr("Could not enable 2M PHY feature: %d\n", ret);
@@ -551,7 +657,6 @@ int nrf52_sdc_initialize(void)
 
 #ifdef CONFIG_NRF52_SDC_LE_CODED_PHY
   ret = sdc_support_le_coded_phy();
-
   if (ret < 0)
     {
       wlerr("Could not enable Coded PHY feature: %d\n", ret);
@@ -559,19 +664,47 @@ int nrf52_sdc_initialize(void)
     }
 #endif
 
+#ifdef HAVE_BTADDR_CONFIGURE
+  /* Configure BT address */
+
+  ret = nrf52_sdc_btaddr_configure();
+  if (ret < 0)
+    {
+      wlerr("Could not configure BT addr: %d\n", ret);
+      return ret;
+    }
+#endif
+
   /* Finally enable SoftDevice Controller */
 
   ret = sdc_enable(on_hci, g_sdc_dev.mempool);
-
   if (ret < 0)
     {
       wlerr("SoftDevice controller enable failed: %d\n", ret);
       return ret;
     }
 
+#ifdef CONFIG_UART_BTH4
+  /* Register UART BT H4 device */
+
+  ret = uart_bth4_register(CONFIG_NRF52_BLE_TTY_NAME, &g_bt_driver);
+  if (ret < 0)
+    {
+      wlerr("bt_bth4_register error: %d\n", ret);
+      return ret;
+    }
+#elif defined(CONFIG_NET_BLUETOOTH)
   /* Register network device */
 
   ret = bt_netdev_register(&g_bt_driver);
+  if (ret < 0)
+    {
+      wlerr("bt_netdev_register error: %d\n", ret);
+      return ret;
+    }
+#else
+#  error
+#endif
 
   return ret;
 }
