@@ -28,8 +28,7 @@
 #include <nuttx/spinlock.h>
 
 #include "hardware/rp2040_sio.h"
-
-#include "arm_arch.h"
+#include "arm_internal.h"
 
 /****************************************************************************
  * Pre-processor Definitions
