@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_S32K1XX_LOWPUTC_H
-#define __ARCH_ARM_SRC_S32K1XX_LOWPUTC_H
+#ifndef __ARCH_ARM_SRC_S32K1XX_S32K1XX_LOWPUTC_H
+#define __ARCH_ARM_SRC_S32K1XX_S32K1XX_LOWPUTC_H
 
 /****************************************************************************
  * Included Files
@@ -101,4 +101,4 @@ void s32k1xx_lowputc(int ch);
 #  define s32k1xx_lowputc(ch)
 #endif
 
-#endif /* __ARCH_ARM_SRC_S32K1XX_LOWPUTC_H */
+#endif /* __ARCH_ARM_SRC_S32K1XX_S32K1XX_LOWPUTC_H */
