@@ -42,8 +42,7 @@
 
 #include <arch/irq.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "s32k1xx_pin.h"
 #include "hardware/s32k1xx_pinmux.h"
 #include "s32k1xx_lpi2c.h"
@@ -1556,7 +1555,7 @@ static int s32k1xx_lpi2c_transfer(FAR struct i2c_master_s *dev,
   priv->msgc  = count;
   priv->flags = msgs->flags;
 
-  i2cinfo("Flags %x, len %d \n", msgs->flags, msgs->length);
+  i2cinfo("Flags %x, len %d\n", msgs->flags, msgs->length);
 
   /* Reset I2C trace logic */
 
