@@ -40,8 +40,7 @@
 
 #include <arch/irq.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "s32k1xx_pin.h"
 #include "hardware/s32k1xx_pinmux.h"
 #include "s32k1xx_lpi2c.h"
