@@ -43,7 +43,7 @@
 #include <nuttx/irq.h>
 #include <arch/board/board.h>
 #include "hardware/sam4s_pinmap.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "sam4s_nand.h"
 
 /****************************************************************************
