@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_SRC_SAM34_SAM_ETHERNET_H
-#define __ARCH_ARM_SRC_SAM34_SAM_ETHERNET_H
+#ifndef __ARCH_ARM_SRC_SAM34_SAM_EMAC_H
+#define __ARCH_ARM_SRC_SAM34_SAM_EMAC_H
 
 /****************************************************************************
  * Included Files
@@ -106,4 +106,4 @@ int sam_phy_boardinitialize(int intf);
 
 #endif /* __ASSEMBLY__ */
 #endif /* CONFIG_SAM34_EMAC */
-#endif /* __ARCH_ARM_SRC_SAM34_SAM_ETHERNET_H */
+#endif /* __ARCH_ARM_SRC_SAM34_SAM_EMAC_H */
