@@ -45,9 +45,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
 #include "arm_internal.h"
-
 #include "chip.h"
 #include "hardware/sam_uart.h"
 #include "sam_config.h"
@@ -1074,13 +1072,13 @@ static int up_setup(struct uart_dev_s *dev)
            && priv->usartbase != SAM_UART1_VBASE
 #endif
 #if defined(CONFIG_SAMA5_UART2)
-#  warning REVIST
+#  warning REVISIT
 #endif
 #if defined(CONFIG_SAMA5_UART3)
-#  warning REVIST
+#  warning REVISIT
 #endif
 #if defined(CONFIG_SAMA5_UART4)
-#  warning REVIST
+#  warning REVISIT
 #endif
           )
     {
