@@ -36,9 +36,7 @@
 #include <nuttx/drivers/drivers.h>
 #include <nuttx/semaphore.h>
 
-#include "arm_arch.h"
 #include "arm_internal.h"
-
 #include "sam_periphclks.h"
 #include "sam_trng.h"
 
@@ -86,6 +84,9 @@ static const struct file_operations g_trngops =
   NULL,            /* seek */
   NULL,            /* ioctl */
   NULL             /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL           /* unlink */
+#endif
 };
 
 /****************************************************************************
@@ -400,7 +401,7 @@ void devrandom_register(void)
   ret = sam_rng_initialize();
   if (ret >= 0)
     {
-      ret = register_driver("/dev/random", &g_trngops, 0644, NULL);
+      ret = register_driver("/dev/random", &g_trngops, 0444, NULL);
       if (ret < 0)
         {
           ferr("ERROR: Failed to register /dev/random\n");
@@ -433,7 +434,7 @@ void devurandom_register(void)
   if (ret >= 0)
 #endif
     {
-      ret = register_driver("/dev/urandom", &g_trngops, 0644, NULL);
+      ret = register_driver("/dev/urandom", &g_trngops, 0444, NULL);
       if (ret < 0)
         {
           ferr("ERROR: Failed to register /dev/urandom\n");
