@@ -40,8 +40,7 @@
 #include <stdbool.h>
 #include <assert.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/samd_pm.h"
 #include "hardware/samd_sysctrl.h"
 #include "hardware/samd_gclk.h"
