@@ -30,7 +30,7 @@
 
 #include <nuttx/irq.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "hardware/sam_pm.h"
 #include "sam_config.h"
 #include "sam_gclk.h"
