@@ -74,7 +74,7 @@
 #include <assert.h>
 #include <errno.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 
 #include <nuttx/arch.h>
 
