@@ -43,7 +43,6 @@
 #include <nuttx/spi/qspi.h>
 
 #include "arm_internal.h"
-#include "arm_arch.h"
 #include "barriers.h"
 
 #include "sam_gpio.h"
@@ -55,7 +54,7 @@
 #include "hardware/sam_qspi.h"
 #include "hardware/sam_pinmap.h"
 
-#ifdef CONFIG_SAMV7_QSPI
+#if defined(CONFIG_SAMV7_QSPI) && !defined(CONFIG_SAMV7_QSPI_SPI_MODE)
 
 /****************************************************************************
  * Pre-processor Definitions
