@@ -37,8 +37,7 @@
 #include <nuttx/semaphore.h>
 #include <nuttx/spi/slave.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "sam_config.h"
 #include "sam_gpio.h"
 #include "sam_periphclks.h"
