@@ -51,6 +51,9 @@
 #define TC_CHAN6     6  /* TC2 */
 #define TC_CHAN7     7
 #define TC_CHAN8     8
+#define TC_CHAN9     9  /* TC3 */
+#define TC_CHAN10    10
+#define TC_CHAN11    11
 
 /* Register identifier used with sam_tc_setregister */
 
@@ -186,7 +189,7 @@ void sam_tc_stop(TC_HANDLE handle);
  *   arg     An opaque argument that will be provided when the interrupt
  *           handler callback is executed.  Ignored if handler is NULL.
  *   mask    The value of the timer interrupt mask register that defines
- *           which interrupts should be disabled.  Ignored if handler is
+ *           which interrupts should be enabled.  Ignored if handler is
  *           NULL.
  *
  * Returned Value:
@@ -203,7 +206,7 @@ tc_handler_t sam_tc_attach(TC_HANDLE handle, tc_handler_t handler,
  * Name: sam_tc_getpending
  *
  * Description:
- *   Return the current contents of the interrutp status register, clearing
+ *   Return the current contents of the interrupt status register, clearing
  *   all pending interrupts.
  *
  * Input Parameters:
@@ -232,7 +235,7 @@ uint32_t sam_tc_getpending(TC_HANDLE handle);
  *
  ****************************************************************************/
 
-void sam_tc_setregister(TC_HANDLE handle, int regid, uint32_t regval);
+void sam_tc_setregister(TC_HANDLE handle, int regid, uint16_t regval);
 
 /****************************************************************************
  * Name: sam_tc_getregister
@@ -249,7 +252,7 @@ void sam_tc_setregister(TC_HANDLE handle, int regid, uint32_t regval);
  *
  ****************************************************************************/
 
-uint32_t sam_tc_getregister(TC_HANDLE handle, int regid);
+uint16_t sam_tc_getregister(TC_HANDLE handle, int regid);
 
 /****************************************************************************
  * Name: sam_tc_getcounter
@@ -265,24 +268,24 @@ uint32_t sam_tc_getregister(TC_HANDLE handle, int regid);
  *
  ****************************************************************************/
 
-uint32_t sam_tc_getcounter(TC_HANDLE handle);
+uint16_t sam_tc_getcounter(TC_HANDLE handle);
 
 /****************************************************************************
- * Name: sam_tc_infreq
+ * Name: sam_tc_setblockmode
  *
  * Description:
- *   Return the timer input frequency, that is, the MCK frequency divided
- *   down so that the timer/counter is driven within its maximum frequency.
+ *   Set the value of TC_BMR register
  *
  * Input Parameters:
- *   None
+ *   handle Channel handle previously allocated by sam_tc_allocate()
+ *   regval Then value to set in the register
  *
  * Returned Value:
- *  The timer input frequency.
+ *   None
  *
  ****************************************************************************/
 
-uint32_t sam_tc_infreq(void);
+void sam_tc_setblockmode(TC_HANDLE handle, uint32_t regval);
 
 /****************************************************************************
  * Name: sam_tc_divfreq
