@@ -66,8 +66,7 @@
 #include <nuttx/irq.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "hardware/sam_pmc.h"
 #include "hardware/sam_pinmap.h"
 
