@@ -35,7 +35,7 @@
 
 /* Configuration ************************************************************/
 
-/* This is implementation for STM32 ADC IPv2 - F0, F3 (without F37x), G4,
+/* This is implementation for STM32 ADC IPv2 - F0, F3 (without F37x),
  * H7, L0, L4, L4+
  */
 
@@ -363,71 +363,6 @@
 #  define ADC34_CFGR1_EXTSEL_T7TRGO    (13 << ADC_CFGR1_EXTSEL_SHIFT)
 #  define ADC34_CFGR1_EXTSEL_T15TRGO   (14 << ADC_CFGR1_EXTSEL_SHIFT)
 #  define ADC34_CFGR1_EXTSEL_T2CC1     (15 << ADC_CFGR1_EXTSEL_SHIFT)
-#elif defined(CONFIG_STM32_STM32G4XXX)
-#  define ADC12_CFGR1_EXTSEL_T1CC1     (0 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T1CC2     (1 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T1CC3     (2 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T2CC2     (3 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T3TRGO    (4 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T4CC4     (5 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_EXTI11    (6 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T8TRGO    (7 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T8TRGO2   (8 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T1TRGO    (9 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T1TRGO2   (10 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T2TRGO    (11 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T4TRGO    (12 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T6TRGO    (13 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T15TRGO   (14 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T3CC4     (15 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T20TRGO   (16 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T20TRGO2  (17 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T20CC1    (18 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T20CC2    (19 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T20CC3    (20 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG1  (21 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG3  (22 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG5  (23 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG6  (24 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG7  (25 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG8  (26 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG9  (27 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_HRT1TRG10 (28 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_LPTIMOUT  (29 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_T7TRGO    (30 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC12_CFGR1_EXTSEL_RSVD1     (31 << ADC_CFGR1_EXTSEL_SHIFT) /* 11111: Reserved */
-#  define ADC34_CFGR1_EXTSEL_T3CC1     (0 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T2CC3     (1 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T1CC3     (2 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T8CC1     (3 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T3TRGO    (4 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_EXTI2     (5 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T4CC1     (6 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T8TRGO    (7 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T8TRGO2   (8 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T1TRGO    (9 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T1TRGO2   (10 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T2TRGO    (11 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T4TRGO    (12 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T6TRGO    (13 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T15TRGO   (14 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T2CC1     (15 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T20TRGO   (16 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T20TRGO2  (17 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T20CC1    (18 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG2  (19 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG4  (20 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG1  (21 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG3  (22 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG5  (23 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG6  (24 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG7  (25 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG8  (26 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG9  (27 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_HRT1TRG10 (28 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_LPTIMOUT  (29 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_T7TRGO    (30 << ADC_CFGR1_EXTSEL_SHIFT)
-#  define ADC34_CFGR1_EXTSEL_RSVD1     (31 << ADC_CFGR1_EXTSEL_SHIFT) /* 11111: Reserved */
 #else
 #  error TODO EXTSEL
 #endif
@@ -654,72 +589,6 @@
 #  define ADC34_JSQR_JEXTSEL_T2TRGO    (13 << ADC_JSQR_JEXTSEL_SHIFT)
 #  define ADC34_JSQR_JEXTSEL_T7TRGO    (14 << ADC_JSQR_JEXTSEL_SHIFT)
 #  define ADC34_JSQR_JEXTSEL_T15TRGO   (15 << ADC_JSQR_JEXTSEL_SHIFT)
-#elif defined(CONFIG_STM32_STM32G4XXX)
-#  define ADC12_JSQR_JEXTSEL_T1TRGO    (0 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T1CC4     (1 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T2TRGO    (2 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T2CC1     (3 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T3CC4     (4 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T4TRGO    (5 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_EXTI15    (6 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T8CC4     (7 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T1TRGO2   (8 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T8TRGO    (9 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T8TRGO2   (10 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T3CC3     (11 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T3TRGO    (12 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T3CC1     (13 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T6TRGO    (14 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T15TRGO   (15 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T20TRGO   (16 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T20TRGO2  (17 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T20CC4    (18 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG2  (19 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG4  (20 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG5  (21 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG6  (22 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG7  (23 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG8  (24 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG9  (25 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_HRT1TRG10 (26 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T16CC1    (27 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_RSVD1     (28 << ADC_JSQR_JEXTSEL_SHIFT) /* 11100: Reserved */
-#  define ADC12_JSQR_JEXTSEL_LPTIMOUT  (29 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_T7TRGO    (30 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC12_JSQR_JEXTSEL_RSVD2     (31 << ADC_JSQR_JEXTSEL_SHIFT) /* 11111: Reserved */
-
-#  define ADC34_JSQR_JEXTSEL_T1TRGO    (0 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T1CC4     (1 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T2TRGO    (2 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T8CC2     (3 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T4CC3     (4 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T4TRGO    (5 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T4CC4     (6 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T8CC4     (7 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T1TRGO2   (8 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T8TRGO    (9 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T8TRGO2   (10 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T1CC3     (11 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T3TRGO    (12 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_EXTI3     (13 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T6TRGO    (14 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T15TRGO   (15 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T20TRGO   (16 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T20TRGO2  (17 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T20CC2    (18 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG2  (19 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG4  (20 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG5  (21 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG6  (22 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG7  (23 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG8  (24 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG9  (25 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG10 (26 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG1  (27 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_HRT1TRG3  (28 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_LPTIMOUT  (29 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_T7TRGO    (30 << ADC_JSQR_JEXTSEL_SHIFT)
-#  define ADC34_JSQR_JEXTSEL_RSVD1     (31 << ADC_JSQR_JEXTSEL_SHIFT) /* 11111: Reserved */
 #else
 #  error TODO JEXTSEL
 #endif
