@@ -48,9 +48,6 @@
 #  undef CONFIG_STM32_CAN1
 #endif
 
-#if defined(CONFIG_CAN) && \
-    (defined(CONFIG_STM32_CAN1) || defined(CONFIG_STM32_CAN2))
-
 /* CAN BAUD */
 
 #if defined(CONFIG_STM32_CAN1) && !defined(CONFIG_STM32_CAN1_BAUD)
@@ -107,11 +104,13 @@ extern "C"
  * Public Function Prototypes
  ****************************************************************************/
 
+#ifdef CONFIG_STM32_CAN_CHARDRIVER
+
 /****************************************************************************
  * Name: stm32_caninitialize
  *
  * Description:
- *   Initialize the selected CAN port
+ *   Initialize the selected CAN port as character device
  *
  * Input Parameters:
  *   Port number (for hardware that has multiple CAN interfaces)
@@ -123,6 +122,26 @@ extern "C"
 
 struct can_dev_s;
 FAR struct can_dev_s *stm32_caninitialize(int port);
+#endif
+
+#ifdef CONFIG_STM32_CAN_SOCKET
+
+/****************************************************************************
+ * Name: stm32_cansockinitialize
+ *
+ * Description:
+ *   Initialize the selected CAN port as SocketCAN interface
+ *
+ * Input Parameters:
+ *   Port number (for hardware that has multiple CAN interfaces)
+ *
+ * Returned Value:
+ *   OK on success; Negated errno on failure.
+ *
+ ****************************************************************************/
+
+int stm32_cansockinitialize(int port);
+#endif
 
 #undef EXTERN
 #if defined(__cplusplus)
@@ -130,5 +149,4 @@ FAR struct can_dev_s *stm32_caninitialize(int port);
 #endif
 
 #endif /* __ASSEMBLY__ */
-#endif /* CONFIG_CAN && (CONFIG_STM32_CAN1 || CONFIG_STM32_CAN2) */
 #endif /* __ARCH_ARM_SRC_STM32_STM32_CAN_H */
