@@ -68,8 +68,6 @@
 #include <arch/board/board.h>
 
 #include "arm_internal.h"
-#include "arm_arch.h"
-
 #include "stm32_dma.h"
 #include "stm32_spi.h"
 #include "stm32_rcc.h"
@@ -1946,7 +1944,7 @@ errout_with_buf:
 #endif
 }
 
-static int roundf(float num)
+static int stm32_i2s_roundf(float num)
 {
   if (((int)(num + 0.5f)) > num)
     {
@@ -2209,8 +2207,8 @@ static uint32_t i2s_mckdivider(struct stm32_i2s_s *priv)
             {
               for (n = 2; n <= 256; ++n)
                 {
-                  napprox = roundf(priv->samplerate / 1000000.0f *
-                                   (8 * 32 * R * (2 * n + od)));
+                  napprox = stm32_i2s_roundf(priv->samplerate / 1000000.0f *
+                                             (8 * 32 * R * (2 * n + od)));
                   if ((napprox > 432) || (napprox < 50))
                     {
                       continue;
@@ -2625,6 +2623,7 @@ FAR struct i2s_dev_s *stm32_i2sbus_initialize(int port)
 #endif
     {
       i2serr("ERROR: Unsupported I2S port: %d\n", port);
+      leave_critical_section(flags);
       return NULL;
     }
 
@@ -2646,6 +2645,7 @@ FAR struct i2s_dev_s *stm32_i2sbus_initialize(int port)
   /* Failure exits */
 
 errout_with_alloc:
+  leave_critical_section(flags);
   nxsem_destroy(&priv->exclsem);
   kmm_free(priv);
   return NULL;
