@@ -30,9 +30,9 @@
 
 #include <nuttx/init.h>
 
-#include "arm_arch.h"
 #include "arm_internal.h"
 #include "nvic.h"
+#include "mpu.h"
 
 #include "stm32.h"
 #include "stm32_gpio.h"
@@ -217,6 +217,10 @@ void __start(void)
                    "r"(CONFIG_IDLETHREAD_STACKSIZE - 64) :);
 #endif
 
+  /* If enabled reset the MPU */
+
+  mpu_early_reset();
+
   /* Configure the UART so that we can get debug output as soon as possible */
 
   stm32_clockconfig();
