@@ -48,10 +48,10 @@
 
 /* DMAP for DMA1 */
 
-#define DMAMAP_DMA1_REGGEN0     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN0)
-#define DMAMAP_DMA1_REGGEN1     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN1)
-#define DMAMAP_DMA1_REGGEN2     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN2)
-#define DMAMAP_DMA1_REGGEN3     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN3)
+#define DMAMAP_DMA1_REQGEN0     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN0)
+#define DMAMAP_DMA1_REQGEN1     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN1)
+#define DMAMAP_DMA1_REQGEN2     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN2)
+#define DMAMAP_DMA1_REQGEN3     DMAMAP_MAP(DMA1, DMAMUX1_REQ_GEN3)
 #define DMAMAP_DMA1_ADC1        DMAMAP_MAP(DMA1, DMAMUX1_ADC1)
 
 /* TODO: ... */
