@@ -43,7 +43,6 @@
 #  include <termios.h>
 #endif
 
-#include "arm_arch.h"
 #include "arm_internal.h"
 #include "chip.h"
 #include "stm32_gpio.h"
@@ -2216,6 +2215,7 @@ static void stm32serial_txint(FAR struct uart_dev_s *dev, bool enable)
 #  ifdef CONFIG_STM32F0L0G0_SERIALBRK_BSDCOMPAT
       if (priv->ie & USART_CR1_IE_BREAK_INPROGRESS)
         {
+          leave_critical_section(flags);
           return;
         }
 #  endif
