@@ -32,9 +32,9 @@
 #include <nuttx/init.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
 #include "arm_internal.h"
 #include "nvic.h"
+#include "mpu.h"
 #include "barriers.h"
 
 #include "stm32_rcc.h"
@@ -261,6 +261,10 @@ void __start(void)
                    "r"(CONFIG_IDLETHREAD_STACKSIZE - 64) :);
 #endif
 
+  /* If enabled reset the MPU */
+
+  mpu_early_reset();
+
   /* Clear .bss.  We'll do this inline (vs. calling memset) just to be
    * certain that there are no issues with the state of global variables.
    */
