@@ -40,7 +40,7 @@
  * Public Data
  ****************************************************************************/
 
-struct mm_heap_s g_dtcm_heap;
+FAR struct mm_heap_s *g_dtcm_heap;
 
 /****************************************************************************
  * Private Functions
