@@ -33,8 +33,7 @@
 #include <nuttx/arch.h>
 #include <nuttx/timers/rtc.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "chip.h"
 #include "stm32_rtc.h"
 
