@@ -32,10 +32,10 @@
 #include <nuttx/init.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
 #include "arm_internal.h"
 #include "barriers.h"
 #include "nvic.h"
+#include "mpu.h"
 
 #include "stm32_rcc.h"
 #include "stm32_userspace.h"
@@ -276,7 +276,11 @@ void __start(void)
                    "r"(CONFIG_IDLETHREAD_STACKSIZE - 64) :);
 #endif
 
-  /* Clear .bss.  We'll do this inline (vs. calling memset) just to be
+  /* If enabled reset the MPU */
+
+  mpu_early_reset();
+
+/* Clear .bss.  We'll do this inline (vs. calling memset) just to be
    * certain that there are no issues with the state of global variables.
    */
 
