@@ -33,7 +33,7 @@
 
 #include <arch/irq.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "stm32l4_gpio.h"
 #include "stm32l4_exti.h"
