@@ -28,7 +28,7 @@
 
 #include <nuttx/arch.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "hardware/stm32l4_syscfg.h"
 
 #include "stm32l4_firewall.h"
