@@ -281,8 +281,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "stm32l4_gpio.h"
 #include "stm32l4_rcc.h"
 #include "stm32l4_i2c.h"
