@@ -35,7 +35,7 @@
 #include <nuttx/timers/watchdog.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "stm32l4_rcc.h"
 #include "stm32l4_dbgmcu.h"
 #include "stm32l4_wdg.h"
