@@ -37,8 +37,6 @@
 
 #include "chip.h"
 #include "arm_internal.h"
-#include "arm_arch.h"
-
 #include "stm32l4.h"
 #include "stm32l4_gpio.h"
 #include "stm32l4_tim.h"
@@ -247,8 +245,8 @@ static int stm32l4_shutdown(FAR struct qe_lowerhalf_s *lower);
 static int stm32l4_position(FAR struct qe_lowerhalf_s *lower,
                             FAR int32_t *pos);
 static int stm32l4_reset(FAR struct qe_lowerhalf_s *lower);
-static int stm32l4_ioctl(FAR struct qe_lowerhalf_s *lower,
-                         int cmd, unsigned long arg);
+static int stm32l4_ioctl(FAR struct qe_lowerhalf_s *lower, int cmd,
+                         unsigned long arg);
 
 /****************************************************************************
  * Private Data
@@ -263,6 +261,7 @@ static const struct qe_ops_s g_qecallbacks =
   .position  = stm32l4_position,
   .setposmax = NULL,            /* not supported yet */
   .reset     = stm32l4_reset,
+  .setindex  = NULL,            /* not supported yet */
   .ioctl     = stm32l4_ioctl,
 };
 
@@ -976,6 +975,7 @@ static int stm32l4_shutdown(FAR struct qe_lowerhalf_s *lower)
         break;
 #endif
       default:
+        leave_critical_section(flags);
         return -EINVAL;
     }
 
