@@ -38,8 +38,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "stm32l4_rcc.h"
 #include "stm32l4_pwr.h"
 #include "stm32l4_exti.h"
