@@ -156,7 +156,7 @@ struct stm32l4_sai_s
   uint32_t samplerate;         /* Data sample rate */
   uint8_t rxenab:1;            /* True: RX transfers enabled */
   uint8_t txenab:1;            /* True: TX transfers enabled */
-  WDOG_ID dog;                 /* Watchdog that handles timeouts */
+  struct wdog_s dog;           /* Watchdog that handles timeouts */
   sq_queue_t pend;             /* A queue of pending transfers */
   sq_queue_t act;              /* A queue of active transfers */
   sq_queue_t done;             /* A queue of completed transfers */
@@ -501,8 +501,7 @@ static void sai_mckdivider(struct stm32l4_sai_s *priv)
  *   The watchdog timeout without completion of the transfer.
  *
  * Input Parameters:
- *   argc   - The number of arguments (should be 1)
- *   arg    - The argument (state structure reference cast to uint32_t)
+ *   arg    - The argument
  *
  * Returned Value:
  *   None
@@ -512,7 +511,7 @@ static void sai_mckdivider(struct stm32l4_sai_s *priv)
  *
  ****************************************************************************/
 
-static void sai_timeout(int argc, uint32_t arg, ...)
+static void sai_timeout(wdparm_t arg)
 {
   struct stm32l4_sai_s *priv = (struct stm32l4_sai_s *)arg;
   DEBUGASSERT(priv != NULL);
@@ -657,8 +656,8 @@ static int sai_dma_setup(struct stm32l4_sai_s *priv)
 
   if (bfcontainer->timeout > 0)
     {
-      ret = wd_start(priv->dog, bfcontainer->timeout, sai_timeout,
-                     1, (uint32_t)priv);
+      ret = wd_start(&priv->dog, bfcontainer->timeout,
+                     sai_timeout, (wdparm_t)priv);
 
       /* Check if we have successfully started the watchdog timer.  Note
        * that we do nothing in the case of failure to start the timer.  We
@@ -839,7 +838,7 @@ static void sai_dma_callback(DMA_HANDLE handle, uint8_t isr, void *arg)
 
   /* Cancel the watchdog timeout */
 
-  wd_cancel(priv->dog);
+  wd_cancel(&priv->dog);
 
   /* Then schedule completion of the transfer to occur on the worker thread */
 
@@ -1296,11 +1295,6 @@ static void sai_portinitialize(struct stm32l4_sai_s *priv)
 
   nxsem_init(&priv->exclsem, 0, 1);
 
-  /* Create a watchdog timer to catch transfer timeouts */
-
-  priv->dog = wd_create();
-  DEBUGASSERT(priv->dog);
-
   /* Initialize buffering */
 
   sai_buf_initialize(priv);
