@@ -53,7 +53,6 @@
 #  include "stm32l5_dma.h"
 #endif
 #include "stm32l5_rcc.h"
-#include "arm_arch.h"
 #include "arm_internal.h"
 
 /****************************************************************************
@@ -2741,6 +2740,7 @@ static void stm32l5serial_txint(FAR struct uart_dev_s *dev, bool enable)
 #  ifdef CONFIG_STM32L5_SERIALBRK_BSDCOMPAT
       if (priv->ie & USART_CR1_IE_BREAK_INPROGRESS)
         {
+          leave_critical_section(flags);
           return;
         }
 #  endif
