@@ -32,7 +32,7 @@
 
 #include <arch/tiva/chip.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "hardware/tiva_timer.h"
 
