@@ -55,7 +55,7 @@
 
 #include <nuttx/config.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "hardware/xmc4_scu.h"
 #include "xmc4_clockconfig.h"
 #include "hardware/xmc4_ports.h"
