@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_AVR_SRC_ATMEGA_ATMEGA_CONFIG_H
-#define __ARCH_AVR_SRC_ATMEGA_ATMEGA_CONFIG_H
+#ifndef __ARCH_AVR_SRC_AT90USB_AT90USB_CONFIG_H
+#define __ARCH_AVR_SRC_AT90USB_AT90USB_CONFIG_H
 
 /****************************************************************************
  * Included Files
@@ -92,4 +92,4 @@
  * Public Functions Prototypes
  ****************************************************************************/
 
-#endif /* __ARCH_AVR_SRC_ATMEGA_ATMEGA_CONFIG_H */
+#endif /* __ARCH_AVR_SRC_AT90USB_AT90USB_CONFIG_H */
