@@ -18,8 +18,8 @@
  *
  ************************************************************************************/
 
-#ifndef __ARCH_AVR_SRC_ATMEGA_ATMEGA_MEMORYMAP_H
-#define __ARCH_AVR_SRC_ATMEGA_ATMEGA_MEMORYMAP_H
+#ifndef __ARCH_AVR_SRC_AT90USB_AT90USB_MEMORYMAP_H
+#define __ARCH_AVR_SRC_AT90USB_AT90USB_MEMORYMAP_H
 
 /************************************************************************************
  * Included Files
@@ -43,4 +43,4 @@
  * Public Functions Prototypes
  ************************************************************************************/
 
-#endif /* __ARCH_AVR_SRC_ATMEGA_ATMEGA_MEMORYMAP_H */
+#endif /* __ARCH_AVR_SRC_AT90USB_AT90USB_MEMORYMAP_H */
