@@ -74,6 +74,12 @@ typedef unsigned long long _uint64_t;
 typedef _int64_t           _intmax_t;
 typedef _uint64_t          _uintmax_t;
 
+#if defined(__WCHAR_TYPE__)
+typedef __WCHAR_TYPE__     _wchar_t;
+#else
+typedef int                _wchar_t;
+#endif
+
 /* A size is two bytes */
 
 #if defined(__SIZE_TYPE__)
