@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_HC_SRC_M9S12_M9S12_ATD_H
-#define __ARCH_ARM_HC_SRC_M9S12_M9S12_ATD_H
+#ifndef __ARCH_HC_SRC_M9S12_M9S12_ATD_H
+#define __ARCH_HC_SRC_M9S12_M9S12_ATD_H
 
 /****************************************************************************
  * Included Files
@@ -310,4 +310,4 @@
  * Public Functions Prototypes
  ****************************************************************************/
 
-#endif /* __ARCH_ARM_HC_SRC_M9S12_M9S12_ATD_H */
+#endif /* __ARCH_HC_SRC_M9S12_M9S12_ATD_H */
