@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_ARM_HC_SRC_M9S12_M9S12_FLASH_H
-#define __ARCH_ARM_HC_SRC_M9S12_M9S12_FLASH_H
+#ifndef __ARCH_HC_SRC_M9S12_M9S12_FLASH_H
+#define __ARCH_HC_SRC_M9S12_M9S12_FLASH_H
 
 /****************************************************************************
  * Included Files
@@ -91,7 +91,7 @@
 
 /* Interrupts */
 
-#  define HCS12_UVECTOR_BASE 0xf780 /* 0xf7800xf7fe: User vector base */
+#  define HCS12_UVECTOR_BASE 0xf780 /* 0xf780-0xf7fe: User vector base */
 #endif
 
 /* FLASH interface */
@@ -104,7 +104,7 @@
 
 /* Interrupts */
 
-#define HCS12_VECTOR_BASE  0xff80 /* 0xff800xfffe: Actual vector base */
+#define HCS12_VECTOR_BASE  0xff80 /* 0xff80-0xfffe: Actual vector base */
 
 /* Register Offsets *********************************************************/
 
@@ -191,4 +191,4 @@
  * Public Functions Prototypes
  ****************************************************************************/
 
-#endif /* __ARCH_ARM_HC_SRC_M9S12_M9S12_FLASH_H */
+#endif /* __ARCH_HC_SRC_M9S12_M9S12_FLASH_H */
