@@ -32,7 +32,7 @@
 #include <nuttx/irq.h>
 #include <nuttx/arch.h>
 
-#include "up_arch.h"
+#include "up_internal.h"
 #include "m9s12.h"
 #include "m9s12_pim.h"
 #include "m9s12_mebi.h"
