@@ -34,8 +34,7 @@
 #include <nuttx/board.h>
 #include <arch/board/board.h>
 
-#include "mips_arch.h"
-
+#include "mips_internal.h"
 #include "pic32mx_int.h"
 #include "pic32mx.h"
 
