@@ -35,8 +35,7 @@
 #include <arch/board/board.h>
 #include <arch/pic32mx/cp0.h>
 
-#include "mips_arch.h"
-
+#include "mips_internal.h"
 #include "pic32mx_int.h"
 #include "pic32mx.h"
 
