@@ -31,7 +31,7 @@
 #include <nuttx/arch.h>
 #include <arch/board/board.h>
 
-#include "mips_arch.h"
+#include "mips_internal.h"
 #include "pic32mx_gpio.h"
 #include "pic32mx.h"
 
