@@ -26,11 +26,10 @@
 
 #include <assert.h>
 
+#include <nuttx/arch.h>
 #include <arch/pic32mx/cp0.h>
 
 #include "mips_internal.h"
-#include "mips_arch.h"
-
 #include "chip.h"
 #include "pic32mx.h"
 #include "pic32mx_bmx.h"
