@@ -26,12 +26,11 @@
 
 #include <assert.h>
 
+#include <nuttx/arch.h>
 #include <arch/pic32mz/cp0.h>
 #include <arch/board/board.h>
 
 #include "mips_internal.h"
-#include "mips_arch.h"
-
 #include "hardware/pic32mz_features.h"
 #include "hardware/pic32mz_prefetch.h"
 #include "hardware/pic32mz_osc.h"
