@@ -38,26 +38,6 @@
 
 #include "minerva.h"
 
-/****************************************************************************
- * Pre-processor Macros
- ****************************************************************************/
-
-/* MINERVA requires at least a 4-byte stack alignment.  For floating point
- * use, however, the stack must be aligned to 8-byte addresses.
- */
-
-#ifdef CONFIG_LIBC_FLOATINGPOINT
-#  define STACK_ALIGNMENT   8
-#else
-#  define STACK_ALIGNMENT   4
-#endif
-
-/* Stack alignment macros */
-
-#define STACK_ALIGN_MASK    (STACK_ALIGNMENT-1)
-#define STACK_ALIGN_DOWN(a) ((a) & ~STACK_ALIGN_MASK)
-#define STACK_ALIGN_UP(a)   (((a) + STACK_ALIGN_MASK) & ~STACK_ALIGN_MASK)
-
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
