@@ -29,8 +29,8 @@
 
 #include <nuttx/arch.h>
 #include <nuttx/board.h>
+#include <arch/board/board.h>
 
-#include "up_arch.h"
 #include "up_internal.h"
 
 /****************************************************************************
