@@ -36,10 +36,7 @@
 #include <nuttx/semaphore.h>
 
 #include "up_internal.h"
-#include "up_arch.h"
-
 #include "chip.h"
-#include "up_arch.h"
 #include "rx65n_definitions.h"
 #include "rx65n_dtc.h"
 
@@ -1326,6 +1323,7 @@ dtc_err_t rx65n_dtc_setup_seq_dynamic_transferdata(DTC_HANDLE handle,
   ret = rx65n_dtc_validate_dynamic_params(p_dtransfer_cfg, p_transfer_data);
   if (DTC_SUCCESS != ret)
     {
+      leave_critical_section(flags);
       return ret;
     }
 
@@ -1345,12 +1343,13 @@ dtc_err_t rx65n_dtc_setup_seq_dynamic_transferdata(DTC_HANDLE handle,
           if (rx65n_dtc_set_dynamic_transfer_data(p_dtransfer_cfg,
                                   p_transfer_data) != DTC_SUCCESS)
             {
+              leave_critical_section(flags);
               return DTC_ERR_INVALID_ARG;
             }
 
           p_dtransfer_cfg++;
           p_transfer_data++;
-          count --;
+          count--;
         }
     }
 
@@ -1536,6 +1535,7 @@ dtc_err_t rx65n_dtc_setup_dynamic_transferdata(DTC_HANDLE handle,
   ret = rx65n_dtc_validate_dynamic_params(p_dtransfer_cfg, p_transfer_data);
   if (DTC_SUCCESS != ret)
     {
+      leave_critical_section(flags);
       return ret;
     }
 
@@ -1546,12 +1546,13 @@ dtc_err_t rx65n_dtc_setup_dynamic_transferdata(DTC_HANDLE handle,
       if (rx65n_dtc_set_dynamic_transfer_data(p_dtransfer_cfg,
                                   p_transfer_data) != DTC_SUCCESS)
         {
+          leave_critical_section(flags);
           return DTC_ERR_INVALID_ARG;
         }
 
       p_dtransfer_cfg++;
       p_transfer_data++;
-      count --;
+      count--;
     }
 
   /* Restore RRS bit */
