@@ -55,68 +55,68 @@
 
 /* User Counter/Times Registers */
 
-#define CSR_CYCLE           0xC00
-#define CSR_TIME            0xC01
-#define CSR_INSTRET         0xC02
-#define CSR_HPCOUNTER3      0xC03
-#define CSR_HPCOUNTER4      0xC04
-#define CSR_HPCOUNTER5      0xC05
-#define CSR_HPCOUNTER6      0xC06
-#define CSR_HPCOUNTER7      0xC07
-#define CSR_HPCOUNTER8      0xC08
-#define CSR_HPCOUNTER9      0xC09
-#define CSR_HPCOUNTER10     0xC0A
-#define CSR_HPCOUNTER11     0xC0B
-#define CSR_HPCOUNTER12     0xC0C
-#define CSR_HPCOUNTER13     0xC0D
-#define CSR_HPCOUNTER14     0xC0E
-#define CSR_HPCOUNTER15     0xC0F
-#define CSR_HPCOUNTER16     0xC10
-#define CSR_HPCOUNTER17     0xC11
-#define CSR_HPCOUNTER18     0xC12
-#define CSR_HPCOUNTER19     0xC13
-#define CSR_HPCOUNTER20     0xC14
-#define CSR_HPCOUNTER21     0xC15
-#define CSR_HPCOUNTER22     0xC16
-#define CSR_HPCOUNTER24     0xC17
-#define CSR_HPCOUNTER25     0xC18
-#define CSR_HPCOUNTER26     0xC19
-#define CSR_HPCOUNTER27     0xC1A
-#define CSR_HPCOUNTER28     0xC1B
-#define CSR_HPCOUNTER29     0xC1C
-#define CSR_HPCOUNTER30     0xC1D
-#define CSR_HPCOUNTER31     0xC1F
-#define CSR_CYCLEH          0xC80
-#define CSR_TIMEH           0xC81
-#define CSR_INSTRETH        0xC82
-#define CSR_HPCOUNTER3H     0xC83
-#define CSR_HPCOUNTER4H     0xC84
-#define CSR_HPCOUNTER5H     0xC85
-#define CSR_HPCOUNTER6H     0xC86
-#define CSR_HPCOUNTER7H     0xC87
-#define CSR_HPCOUNTER8H     0xC88
-#define CSR_HPCOUNTER9H     0xC89
-#define CSR_HPCOUNTER10H    0xC8A
-#define CSR_HPCOUNTER11H    0xC8B
-#define CSR_HPCOUNTER12H    0xC8C
-#define CSR_HPCOUNTER13H    0xC8D
-#define CSR_HPCOUNTER14H    0xC8E
-#define CSR_HPCOUNTER15H    0xC8F
-#define CSR_HPCOUNTER16H    0xC90
-#define CSR_HPCOUNTER17H    0xC91
-#define CSR_HPCOUNTER18H    0xC92
-#define CSR_HPCOUNTER19H    0xC93
-#define CSR_HPCOUNTER20H    0xC94
-#define CSR_HPCOUNTER21H    0xC95
-#define CSR_HPCOUNTER22H    0xC96
-#define CSR_HPCOUNTER24H    0xC97
-#define CSR_HPCOUNTER25H    0xC98
-#define CSR_HPCOUNTER26H    0xC99
-#define CSR_HPCOUNTER27H    0xC9A
-#define CSR_HPCOUNTER28H    0xC9B
-#define CSR_HPCOUNTER29H    0xC9C
-#define CSR_HPCOUNTER30H    0xC9D
-#define CSR_HPCOUNTER31H    0xC9F
+#define CSR_CYCLE           0xc00
+#define CSR_TIME            0xc01
+#define CSR_INSTRET         0xc02
+#define CSR_HPCOUNTER3      0xc03
+#define CSR_HPCOUNTER4      0xc04
+#define CSR_HPCOUNTER5      0xc05
+#define CSR_HPCOUNTER6      0xc06
+#define CSR_HPCOUNTER7      0xc07
+#define CSR_HPCOUNTER8      0xc08
+#define CSR_HPCOUNTER9      0xc09
+#define CSR_HPCOUNTER10     0xc0a
+#define CSR_HPCOUNTER11     0xc0b
+#define CSR_HPCOUNTER12     0xc0c
+#define CSR_HPCOUNTER13     0xc0d
+#define CSR_HPCOUNTER14     0xc0e
+#define CSR_HPCOUNTER15     0xc0f
+#define CSR_HPCOUNTER16     0xc10
+#define CSR_HPCOUNTER17     0xc11
+#define CSR_HPCOUNTER18     0xc12
+#define CSR_HPCOUNTER19     0xc13
+#define CSR_HPCOUNTER20     0xc14
+#define CSR_HPCOUNTER21     0xc15
+#define CSR_HPCOUNTER22     0xc16
+#define CSR_HPCOUNTER24     0xc17
+#define CSR_HPCOUNTER25     0xc18
+#define CSR_HPCOUNTER26     0xc19
+#define CSR_HPCOUNTER27     0xc1a
+#define CSR_HPCOUNTER28     0xc1b
+#define CSR_HPCOUNTER29     0xc1c
+#define CSR_HPCOUNTER30     0xc1d
+#define CSR_HPCOUNTER31     0xc1f
+#define CSR_CYCLEH          0xc80
+#define CSR_TIMEH           0xc81
+#define CSR_INSTRETH        0xc82
+#define CSR_HPCOUNTER3H     0xc83
+#define CSR_HPCOUNTER4H     0xc84
+#define CSR_HPCOUNTER5H     0xc85
+#define CSR_HPCOUNTER6H     0xc86
+#define CSR_HPCOUNTER7H     0xc87
+#define CSR_HPCOUNTER8H     0xc88
+#define CSR_HPCOUNTER9H     0xc89
+#define CSR_HPCOUNTER10H    0xc8a
+#define CSR_HPCOUNTER11H    0xc8b
+#define CSR_HPCOUNTER12H    0xc8c
+#define CSR_HPCOUNTER13H    0xc8d
+#define CSR_HPCOUNTER14H    0xc8e
+#define CSR_HPCOUNTER15H    0xc8f
+#define CSR_HPCOUNTER16H    0xc90
+#define CSR_HPCOUNTER17H    0xc91
+#define CSR_HPCOUNTER18H    0xc92
+#define CSR_HPCOUNTER19H    0xc93
+#define CSR_HPCOUNTER20H    0xc94
+#define CSR_HPCOUNTER21H    0xc95
+#define CSR_HPCOUNTER22H    0xc96
+#define CSR_HPCOUNTER24H    0xc97
+#define CSR_HPCOUNTER25H    0xc98
+#define CSR_HPCOUNTER26H    0xc99
+#define CSR_HPCOUNTER27H    0xc9a
+#define CSR_HPCOUNTER28H    0xc9b
+#define CSR_HPCOUNTER29H    0xc9c
+#define CSR_HPCOUNTER30H    0xc9d
+#define CSR_HPCOUNTER31H    0xc9f
 
 /* Supervisor Trap Setup Registers */
 
@@ -141,10 +141,10 @@
 
 /* Machine Information Registers */
 
-#define CSR_MVENDORID       0xF11
-#define CSR_MARCHID         0xF12
-#define CSR_MIMPID          0xF13
-#define CSR_MHARTID         0xF14
+#define CSR_MVENDORID       0xf11
+#define CSR_MARCHID         0xf12
+#define CSR_MIMPID          0xf13
+#define CSR_MHARTID         0xf14
 
 /* Machine Trap Registers */
 
@@ -166,91 +166,91 @@
 
 /* Machine Protection and Translation */
 
-#define CSR_PMPCFG0         0x3A0
-#define CSR_PMPCFG1         0x3A1
-#define CSR_PMPCFG2         0x3A2
-#define CSR_PMPCFG3         0x3A3
-#define CSR_PMPADDR0        0x3B0
-#define CSR_PMPADDR1        0x3B1
-#define CSR_PMPADDR2        0x3B2
-#define CSR_PMPADDR3        0x3B3
-#define CSR_PMPADDR4        0x3B4
-#define CSR_PMPADDR5        0x3B5
-#define CSR_PMPADDR6        0x3B6
-#define CSR_PMPADDR7        0x3B7
-#define CSR_PMPADDR8        0x3B8
-#define CSR_PMPADDR9        0x3B9
-#define CSR_PMPADDR10       0x3BA
-#define CSR_PMPADDR11       0x3BB
-#define CSR_PMPADDR12       0x3BC
-#define CSR_PMPADDR13       0x3BD
-#define CSR_PMPADDR14       0x3BE
-#define CSR_PMPADDR15       0x3BF
+#define CSR_PMPCFG0         0x3a0
+#define CSR_PMPCFG1         0x3a1
+#define CSR_PMPCFG2         0x3a2
+#define CSR_PMPCFG3         0x3a3
+#define CSR_PMPADDR0        0x3b0
+#define CSR_PMPADDR1        0x3b1
+#define CSR_PMPADDR2        0x3b2
+#define CSR_PMPADDR3        0x3b3
+#define CSR_PMPADDR4        0x3b4
+#define CSR_PMPADDR5        0x3b5
+#define CSR_PMPADDR6        0x3b6
+#define CSR_PMPADDR7        0x3b7
+#define CSR_PMPADDR8        0x3b8
+#define CSR_PMPADDR9        0x3b9
+#define CSR_PMPADDR10       0x3ba
+#define CSR_PMPADDR11       0x3bb
+#define CSR_PMPADDR12       0x3bc
+#define CSR_PMPADDR13       0x3bd
+#define CSR_PMPADDR14       0x3be
+#define CSR_PMPADDR15       0x3bf
 
 /* Machine Timers and Counters */
 
-#define CSR_MCYCLE          0xB00
-#define CSR_MINSTRET        0xB02
-#define CSR_MHPMCOUNTER3    0xB03
-#define CSR_MHPMCOUNTER4    0xB04
-#define CSR_MHPMCOUNTER5    0xB05
-#define CSR_MHPMCOUNTER6    0xB06
-#define CSR_MHPMCOUNTER7    0xB07
-#define CSR_MHPMCOUNTER8    0xB08
-#define CSR_MHPMCOUNTER9    0xB09
-#define CSR_MHPMCOUNTER10   0xB0A
-#define CSR_MHPMCOUNTER11   0xB0B
-#define CSR_MHPMCOUNTER12   0xB0C
-#define CSR_MHPMCOUNTER13   0xB0D
-#define CSR_MHPMCOUNTER14   0xB0E
-#define CSR_MHPMCOUNTER15   0xB0F
-#define CSR_MHPMCOUNTER16   0xB10
-#define CSR_MHPMCOUNTER17   0xB11
-#define CSR_MHPMCOUNTER18   0xB12
-#define CSR_MHPMCOUNTER19   0xB13
-#define CSR_MHPMCOUNTER20   0xB14
-#define CSR_MHPMCOUNTER21   0xB15
-#define CSR_MHPMCOUNTER22   0xB16
-#define CSR_MHPMCOUNTER23   0xB17
-#define CSR_MHPMCOUNTER24   0xB18
-#define CSR_MHPMCOUNTER25   0xB19
-#define CSR_MHPMCOUNTER26   0xB1A
-#define CSR_MHPMCOUNTER27   0xB1B
-#define CSR_MHPMCOUNTER28   0xB1C
-#define CSR_MHPMCOUNTER29   0xB1D
-#define CSR_MHPMCOUNTER30   0xB1E
-#define CSR_MHPMCOUNTER31   0xB1F
-#define CSR_MCYCLEH         0xB80
-#define CSR_MINSTRETH       0xB82
-#define CSR_MHPMCOUNTER3H   0xB83
-#define CSR_MHPMCOUNTER4H   0xB84
-#define CSR_MHPMCOUNTER5H   0xB85
-#define CSR_MHPMCOUNTER6H   0xB86
-#define CSR_MHPMCOUNTER7H   0xB87
-#define CSR_MHPMCOUNTER8H   0xB88
-#define CSR_MHPMCOUNTER9H   0xB89
-#define CSR_MHPMCOUNTER10H  0xB8A
-#define CSR_MHPMCOUNTER11H  0xB8B
-#define CSR_MHPMCOUNTER12H  0xB8C
-#define CSR_MHPMCOUNTER13H  0xB8D
-#define CSR_MHPMCOUNTER14H  0xB8E
-#define CSR_MHPMCOUNTER15H  0xB8F
-#define CSR_MHPMCOUNTER16H  0xB90
-#define CSR_MHPMCOUNTER17H  0xB91
-#define CSR_MHPMCOUNTER18H  0xB92
-#define CSR_MHPMCOUNTER19H  0xB93
-#define CSR_MHPMCOUNTER20H  0xB94
-#define CSR_MHPMCOUNTER21H  0xB95
-#define CSR_MHPMCOUNTER22H  0xB96
-#define CSR_MHPMCOUNTER23H  0xB97
-#define CSR_MHPMCOUNTER24H  0xB98
-#define CSR_MHPMCOUNTER25H  0xB99
-#define CSR_MHPMCOUNTER26H  0xB9A
-#define CSR_MHPMCOUNTER27H  0xB9B
-#define CSR_MHPMCOUNTER28H  0xB9C
-#define CSR_MHPMCOUNTER29H  0xB9D
-#define CSR_MHPMCOUNTER30H  0xB9E
-#define CSR_MHPMCOUNTER31H  0xB9F
+#define CSR_MCYCLE          0xb00
+#define CSR_MINSTRET        0xb02
+#define CSR_MHPMCOUNTER3    0xb03
+#define CSR_MHPMCOUNTER4    0xb04
+#define CSR_MHPMCOUNTER5    0xb05
+#define CSR_MHPMCOUNTER6    0xb06
+#define CSR_MHPMCOUNTER7    0xb07
+#define CSR_MHPMCOUNTER8    0xb08
+#define CSR_MHPMCOUNTER9    0xb09
+#define CSR_MHPMCOUNTER10   0xb0a
+#define CSR_MHPMCOUNTER11   0xb0b
+#define CSR_MHPMCOUNTER12   0xb0c
+#define CSR_MHPMCOUNTER13   0xb0d
+#define CSR_MHPMCOUNTER14   0xb0e
+#define CSR_MHPMCOUNTER15   0xb0f
+#define CSR_MHPMCOUNTER16   0xb10
+#define CSR_MHPMCOUNTER17   0xb11
+#define CSR_MHPMCOUNTER18   0xb12
+#define CSR_MHPMCOUNTER19   0xb13
+#define CSR_MHPMCOUNTER20   0xb14
+#define CSR_MHPMCOUNTER21   0xb15
+#define CSR_MHPMCOUNTER22   0xb16
+#define CSR_MHPMCOUNTER23   0xb17
+#define CSR_MHPMCOUNTER24   0xb18
+#define CSR_MHPMCOUNTER25   0xb19
+#define CSR_MHPMCOUNTER26   0xb1a
+#define CSR_MHPMCOUNTER27   0xb1b
+#define CSR_MHPMCOUNTER28   0xb1c
+#define CSR_MHPMCOUNTER29   0xb1d
+#define CSR_MHPMCOUNTER30   0xb1e
+#define CSR_MHPMCOUNTER31   0xb1f
+#define CSR_MCYCLEH         0xb80
+#define CSR_MINSTRETH       0xb82
+#define CSR_MHPMCOUNTER3H   0xb83
+#define CSR_MHPMCOUNTER4H   0xb84
+#define CSR_MHPMCOUNTER5H   0xb85
+#define CSR_MHPMCOUNTER6H   0xb86
+#define CSR_MHPMCOUNTER7H   0xb87
+#define CSR_MHPMCOUNTER8H   0xb88
+#define CSR_MHPMCOUNTER9H   0xb89
+#define CSR_MHPMCOUNTER10H  0xb8a
+#define CSR_MHPMCOUNTER11H  0xb8b
+#define CSR_MHPMCOUNTER12H  0xb8c
+#define CSR_MHPMCOUNTER13H  0xb8d
+#define CSR_MHPMCOUNTER14H  0xb8e
+#define CSR_MHPMCOUNTER15H  0xb8f
+#define CSR_MHPMCOUNTER16H  0xb90
+#define CSR_MHPMCOUNTER17H  0xb91
+#define CSR_MHPMCOUNTER18H  0xb92
+#define CSR_MHPMCOUNTER19H  0xb93
+#define CSR_MHPMCOUNTER20H  0xb94
+#define CSR_MHPMCOUNTER21H  0xb95
+#define CSR_MHPMCOUNTER22H  0xb96
+#define CSR_MHPMCOUNTER23H  0xb97
+#define CSR_MHPMCOUNTER24H  0xb98
+#define CSR_MHPMCOUNTER25H  0xb99
+#define CSR_MHPMCOUNTER26H  0xb9a
+#define CSR_MHPMCOUNTER27H  0xb9b
+#define CSR_MHPMCOUNTER28H  0xb9c
+#define CSR_MHPMCOUNTER29H  0xb9d
+#define CSR_MHPMCOUNTER30H  0xb9e
+#define CSR_MHPMCOUNTER31H  0xb9f
 
 /* Machine Counter Setup */
 
@@ -261,12 +261,12 @@
 #define CSR_MPHEVENT7       0x327
 #define CSR_MPHEVENT8       0x328
 #define CSR_MPHEVENT9       0x329
-#define CSR_MPHEVENT10      0x32A
-#define CSR_MPHEVENT11      0x32B
-#define CSR_MPHEVENT12      0x32C
-#define CSR_MPHEVENT13      0x32D
-#define CSR_MPHEVENT14      0x32E
-#define CSR_MPHEVENT15      0x32F
+#define CSR_MPHEVENT10      0x32a
+#define CSR_MPHEVENT11      0x32b
+#define CSR_MPHEVENT12      0x32c
+#define CSR_MPHEVENT13      0x32d
+#define CSR_MPHEVENT14      0x32e
+#define CSR_MPHEVENT15      0x32f
 #define CSR_MPHEVENT16      0x330
 #define CSR_MPHEVENT17      0x331
 #define CSR_MPHEVENT18      0x332
@@ -277,25 +277,25 @@
 #define CSR_MPHEVENT23      0x337
 #define CSR_MPHEVENT24      0x338
 #define CSR_MPHEVENT25      0x339
-#define CSR_MPHEVENT26      0x33A
-#define CSR_MPHEVENT27      0x33B
-#define CSR_MPHEVENT28      0x33C
-#define CSR_MPHEVENT29      0x33D
-#define CSR_MPHEVENT30      0x33E
-#define CSR_MPHEVENT31      0x33F
+#define CSR_MPHEVENT26      0x33a
+#define CSR_MPHEVENT27      0x33b
+#define CSR_MPHEVENT28      0x33c
+#define CSR_MPHEVENT29      0x33d
+#define CSR_MPHEVENT30      0x33e
+#define CSR_MPHEVENT31      0x33f
 
 /* Debug/Trace Registers */
 
-#define CSR_TSELECT         0x7A0
-#define CSR_TDATA1          0x7A1
-#define CSR_TDATA2          0x7A2
-#define CSR_TDATA3          0x7A3
+#define CSR_TSELECT         0x7a0
+#define CSR_TDATA1          0x7a1
+#define CSR_TDATA2          0x7a2
+#define CSR_TDATA3          0x7a3
 
 /* Debug interface CSRs */
 
-#define CSR_DCSR            0x7B0
-#define CSR_DPC             0x7B1
-#define CSR_DSCRATCH        0x7B2
+#define CSR_DCSR            0x7b0
+#define CSR_DPC             0x7b1
+#define CSR_DSCRATCH        0x7b2
 
 /* In mstatus register */
 
@@ -326,6 +326,13 @@
      tmp; \
   })
 
+#define READ_AND_SET_CSR(reg, bits) \
+  ({ \
+     unsigned long tmp; \
+     asm volatile("csrrs %0, " CSR_STR(reg) ", %1": "=r"(tmp) : "rK"(bits)); \
+     tmp; \
+  })
+
 #define WRITE_CSR(reg, val) \
   ({ \
      asm volatile("csrw " CSR_STR(reg) ", %0" :: "rK"(val)); \
@@ -346,6 +353,7 @@
 #define PMPCFG_R        (1 << 0)  /* readable ? */
 #define PMPCFG_W        (1 << 1)  /* writeable ? */
 #define PMPCFG_X        (1 << 2)  /* excutable ? */
+#define PMPCFG_RWX_MASK (7 << 0)  /* access rights mask */
 #define PMPCFG_A_OFF    (0 << 3)  /* null region (disabled) */
 #define PMPCFG_A_TOR    (1 << 3)  /* top of range */
 #define PMPCFG_A_NA4    (2 << 3)  /* naturally aligned four-byte region */
