@@ -529,7 +529,7 @@ static void bl602_net_reply(struct bl602_net_driver_s *priv)
         {
           /* NOTIC: The release path of tx buffer cannot acquire net lock */
 
-          nerr("can not replay due to no tx buffer! \n");
+          nerr("can not replay due to no tx buffer!\n");
           PANIC();
         }
     }
@@ -607,7 +607,7 @@ static void bl602_net_receive(struct bl602_net_driver_s *priv)
 #ifdef CONFIG_NET_ARP
   /* Check for an ARP packet */
 
-  if (BUF->type == htons(ETHTYPE_ARP))
+  if (BUF->type == HTONS(ETHTYPE_ARP))
     {
       /* Dispatch ARP packet to the network layer */
 
@@ -1786,7 +1786,7 @@ bl602_net_ioctl(struct net_driver_s *dev, int cmd, unsigned long arg)
               memcpy(priv->wlan->mac,
                      priv->net_dev.d_mac.ether.ether_addr_octet,
                      6);
-              wlinfo("now in station mode \n");
+              wlinfo("now in station mode\n");
               priv->current_mode = IW_MODE_INFRA;
               return OK;
             }
