@@ -33,9 +33,7 @@
 
 #include <arch/board/board.h>
 
-#include "riscv_arch.h"
 #include "riscv_internal.h"
-
 #include "bl602_gpio.h"
 #include "bl602_pwm_lowerhalf.h"
 #include "hardware/bl602_pwm.h"
@@ -372,9 +370,18 @@ static int bl602_pwm_start(struct pwm_lowerhalf_s *dev,
 #ifdef CONFIG_PWM_NCHANNELS
   for (i = 0; i < CONFIG_PWM_NCHANNELS; i++)
     {
-      bl602_pwm_freq(priv, i, info->frequency);
-      bl602_pwm_duty(priv, i, info->channels[i].duty);
-      pwm_channel_enable(i);
+      int8_t chan = info->channels[i].channel;
+
+      /* Break the loop if all following channels are not configured */
+
+      if (chan == -1)
+        {
+          break;
+        }
+
+      bl602_pwm_freq(priv, chan, info->frequency);
+      bl602_pwm_duty(priv, chan, info->channels[i].duty);
+      pwm_channel_enable(chan);
     }
 #else
   bl602_pwm_freq(priv, 0, info->frequency);
