@@ -43,10 +43,7 @@
 
 #include "hardware/bl602_uart.h"
 #include "hardware/bl602_glb.h"
-
-#include "riscv_arch.h"
 #include "riscv_internal.h"
-
 #include "bl602_config.h"
 #include "chip.h"
 
@@ -452,7 +449,7 @@ static int bl602_ioctl(struct file *filep, int cmd, unsigned long arg)
       do
         {
           struct termios * termiosp = (struct termios *)arg;
-          struct bl602_uart_s *priv     = (struct bl602_uart_s *)dev->priv;
+          struct bl602_uart_s *priv = (struct bl602_uart_s *)dev->priv;
 
           if (!termiosp)
             {
@@ -567,19 +564,19 @@ static int bl602_ioctl(struct file *filep, int cmd, unsigned long arg)
 
           if (priv->config.idx == 0)
             {
-#if CONFIG_UART0_IFLOWCONTROL
+#ifdef CONFIG_UART0_IFLOWCONTROL
               config.iflow_ctl = (termiosp->c_cflag & CRTS_IFLOW) != 0;
 #endif
-#if CONFIG_UART0_OFLOWCONTROL
+#ifdef CONFIG_UART0_OFLOWCONTROL
               config.oflow_ctl = (termiosp->c_cflag & CCTS_OFLOW) != 0;
 #endif
             }
           else
             {
-#if CONFIG_UART1_IFLOWCONTROL
+#ifdef CONFIG_UART1_IFLOWCONTROL
               config.iflow_ctl = (termiosp->c_cflag & CRTS_IFLOW) != 0;
 #endif
-#if CONFIG_UART1_OFLOWCONTROL
+#ifdef CONFIG_UART1_OFLOWCONTROL
               config.oflow_ctl = (termiosp->c_cflag & CCTS_OFLOW) != 0;
 #endif
             }
@@ -662,7 +659,7 @@ static int bl602_receive(struct uart_dev_s *dev, unsigned int *status)
 static void bl602_rxint(struct uart_dev_s *dev, bool enable)
 {
   uint32_t int_mask;
-  struct bl602_uart_s *priv  = (struct bl602_uart_s *)dev->priv;
+  struct bl602_uart_s *priv = (struct bl602_uart_s *)dev->priv;
   uint8_t uart_idx = priv->config.idx;
   irqstate_t       flags = enter_critical_section();
 
