@@ -34,8 +34,7 @@
 #include "esp32c3_clockconfig.h"
 #include "esp32c3_gpio.h"
 #include "esp32c3_ledc.h"
-
-#include "riscv_arch.h"
+#include "riscv_internal.h"
 #include "hardware/esp32c3_ledc.h"
 #include "hardware/esp32c3_system.h"
 #include "hardware/esp32c3_gpio_sigmap.h"
