@@ -32,9 +32,7 @@
 #include <nuttx/board.h>
 #include <arch/board/board.h>
 
-#include "riscv_arch.h"
 #include "riscv_internal.h"
-
 #include "fe310_gpio.h"
 #include "fe310.h"
 
@@ -42,24 +40,24 @@
  * Public Data
  ****************************************************************************/
 
-volatile uint32_t * g_current_regs;
+volatile uintptr_t *g_current_regs[1];
 
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
 /****************************************************************************
- * fe310_dispatch_irq
+ * riscv_dispatch_irq
  ****************************************************************************/
 
-void *fe310_dispatch_irq(uint32_t vector, uint32_t *regs)
+void *riscv_dispatch_irq(uintptr_t vector, uintptr_t *regs)
 {
-  uint32_t  irq = (vector >> 27) | (vector & 0xf);
-  uint32_t *mepc = regs;
+  uintptr_t  irq = (vector >> 27) | (vector & 0xf);
+  uintptr_t *mepc = regs;
 
   /* Firstly, check if the irq is machine external interrupt */
 
-  if (FE310_IRQ_MEXT == irq)
+  if (RISCV_IRQ_MEXT == irq)
     {
       uint32_t val = getreg32(FE310_PLIC_CLAIM);
 
@@ -70,7 +68,7 @@ void *fe310_dispatch_irq(uint32_t vector, uint32_t *regs)
 
   /* NOTE: In case of ecall, we need to adjust mepc in the context */
 
-  if (FE310_IRQ_ECALLM == irq)
+  if (RISCV_IRQ_ECALLM == irq)
     {
       *mepc += 4;
     }
@@ -83,19 +81,19 @@ void *fe310_dispatch_irq(uint32_t vector, uint32_t *regs)
   PANIC();
 #else
   /* Current regs non-zero indicates that we are processing an interrupt;
-   * g_current_regs is also used to manage interrupt level context switches.
+   * CURRENT_REGS is also used to manage interrupt level context switches.
    *
    * Nested interrupts are not supported
    */
 
-  DEBUGASSERT(g_current_regs == NULL);
-  g_current_regs = regs;
+  DEBUGASSERT(CURRENT_REGS == NULL);
+  CURRENT_REGS = regs;
 
   /* Deliver the IRQ */
 
   irq_dispatch(irq, regs);
 
-  if (FE310_IRQ_MEXT <= irq)
+  if (RISCV_IRQ_MEXT <= irq)
     {
       /* If the irq is from GPIO, clear pending bit in the GPIO */
 
@@ -106,18 +104,18 @@ void *fe310_dispatch_irq(uint32_t vector, uint32_t *regs)
 
       /* Then write PLIC_CLAIM to clear pending in PLIC */
 
-      putreg32(irq - FE310_IRQ_MEXT, FE310_PLIC_CLAIM);
+      putreg32(irq - RISCV_IRQ_MEXT, FE310_PLIC_CLAIM);
     }
 #endif
 
   /* If a context switch occurred while processing the interrupt then
-   * g_current_regs may have change value.  If we return any value different
+   * CURRENT_REGS may have change value.  If we return any value different
    * from the input regs, then the lower level will know that a context
    * switch occurred during interrupt processing.
    */
 
-  regs = (uint32_t *)g_current_regs;
-  g_current_regs = NULL;
+  regs = (uintptr_t *)CURRENT_REGS;
+  CURRENT_REGS = NULL;
 
   return regs;
 }
