@@ -1,35 +1,20 @@
 /****************************************************************************
  * arch/sim/src/sim/up_hostfs.c
  *
- *   Copyright (C) 2015 Ken Pettit. All rights reserved.
- *   Author: Ken Pettit <pettitkd@gmail.com>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -49,7 +34,6 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#define __SIM__ 1
 #include "hostfs.h"
 
 /****************************************************************************
@@ -141,7 +125,7 @@ static void host_stat_convert(struct stat *hostbuf, struct nuttx_stat_s *buf)
  * Name: host_open
  ****************************************************************************/
 
-int host_open(const char *pathname, int flags, int mode)
+int host_open(const char *pathname, int flags, nuttx_mode_t mode)
 {
   int mapflags = 0;
 
@@ -227,11 +211,11 @@ int host_close(int fd)
  * Name: host_read
  ****************************************************************************/
 
-ssize_t host_read(int fd, void *buf, size_t count)
+nuttx_ssize_t host_read(int fd, void *buf, nuttx_size_t count)
 {
   /* Just call the read routine */
 
-  ssize_t ret = read(fd, buf, count);
+  nuttx_ssize_t ret = read(fd, buf, count);
   if (ret == -1)
     {
       ret = -errno;
@@ -244,11 +228,11 @@ ssize_t host_read(int fd, void *buf, size_t count)
  * Name: host_write
  ****************************************************************************/
 
-ssize_t host_write(int fd, const void *buf, size_t count)
+nuttx_ssize_t host_write(int fd, const void *buf, nuttx_size_t count)
 {
   /* Just call the write routine */
 
-  ssize_t ret = write(fd, buf, count);
+  nuttx_ssize_t ret = write(fd, buf, count);
   if (ret == -1)
     {
       ret = -errno;
@@ -261,12 +245,12 @@ ssize_t host_write(int fd, const void *buf, size_t count)
  * Name: host_lseek
  ****************************************************************************/
 
-off_t host_lseek(int fd, off_t offset, int whence)
+nuttx_off_t host_lseek(int fd, nuttx_off_t offset, int whence)
 {
   /* Just call the lseek routine */
 
-  off_t ret = lseek(fd, offset, whence);
-  if (ret == (off_t)-1)
+  nuttx_off_t ret = lseek(fd, offset, whence);
+  if (ret == (nuttx_off_t)-1)
     {
       ret = -errno;
     }
@@ -328,11 +312,70 @@ int host_fstat(int fd, struct nuttx_stat_s *buf)
   return ret;
 }
 
+/****************************************************************************
+ * Name: host_fchstat
+ ****************************************************************************/
+
+int host_fchstat(int fd, const struct nuttx_stat_s *buf, int flags)
+{
+  struct timespec times[2];
+  int ret;
+
+  if (flags & NUTTX_CH_STAT_MODE)
+    {
+      ret = fchmod(fd, buf->st_mode);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  if (flags & (NUTTX_CH_STAT_UID | NUTTX_CH_STAT_GID))
+    {
+      ret = fchown(fd, buf->st_uid, buf->st_gid);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  if (flags & (NUTTX_CH_STAT_ATIME | NUTTX_CH_STAT_MTIME))
+    {
+      if (flags & NUTTX_CH_STAT_ATIME)
+        {
+          times[0].tv_sec  = buf->st_atim.tv_sec;
+          times[0].tv_nsec = buf->st_atim.tv_nsec;
+        }
+      else
+        {
+          times[0].tv_nsec = UTIME_OMIT;
+        }
+
+      if (flags & NUTTX_CH_STAT_MTIME)
+        {
+          times[1].tv_sec  = buf->st_mtim.tv_sec;
+          times[1].tv_nsec = buf->st_mtim.tv_nsec;
+        }
+      else
+        {
+          times[1].tv_nsec = UTIME_OMIT;
+        }
+
+      ret = futimens(fd, times);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  return 0;
+}
+
 /****************************************************************************
  * Name: host_truncate
  ****************************************************************************/
 
-int host_ftruncate(int fd, off_t length)
+int host_ftruncate(int fd, nuttx_off_t length)
 {
   int ret = ftruncate(fd, length);
   if (ret < 0)
@@ -554,3 +597,62 @@ int host_stat(const char *path, struct nuttx_stat_s *buf)
   host_stat_convert(&hostbuf, buf);
   return ret;
 }
+
+/****************************************************************************
+ * Name: host_chstat
+ ****************************************************************************/
+
+int host_chstat(const char *path, const struct nuttx_stat_s *buf, int flags)
+{
+  struct timespec times[2];
+  int ret;
+
+  if (flags & NUTTX_CH_STAT_MODE)
+    {
+      ret = chmod(path, buf->st_mode);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  if (flags & (NUTTX_CH_STAT_UID | NUTTX_CH_STAT_GID))
+    {
+      ret = chown(path, buf->st_uid, buf->st_gid);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  if (flags & (NUTTX_CH_STAT_ATIME | NUTTX_CH_STAT_MTIME))
+    {
+      if (flags & NUTTX_CH_STAT_ATIME)
+        {
+          times[0].tv_sec  = buf->st_atim.tv_sec;
+          times[0].tv_nsec = buf->st_atim.tv_nsec;
+        }
+      else
+        {
+          times[0].tv_nsec = UTIME_OMIT;
+        }
+
+      if (flags & NUTTX_CH_STAT_MTIME)
+        {
+          times[1].tv_sec  = buf->st_mtim.tv_sec;
+          times[1].tv_nsec = buf->st_mtim.tv_nsec;
+        }
+      else
+        {
+          times[1].tv_nsec = UTIME_OMIT;
+        }
+
+      ret = utimensat(AT_FDCWD, path, times, 0);
+      if (ret < 0)
+        {
+          return -errno;
+        }
+    }
+
+  return 0;
+}
