@@ -73,44 +73,9 @@ void up_idle(void)
     }
 #endif
 
-  /* Handle UART data availability */
-
-  up_uartloop();
-
-#if defined(CONFIG_SIM_TOUCHSCREEN) || defined(CONFIG_SIM_AJOYSTICK) || \
-    defined(CONFIG_SIM_BUTTONS)
-  /* Drive the X11 event loop */
-
-  up_x11events();
-#endif
-
-#ifdef CONFIG_SIM_NETDEV
-  /* Run the network if enabled */
-
-  netdriver_loop();
-#endif
-
-#ifdef CONFIG_RPTUN
-  up_rptun_loop();
-#endif
-
-#ifdef CONFIG_SIM_HCISOCKET
-  bthcisock_loop();
-#endif
-
-#ifdef CONFIG_SIM_SOUND
-  sim_audio_loop();
-#endif
-
 #ifdef CONFIG_ONESHOT
   /* Driver the simulated interval timer */
 
   up_timer_update();
 #endif
-
-#ifdef CONFIG_SIM_MOTOR_FOC
-  /* Update simulated FOC device */
-
-  sim_foc_update();
-#endif
 }
