@@ -18,15 +18,15 @@
  *
  ****************************************************************************/
 
-#ifndef __ARCH_SIM_SRC_UP_INTERNAL_H
-#define __ARCH_SIM_SRC_UP_INTERNAL_H
+#ifndef __ARCH_SIM_SRC_SIM_UP_INTERNAL_H
+#define __ARCH_SIM_SRC_SIM_UP_INTERNAL_H
 
 /****************************************************************************
  * Included Files
  ****************************************************************************/
 
 #ifdef __SIM__
-#include "config.h"
+#  include "config.h"
 #endif
 
 #ifndef __ASSEMBLY__
@@ -39,6 +39,10 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
+#ifndef CONFIG_SMP_NCPUS
+#  define CONFIG_SMP_NCPUS 1
+#endif
+
 /* Determine which (if any) console driver to use */
 
 #ifndef CONFIG_DEV_CONSOLE
@@ -51,6 +55,18 @@
 #  endif
 #endif
 
+/* Use a stack alignment of 16 bytes.  If necessary frame_size must be
+ * rounded up to the next boundary
+ */
+
+#define STACK_ALIGNMENT     16
+
+/* Stack alignment macros */
+
+#define STACK_ALIGN_MASK    (STACK_ALIGNMENT - 1)
+#define STACK_ALIGN_DOWN(a) ((a) & ~STACK_ALIGN_MASK)
+#define STACK_ALIGN_UP(a)   (((a) + STACK_ALIGN_MASK) & ~STACK_ALIGN_MASK)
+
 /* Simulated Heap Definitions ***********************************************/
 
 /* Size of the simulated heap */
@@ -91,10 +107,6 @@
  ****************************************************************************/
 
 struct tcb_s;
-struct foc_dev_s;
-struct spi_dev_s;
-struct qspi_dev_s;
-struct ioexpander_dev_s;
 struct i2c_master_s;
 
 /****************************************************************************
@@ -107,21 +119,12 @@ struct i2c_master_s;
  * CURRENT_REGS for portability.
  */
 
-#ifdef CONFIG_SMP
 /* For the case of architectures with multiple CPUs, then there must be one
  * such value for each processor that can receive an interrupt.
  */
 
-int up_cpu_index(void); /* See include/nuttx/arch.h */
 extern volatile void *g_current_regs[CONFIG_SMP_NCPUS];
-#  define CURRENT_REGS (g_current_regs[up_cpu_index()])
-
-#else
-
-extern volatile void *g_current_regs[1];
-#  define CURRENT_REGS (g_current_regs[0])
-
-#endif
+#define CURRENT_REGS (g_current_regs[up_cpu_index()])
 
 /* The command line  arguments passed to simulator */
 
@@ -134,17 +137,13 @@ extern char **g_argv;
 
 /* Context switching */
 
-#if defined(CONFIG_HOST_X86_64) && !defined(CONFIG_SIM_M32)
 void up_copyfullstate(unsigned long *dest, unsigned long *src);
-#else
-void up_copyfullstate(uint32_t *dest, uint32_t *src);
-#endif
-
 void *up_doirq(int irq, void *regs);
 
-/* up_head.c ****************************************************************/
+/* up_hostmisc.c ************************************************************/
 
 void host_abort(int status);
+int  host_backtrace(void** array, int size);
 
 /* up_hostmemory.c **********************************************************/
 
@@ -190,12 +189,6 @@ int up_init_ipi(int irq);
 void up_timer_update(void);
 #endif
 
-/* rpmsg_serialinit *********************************************************/
-
-#ifdef CONFIG_RPMSG_UART
-void rpmsg_serialinit(void);
-#endif
-
 /* up_uart.c ****************************************************************/
 
 void up_uartinit(void);
@@ -252,61 +245,61 @@ void up_buttonevent(int x, int y, int buttons);
 int sim_ajoy_initialize(void);
 #endif
 
-/* up_ioexpander.c **********************************************************/
-
-#ifdef CONFIG_SIM_IOEXPANDER
-struct ioexpander_dev_s *sim_ioexpander_initialize(void);
-#endif
-
 /* up_tapdev.c **************************************************************/
 
 #if defined(CONFIG_SIM_NETDEV_TAP) && !defined(__CYGWIN__)
-void tapdev_init(void);
+void tapdev_init(void *priv,
+                 void (*tx_done_intr_cb)(void *priv),
+                 void (*rx_ready_intr_cb)(void *priv));
 int tapdev_avail(void);
 unsigned int tapdev_read(unsigned char *buf, unsigned int buflen);
 void tapdev_send(unsigned char *buf, unsigned int buflen);
 void tapdev_ifup(in_addr_t ifaddr);
 void tapdev_ifdown(void);
 
-#  define netdev_init()           tapdev_init()
-#  define netdev_avail()          tapdev_avail()
-#  define netdev_read(buf,buflen) tapdev_read(buf,buflen)
-#  define netdev_send(buf,buflen) tapdev_send(buf,buflen)
-#  define netdev_ifup(ifaddr)     tapdev_ifup(ifaddr)
-#  define netdev_ifdown()         tapdev_ifdown()
+#  define netdev_init(priv,txcb,rxcb) tapdev_init(priv,txcb,rxcb)
+#  define netdev_avail()              tapdev_avail()
+#  define netdev_read(buf,buflen)     tapdev_read(buf,buflen)
+#  define netdev_send(buf,buflen)     tapdev_send(buf,buflen)
+#  define netdev_ifup(ifaddr)         tapdev_ifup(ifaddr)
+#  define netdev_ifdown()             tapdev_ifdown()
 #endif
 
 /* up_wpcap.c ***************************************************************/
 
 #if defined(CONFIG_SIM_NETDEV_TAP) && defined(__CYGWIN__)
-void wpcap_init(void);
+void wpcap_init(void *priv,
+                void (*tx_done_intr_cb)(void *priv),
+                void (*rx_ready_intr_cb)(void *priv));
 unsigned int wpcap_read(unsigned char *buf, unsigned int buflen);
 void wpcap_send(unsigned char *buf, unsigned int buflen);
 
-#  define netdev_init()           wpcap_init()
-#  define netdev_avail()          1
-#  define netdev_read(buf,buflen) wpcap_read(buf,buflen)
-#  define netdev_send(buf,buflen) wpcap_send(buf,buflen)
-#  define netdev_ifup(ifaddr)     {}
-#  define netdev_ifdown()         {}
+#  define netdev_init(priv,txcb,rxcb) wpcap_init(priv,txcb,rxcb)
+#  define netdev_avail()              1
+#  define netdev_read(buf,buflen)     wpcap_read(buf,buflen)
+#  define netdev_send(buf,buflen)     wpcap_send(buf,buflen)
+#  define netdev_ifup(ifaddr)         {}
+#  define netdev_ifdown()             {}
 #endif
 
 /* up_vpnkit.c **************************************************************/
 
 #if defined(CONFIG_SIM_NETDEV_VPNKIT)
-void vpnkit_init(void);
+void vpnkit_init(void *priv,
+                 void (*tx_done_intr_cb)(void *priv),
+                 void (*rx_ready_intr_cb)(void *priv));
 int vpnkit_avail(void);
 unsigned int vpnkit_read(unsigned char *buf, unsigned int buflen);
 void vpnkit_send(unsigned char *buf, unsigned int buflen);
 void vpnkit_ifup(in_addr_t ifaddr);
 void vpnkit_ifdown(void);
 
-#  define netdev_init()           vpnkit_init()
-#  define netdev_avail()          vpnkit_avail()
-#  define netdev_read(buf,buflen) vpnkit_read(buf,buflen)
-#  define netdev_send(buf,buflen) vpnkit_send(buf,buflen)
-#  define netdev_ifup(ifaddr)     vpnkit_ifup(ifaddr)
-#  define netdev_ifdown()         vpnkit_ifdown()
+#  define netdev_init(priv,txcb,rxcb) vpnkit_init(priv,txcb,rxcb)
+#  define netdev_avail()              vpnkit_avail()
+#  define netdev_read(buf,buflen)     vpnkit_read(buf,buflen)
+#  define netdev_send(buf,buflen)     vpnkit_send(buf,buflen)
+#  define netdev_ifup(ifaddr)         vpnkit_ifup(ifaddr)
+#  define netdev_ifdown()             vpnkit_ifdown()
 #endif
 
 /* up_netdriver.c ***********************************************************/
@@ -316,6 +309,13 @@ void netdriver_setmacaddr(unsigned char *macaddr);
 void netdriver_setmtu(int mtu);
 void netdriver_loop(void);
 
+/* up_usrsock.c *************************************************************/
+
+#ifdef CONFIG_SIM_NETUSRSOCK
+int usrsock_init(void);
+void usrsock_loop(void);
+#endif
+
 /* up_rptun.c ***************************************************************/
 
 #ifdef CONFIG_RPTUN
@@ -323,14 +323,6 @@ int up_rptun_init(const char *shmemname, const char *cpuname, bool master);
 void up_rptun_loop(void);
 #endif
 
-#ifdef CONFIG_SIM_SPIFLASH
-struct spi_dev_s *up_spiflashinitialize(const char *name);
-#endif
-
-#ifdef CONFIG_SIM_QSPIFLASH
-struct qspi_dev_s *up_qspiflashinitialize(void);
-#endif
-
 /* up_hcisocket.c ***********************************************************/
 
 #ifdef CONFIG_SIM_HCISOCKET
@@ -365,12 +357,5 @@ int sim_spi_uninitialize(struct spi_dev_s *dev);
 void up_stack_color(void *stackbase, size_t nbytes);
 #endif
 
-/* up_foc.c *****************************************************************/
-
-#ifdef CONFIG_MOTOR_FOC
-struct foc_dev_s *sim_foc_initialize(int inst);
-void sim_foc_update(void);
-#endif
-
 #endif /* __ASSEMBLY__ */
-#endif /* __ARCH_SIM_SRC_UP_INTERNAL_H */
+#endif /* __ARCH_SIM_SRC_SIM_UP_INTERNAL_H */
