@@ -27,6 +27,7 @@
 #include <stdint.h>
 #include <stdbool.h>
 #include <sched.h>
+#include <assert.h>
 #include <debug.h>
 #include <nuttx/arch.h>
 #include <nuttx/sched.h>
@@ -50,8 +51,7 @@
  *   1) The priority of the currently running task drops and the next
  *      task in the ready to run list has priority.
  *   2) An idle, ready to run task's priority has been raised above the
- *      the priority of the current, running task and it now has the
- *      priority.
+ *      priority of the current, running task and it now has the priority.
  *
  * Input Parameters:
  *   tcb: The TCB of the task that has been reprioritized
@@ -109,7 +109,6 @@ void up_reprioritize_rtr(struct tcb_s *tcb, uint8_t priority)
         {
           /* If we are going to do a context switch, then now is the right
            * time to add any pending tasks back into the ready-to-run list.
-           * task list now
            */
 
           if (g_pendingtasks.head)
