@@ -238,7 +238,11 @@ static const struct file_operations g_vgaops =
   vga_read,                  /* read */
   vga_write,                 /* write */
   vga_seek,                  /* seek */
-  0,                         /* ioctl */
+  NULL,                      /* ioctl */
+  NULL                       /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL                     /* unlink */
+#endif
 };
 
 /****************************************************************************
