@@ -56,13 +56,6 @@ void xtensa_sig_deliver(void)
   struct tcb_s *rtcb = this_task();
   uint32_t regs[XCPTCONTEXT_REGS];
 
-  /* Save the errno.  This must be preserved throughout the signal handling
-   * so that the user code final gets the correct errno value (probably
-   * EINTR).
-   */
-
-  int saved_errno = get_errno();
-
 #ifdef CONFIG_SMP
   /* In the SMP case, we must terminate the critical section while the signal
    * handler executes, but we also need to restore the irqcount when the
@@ -138,10 +131,6 @@ void xtensa_sig_deliver(void)
   up_irq_save();
 #endif
 
-  /* Restore the saved errno value */
-
-  set_errno(saved_errno);
-
   /* Modify the saved return state with the actual saved values in the
    * TCB.  This depends on the fact that nested signal handling is
    * not supported.  Therefore, these values will persist throughout the
