@@ -35,6 +35,7 @@
 #include <nuttx/arch.h>
 #include <nuttx/timers/oneshot.h>
 #include <nuttx/kmalloc.h>
+#include <nuttx/spinlock.h>
 
 #include "esp32_oneshot.h"
 
@@ -55,11 +56,12 @@ struct esp32_oneshot_lowerhalf_s
    * That means, opaque pointers.
    */
 
-  struct oneshot_lowerhalf_s        lh;  /* Lower half instance */
-  struct esp32_oneshot_s       oneshot;  /* ESP32-specific oneshot state */
-  oneshot_callback_t          callback;  /* Upper half Interrupt callback */
-  void                        *arg;      /* Argument passed to handler */
-  uint16_t                  resolution;
+  struct oneshot_lowerhalf_s  lh;         /* Lower half instance */
+  struct esp32_oneshot_s      oneshot;    /* ESP32-specific oneshot state */
+  oneshot_callback_t          callback;   /* Upper half Interrupt callback */
+  void                        *arg;       /* Argument passed to handler */
+  uint16_t                    resolution; /* Timer's resulation in uS */
+  spinlock_t                  lock;       /* Device specific lock */
 };
 
 /****************************************************************************
@@ -115,20 +117,26 @@ static void esp32_oneshot_lh_handler(void *arg)
 {
   struct esp32_oneshot_lowerhalf_s *priv =
     (struct esp32_oneshot_lowerhalf_s *)arg;
+  oneshot_callback_t callback;
+  FAR void *cb_arg;
 
   DEBUGASSERT(priv != NULL);
   DEBUGASSERT(priv->callback != NULL);
 
   tmrinfo("Oneshot LH handler triggered\n");
 
-  /* Call the callback */
-
-  priv->callback(&priv->lh, priv->arg);
-
-  /* Restore state */
+  /* Sample and nullify BEFORE executing callback (in case the callback
+   * restarts the oneshot).
+   */
 
+  callback       = priv->callback;
+  cb_arg         = priv->arg;
   priv->callback = NULL;
-  priv->arg = NULL;
+  priv->arg      = NULL;
+
+  /* Then perform the callback */
+
+  callback(&priv->lh, cb_arg);
 }
 
 /****************************************************************************
@@ -208,12 +216,12 @@ static int esp32_lh_start(struct oneshot_lowerhalf_s *lower,
 
   /* Save the callback information and start the timer */
 
-  flags          = enter_critical_section();
+  flags          = spin_lock_irqsave(&priv->lock);
   priv->callback = callback;
   priv->arg      = arg;
   ret            = esp32_oneshot_start(&priv->oneshot,
                                        esp32_oneshot_lh_handler, priv, ts);
-  leave_critical_section(flags);
+  spin_unlock_irqrestore(&priv->lock, flags);
 
   if (ret < 0)
     {
@@ -259,11 +267,11 @@ static int esp32_lh_cancel(struct oneshot_lowerhalf_s *lower,
 
   /* Cancel the timer */
 
-  flags          = enter_critical_section();
+  flags          = spin_lock_irqsave(&priv->lock);
   ret            = esp32_oneshot_cancel(&priv->oneshot, ts);
   priv->callback = NULL;
   priv->arg      = NULL;
-  leave_critical_section(flags);
+  spin_unlock_irqrestore(&priv->lock, flags);
 
   if (ret < 0)
     {
