@@ -29,6 +29,7 @@
 #include <arch/xtensa/core.h>
 
 #include <sys/types.h>
+#include <assert.h>
 #include <debug.h>
 
 #include "xtensa.h"
@@ -37,9 +38,9 @@
  * Public Data
  ****************************************************************************/
 
-#ifdef CONFIG_ARCH_USE_MODULE_TEXT
-extern uint32_t _smodtext;
-extern uint32_t _emodtext;
+#ifdef CONFIG_ARCH_USE_TEXT_HEAP
+extern uint32_t _siramheap;
+extern uint32_t _eiramheap;
 #endif
 
 /****************************************************************************
@@ -50,7 +51,7 @@ extern uint32_t _emodtext;
  * Private Functions
  ****************************************************************************/
 
-#ifdef CONFIG_ARCH_USE_MODULE_TEXT
+#ifdef CONFIG_ARCH_USE_TEXT_HEAP
 #ifdef CONFIG_ENDIAN_BIG
 #error not implemented
 #endif
@@ -248,6 +249,36 @@ static int decode_l16ui(const uint8_t *p, uint8_t *imm8, uint8_t *s,
   return 0;
 }
 
+/****************************************************************************
+ * Name: decode_l16si
+ *
+ * Description:
+ *   Decode L16SI instruction using 32-bit aligned access.
+ *   Return non-zero on successful decoding.
+ *
+ ****************************************************************************/
+
+static int decode_l16si(const uint8_t *p, uint8_t *imm8, uint8_t *s,
+                       uint8_t *t)
+{
+  /*  23           16 15   12 11    8 7     4 3     0
+   * | imm8          |1 0 0 1| s     | t     |0 0 1 0|
+   */
+
+  uint8_t b0 = load_uint8(p);
+  uint8_t b1 = load_uint8(p + 1);
+
+  if ((b0 & 0xf) == 2 && (b1 & 0xf0) == 0x90)
+    {
+      *t = b0 >> 4;
+      *s = b1 & 0xf;
+      *imm8 = load_uint8(p + 2);
+      return 1;
+    }
+
+  return 0;
+}
+
 /****************************************************************************
  * Name: advance_pc
  *
@@ -263,7 +294,7 @@ static void advance_pc(uint32_t *regs, int diff)
   /* Advance to the next instruction. */
 
   nextpc = regs[REG_PC] + diff;
-#ifdef XCHAL_HAVE_LOOPS
+#if XCHAL_HAVE_LOOPS != 0
   /* See Xtensa ISA 4.3.2.4 Loopback Semantics */
 
   if (regs[REG_LCOUNT] != 0 && nextpc == regs[REG_LEND])
@@ -292,7 +323,7 @@ static void advance_pc(uint32_t *regs, int diff)
 
 uint32_t *xtensa_user(int exccause, uint32_t *regs)
 {
-#ifdef CONFIG_ARCH_USE_MODULE_TEXT
+#ifdef CONFIG_ARCH_USE_TEXT_HEAP
   /* Emulate byte access for module text.
    *
    * ESP32 only allows word-aligned accesses to the instruction memory
@@ -307,8 +338,8 @@ uint32_t *xtensa_user(int exccause, uint32_t *regs)
    */
 
   if (exccause == XCHAL_EXCCAUSE_LOAD_STORE_ERROR &&
-      (uintptr_t)&_smodtext <= regs[REG_EXCVADDR] &&
-      (uintptr_t)&_emodtext > regs[REG_EXCVADDR])
+      (uintptr_t)&_siramheap <= regs[REG_EXCVADDR] &&
+      (uintptr_t)&_eiramheap > regs[REG_EXCVADDR])
     {
       uint8_t *pc = (uint8_t *)regs[REG_PC];
       uint8_t imm8;
@@ -316,7 +347,7 @@ uint32_t *xtensa_user(int exccause, uint32_t *regs)
       uint8_t t;
 
       binfo("XCHAL_EXCCAUSE_LOAD_STORE_ERROR at %p, pc=%p\n",
-            (FAR void *)regs[REG_EXCVADDR],
+            (void *)regs[REG_EXCVADDR],
             pc);
 
       if (decode_s8i(pc, &imm8, &s, &t))
@@ -343,11 +374,10 @@ uint32_t *xtensa_user(int exccause, uint32_t *regs)
                 (unsigned int)t,
                 (void *)regs[REG_A0 + t]);
 
-          DEBUGASSERT(regs[REG_A0 + s] + imm8 == regs[REG_EXCVADDR]);
-          store_uint8(((uint8_t *)regs[REG_A0 + s]) + imm8,
-                      regs[REG_A0 + t]);
-          store_uint8(((uint8_t *)regs[REG_A0 + s]) + imm8 + 1,
-                      regs[REG_A0 + t] >> 8);
+          uintptr_t va = regs[REG_A0 + s] + (imm8 << 1);
+          DEBUGASSERT(va == regs[REG_EXCVADDR]);
+          store_uint8((uint8_t *)va, regs[REG_A0 + t]);
+          store_uint8((uint8_t *)va + 1, regs[REG_A0 + t] >> 8);
           advance_pc(regs, 3);
           return regs;
         }
@@ -366,6 +396,23 @@ uint32_t *xtensa_user(int exccause, uint32_t *regs)
           advance_pc(regs, 3);
           return regs;
         }
+      else if (decode_l16si(pc, &imm8, &s, &t))
+        {
+          binfo("Emulating L16SI imm8=%u, s=%u (%p), t=%u (%p)\n",
+                (unsigned int)imm8,
+                (unsigned int)s,
+                (void *)regs[REG_A0 + s],
+                (unsigned int)t,
+                (void *)regs[REG_A0 + t]);
+
+          uintptr_t va = regs[REG_A0 + s] + (imm8 << 1);
+          DEBUGASSERT(va == regs[REG_EXCVADDR]);
+          uint8_t lo = load_uint8((uint8_t *)va);
+          uint8_t hi = load_uint8((uint8_t *)va + 1);
+          regs[REG_A0 + t] = (int16_t)((hi << 8) | lo);
+          advance_pc(regs, 3);
+          return regs;
+        }
       else if (decode_l16ui(pc, &imm8, &s, &t))
         {
           binfo("Emulating L16UI imm8=%u, s=%u (%p), t=%u (%p)\n",
@@ -375,9 +422,10 @@ uint32_t *xtensa_user(int exccause, uint32_t *regs)
                 (unsigned int)t,
                 (void *)regs[REG_A0 + t]);
 
-          DEBUGASSERT(regs[REG_A0 + s] + imm8 == regs[REG_EXCVADDR]);
-          uint8_t lo = load_uint8(((uint8_t *)regs[REG_A0 + s]) + imm8);
-          uint8_t hi = load_uint8(((uint8_t *)regs[REG_A0 + s]) + imm8 + 1);
+          uintptr_t va = regs[REG_A0 + s] + (imm8 << 1);
+          DEBUGASSERT(va == regs[REG_EXCVADDR]);
+          uint8_t lo = load_uint8((uint8_t *)va);
+          uint8_t hi = load_uint8((uint8_t *)va + 1);
           regs[REG_A0 + t] = (hi << 8) | lo;
           advance_pc(regs, 3);
           return regs;
