@@ -63,7 +63,15 @@ extern "C"
 
 #define MAC_LEN                     (6)
 
-/* WiFi event ID */
+/* Needed to fix coex_adapter_funcs_t definition */
+
+#define CONFIG_IDF_TARGET_ESP32   1
+
+/* Define esp_err_t */
+
+typedef int esp_err_t;
+
+/* Wi-Fi event ID */
 
 enum wifi_adpt_evt_e
 {
@@ -76,14 +84,26 @@ enum wifi_adpt_evt_e
   WIFI_ADPT_EVT_MAX,
 };
 
-/* WiFi event callback function */
+enum coex_log_level_e
+{
+    COEX_LOG_NONE = 0,
+    COEX_LOG_ERROR,
+    COEX_LOG_WARN,
+    COEX_LOG_INFO,
+    COEX_LOG_DEBUG,
+    COEX_LOG_VERBOSE
+};
+
+/* Wi-Fi event callback function */
 
 typedef void (*wifi_evt_cb_t)(void *p);
 
-/* WiFi TX done callback function */
+/* Wi-Fi TX done callback function */
 
 typedef void (*wifi_txdone_cb_t)(uint8_t *data, uint16_t *len, bool status);
 
+#define COEX_ADAPTER_FUNCS_TIME_BLOCKING      0xffffffff
+
 /****************************************************************************
  * Public Function Prototypes
  ****************************************************************************/
@@ -92,7 +112,7 @@ typedef void (*wifi_txdone_cb_t)(uint8_t *data, uint16_t *len, bool status);
  * Name: esp_wifi_adapter_init
  *
  * Description:
- *   Initialize ESP32 WiFi adapter
+ *   Initialize ESP32 Wi-Fi adapter
  *
  * Input Parameters:
  *   None
@@ -108,10 +128,10 @@ int esp_wifi_adapter_init(void);
  * Name: esp_wifi_free_eb
  *
  * Description:
- *   Free WiFi receive callback input eb pointer
+ *   Free Wi-Fi receive callback input eb pointer
  *
  * Input Parameters:
- *   eb - WiFi receive callback input eb pointer
+ *   eb - Wi-Fi receive callback input eb pointer
  *
  * Returned Value:
  *   None
@@ -143,7 +163,7 @@ int esp_wifi_notify_subscribe(pid_t pid, struct sigevent *event);
  * Name: esp_wifi_sta_start
  *
  * Description:
- *   Start WiFi station.
+ *   Start Wi-Fi station.
  *
  * Input Parameters:
  *   None
@@ -160,7 +180,7 @@ int esp_wifi_sta_start(void);
  * Name: esp_wifi_sta_stop
  *
  * Description:
- *   Stop WiFi station.
+ *   Stop Wi-Fi station.
  *
  * Input Parameters:
  *   None
@@ -177,7 +197,7 @@ int esp_wifi_sta_stop(void);
  * Name: esp_wifi_sta_send_data
  *
  * Description:
- *   Use WiFi station interface to send 802.3 frame
+ *   Use Wi-Fi station interface to send 802.3 frame
  *
  * Input Parameters:
  *   pbuf - Packet buffer pointer
@@ -195,7 +215,7 @@ int esp_wifi_sta_send_data(void *pbuf, uint32_t len);
  * Name: esp_wifi_sta_register_recv_cb
  *
  * Description:
- *   Regitser WiFi station receive packet callback function
+ *   Regitser Wi-Fi station receive packet callback function
  *
  * Input Parameters:
  *   recv_cb - Receive callback function
@@ -246,7 +266,7 @@ int esp_wifi_sta_read_mac(uint8_t *mac);
  * Name: esp_wifi_set_password
  *
  * Description:
- *   Set/Get WiFi station password
+ *   Set/Get Wi-Fi station password
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -264,7 +284,7 @@ int esp_wifi_sta_password(struct iwreq *iwr, bool set);
  * Name: esp_wifi_sta_essid
  *
  * Description:
- *   Set/Get WiFi station ESSID
+ *   Set/Get Wi-Fi station ESSID
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -282,7 +302,7 @@ int esp_wifi_sta_essid(struct iwreq *iwr, bool set);
  * Name: esp_wifi_sta_bssid
  *
  * Description:
- *   Set/Get WiFi station BSSID
+ *   Set/Get Wi-Fi station BSSID
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -300,7 +320,7 @@ int esp_wifi_sta_bssid(struct iwreq *iwr, bool set);
  * Name: esp_wifi_sta_connect
  *
  * Description:
- *   Trigger WiFi station connection action
+ *   Trigger Wi-Fi station connection action
  *
  * Input Parameters:
  *   None
@@ -317,7 +337,7 @@ int esp_wifi_sta_connect(void);
  * Name: esp_wifi_sta_disconnect
  *
  * Description:
- *   Trigger WiFi station disconnection action
+ *   Trigger Wi-Fi station disconnection action
  *
  * Input Parameters:
  *   None
@@ -334,7 +354,7 @@ int esp_wifi_sta_disconnect(void);
  * Name: esp_wifi_sta_mode
  *
  * Description:
- *   Set/Get WiFi Station mode code.
+ *   Set/Get Wi-Fi Station mode code.
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -460,7 +480,7 @@ int esp_wifi_sta_country(struct iwreq *iwr, bool set);
  * Name: esp_wifi_sta_rssi
  *
  * Description:
- *   Get WiFi sensitivity (dBm).
+ *   Get Wi-Fi sensitivity (dBm).
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -481,7 +501,7 @@ int esp_wifi_sta_rssi(struct iwreq *iwr, bool set);
  * Name: esp_wifi_softap_start
  *
  * Description:
- *   Start WiFi softAP.
+ *   Start Wi-Fi softAP.
  *
  * Input Parameters:
  *   None
@@ -498,7 +518,7 @@ int esp_wifi_softap_start(void);
  * Name: esp_wifi_softap_stop
  *
  * Description:
- *   Stop WiFi softAP.
+ *   Stop Wi-Fi softAP.
  *
  * Input Parameters:
  *   None
@@ -515,7 +535,7 @@ int esp_wifi_softap_stop(void);
  * Name: esp_wifi_softap_send_data
  *
  * Description:
- *   Use WiFi softAP interface to send 802.3 frame
+ *   Use Wi-Fi softAP interface to send 802.3 frame
  *
  * Input Parameters:
  *   pbuf - Packet buffer pointer
@@ -533,7 +553,7 @@ int esp_wifi_softap_send_data(void *pbuf, uint32_t len);
  * Name: esp_wifi_softap_register_recv_cb
  *
  * Description:
- *   Regitser WiFi softAP receive packet callback function
+ *   Regitser Wi-Fi softAP receive packet callback function
  *
  * Input Parameters:
  *   recv_cb - Receive callback function
@@ -584,7 +604,7 @@ int esp_wifi_softap_read_mac(uint8_t *mac);
  * Name: esp_wifi_softap_password
  *
  * Description:
- *   Set/Get WiFi SoftAP password
+ *   Set/Get Wi-Fi SoftAP password
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -602,7 +622,7 @@ int esp_wifi_softap_password(struct iwreq *iwr, bool set);
  * Name: esp_wifi_softap_essid
  *
  * Description:
- *   Set/Get WiFi SoftAP ESSID
+ *   Set/Get Wi-Fi SoftAP ESSID
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -620,7 +640,7 @@ int esp_wifi_softap_essid(struct iwreq *iwr, bool set);
  * Name: esp_wifi_softap_bssid
  *
  * Description:
- *   Set/Get WiFi softAP BSSID
+ *   Set/Get Wi-Fi softAP BSSID
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -638,7 +658,7 @@ int esp_wifi_softap_bssid(struct iwreq *iwr, bool set);
  * Name: esp_wifi_softap_connect
  *
  * Description:
- *   Trigger WiFi softAP accept connection action
+ *   Trigger Wi-Fi softAP accept connection action
  *
  * Input Parameters:
  *   None
@@ -655,7 +675,7 @@ int esp_wifi_softap_connect(void);
  * Name: esp_wifi_softap_disconnect
  *
  * Description:
- *   Trigger WiFi softAP drop connection action
+ *   Trigger Wi-Fi softAP drop connection action
  *
  * Input Parameters:
  *   None
@@ -672,7 +692,7 @@ int esp_wifi_softap_disconnect(void);
  * Name: esp_wifi_softap_mode
  *
  * Description:
- *   Set/Get WiFi SoftAP mode code.
+ *   Set/Get Wi-Fi SoftAP mode code.
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -797,7 +817,7 @@ int esp_wifi_softap_country(struct iwreq *iwr, bool set);
  * Name: esp_wifi_softap_rssi
  *
  * Description:
- *   Get WiFi sensitivity (dBm).
+ *   Get Wi-Fi sensitivity (dBm).
  *
  * Input Parameters:
  *   iwr - The argument of the ioctl cmd
@@ -810,8 +830,44 @@ int esp_wifi_softap_country(struct iwreq *iwr, bool set);
  ****************************************************************************/
 
 int esp_wifi_softap_rssi(struct iwreq *iwr, bool set);
+#endif /* ESP32_WLAN_HAS_SOFTAP */
+
+/****************************************************************************
+ * Name: esp32_wifi_bt_coexist_init
+ *
+ * Description:
+ *   Initialize ESP32 Wi-Fi and BT coexistence module.
+ *
+ * Input Parameters:
+ *   None
+ *
+ * Returned Value:
+ *   OK on success (positive non-zero values are cmd-specific)
+ *   Negated errno returned on failure.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_ESP32_WIFI_BT_COEXIST
+int esp32_wifi_bt_coexist_init(void);
+void coex_dbg_set_log_level(int level);
 #endif
 
+/****************************************************************************
+ * Name: esp_wifi_stop_callback
+ *
+ * Description:
+ *   Callback to stop Wi-Fi
+ *
+ * Input Parameters:
+ *   None
+ *
+ * Returned Value:
+ *   None
+ *
+ ****************************************************************************/
+
+void esp_wifi_stop_callback(void);
+
 #ifdef __cplusplus
 }
 #endif
