@@ -295,9 +295,9 @@
  * This table is decided by hardware, don't touch this.
  */
 
-#define ETS_WIFI_MAC_INTR_SOURCE                0  /* Interrupt of WiFi MAC, level */
-#define ETS_WIFI_MAC_NMI_SOURCE                 1  /* Interrupt of WiFi MAC, NMI, use if MAC have bug to fix in NMI */
-#define ETS_WIFI_BB_INTR_SOURCE                 2  /* Interrupt of WiFi BB, level, we can do some calibartion */
+#define ETS_WIFI_MAC_INTR_SOURCE                0  /* Interrupt of Wi-Fi MAC, level */
+#define ETS_WIFI_MAC_NMI_SOURCE                 1  /* Interrupt of Wi-Fi MAC, NMI, use if MAC have bug to fix in NMI */
+#define ETS_WIFI_BB_INTR_SOURCE                 2  /* Interrupt of Wi-Fi BB, level, we can do some calibartion */
 #define ETS_BT_MAC_INTR_SOURCE                  3  /* will be cancelled */
 #define ETS_BT_BB_INTR_SOURCE                   4  /* Interrupt of BT BB, level */
 #define ETS_BT_BB_NMI_SOURCE                    5  /* Interrupt of BT BB, NMI, use if BB have bug to fix in NMI */
@@ -620,7 +620,7 @@ extern int rom_i2c_writereg(int block, int block_id, int reg_add,
                                     (REG_GET_FIELD(EFUSE_BLK0_RDATA5_REG, \
                                      EFUSE_RD_VOL_LEVEL_HP_INV)))
 
-#ifdef CONFIG_ESPTOOLPY_FLASHFREQ_80M
+#ifdef CONFIG_ESP32_FLASH_FREQ_80M
 #define DIG_DBIAS_80M_160M          RTC_CNTL_DBIAS_HP_VOLT
 #else
 #define DIG_DBIAS_80M_160M          RTC_CNTL_DBIAS_1V10
@@ -738,7 +738,7 @@ extern int rom_i2c_writereg(int block, int block_id, int reg_add,
 #define BB_DC_EST_FORCE_PD_V        1
 #define BB_DC_EST_FORCE_PD_S        0
 
-/* Some of the WiFi RX control registers.
+/* Some of the Wi-Fi RX control registers.
  * PU/PD fields defined here are used in sleep related functions.
  */
 
@@ -804,6 +804,10 @@ extern int rom_i2c_writereg(int block, int block_id, int reg_add,
 
 #define INVALID_MMU_VAL             0x100
 
+/*  phy registers and memory size */
+
+#define SOC_PHY_DIG_REGS_MEM_SIZE   (21*4)
+
 /****************************************************************************
  * Inline Functions
  ****************************************************************************/
