@@ -178,9 +178,9 @@ static int audio_comp_getcaps(FAR struct audio_lowerhalf_s *dev, int type,
   int ret = -ENOTTY;
   int i;
 
-  caps->ac_channels   = 0;
-  caps->ac_format.hw  = 0;
-  caps->ac_controls.w = 0;
+  caps->ac_channels   = UINT8_MAX;
+  caps->ac_format.hw  = UINT16_MAX;
+  caps->ac_controls.w = UINT32_MAX;
 
   for (i = 0; i < priv->count; i++)
     {
@@ -200,13 +200,13 @@ static int audio_comp_getcaps(FAR struct audio_lowerhalf_s *dev, int type,
               break;
             }
 
-          if (caps->ac_channels < dup.ac_channels)
+          if (caps->ac_channels > dup.ac_channels)
             {
               caps->ac_channels = dup.ac_channels;
             }
 
-          caps->ac_format.hw   |= dup.ac_format.hw;
-          caps->ac_controls.w  |= dup.ac_controls.w;
+          caps->ac_format.hw   &= dup.ac_format.hw;
+          caps->ac_controls.w  &= dup.ac_controls.w;
         }
     }
 
