@@ -92,6 +92,8 @@ static cxd56_audio_dma_cb_t g_dma_cb[DMA_HANDLE_MAX_NUM];
 
 static bool s_work_arroud_dmac[DMA_HANDLE_MAX_NUM] =
 {
+  true,
+  true,
   true,
   true,
   true
@@ -146,6 +148,14 @@ static CXD56_AUDIO_ECODE get_dma_handle(cxd56_audio_dma_path_t path,
         *handle = CXD56_AUDIO_DMAC_MIC;
         break;
 
+      case CXD56_AUDIO_DMA_PATH_I2S0_TO_MEM:
+        *handle = CXD56_AUDIO_DMAC_I2S0_UP;
+        break;
+
+      case CXD56_AUDIO_DMA_PATH_I2S1_TO_MEM:
+        *handle = CXD56_AUDIO_DMAC_I2S1_UP;
+        break;
+
       case CXD56_AUDIO_DMA_PATH_MEM_TO_BUSIF1:
         *handle = CXD56_AUDIO_DMAC_I2S0_DOWN;
         break;
@@ -170,6 +180,14 @@ static CXD56_AUDIO_ECODE get_dma_path(cxd56_audio_dma_t handle,
         *path = CXD56_AUDIO_DMA_PATH_MIC_TO_MEM;
         break;
 
+      case CXD56_AUDIO_DMAC_I2S0_UP:
+        *path = CXD56_AUDIO_DMA_PATH_I2S0_TO_MEM;
+        break;
+
+      case CXD56_AUDIO_DMAC_I2S1_UP:
+        *path = CXD56_AUDIO_DMA_PATH_I2S1_TO_MEM;
+        break;
+
       case CXD56_AUDIO_DMAC_I2S0_DOWN:
         *path = CXD56_AUDIO_DMA_PATH_MEM_TO_BUSIF1;
         break;
@@ -237,6 +255,8 @@ static CXD56_AUDIO_ECODE exec_dma_ch_sync_workaround(
 
       if (timeout_cnt == DMA_TIMEOUT_CNT)
         {
+          sched_unlock();
+          up_irq_enable();
           return CXD56_AUDIO_ECODE_DMA_SMP_TIMEOUT;
         }
 
@@ -601,6 +621,12 @@ void cxd56_audio_dma_int_handler(void)
 
       /* Check done complete state. */
 
+      if (int_i2s & DMA_STATE_BIT_I2S_IN_DONE)
+        {
+          (*g_dma_cb[CXD56_AUDIO_DMAC_I2S0_UP])(CXD56_AUDIO_DMAC_I2S0_UP,
+                                               CXD56_AUDIO_ECODE_DMA_CMPLT);
+        }
+
       if (int_i2s & DMA_STATE_BIT_I2S_OUT_DONE)
         {
           (*g_dma_cb[CXD56_AUDIO_DMAC_I2S0_DOWN])(CXD56_AUDIO_DMAC_I2S0_DOWN,
@@ -609,6 +635,16 @@ void cxd56_audio_dma_int_handler(void)
 
       /* Check transfer err state. */
 
+      if (int_i2s & DMA_STATE_BIT_I2S_IN_ERR)
+        {
+          cxd56_audio_bca_reg_mask_err_int(CXD56_AUDIO_DMAC_I2S0_UP);
+
+          cxd56_audio_bca_reg_clear_err_int(CXD56_AUDIO_DMAC_I2S0_UP);
+
+          (*g_dma_cb[CXD56_AUDIO_DMAC_I2S0_UP])(CXD56_AUDIO_DMAC_I2S0_UP,
+                                               CXD56_AUDIO_ECODE_DMA_TRANS);
+        }
+
       if (int_i2s & DMA_STATE_BIT_I2S_OUT_ERR)
         {
           cxd56_audio_bca_reg_mask_err_int(CXD56_AUDIO_DMAC_I2S0_DOWN);
@@ -638,6 +674,12 @@ void cxd56_audio_dma_int_handler(void)
     {
       /* Clear interrupt. */
 
+      if (int_i2s2 & DMA_STATE_BIT_I2S_IN_DONE)
+        {
+          (*g_dma_cb[CXD56_AUDIO_DMAC_I2S1_UP])(CXD56_AUDIO_DMAC_I2S1_UP,
+                                                CXD56_AUDIO_ECODE_DMA_CMPLT);
+        }
+
       cxd56_audio_bca_reg_clear_dma_done_state_i2s2(int_i2s2);
 
       /* Check done complete state. */
@@ -651,6 +693,16 @@ void cxd56_audio_dma_int_handler(void)
 
       /* Check transfer err state. */
 
+      if (int_i2s2 & DMA_STATE_BIT_I2S_IN_ERR)
+        {
+          cxd56_audio_bca_reg_mask_err_int(CXD56_AUDIO_DMAC_I2S1_UP);
+
+          cxd56_audio_bca_reg_clear_err_int(CXD56_AUDIO_DMAC_I2S1_UP);
+
+          (*g_dma_cb[CXD56_AUDIO_DMAC_I2S1_UP])(CXD56_AUDIO_DMAC_I2S1_UP,
+                                                CXD56_AUDIO_ECODE_DMA_TRANS);
+        }
+
       if (int_i2s2 & DMA_STATE_BIT_I2S_OUT_ERR)
         {
           cxd56_audio_bca_reg_mask_err_int(CXD56_AUDIO_DMAC_I2S1_DOWN);
