@@ -28,13 +28,10 @@
 #include <syslog.h>
 
 #include <nuttx/board.h>
+#include <nuttx/leds/userled.h>
 
 #include "teensy-4.h"
 
-#if !defined(CONFIG_ARCH_LEDS) && defined(CONFIG_USERLED_LOWER)
-#  define HAVE_LEDS 0
-#endif
-
 #ifdef CONFIG_BOARDCTL
 
 /****************************************************************************
@@ -69,7 +66,7 @@
 int board_app_initialize(uintptr_t arg)
 {
   int ret;
-  #ifdef HAVE_LEDS
+#if !defined(CONFIG_ARCH_LEDS) && defined(CONFIG_USERLED_LOWER)
   /* Register the LED driver */
 
   ret = userled_lower_initialize(LED_DRIVER_PATH);
