@@ -30,7 +30,7 @@
 
 #include <nuttx/i2c/i2c_master.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "kinetis.h"
 #include "kinetis_i2c.h"
