@@ -31,7 +31,7 @@
 #include <nuttx/board.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "kwikstik-k40.h"
 
 /****************************************************************************
