@@ -37,7 +37,7 @@
 #include <nuttx/lcd/lcd.h>
 #include <nuttx/lcd/st7565.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "lc823450_gpio.h"
 #include "lc823450_spi.h"
 #include "lc823450-xgevk.h"
