@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef _BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H
-#define _BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H
+#ifndef __BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H
+#define __BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H
 
 /****************************************************************************
  * Included Files
@@ -98,4 +98,4 @@
 void weak_function lincoln60_sspdev_initialize(void);
 
 #endif /* __ASSEMBLY__ */
-#endif /* _BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H */
+#endif /* __BOARDS_ARM_LPC17XX_40XX_LINCOLN60_SRC_LINCOLN60_H */
