@@ -34,7 +34,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "lpc17_40_pwm.h"
 #include "lpc17_40_timer.h"
 #include "mcb1700.h"
