@@ -31,8 +31,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "lpc17_40_can.h"
 #include "lpc1766stk.h"
 
