@@ -36,7 +36,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "lpc17_40_gpio.h"
 #include "lpc17_40_ssp.h"
