@@ -37,8 +37,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "lpc31_syscreg.h"
 #include "lpc31_cgudrvr.h"
 #include "lpc31_mpmc.h"
