@@ -38,8 +38,7 @@
 #include <nuttx/usb/usbhost.h>
 #include <nuttx/usb/usbdev_trace.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "lpc31.h"
 #include "lpc_h3131.h"
 
