@@ -32,7 +32,7 @@
 #include <nuttx/spi/spi.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "rp2040_gpio.h"
 #include "hardware/rp2040_spi.h"
