@@ -23,9 +23,10 @@
  ****************************************************************************/
 
 #include <nuttx/config.h>
-
 #include <nuttx/board.h>
 
+#include <stdint.h>
+
 #include "s32k148evb.h"
 
 /****************************************************************************
@@ -50,14 +51,14 @@
  *
  * Input Parameters:
  *   arg - The boardctl() argument is passed to the board_app_initialize()
- *         implementation without modification.  The argument has no
- *         meaning to NuttX; the meaning of the argument is a contract
- *         between the board-specific initialization logic and the
- *         matching application logic.  The value could be such things as a
- *         mode enumeration value, a set of DIP switch switch settings, a
- *         pointer to configuration data read from a file or serial FLASH,
- *         or whatever you would like to do with it.  Every implementation
- *         should accept zero/NULL as a default configuration.
+ *         implementation without modification.  The argument has no meaning
+ *         to NuttX; the meaning of the argument is a contract between the
+ *         board-specific initialization logic and the matching application
+ *         logic.  The value could be such things as a mode enumeration
+ *         value, a set of DIP switch settings, a pointer to configuration
+ *         data read from a file or serial FLASH, or whatever you would like
+ *         to do with it.  Every implementation should accept zero/NULL as a
+ *         default configuration.
  *
  * Returned Value:
  *   Zero (OK) is returned on success; a negated errno value is returned on
