@@ -119,7 +119,7 @@
 
 #include <arch/irq.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "sam_gpio.h"
 #include "hardware/sam_pmc.h"
 #include "hardware/sam_smc.h"
