@@ -117,7 +117,7 @@
 #include <arch/irq.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "sam_gpio.h"
 #include "sam_periphclks.h"
 #include "hardware/sam_pmc.h"
