@@ -31,8 +31,7 @@
 #include <nuttx/video/fb.h>
 #include <nuttx/video/ov2640.h>
 
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "sam_periphclks.h"
 #include "sam_lcd.h"
 #include "sam_pck.h"
