@@ -32,7 +32,7 @@
 #include <nuttx/usb/usbdev.h>
 #include <nuttx/usb/usbdev_trace.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "sam_gpio.h"
 #include "same70-xplained.h"
 
@@ -52,7 +52,7 @@
  * Name:  sam_usbinitialize
  *
  * Description:
- *   Called from stm32_boardinitialize very early in initialization to setup
+ *   Called from sam_boardinitialize very early in initialization to setup
  *   USB-related GPIO pins for the SAME70-XPLD board.
  *
  ****************************************************************************/
