@@ -38,7 +38,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "sam_gpio.h"
 #include "sam_twihs.h"
 #include "sam_ssc.h"
