@@ -35,7 +35,7 @@
 #include <nuttx/wireless/nrf24l01.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "stm32.h"
 #include "stm32_nrf24l01.h"
