@@ -32,8 +32,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "arm_arch.h"
-
+#include "arm_internal.h"
 #include "stm32_gpio.h"
 #include "stm32.h"
 #include "fire-stm32v2.h"
