@@ -220,7 +220,7 @@ int board_app_initialize(uintptr_t arg)
           const char *partstring = CONFIG_MIKROE_FLASH_PART_LIST;
           const char *ptr;
           FAR struct mtd_dev_s *mtd_part;
-          char  partname[4];
+          char  partname[16];
 
           /* Now create a partition on the FLASH device */
 
@@ -254,7 +254,7 @@ int board_app_initialize(uintptr_t arg)
                    */
 
   #if defined(CONFIG_MTD_SMART) && defined(CONFIG_FS_SMARTFS)
-                  sprintf(partname, "p%d", partno);
+                  snprintf(partname, sizeof(partname), "p%d", partno);
                   smart_initialize(CONFIG_MIKROE_FLASH_MINOR, mtd_part,
                                    partname);
 #endif
