@@ -96,7 +96,7 @@ void board_late_initialize(void)
    * user-space but the initialization function must run in kernel space.
    */
 
-#if defined(CONFIG_NSH_LIBRARY) && !defined(CONFIG_LIB_BOARDCTL)
+#if defined(CONFIG_NSH_LIBRARY) && !defined(CONFIG_BOARDCTL)
   board_app_initialize(0);
 #endif
 }
