@@ -60,7 +60,7 @@
 #include <arch/board/board.h>
 #include <nuttx/power/pm.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "stm32.h"
 #include "stm3210e-eval.h"
 
