@@ -35,7 +35,7 @@
 
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "stm32f429i-disco.h"
 #include "stm32_ltdc.h"
 
