@@ -33,7 +33,7 @@
 #include <nuttx/spinlock.h>
 #include <nuttx/wireless/gs2200m.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "stm32.h"
 
@@ -107,7 +107,7 @@ static void gs2200m_irq_enable(void)
   irqstate_t flags = spin_lock_irqsave(NULL);
   uint32_t dready = 0;
 
-  wlinfo("== ec:%" PRId32 " called=%" PRId32 " \n",
+  wlinfo("== ec:%" PRId32 " called=%" PRId32 "\n",
          _enable_count, _n_called++);
 
   if (0 == _enable_count)
@@ -130,7 +130,7 @@ static void gs2200m_irq_enable(void)
     {
       /* Call g_irq_handler directly */
 
-      wlinfo("== ** call irq handler ** \n");
+      wlinfo("== ** call irq handler **\n");
       g_irq_handler(0, NULL, g_irq_arg);
     }
 }
@@ -143,7 +143,7 @@ static void gs2200m_irq_disable(void)
 {
   irqstate_t flags = spin_lock_irqsave(NULL);
 
-  wlinfo("== ec:%" PRId32 " called=%" PRId32 " \n",
+  wlinfo("== ec:%" PRId32 " called=%" PRId32 "\n",
          _enable_count, _n_called++);
 
   _enable_count--;
