@@ -24,9 +24,6 @@
 
 #include <nuttx/config.h>
 
-#include <nuttx/board.h>
-#include <nuttx/power/pm.h>
-
 #include "arm_internal.h"
 #include "stm32_pm.h"
 #include "stm32f4discovery.h"
@@ -57,10 +54,6 @@
 
 void arm_pminitialize(void)
 {
-  /* Then initialize the NuttX power management subsystem proper */
-
-  pm_initialize();
-
 #if defined(CONFIG_ARCH_IDLE_CUSTOM) && defined(CONFIG_PM_BUTTONS)
   /* Initialize the buttons to wake up the system from low power modes */
 
