@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_H
-#define __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_H
+#ifndef __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_VIEWTOOL_STM32F107_H
+#define __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_VIEWTOOL_STM32F107_H
 
 /****************************************************************************
  * Included Files
@@ -442,7 +442,7 @@ int stm32_sdinitialize(int minor);
  *
  ****************************************************************************/
 
-#ifdef CONFIG_CAN
+#ifdef CONFIG_STM32_CAN_CHARDRIVER
 int stm32_can_setup(void);
 #endif
 
@@ -505,4 +505,4 @@ int stm32_max3421e_setup(void);
 #endif
 
 #endif /* __ASSEMBLY__ */
-#endif /* __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_H */
+#endif /* __BOARDS_ARM_STM32_VIEWTOOL_STM32F107_SRC_VIEWTOOL_STM32F107_H */
