@@ -33,7 +33,7 @@
 #include <nuttx/wireless/nrf24l01.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "stm32.h"
 #include "nucleo-h743zi.h"
