@@ -1,37 +1,20 @@
 /****************************************************************************
  * boards/arm/stm32l4/nucleo-l496zg/include/board.h
  *
- *   Copyright (C) 2016, 2019 Gregory Nutt. All rights reserved.
- *   Authors: Gregory Nutt <gnutt@nuttx.org>
- *            Mark Olsson <post@markolsson.se>
- *            David Sidrane <david_s5@nscdg.com>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -148,7 +131,6 @@
 
 #define STM32L4_RCC_CFGR_HPRE     RCC_CFGR_HPRE_SYSCLK      /* HCLK  = SYSCLK / 1 */
 #define STM32L4_HCLK_FREQUENCY    STM32L4_SYSCLK_FREQUENCY
-#define STM32L4_BOARD_HCLK        STM32L4_HCLK_FREQUENCY    /* Same as above, to satisfy compiler */
 
 /* APB1 clock (PCLK1) is HCLK/1 (80MHz) */
 
@@ -259,7 +241,6 @@
 
 #define STM32L4_RCC_CFGR_HPRE     RCC_CFGR_HPRE_SYSCLK      /* HCLK  = SYSCLK / 1 */
 #define STM32L4_HCLK_FREQUENCY    STM32L4_SYSCLK_FREQUENCY
-#define STM32L4_BOARD_HCLK        STM32L4_HCLK_FREQUENCY    /* Same as above, to satisfy compiler */
 
 /* APB1 clock (PCLK1) is HCLK/1 (80MHz) */
 
@@ -371,7 +352,6 @@
 
 #define STM32L4_RCC_CFGR_HPRE     RCC_CFGR_HPRE_SYSCLK      /* HCLK  = SYSCLK / 1 */
 #define STM32L4_HCLK_FREQUENCY    STM32L4_SYSCLK_FREQUENCY
-#define STM32L4_BOARD_HCLK        STM32L4_HCLK_FREQUENCY    /* Same as above, to satisfy compiler */
 
 /* APB1 clock (PCLK1) is HCLK/1 (80MHz) */
 
@@ -570,20 +550,20 @@
 
 /* Alternate function pin selections ****************************************/
 
-#define GPIO_USART2_TX        GPIO_USART2_TX_2
-#define GPIO_USART2_RX        GPIO_USART2_RX_2
-#define GPIO_USART3_TX        GPIO_USART3_TX_2
-#define GPIO_USART3_RX        GPIO_USART3_RX_2
+#define GPIO_USART2_TX     GPIO_USART2_TX_2
+#define GPIO_USART2_RX     GPIO_USART2_RX_2
+#define GPIO_USART3_TX     GPIO_USART3_TX_2
+#define GPIO_USART3_RX     GPIO_USART3_RX_2
 
 #if defined(CONFIG_NUCLEO_CONSOLE_ARDUINO)
 /* USART6:
  *
- * These configurations assume that you are using a standard Arduio RS-232
+ * These configurations assume that you are using a standard Arduino RS-232
  * shield with the serial interface with RX on pin D0 and TX on pin D1:
  *
  *   -------- ---------------
- *               STM32F7
- *   ARDUIONO FUNCTION  GPIO
+ *               STM32L4
+ *   ARDUINO  FUNCTION  GPIO
  *   -- ----- --------- -----
  *   DO RX    USART6_RX PG9
  *   D1 TX    USART6_TX PG14
@@ -598,17 +578,10 @@
  * Use  USART3 and the USB virtual COM port
  */
 
-#if defined(CONFIG_NUCLEO_CONSOLE_VIRTUAL)
-/* LPUART1 is connector to Virtual COM port PG6 and PG7,
- * but there is no lpserial.
- */
+/* LPUART1 is connector to Virtual COM port PG6 and PG7. */
 
-/* #define GPIO_USART2_TX        GPIO_LPUART1_TX_3 */
-
-/* #define GPIO_USART2_RX        GPIO_LPUART1_RX_3 */
-
-#  error "No Nucleo virtual console before lpserial is unimplemented"
-#endif
+#define GPIO_LPUART1_TX    GPIO_LPUART1_TX_3
+#define GPIO_LPUART1_RX    GPIO_LPUART1_RX_3
 
 /* DMA channels *************************************************************/
 
