@@ -26,7 +26,6 @@
 
 #include <sys/types.h>
 #include <stdio.h>
-#include <syslog.h>
 #include <errno.h>
 #include <debug.h>
 #include <string.h>
@@ -101,7 +100,7 @@ static struct i2c_master_s *g_i2c3;
  *
  ****************************************************************************/
 
-#ifdef CONFIG_LIB_BOARDCTL
+#ifdef CONFIG_BOARDCTL
 int board_app_initialize(uintptr_t arg)
 {
 #ifdef HAVE_RTC_DRIVER
@@ -211,7 +210,7 @@ int board_app_initialize(uintptr_t arg)
 
   return ret;
 }
-#endif /* CONFIG_LIB_BOARDCTL */
+#endif /* CONFIG_BOARDCTL */
 
 #ifdef CONFIG_BOARDCTL_IOCTL
 int board_ioctl(unsigned int cmd, uintptr_t arg)
