@@ -31,7 +31,7 @@
 #include <nuttx/spi/spi.h>
 #include <arch/board/board.h>
 
-#include "arm_arch.h"
+#include "arm_internal.h"
 #include "chip.h"
 #include "tms570_spi.h"
 #include "tms570ls31x_usb_kit.h"
