@@ -54,7 +54,7 @@
 #  include <nuttx/spinlock.h>
 #endif
 
-#if defined(CONFIG_BUILD_PROTECTED) && defined(CONFIG_FS_BINFS)
+#if defined(CONFIG_BUILD_PROTECTED) && defined(CONFIG_BUILTIN)
 #  include <nuttx/lib/builtin.h>
 #endif
 
@@ -592,13 +592,13 @@ int boardctl(unsigned int cmd, uintptr_t arg)
        * ARG:           A pointer to an instance of struct boardioc_builtin_s
        * CONFIGURATION: This BOARDIOC command is always available when
        *                CONFIG_BUILTIN is enabled, but does nothing unless
-       *                CONFIG_BUILD_KERNEL and CONFIG_FS_BINFS are selected.
+       *                CONFIG_BUILD_KERNEL is selected.
        * DEPENDENCIES:  None
        */
 
       case BOARDIOC_BUILTINS:
         {
-#if defined(CONFIG_BUILD_PROTECTED) && defined(CONFIG_FS_BINFS)
+#if defined(CONFIG_BUILD_PROTECTED)
           FAR const struct boardioc_builtin_s *builtin =
             (FAR const struct boardioc_builtin_s *)arg;
 
@@ -657,7 +657,7 @@ int boardctl(unsigned int cmd, uintptr_t arg)
        * ARG:           A reference readable instance of struct
        *                boardioc_vncstart_s
        * CONFIGURATION: CONFIG_VNCSERVER
-       * DEPENDENCIES:  VNC server provides vnc_default_fbinitialize()
+       * DEPENDENCIES:  VNC server provides nx_vnc_fbinitialize()
        */
 
       case BOARDIOC_VNC_START:
@@ -673,7 +673,7 @@ int boardctl(unsigned int cmd, uintptr_t arg)
             {
               /* Setup the VNC server to support keyboard/mouse inputs */
 
-              ret = vnc_default_fbinitialize(vnc->display, vnc->handle);
+              ret = nx_vnc_fbinitialize(vnc->display, vnc->handle);
             }
         }
         break;
