@@ -40,9 +40,7 @@
 #include <nuttx/semaphore.h>
 
 #include <arch/board/board.h>
-#include "mips_arch.h"
 #include "mips_internal.h"
-
 #include "pic32mx.h"
 #include "pic32mx_adc.h"
 #include "pic32mx_ioport.h"
@@ -246,10 +244,13 @@ static const struct file_operations tc_fops =
   tc_open,    /* open */
   tc_close,   /* close */
   tc_read,    /* read */
-  0,          /* write */
-  0,          /* seek */
+  NULL,       /* write */
+  NULL,       /* seek */
   tc_ioctl,   /* ioctl */
   tc_poll     /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL      /* unlink */
+#endif
 };
 
 /* If only a single touchscreen device is supported, then the driver state
