@@ -33,8 +33,7 @@
 #include <arch/board/board.h>
 
 #include "chip.h"
-#include "mips_arch.h"
-
+#include "mips_internal.h"
 #include "pic32mx.h"
 #include "pic32mx_ioport.h"
 #include "pic32mx_adc.h"
