@@ -101,15 +101,6 @@ int esp32_bringup(void);
 
 int esp32_mmcsd_initialize(int minor);
 
-/****************************************************************************
- * Name: esp32_spiflash_init
- *
- * Description:
- *   Initialize the SPIFLASH and register the MTD device.
- ****************************************************************************/
-
-int esp32_spiflash_init(void);
-
 /****************************************************************************
  * Name: esp32_gpio_init
  ****************************************************************************/
@@ -118,6 +109,18 @@ int esp32_spiflash_init(void);
 int esp32_gpio_init(void);
 #endif
 
+/****************************************************************************
+ * Name: esp32_ledc_setup
+ *
+ * Description:
+ *   Initialize LEDC PWM and register the PWM device.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_ESP32_LEDC
+int esp32_pwm_setup(void);
+#endif
+
 /****************************************************************************
  * Name: board_spidev_initialize
  *
