@@ -326,6 +326,7 @@ static int gpint_enable(FAR struct gpio_dev_s *dev, bool enable)
 
 int esp32_gpio_init(void)
 {
+  int pincount = 0;
   int i;
 
 #if BOARD_NGPIOOUT > 0
@@ -336,7 +337,7 @@ int esp32_gpio_init(void)
       g_gpout[i].gpio.gp_pintype = GPIO_OUTPUT_PIN;
       g_gpout[i].gpio.gp_ops     = &gpout_ops;
       g_gpout[i].id              = i;
-      gpio_pin_register(&g_gpout[i].gpio, i);
+      gpio_pin_register(&g_gpout[i].gpio, pincount);
 
       /* Configure the pins that will be used as output */
 
@@ -344,6 +345,8 @@ int esp32_gpio_init(void)
       esp32_configgpio(g_gpiooutputs[i], OUTPUT_FUNCTION_3 |
                        INPUT_FUNCTION_3);
       esp32_gpiowrite(g_gpiooutputs[i], 0);
+
+      pincount++;
     }
 #endif
 
@@ -355,11 +358,13 @@ int esp32_gpio_init(void)
       g_gpin[i].gpio.gp_pintype = GPIO_INPUT_PIN;
       g_gpin[i].gpio.gp_ops     = &gpin_ops;
       g_gpin[i].id              = i;
-      gpio_pin_register(&g_gpin[i].gpio, i);
+      gpio_pin_register(&g_gpin[i].gpio, pincount);
 
       /* Configure the pins that will be used as INPUT */
 
       esp32_configgpio(g_gpioinputs[i], INPUT_FUNCTION_3);
+
+      pincount++;
     }
 #endif
 
@@ -371,11 +376,13 @@ int esp32_gpio_init(void)
       g_gpint[i].esp32gpio.gpio.gp_pintype = GPIO_INTERRUPT_PIN;
       g_gpint[i].esp32gpio.gpio.gp_ops     = &gpint_ops;
       g_gpint[i].esp32gpio.id              = i;
-      gpio_pin_register(&g_gpint[i].esp32gpio.gpio, i);
+      gpio_pin_register(&g_gpint[i].esp32gpio.gpio, pincount);
 
       /* Configure the pins that will be used as interrupt input */
 
       esp32_configgpio(g_gpiointinputs[i], INPUT_FUNCTION_3 | PULLDOWN);
+
+      pincount++;
     }
 #endif
 
