@@ -23,6 +23,10 @@
  ****************************************************************************/
 
 #include <nuttx/config.h>
+
+#include <assert.h>
+#include <debug.h>
+
 #include <nuttx/audio/audio.h>
 #include <nuttx/audio/i2s.h>
 #include <nuttx/kmalloc.h>
