@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <string.h>
+#include <assert.h>
 #include <errno.h>
 #include <fixedmath.h>
 #include <queue.h>
@@ -46,7 +47,6 @@
 #include <nuttx/audio/i2s.h>
 #include <nuttx/audio/audio.h>
 #include <nuttx/audio/cs4344.h>
-#include <nuttx/lib/math.h>
 
 #include "cs4344.h"
 
