@@ -239,6 +239,9 @@ static const struct file_operations ee24xx_fops =
   ee24xx_seek,  /* seek */
   ee24xx_ioctl, /* ioctl */
   NULL          /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL        /* unlink */
+#endif
 };
 
 #ifdef CONFIG_AT24CS_UUID
@@ -251,6 +254,9 @@ static const struct file_operations at24cs_uuid_fops =
   NULL,             /* seek */
   NULL,             /* ioctl */
   NULL              /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL            /* unlink */
+#endif
 };
 #endif
 
