@@ -276,6 +276,9 @@ static const struct file_operations ee25xx_fops =
   ee25xx_seek,  /* seek */
   ee25xx_ioctl, /* ioctl */
   NULL          /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL        /* unlink */
+#endif
 };
 
 /****************************************************************************
