@@ -119,10 +119,13 @@ static const struct file_operations ads7843e_fops =
   ads7843e_open,    /* open */
   ads7843e_close,   /* close */
   ads7843e_read,    /* read */
-  0,                /* write */
-  0,                /* seek */
+  NULL,             /* write */
+  NULL,             /* seek */
   ads7843e_ioctl,   /* ioctl */
   ads7843e_poll     /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL            /* unlink */
+#endif
 };
 
 /* If only a single ADS7843E device is supported, then the driver state
@@ -1216,6 +1219,7 @@ int ads7843e_register(FAR struct spi_dev_s *spi,
    */
 
 #ifdef CONFIG_ADS7843E_MULTIPLE
+  flags = enter_critical_section();
   priv->flink    = g_ads7843elist;
   g_ads7843elist = priv;
   leave_critical_section(flags);
