@@ -276,10 +276,13 @@ static const struct file_operations mxt_fops =
   mxt_open,    /* open */
   mxt_close,   /* close */
   mxt_read,    /* read */
-  0,           /* write */
-  0,           /* seek */
+  NULL,        /* write */
+  NULL,        /* seek */
   mxt_ioctl,   /* ioctl */
   mxt_poll     /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL       /* unlink */
+#endif
 };
 
 /****************************************************************************
