@@ -123,9 +123,9 @@ static const struct file_operations g_pcf8574_lcd_fops =
   pcf8574_lcd_write,            /* write */
   pcf8574_lcd_seek,             /* seek */
   pcf8574_lcd_ioctl,            /* ioctl */
-  pcf8574lcd_poll,              /* poll */
+  pcf8574lcd_poll               /* poll */
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  pcf8574_lcd_unlink            /* unlink */
+  , pcf8574_lcd_unlink          /* unlink */
 #endif
 };
 
