@@ -42,6 +42,10 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
+#ifndef MIN
+#  define MIN(a, b) (((a) < (b)) ? (a) : (b))
+#endif
+
 /* Configuration ************************************************************/
 
 #ifndef CONFIG_FILEMTD_BLOCKSIZE
@@ -131,7 +135,8 @@ static ssize_t filemtd_write(FAR struct file_dev_s *priv, size_t offset,
   FAR const uint8_t *pin  = (FAR const uint8_t *)src;
   FAR uint8_t       *pout;
   char               buf[128];
-  int                buflen = 0;
+  int                buflen;
+  int                remain;
   uint8_t            oldvalue;
   uint8_t            srcvalue;
   uint8_t            newvalue;
@@ -141,15 +146,16 @@ static ssize_t filemtd_write(FAR struct file_dev_s *priv, size_t offset,
 
   seekpos = priv->offset + offset;
 
-  while (len-- > 0)
+  for (buflen = 0; len > 0; len--)
     {
       if (buflen == 0)
         {
           /* Read more data from the file */
 
           file_seek(&priv->mtdfile, seekpos, SEEK_SET);
-          buflen = file_read(&priv->mtdfile, buf, sizeof(buf));
+          buflen = file_read(&priv->mtdfile, buf, MIN(len, sizeof(buf)));
           pout   = (FAR uint8_t *) buf;
+          remain = buflen;
         }
 
       /* Get the source and destination values */
@@ -182,17 +188,18 @@ static ssize_t filemtd_write(FAR struct file_dev_s *priv, size_t offset,
       /* Write the modified value to simulated FLASH */
 
       *pout++ = newvalue;
-      buflen--;
+      remain--;
 
       /* If our buffer is full, then seek back to beginning of
        * the file and write the buffer contents
        */
 
-      if (buflen == 0)
+      if (remain == 0)
         {
           file_seek(&priv->mtdfile, seekpos, SEEK_SET);
-          file_write(&priv->mtdfile, buf, sizeof(buf));
-          seekpos += sizeof(buf);
+          file_write(&priv->mtdfile, buf, buflen);
+          seekpos += buflen;
+          buflen = 0;
         }
     }
 
@@ -201,7 +208,7 @@ static ssize_t filemtd_write(FAR struct file_dev_s *priv, size_t offset,
   if (buflen != 0)
     {
       file_seek(&priv->mtdfile, seekpos, SEEK_SET);
-      file_write(&priv->mtdfile, buf, sizeof(buf));
+      file_write(&priv->mtdfile, buf, buflen);
     }
 
   return len;
@@ -252,8 +259,8 @@ static int filemtd_erase(FAR struct mtd_dev_s *dev, off_t startblock,
    * in logical block numbers
    */
 
-  startblock *= FILEMTD_BLKPER;
-  nblocks    *= FILEMTD_BLKPER;
+  startblock *= (priv->erasesize / priv->blocksize);
+  nblocks    *= (priv->erasesize / priv->blocksize);
 
   /* Get the offset corresponding to the first block and the size
    * corresponding to the number of blocks.
@@ -266,10 +273,10 @@ static int filemtd_erase(FAR struct mtd_dev_s *dev, off_t startblock,
 
   file_seek(&priv->mtdfile, priv->offset + offset, SEEK_SET);
   memset(buffer, CONFIG_FILEMTD_ERASESTATE, sizeof(buffer));
-  while (nbytes)
+  while (nbytes > 0)
     {
-      file_write(&priv->mtdfile, buffer, sizeof(buffer));
-      nbytes -= sizeof(buffer);
+      file_write(&priv->mtdfile, buffer, MIN(nbytes, sizeof(buffer)));
+      nbytes -= MIN(nbytes, sizeof(buffer));
     }
 
   return OK;
@@ -291,7 +298,7 @@ static ssize_t filemtd_bread(FAR struct mtd_dev_s *dev, off_t startblock,
 
   /* Don't let the read exceed the original size of the file */
 
-  maxblock = priv->nblocks * FILEMTD_BLKPER;
+  maxblock = priv->nblocks * (priv->erasesize / priv->blocksize);
   if (startblock >= maxblock)
     {
       return 0;
@@ -331,7 +338,7 @@ static ssize_t filemtd_bwrite(FAR struct mtd_dev_s *dev, off_t startblock,
 
   /* Don't let the write exceed the original size of the file */
 
-  maxblock = priv->nblocks * FILEMTD_BLKPER;
+  maxblock = priv->nblocks * (priv->erasesize / priv->blocksize);
   if (startblock >= maxblock)
     {
       return 0;
@@ -363,16 +370,23 @@ static ssize_t filemtd_byteread(FAR struct mtd_dev_s *dev, off_t offset,
                                 size_t nbytes, FAR uint8_t *buf)
 {
   FAR struct file_dev_s *priv = (FAR struct file_dev_s *)dev;
+  off_t maxoffset;
 
   DEBUGASSERT(dev && buf);
 
-  /* Don't let read read past end of buffer */
+  /* Don't let the read exceed the original size of the file */
 
-  if (offset + nbytes > priv->nblocks * priv->erasesize)
+  maxoffset = priv->nblocks * priv->erasesize;
+  if (offset >= maxoffset)
     {
       return 0;
     }
 
+  if (offset + nbytes > maxoffset)
+    {
+      nbytes = maxoffset - offset;
+    }
+
   filemtd_read(priv, buf, offset, nbytes);
   return nbytes;
 }
@@ -398,6 +412,11 @@ static ssize_t file_bytewrite(FAR struct mtd_dev_s *dev, off_t offset,
       return 0;
     }
 
+  if (offset + nbytes > maxoffset)
+    {
+      nbytes = maxoffset - offset;
+    }
+
   /* Then write the data to the file */
 
   filemtd_write(priv, offset, buf, nbytes);
@@ -456,8 +475,7 @@ static int filemtd_ioctl(FAR struct mtd_dev_s *dev, int cmd,
         {
           /* Erase the entire device */
 
-          filemtd_erase(dev, 0, priv->nblocks);
-          ret = OK;
+          ret = filemtd_erase(dev, 0, priv->nblocks);
         }
         break;
 
@@ -550,6 +568,15 @@ FAR struct mtd_dev_s *blockmtd_initialize(FAR const char *path,
       priv->erasesize = erasesize;
     }
 
+  if ((priv->erasesize / priv->blocksize) * priv->blocksize
+      != priv->erasesize)
+    {
+      ferr("ERROR: erasesize must be an even multiple of sectsize\n");
+      file_close(&priv->mtdfile);
+      kmm_free(priv);
+      return NULL;
+    }
+
   /* Force the size to be an even number of the erase block size */
 
   nblocks = mtdlen / priv->erasesize;
