@@ -97,18 +97,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-/* Debug ********************************************************************/
-
-#ifdef CONFIG_DEBUG_BQ2429X
-#  define baterr  _err
-#  define batdbg  _info
-#  define batinfo _info
-#else
-#  define baterr  _none
-#  define batdbg  _none
-#  define batinfo _none
-#endif
-
 /****************************************************************************
  * Private
  ****************************************************************************/
@@ -259,7 +247,7 @@ static int bq2429x_putreg8(FAR struct bq2429x_dev_s *priv, uint8_t regaddr,
   config.address   = priv->addr;
   config.addrlen   = 7;
 
-  batdbg("addr: %02x regval: %08x\n", regaddr, regval);
+  batinfo("addr: %02x regval: %08x\n", regaddr, regval);
 
   /* Set up a message to send */
 
@@ -278,28 +266,28 @@ static int (bq2429x_dump_regs) (FAR struct bq2429x_dev_s * priv)
   uint8_t value = 0;
 
   ret  = bq2429x_getreg8(priv, BQ2429X_REG00, &value, 1);
-  batdbg("REG#0: 0x%08X\n", value);
+  batinfo("REG#0: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG01, &value, 1);
-  batdbg("REG#1: 0x%08X\n", value);
+  batinfo("REG#1: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG02, &value, 1);
-  batdbg("REG#2: 0x%08X\n", value);
+  batinfo("REG#2: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG03, &value, 1);
-  batdbg("REG#3: 0x%08X\n", value);
+  batinfo("REG#3: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG04, &value, 1);
-  batdbg("REG#4: 0x%08X\n", value);
+  batinfo("REG#4: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG05, &value, 1);
-  batdbg("REG#5: 0x%08X\n", value);
+  batinfo("REG#5: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG06, &value, 1);
-  batdbg("REG#6: 0x%08X\n", value);
+  batinfo("REG#6: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG07, &value, 1);
-  batdbg("REG#7: 0x%08X\n", value);
+  batinfo("REG#7: 0x%08X\n", value);
   ret |= bq2429x_getreg8(priv, BQ2429X_REG08, &value, 1);
-  batdbg("REG#8: 0x%08X\n", value);
+  batinfo("REG#8: 0x%08X\n", value);
 
   /* Not reading fault register. */
 
   ret |= bq2429x_getreg8(priv, BQ2429X_REG0A, &value, 1);
-  batdbg("REG#10: 0x%08X\n", value);
+  batinfo("REG#10: 0x%08X\n", value);
 
   return ret;
 }
@@ -415,7 +403,7 @@ static int bq2429x_sysoff(FAR struct bq2429x_dev_s *priv)
   uint8_t value = 0;
 
   ret = bq2429x_getreg8(priv, BQ2429X_REG07, &value, 1);
-  batdbg("REG7 read value: 0x%08X\n", value);
+  batinfo("REG7 read value: 0x%08X\n", value);
   value |= BQ2429XR7_BATFET_DISABLE;
   ret |= bq2429x_putreg8(priv, BQ2429X_REG07, value);
 
@@ -436,7 +424,7 @@ static int bq2429x_syson(FAR struct bq2429x_dev_s *priv)
   uint8_t value = 0;
 
   ret = bq2429x_getreg8(priv, BQ2429X_REG07, &value, 1);
-  batdbg("REG7 read value: 0x%08X\n", value);
+  batinfo("REG7 read value: 0x%08X\n", value);
   value &= ~BQ2429XR7_BATFET_DISABLE;
   ret |= bq2429x_putreg8(priv, BQ2429X_REG07, value);
 
@@ -464,7 +452,7 @@ static int bq2429x_en_term(FAR struct bq2429x_dev_s *priv, bool state)
       return ret;
     }
 
-  batdbg("en_term: REG05 %02X EN_TERM=%d\n",
+  batinfo("en_term: REG05 %02X EN_TERM=%d\n",
          regval, !!(regval & BQ2429XR5_EN_TERM));
 
   /* Clear previous and set new value */
@@ -509,8 +497,8 @@ static int bq2429x_en_hiz(FAR struct bq2429x_dev_s *priv, bool state)
       return ret;
     }
 
-  batdbg("en_hiz: REG00 %02X EN_HIZ=%d\n",
-         regval, !!(regval & BQ2429XR1_EN_HIZ));
+  batinfo("en_hiz: REG00 %02X EN_HIZ=%d\n",
+          regval, !!(regval & BQ2429XR1_EN_HIZ));
 
   /* Clear previous and set new value */
 
@@ -553,8 +541,9 @@ static int bq2429x_en_stat(FAR struct bq2429x_dev_s *priv, bool state)
       return ret;
     }
 
-  batdbg("int stat: REG07 %02X INT_MASK1=%d INT_MASK0=%d\n", regval,
-         !!(regval & BQ2429XR7_INT_MASK1), !!(regval & BQ2429XR7_INT_MASK0));
+  batinfo("int stat: REG07 %02X INT_MASK1=%d INT_MASK0=%d\n", regval,
+          !!(regval & BQ2429XR7_INT_MASK1),
+          !!(regval & BQ2429XR7_INT_MASK0));
 
   /* We always set or clear both interrupts together. */
 
@@ -621,8 +610,8 @@ static int bq2429x_setboost_otg_config(FAR struct bq2429x_dev_s *priv,
     }
 
 #define BST_CONFIG_MASK (BQ2429XR1_CHG_CONFIG | BQ2429XR1_OTG_CONFIG)
-  batdbg("otg_config: REG01 %02X Boost=%d\n", regval,
-      ((BQ2429XR1_OTG_CONFIG == (regval & BST_CONFIG_MASK)) ? 1 : 0));
+  batinfo("otg_config: REG01 %02X Boost=%d\n", regval,
+          ((BQ2429XR1_OTG_CONFIG == (regval & BST_CONFIG_MASK)) ? 1 : 0));
 
   return OK;
 }
