@@ -146,14 +146,6 @@
 
 #define MAX1407X_COMMAND_POR     0x5400
 
-/* Debug ********************************************************************/
-
-#ifdef CONFIG_DEBUG_MAX1704X
-#  define baterr  _err
-#else
-#  define baterr  _none
-#endif
-
 /****************************************************************************
  * Private
  ****************************************************************************/
