@@ -71,10 +71,14 @@
 
 enum pm_state_e pm_checkstate(int domain)
 {
-  DEBUGASSERT(domain >= 0 && domain < CONFIG_PM_NDOMAINS &&
-              g_pmglobals.governor->checkstate);
+  DEBUGASSERT(domain >= 0 && domain < CONFIG_PM_NDOMAINS);
 
-  return g_pmglobals.governor->checkstate(domain);
+  if (g_pmglobals.domain[domain].governor->checkstate)
+    {
+      return g_pmglobals.domain[domain].governor->checkstate(domain);
+    }
+
+  return PM_NORMAL;
 }
 
 #endif /* CONFIG_PM */
