@@ -18,50 +18,6 @@
  *
  ****************************************************************************/
 
-/* TODO:  O_NONBLOCK is not yet supported.  Currently, the source and sink
- * pipes are opened in blocking mode on both the slave and master so only
- * blocking behavior is supported.  This driver must be able to support
- * multiple slave as well as master clients that may have the PTY device
- * opened in blocking and non-blocking modes simultaneously.
- *
- * There are two different possible implementations under consideration:
- *
- * 1. Keep the pipes in blocking mode, but use a test based on FIONREAD (for
- *    the source pipe) or FIONSPACE (for the sink pipe) to determine if the
- *    read or write would block.  There is existing logic like this in
- *    pty_read() to handle the case of a single byte reads which must never
- *    block in any case:  Essentially, this logic uses FIONREAD to determine
- *    if there is anything to read before calling file_read().  Similar
- *    logic could be replicated for all read cases.
- *
- *    Analogous logic could be added for all writes using FIONSPACE to
- *    assure that there is sufficient free space in the sink pipe to write
- *    without blocking.  The write length could be adjusted, in necceary,
- *    to assure that there is no blocking.
- *
- *    Locking, perhaps via sched_lock(), would be required to assure the
- *    test via FIONREAD or FIONWRITE is atomic with respect to the
- *    file_read() or file_write() operation.
- *
- * 2. An alternative that appeals to me is to modify the contained source
- *    or sink pipe file structures before each file_read() or file_write()
- *    operation to assure that the O_NONBLOCK is set correctly when the
- *    pipe read or write operation is performed.  This might be done with
- *    file_fcntl() or directly into the source/sink file structure oflags
- *    mode settings.
- *
- *    This would require (1) the ability to lock each pipe individually,
- *    setting the blocking mode for the source or sink pipe to match the
- *    mode in the open flags of the PTY device file structure, and (2)
- *    logic to restore the default pipe mode after the file_read/write()
- *    operation and before the pipe is unlocked.
- *
- * There are existing locks to support (1) destruction of the driver
- * (pp_exclsem) and (2) slave PTY locking (pp_slavesem), as well as (3)
- * locks within the pipe implementation.  Care must be taken with any new
- * source/sink pipe locking to assure that deadlocks are not possible.
- */
-
 /****************************************************************************
  * Included Files
  ****************************************************************************/
@@ -91,10 +47,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-/* Should never be set... only for comparison to serial.c */
-
-#undef CONFIG_PSEUDOTERM_FULLBLOCKS
-
 /* Maximum number of threads than can be waiting for POLL events */
 
 #ifndef CONFIG_DEV_PTY_NPOLLWAITERS
@@ -120,14 +72,10 @@ struct pty_dev_s
   struct file pd_src;           /* Provides data to read() method (pipe output) */
   struct file pd_sink;          /* Accepts data from write() method (pipe input) */
   bool pd_master;               /* True: this is the master */
-
 #ifdef CONFIG_SERIAL_TERMIOS
-  /* Terminal control flags */
-
-  tcflag_t pd_iflag;            /* Terminal nput modes */
-  tcflag_t pd_oflag;            /* Terminal output modes */
+  tcflag_t pd_iflag;            /* Terminal input modes */
 #endif
-
+  tcflag_t pd_oflag;            /* Terminal output modes */
   struct pty_poll_s pd_poll[CONFIG_DEV_PTY_NPOLLWAITERS];
 };
 
@@ -138,12 +86,11 @@ struct pty_devpair_s
   struct pty_dev_s pp_master;   /* Maseter device */
   struct pty_dev_s pp_slave;    /* Slave device */
 
+  bool pp_susv1;                /* SUSv1 or BSD style */
   bool pp_locked;               /* Slave is locked */
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
   bool pp_unlinked;             /* File has been unlinked */
   uint8_t pp_minor;             /* Minor device number */
   uint16_t pp_nopen;            /* Open file count */
-#endif
   sem_t pp_slavesem;            /* Slave lock semaphore */
   sem_t pp_exclsem;             /* Mutual exclusion */
 };
@@ -153,14 +100,10 @@ struct pty_devpair_s
  ****************************************************************************/
 
 static int     pty_semtake(FAR struct pty_devpair_s *devpair);
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static void    pty_destroy(FAR struct pty_devpair_s *devpair);
-#endif
-
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+static int     pty_pipe(FAR struct pty_devpair_s *devpair);
 static int     pty_open(FAR struct file *filep);
 static int     pty_close(FAR struct file *filep);
-#endif
 static ssize_t pty_read(FAR struct file *filep, FAR char *buffer,
                  size_t buflen);
 static ssize_t pty_write(FAR struct file *filep, FAR const char *buffer,
@@ -178,13 +121,8 @@ static int     pty_unlink(FAR struct inode *inode);
 
 static const struct file_operations g_pty_fops =
 {
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
   pty_open,      /* open */
   pty_close,     /* close */
-#else
-  NULL,          /* open */
-  NULL,          /* close */
-#endif
   pty_read,      /* read */
   pty_write,     /* write */
   NULL,          /* seek */
@@ -218,53 +156,183 @@ static int pty_semtake(FAR struct pty_devpair_s *devpair)
  * Name: pty_destroy
  ****************************************************************************/
 
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static void pty_destroy(FAR struct pty_devpair_s *devpair)
 {
   char devname[16];
 
-  /* Un-register the slave device */
+  if (devpair->pp_susv1)
+    {
+      /* Free this minor number so that it can be reused */
+
+      ptmx_minor_free(devpair->pp_minor);
+
+      /* Un-register the slave device */
+
+      snprintf(devname, 16, "/dev/pts/%d", devpair->pp_minor);
+    }
+  else
+    {
+      /* Un-register the master device (/dev/ptyN may have already been
+       * unlinked).
+       */
+
+      snprintf(devname, 16, "/dev/pty%d", (int)devpair->pp_minor);
+      unregister_driver(devname);
+
+      /* Un-register the slave device */
+
+      snprintf(devname, 16, "/dev/ttyp%d", devpair->pp_minor);
+    }
 
-#ifdef CONFIG_PSEUDOTERM_BSD
-  snprintf(devname, 16, "/dev/ttyp%d", devpair->pp_minor);
-#else
-  snprintf(devname, 16, "/dev/pts/%d", devpair->pp_minor);
-#endif
   unregister_driver(devname);
 
-  /* Un-register the master device (/dev/ptyN may have already been
-   * unlinked).
-   */
-
-  snprintf(devname, 16, "/dev/pty%d", (int)devpair->pp_minor);
-  unregister_driver(devname);
-
-  /* Close the contained file structures */
-
-  file_close(&devpair->pp_master.pd_src);
-  file_close(&devpair->pp_master.pd_sink);
-  file_close(&devpair->pp_slave.pd_src);
-  file_close(&devpair->pp_slave.pd_sink);
-
-#ifdef CONFIG_PSEUDOTERM_SUSV1
-  /* Free this minor number so that it can be reused */
-
-  ptmx_minor_free(devpair->pp_minor);
-#endif
-
   /* And free the device structure */
 
   nxsem_destroy(&devpair->pp_exclsem);
+  nxsem_destroy(&devpair->pp_slavesem);
   kmm_free(devpair);
 }
-#endif
+
+/****************************************************************************
+ * Name: pty_pipe
+ ****************************************************************************/
+
+static int pty_pipe(FAR struct pty_devpair_s *devpair)
+{
+  FAR struct file *pipe_a[2];
+  FAR struct file *pipe_b[2];
+  int ret;
+
+  /* Create two pipes:
+   *
+   *   pipe_a:  Master source, slave sink (TX, slave-to-master)
+   *   pipe_b:  Master sink, slave source (RX, master-to-slave)
+   */
+
+  pipe_a[0] = &devpair->pp_master.pd_src;
+  pipe_a[1] = &devpair->pp_slave.pd_sink;
+
+  ret = file_pipe(pipe_a, CONFIG_PSEUDOTERM_TXBUFSIZE, 0);
+  if (ret < 0)
+    {
+      return ret;
+    }
+
+  pipe_b[0] = &devpair->pp_slave.pd_src;
+  pipe_b[1] = &devpair->pp_master.pd_sink;
+
+  ret = file_pipe(pipe_b, CONFIG_PSEUDOTERM_RXBUFSIZE, 0);
+  if (ret < 0)
+    {
+      file_close(pipe_a[0]);
+      file_close(pipe_a[1]);
+    }
+
+  return ret;
+}
 
 /****************************************************************************
  * Name: pty_open
  ****************************************************************************/
 
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
 static int pty_open(FAR struct file *filep)
+{
+  FAR struct inode *inode;
+  FAR struct pty_dev_s *dev;
+  FAR struct pty_devpair_s *devpair;
+  int ret = OK;
+
+  DEBUGASSERT(filep != NULL && filep->f_inode != NULL);
+  inode   = filep->f_inode;
+  dev     = inode->i_private;
+  DEBUGASSERT(dev != NULL && dev->pd_devpair != NULL);
+  devpair = dev->pd_devpair;
+
+  /* Get exclusive access to the device structure */
+
+  ret = pty_semtake(devpair);
+  if (ret < 0)
+    {
+      return ret;
+    }
+
+  /* Wait if this is an attempt to open the slave device and the slave
+   * device is locked.
+   */
+
+  if (!dev->pd_master)
+    {
+      /* Slave... Check if the slave driver is locked. */
+
+      while (devpair->pp_locked)
+        {
+          /* Release the exclusive access before wait */
+
+          pty_semgive(devpair);
+
+          /* Wait until unlocked.
+           * We will also most certainly suspend here.
+           */
+
+          ret = nxsem_wait(&devpair->pp_slavesem);
+          if (ret < 0)
+            {
+              return ret;
+            }
+
+          /* Restore the semaphore count */
+
+          DEBUGVERIFY(nxsem_post(&devpair->pp_slavesem));
+
+          /* Get exclusive access to the device structure.  This might also
+           * cause suspension.
+           */
+
+          ret = pty_semtake(devpair);
+          if (ret < 0)
+            {
+              return ret;
+            }
+        }
+    }
+
+  /* If one side of the driver has been unlinked, then refuse further
+   * opens.
+   */
+
+  if (devpair->pp_unlinked)
+    {
+      ret = -EIDRM;
+    }
+  else
+    {
+      /* First open? */
+
+      if (devpair->pp_nopen == 0)
+        {
+          /* Yes, create the internal pipe */
+
+          ret = pty_pipe(devpair);
+        }
+
+      /* Increment the count of open references on the driver */
+
+      if (ret >= 0)
+        {
+          devpair->pp_nopen++;
+          DEBUGASSERT(devpair->pp_nopen > 0);
+        }
+    }
+
+  pty_semgive(devpair);
+  return ret;
+}
+
+/****************************************************************************
+ * Name: pty_open
+ ****************************************************************************/
+
+static int pty_close(FAR struct file *filep)
 {
   FAR struct inode *inode;
   FAR struct pty_dev_s *dev;
@@ -277,115 +345,6 @@ static int pty_open(FAR struct file *filep)
   DEBUGASSERT(dev != NULL && dev->pd_devpair != NULL);
   devpair = dev->pd_devpair;
 
-  /* Wait if this is an attempt to open the slave device and the slave
-   * device is locked.
-   */
-
-  if (!dev->pd_master)
-    {
-      /* Slave... Check if the slave driver is locked.  We need to lock the
-       * scheduler while we are running to prevent asyncrhonous modification
-       * of pp_locked by pty_ioctl().
-       */
-
-      sched_lock();
-      while (devpair->pp_locked)
-        {
-          /* Wait until unlocked.
-           * We will also most certainly suspend here.
-           */
-
-          ret = nxsem_wait(&devpair->pp_slavesem);
-          if (ret < 0)
-            {
-              return ret;
-            }
-
-          /* Get exclusive access to the device structure.  This might also
-           * cause suspension.
-           */
-
-          ret = pty_semtake(devpair);
-          if (ret < 0)
-            {
-              return ret;
-            }
-
-          /* Check again in case something happened asynchronously while we
-           * were suspended.
-           */
-
-          if (devpair->pp_locked)
-            {
-              /* This cannot suspend because we have the scheduler locked.
-               * So pp_locked cannot change asyncrhonously between this test
-               * and the redundant test at the top of the loop.
-               */
-
-              pty_semgive(devpair);
-            }
-        }
-
-      sched_unlock();
-    }
-  else
-    {
-      /* Master ... Get exclusive access to the device structure */
-
-      ret = pty_semtake(devpair);
-      if (ret < 0)
-        {
-          goto errout_with_sem;
-        }
-    }
-
-#ifndef CONFIG_PSEUDOTERM_SUSV1
-  /* If one side of the driver has been unlinked, then refuse further
-   * opens.
-   *
-   * NOTE: We ignore this case in the SUSv1 case.  In the SUSv1 case, the
-   * master side is always unlinked.
-   */
-
-  if (devpair->pp_unlinked)
-    {
-      ret = -EIDRM;
-    }
-  else
-#endif
-    {
-      /* Increment the count of open references on the driver */
-
-      devpair->pp_nopen++;
-      DEBUGASSERT(devpair->pp_nopen > 0);
-
-      ret = OK;
-    }
-
-errout_with_sem:
-  pty_semgive(devpair);
-  return ret;
-}
-#endif
-
-/****************************************************************************
- * Name: pty_open
- ****************************************************************************/
-
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-static int pty_close(FAR struct file *filep)
-{
-  FAR struct inode *inode;
-  FAR struct pty_dev_s *dev;
-  FAR struct pty_devpair_s *devpair;
-  int ret;
-
-  DEBUGASSERT(filep != NULL && filep->f_inode != NULL);
-  inode     = filep->f_inode;
-  dev       = inode->i_private;
-  DEBUGASSERT(dev != NULL && dev->pd_devpair != NULL);
-  devpair   = dev->pd_devpair;
-
   /* Get exclusive access */
 
   ret = pty_semtake(devpair);
@@ -394,19 +353,27 @@ static int pty_close(FAR struct file *filep)
       return ret;
     }
 
-#ifdef CONFIG_PSEUDOTERM_SUSV1
-  /* Did the (single) master just close its reference? */
+  /* Check if the decremented inode reference count would go to zero */
 
-  if (dev->pd_master)
+  if (inode->i_crefs == 1)
     {
-      /* Yes, then we are essentially unlinked and when all of the
-       * slaves close there references, then the PTY should be
-       * destroyed.
-       */
+      /* Did the (single) master just close its reference? */
 
-      devpair->pp_unlinked = true;
+      if (dev->pd_master && devpair->pp_susv1)
+        {
+          /* Yes, then we are essentially unlinked and when all of the
+           * slaves close there references, then the PTY should be
+           * destroyed.
+           */
+
+          devpair->pp_unlinked = true;
+        }
+
+      /* Close the contained file structures */
+
+      file_close(&dev->pd_src);
+      file_close(&dev->pd_sink);
     }
-#endif
 
   /* Is this the last open reference?  If so, was the driver previously
    * unlinked?
@@ -430,7 +397,6 @@ static int pty_close(FAR struct file *filep)
   pty_semgive(devpair);
   return OK;
 }
-#endif
 
 /****************************************************************************
  * Name: pty_read
@@ -442,10 +408,9 @@ static ssize_t pty_read(FAR struct file *filep, FAR char *buffer, size_t len)
   FAR struct pty_dev_s *dev;
   ssize_t ntotal;
 #ifdef CONFIG_SERIAL_TERMIOS
-  ssize_t nread;
-  size_t i;
+  ssize_t i;
+  ssize_t j;
   char ch;
-  int ret;
 #endif
 
   DEBUGASSERT(filep != NULL && filep->f_inode != NULL);
@@ -467,129 +432,44 @@ static ssize_t pty_read(FAR struct file *filep, FAR char *buffer, size_t len)
 
   if (dev->pd_iflag & (INLCR | IGNCR | ICRNL))
     {
-      /* We will transfer one byte at a time, making the appropriate
-       * translations.
-       */
-
-      ntotal = 0;
-      for (i = 0; i < len; i++)
+      while ((ntotal = file_read(&dev->pd_src, buffer, len)) > 0)
         {
-#ifndef CONFIG_PSEUDOTERM_FULLBLOCKS
-          /* This logic should return if the pipe becomes empty after some
-           * bytes were read from the pipe.  If we have already read some
-           * data, we use the FIONREAD ioctl to test if there are more bytes
-           * in the pipe.
-           *
-           * REVISIT:  An alternative design might be to (1) configure the
-           * source file as non-blocking, then (2) wait using poll() for the
-           * first byte to be received.  (3) Subsequent bytes would
-           * use file_read() without polling and would (4) terminate when no
-           * data is returned.
-           */
-
-          if (ntotal > 0)
+          for (i = j = 0; i < ntotal; i++)
             {
-              int nsrc;
+              /* Perform input processing */
 
-              /* There are inherent race conditions in this test.  We lock
-               * the scheduler before the test and after the file_read()
-               * below to eliminate one race:  (a) We detect that there is
-               * data in the source file, (b) we are suspended and another
-               * thread reads the data, emptying the fifo, then (c) we
-               * resume and call file_read(), blocking indefinitely.
-               */
+              ch = buffer[i];
 
-              sched_lock();
+              /* \n -> \r or \r -> \n translation? */
 
-              /* Check how many bytes are waiting in the pipe */
-
-              ret = file_ioctl(&dev->pd_src, FIONREAD,
-                               (unsigned long)((uintptr_t)&nsrc));
-              if (ret < 0)
+              if (ch == '\n' && (dev->pd_iflag & INLCR) != 0)
                 {
-                  sched_unlock();
-                  ntotal = ret;
-                  break;
+                  ch = '\r';
+                }
+              else if (ch == '\r' && (dev->pd_iflag & ICRNL) != 0)
+                {
+                  ch = '\n';
                 }
 
-              /* Break out of the loop and return ntotal if the pipe is
-               * empty.  This is another race:  There fifo was empty when we
-               * called file_ioctl() above, but it might not be empty right
-               * now.  Losing that race should not lead to any bad behaviors,
-               * however, we the caller will get those bytes on the next
-               * read.
+              /* Discarding \r ?  Print character if (1) character is not \r
+               * or if (2) we were not asked to ignore \r.
                */
 
-              if (nsrc < 1)
+              if (ch != '\r' || (dev->pd_iflag & IGNCR) == 0)
                 {
-                  sched_unlock();
-                  break;
+                  buffer[j++] = ch;
                 }
-
-              /* Read one byte from the source the byte.  This should not
-               * block.
-               */
-
-              nread = file_read(&dev->pd_src, &ch, 1);
-              sched_unlock();
-            }
-          else
-#else
-          /* If we wanted to return full blocks of data, then file_read()
-           * may need to be called repeatedly.  That is because the pipe
-           * read() method will return early if the fifo becomes empty
-           * after any data has been read.
-           */
-
-# error Missing logic
-#endif
-            {
-              /* Read one byte from the source the byte.  This call will
-               * block if the source pipe is empty.
-               *
-               * REVISIT: Should not block if the oflags include O_NONBLOCK.
-               * How would we ripple the O_NONBLOCK characteristic to the
-               * contained source pipe?  file_fcntl()?  Or FIONREAD? See the
-               * TODO comment at the top of this file.
-               */
-
-              nread = file_read(&dev->pd_src, &ch, 1);
             }
 
-          /* Check if file_read was successful */
+          /* Is the buffer not empty after process? */
 
-          if (nread < 0)
+          if (j != 0)
             {
-              ntotal = nread;
+              /* Yes, we are done. */
+
+              ntotal = j;
               break;
             }
-
-          /* Perform input processing */
-
-          /* \n -> \r or \r -> \n translation? */
-
-          if (ch == '\n' && (dev->pd_iflag & INLCR) != 0)
-            {
-               ch = '\r';
-            }
-          else if (ch == '\r' && (dev->pd_iflag & ICRNL) != 0)
-            {
-              ch = '\n';
-            }
-
-          /* Discarding \r ?  Print character if (1) character is not \r or
-           * if (2) we were not asked to ignore \r.
-           */
-
-          if (ch != '\r' || (dev->pd_iflag & IGNCR) == 0)
-            {
-              /* Transfer the (possibly translated) character and update the
-               * count of bytes transferred.
-               */
-
-              *buffer++ = ch;
-              ntotal++;
-            }
         }
     }
   else
@@ -622,18 +502,15 @@ static ssize_t pty_write(FAR struct file *filep,
   FAR struct inode *inode;
   FAR struct pty_dev_s *dev;
   ssize_t ntotal;
-#ifdef CONFIG_SERIAL_TERMIOS
   ssize_t nwritten;
   size_t i;
   char ch;
-#endif
 
   DEBUGASSERT(filep != NULL && filep->f_inode != NULL);
   inode = filep->f_inode;
   dev   = inode->i_private;
   DEBUGASSERT(dev != NULL);
 
-#ifdef CONFIG_SERIAL_TERMIOS
   /* Do output post-processing */
 
   if ((dev->pd_oflag & OPOST) != 0)
@@ -708,7 +585,6 @@ static ssize_t pty_write(FAR struct file *filep,
         }
     }
   else
-#endif
     {
       /* Write the 'len' bytes to the sink pipe.  This will block until all
        * 'len' bytes have been written to the pipe.
@@ -762,9 +638,6 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
 
       case TIOCGPTN:    /* Get Pty Number (of pty-mux device): FAR int* */
         {
-#ifdef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-          ret = -ENOSYS;
-#else
           FAR int *ptyno = (FAR int *)((uintptr_t)arg);
           if (ptyno == NULL)
             {
@@ -772,10 +645,9 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
             }
           else
             {
-              *ptyno = (int)devpair->pp_minor;
+              *ptyno = devpair->pp_minor;
               ret = OK;
             }
-#endif
         }
         break;
 
@@ -783,35 +655,26 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
         {
           if (arg == 0)
             {
-               int sval;
+              if (devpair->pp_locked)
+                {
+                  /* Release any waiting threads */
 
-               /* Unlocking */
-
-               sched_lock();
-               devpair->pp_locked = false;
-
-               /* Release any waiting threads */
-
-               do
-                 {
-                   DEBUGVERIFY(nxsem_get_value(&devpair->pp_slavesem,
-                                               &sval));
-                   if (sval < 0)
-                     {
-                       nxsem_post(&devpair->pp_slavesem);
-                     }
-                 }
-               while (sval < 0);
-
-               sched_unlock();
-               ret = OK;
+                  ret = nxsem_post(&devpair->pp_slavesem);
+                  if (ret >= 0)
+                    {
+                      devpair->pp_locked = false;
+                    }
+                }
             }
-          else
+          else if (!devpair->pp_locked)
             {
               /* Locking */
 
-               devpair->pp_locked = true;
-               ret = OK;
+              ret = nxsem_wait(&devpair->pp_slavesem);
+              if (ret >= 0)
+                {
+                  devpair->pp_locked = true;
+                }
             }
         }
         break;
@@ -825,7 +688,7 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
             }
           else
             {
-              *ptr = (int)devpair->pp_locked;
+              *ptr = devpair->pp_locked;
               ret = OK;
             }
         }
@@ -891,6 +754,23 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
         }
         break;
 
+      case FIONBIO:
+        {
+          ret = file_ioctl(&dev->pd_src, cmd, arg);
+          if (ret >= 0 || ret == -ENOTTY)
+            {
+              ret = file_ioctl(&dev->pd_sink, cmd, arg);
+            }
+
+          /* Let the default handler set O_NONBLOCK flags for us. */
+
+          if (ret >= 0)
+            {
+              ret = -ENOTTY;
+            }
+        }
+        break;
+
       /* Any unrecognized IOCTL commands will be passed to the contained
        * pipe driver.
        *
@@ -909,7 +789,7 @@ static int pty_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
               ret = file_ioctl(&dev->pd_sink, cmd, arg);
             }
 #else
-          ret = ENOTTY;
+          ret = -ENOTTY;
 #endif
         }
         break;
@@ -1023,8 +903,8 @@ static int pty_unlink(FAR struct inode *inode)
   int ret;
 
   DEBUGASSERT(inode != NULL && inode->i_private != NULL);
-  dev       = inode->i_private;
-  devpair   = dev->pd_devpair;
+  dev     = inode->i_private;
+  devpair = dev->pd_devpair;
   DEBUGASSERT(dev->pd_devpair != NULL);
 
   /* Get exclusive access */
@@ -1059,7 +939,7 @@ static int pty_unlink(FAR struct inode *inode)
  ****************************************************************************/
 
 /****************************************************************************
- * Name: pty_register
+ * Name: pty_register2
  *
  * Description:
  *   Create and register PTY master and slave devices.  The slave side of
@@ -1068,6 +948,7 @@ static int pty_unlink(FAR struct inode *inode)
  *
  * Input Parameters:
  *   minor - The number that qualifies the naming of the created devices.
+ *   susv1 - select SUSv1 or BSD behaviour
  *
  * Returned Value:
  *   0 is returned on success; otherwise, the negative error code return
@@ -1075,11 +956,9 @@ static int pty_unlink(FAR struct inode *inode)
  *
  ****************************************************************************/
 
-int pty_register(int minor)
+int pty_register2(int minor, bool susv1)
 {
   FAR struct pty_devpair_s *devpair;
-  FAR struct file *pipe_a[2];
-  FAR struct file *pipe_b[2];
   char devname[16];
   int ret;
 
@@ -1102,65 +981,17 @@ int pty_register(int minor)
 
   nxsem_set_protocol(&devpair->pp_slavesem, SEM_PRIO_NONE);
 
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  devpair->pp_susv1             = susv1;
   devpair->pp_minor             = minor;
-#endif
   devpair->pp_locked            = true;
   devpair->pp_master.pd_devpair = devpair;
   devpair->pp_master.pd_master  = true;
   devpair->pp_slave.pd_devpair  = devpair;
-#ifdef CONFIG_SERIAL_TERMIOS
-  devpair->pp_slave.pd_iflag    = ISIG;
   devpair->pp_slave.pd_oflag    = OPOST | ONLCR;
-#endif
-
-  /* Create two pipes:
-   *
-   *   pipe_a:  Master source, slave sink (TX, slave-to-master)
-   *   pipe_b:  Master sink, slave source (RX, master-to-slave)
-   */
-
-  pipe_a[0] = &devpair->pp_master.pd_src;
-  pipe_a[1] = &devpair->pp_slave.pd_sink;
-
-  ret = file_pipe(pipe_a, CONFIG_PSEUDOTERM_TXBUFSIZE, 0);
-  if (ret < 0)
-    {
-      goto errout_with_devpair;
-    }
-
-  pipe_b[0] = &devpair->pp_slave.pd_src;
-  pipe_b[1] = &devpair->pp_master.pd_sink;
-
-  ret = file_pipe(pipe_b, CONFIG_PSEUDOTERM_RXBUFSIZE, 0);
-  if (ret < 0)
-    {
-      goto errout_with_pipea;
-    }
-
-  /* Register the slave device
-   *
-   * BSD style (deprecated): /dev/ttypN
-   * SUSv1 style:  /dev/pts/N
-   *
-   * Where N is the minor number
-   */
-
-#ifdef CONFIG_PSEUDOTERM_BSD
-  snprintf(devname, 16, "/dev/ttyp%d", minor);
-#else
-  snprintf(devname, 16, "/dev/pts/%d", minor);
-#endif
-
-  ret = register_driver(devname, &g_pty_fops, 0666, &devpair->pp_slave);
-  if (ret < 0)
-    {
-      goto errout_with_pipeb;
-    }
 
   /* Register the master device
    *
-   * BSD style (deprecated):  /dev/ptyN
+   * BSD style (deprecated): /dev/ptyN
    * SUSv1 style: Master: /dev/ptmx (multiplexor, see ptmx.c)
    *
    * Where N is the minor number
@@ -1171,30 +1002,66 @@ int pty_register(int minor)
   ret = register_driver(devname, &g_pty_fops, 0666, &devpair->pp_master);
   if (ret < 0)
     {
-      goto errout_with_slave;
+      goto errout_with_devpair;
+    }
+
+  /* Register the slave device
+   *
+   * BSD style (deprecated): /dev/ttypN
+   * SUSv1 style: /dev/pts/N
+   *
+   * Where N is the minor number
+   */
+
+  if (susv1)
+    {
+      snprintf(devname, 16, "/dev/pts/%d", minor);
+    }
+  else
+    {
+      snprintf(devname, 16, "/dev/ttyp%d", minor);
+    }
+
+  ret = register_driver(devname, &g_pty_fops, 0666, &devpair->pp_slave);
+  if (ret < 0)
+    {
+      goto errout_with_master;
     }
 
   return OK;
 
-errout_with_slave:
-#ifdef CONFIG_PSEUDOTERM_BSD
-  snprintf(devname, 16, "/dev/ttyp%d", minor);
-#else
-  snprintf(devname, 16, "/dev/pts/%d", minor);
-#endif
+errout_with_master:
+  snprintf(devname, 16, "/dev/pty%d", minor);
   unregister_driver(devname);
 
-errout_with_pipeb:
-  file_close(pipe_b[0]);
-  file_close(pipe_b[1]);
-
-errout_with_pipea:
-  file_close(pipe_a[0]);
-  file_close(pipe_a[1]);
-
 errout_with_devpair:
   nxsem_destroy(&devpair->pp_exclsem);
   nxsem_destroy(&devpair->pp_slavesem);
   kmm_free(devpair);
   return ret;
 }
+
+/****************************************************************************
+ * Name: pty_register
+ *
+ * Description:
+ *   Create and register PTY master and slave devices.  The master device
+ *   will be registered at /dev/ptyN and slave at /dev/ttypN where N is
+ *   the provided minor number.
+ *
+ *   The slave side of the interface is always locked initially.  The
+ *   master must call unlockpt() before the slave device can be opened.
+ *
+ * Input Parameters:
+ *   minor - The number that qualifies the naming of the created devices.
+ *
+ * Returned Value:
+ *   Zero (OK) is returned on success; a negated errno value is returned on
+ *   any failure.
+ *
+ ****************************************************************************/
+
+int pty_register(int minor)
+{
+  return pty_register2(minor, false);
+}
