@@ -46,6 +46,10 @@
 #include <nuttx/usb/usbdev.h>
 #include <nuttx/usb/usbdev_trace.h>
 
+#ifdef CONFIG_PL2303_BOARD_SERIALSTR
+#include <nuttx/board.h>
+#endif
+
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
@@ -824,9 +828,10 @@ static void usbclass_freereq(FAR struct usbdev_ep_s *ep,
  *
  ****************************************************************************/
 
-static int usbclass_mkstrdesc(uint8_t id, struct usb_strdesc_s *strdesc)
+static int usbclass_mkstrdesc(uint8_t id, FAR struct usb_strdesc_s *strdesc)
 {
-  const char *str;
+  FAR uint8_t *data = (FAR uint8_t *)(strdesc + 1);
+  FAR const char *str;
   int len;
   int ndata;
   int i;
@@ -837,10 +842,10 @@ static int usbclass_mkstrdesc(uint8_t id, struct usb_strdesc_s *strdesc)
       {
         /* Descriptor 0 is the language id */
 
-        strdesc->len     = 4;
-        strdesc->type    = USB_DESC_TYPE_STRING;
-        strdesc->data[0] = LSBYTE(PL2303_STR_LANGUAGE);
-        strdesc->data[1] = MSBYTE(PL2303_STR_LANGUAGE);
+        strdesc->len  = 4;
+        strdesc->type = USB_DESC_TYPE_STRING;
+        data[0] = LSBYTE(PL2303_STR_LANGUAGE);
+        data[1] = MSBYTE(PL2303_STR_LANGUAGE);
         return 4;
       }
 
@@ -853,7 +858,11 @@ static int usbclass_mkstrdesc(uint8_t id, struct usb_strdesc_s *strdesc)
       break;
 
     case PL2303_SERIALSTRID:
+#ifdef CONFIG_PL2303_BOARD_SERIALSTR
+      str = board_usbdev_serialstr();
+#else
       str = CONFIG_PL2303_SERIALSTR;
+#endif
       break;
 
     case PL2303_CONFIGSTRID:
@@ -876,8 +885,8 @@ static int usbclass_mkstrdesc(uint8_t id, struct usb_strdesc_s *strdesc)
 
   for (i = 0, ndata = 0; i < len; i++, ndata += 2)
    {
-     strdesc->data[ndata]   = str[i];
-     strdesc->data[ndata + 1] = 0;
+     data[ndata]     = str[i];
+     data[ndata + 1] = 0;
    }
 
   strdesc->len  = ndata + 2;
