@@ -307,6 +307,9 @@ static const struct file_operations g_xboxcontroller_fops =
   NULL,                     /* seek */
   usbhost_ioctl,            /* ioctl */
   usbhost_poll              /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL                    /* unlink */
+#endif
 };
 
 /* This is a bitmap that is used to allocate device names /dev/xboxa-z. */
