@@ -265,14 +265,14 @@ static const struct file_operations g_video_fops =
 {
   video_open,               /* open */
   video_close,              /* close */
-  0,                        /* read */
-  0,                        /* write */
-  0,                        /* seek */
+  NULL,                     /* read */
+  NULL,                     /* write */
+  NULL,                     /* seek */
   video_ioctl,              /* ioctl */
-#ifndef CONFIG_DISABLE_POLL
-  0,                        /* poll */
+  NULL                      /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL                    /* unlink */
 #endif
-  0                         /* unlink */
 };
 
 static bool is_initialized = false;
