@@ -233,8 +233,10 @@ static const struct file_operations g_gs2200m_fops =
   gs2200m_write, /* write */
   NULL,          /* seek */
   gs2200m_ioctl, /* ioctl */
-  gs2200m_poll,  /* poll */
-  NULL           /* unlink */
+  gs2200m_poll   /* poll */
+#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
+  , NULL         /* unlink */
+#endif
 };
 
 static struct evt_code_s _evt_table[] =
@@ -313,7 +315,7 @@ static uint8_t _cid_to_uint8(char c)
 static void _to_ascii_char(uint16_t num, char *str)
 {
   DEBUGASSERT(num <= 2032); /* See Table 20 */
-  snprintf(str, 5, "%04d", num);
+  snprintf(str, 6, "%04d", num);
 }
 
 /****************************************************************************
@@ -423,7 +425,7 @@ static void _notif_q_push(FAR struct gs2200m_dev_s *dev, char cid)
       nxsem_post(dev->pfd->sem);
     }
 
-  wlinfo("+++ pushed %c count=%d \n", cid, dev->notif_q.count);
+  wlinfo("+++ pushed %c count=%d\n", cid, dev->notif_q.count);
 }
 
 /****************************************************************************
@@ -503,7 +505,7 @@ static void _check_pkt_q_cnt(FAR struct gs2200m_dev_s *dev, char cid)
 
   if (0 != cnt)
     {
-      wlinfo("--- _pkt_p_cnt[%c]=%d \n", cid, cnt);
+      wlinfo("--- _pkt_p_cnt[%c]=%d\n", cid, cnt);
     }
 }
 
@@ -522,9 +524,18 @@ static void _check_pkt_q_empty(FAR struct gs2200m_dev_s *dev, char cid)
 
       while (pkt_dat)
         {
-          wlerr("=== error: found (type=%d msg[0]=%s|) \n",
-                pkt_dat->type, pkt_dat->msg[0]);
+          wlerr("=== error: found (cid=%c type=%d msg[0]=%s|)\n",
+                cid, pkt_dat->type, pkt_dat->msg[0]);
           pkt_dat = (FAR struct pkt_dat_s *)pkt_dat->dq.flink;
+
+          if (_cid_is_set(&dev->valid_cid_bits, cid))
+            {
+              wlerr("+++ error: cid=%c is still active !!!\n", cid);
+            }
+
+          /* NOTE: force to disable the cid to remove */
+
+          _enable_cid(&dev->valid_cid_bits, cid, false);
         }
 
       _remove_all_pkt(dev, c);
@@ -543,14 +554,14 @@ static bool _control_pkt_q(FAR struct gs2200m_dev_s *dev)
 
   if (dev->int_enabled && over)
     {
-      wlinfo("--- disable irq \n");
+      wlinfo("--- disable irq\n");
       dev->int_enabled = false;
       dev->lower->disable();
     }
 
   if (!dev->int_enabled && !over)
     {
-      wlinfo("--- enable irq again \n");
+      wlinfo("--- enable irq again\n");
       dev->lower->enable();
       dev->int_enabled = true;
     }
@@ -628,7 +639,7 @@ static bool _copy_data_from_pkt(FAR struct gs2200m_dev_s *dev,
   pkt_dat = (FAR struct pkt_dat_s *)dq_peek(&dev->pkt_q[c]);
   ASSERT(pkt_dat);
 
-  wlinfo("+++ msg(req=%d:len=%d) pkt_data(t=%d:remain=%d) \n",
+  wlinfo("+++ msg(req=%d:len=%d) pkt_data(t=%d:remain=%d)\n",
          msg->reqlen, msg->len, pkt_dat->type, pkt_dat->remain);
 
   if (msg->len && TYPE_DISCONNECT == pkt_dat->type)
@@ -748,7 +759,7 @@ static ssize_t gs2200m_read(FAR struct file *filep, FAR char *buffer,
   ASSERT(0 < _notif_q_count(dev));
   char cid = _notif_q_pop(dev);
 
-  wlinfo("---- cid=%c (notif_q_cnt=%d) \n", cid, _notif_q_count(dev));
+  wlinfo("---- cid=%c (notif_q_cnt=%d)\n", cid, _notif_q_count(dev));
 
   /* Copy the cid to the buffer */
 
@@ -893,7 +904,7 @@ retry:
 
   if (RD_RESP_NOK == res[1])
     {
-      wlwarn("*** warning: RD_RESP_NOK received.. retrying. (n=%d) \n", n);
+      wlwarn("*** warning: RD_RESP_NOK received.. retrying. (n=%d)\n", n);
       nxsig_usleep(100 * 1000);
       n++;
       goto retry;
@@ -940,11 +951,11 @@ retry:
 
   if (dev->lower->dready(NULL))
     {
-      wlwarn("*** warning: gs2200m is busy.. retrying. (n=%d) \n", n);
+      wlwarn("*** warning: gs2200m is busy.. retrying. (n=%d)\n", n);
 
       if (!work_available(&dev->irq_work))
         {
-          wlwarn("*** warning: there is still pending work **** \n");
+          wlwarn("*** warning: there is still pending work ****\n");
         }
       else
         {
@@ -982,7 +993,7 @@ retry:
 
   if (WR_RESP_NOK == res[1] || 0x0 == res[1])
     {
-      wlwarn("*** warning: 0x%x received.. retrying. (n=%d) \n",
+      wlwarn("*** warning: 0x%x received.. retrying. (n=%d)\n",
              res[1], n);
       nxsig_usleep(10 * 1000);
 
@@ -1040,7 +1051,7 @@ enum spi_status_e gs2200m_hal_read(FAR struct gs2200m_dev_s *dev,
 
   if (HAL_TIMEOUT == i)
     {
-      wlerr("***** error: timeout! \n");
+      wlerr("***** error: timeout!\n");
       r = SPI_TIMEOUT;
       goto errout;
     }
@@ -1051,7 +1062,7 @@ enum spi_status_e gs2200m_hal_read(FAR struct gs2200m_dev_s *dev,
 
   *len = _read_data_len(dev);
 
-  wlinfo("+++++ (len=%d) \n", *len);
+  wlinfo("+++++ (len=%d)\n", *len);
 
   /* Check the length */
 
@@ -1085,7 +1096,7 @@ enum pkt_type_e _check_evt(FAR const char *buff)
         }
     }
 
-  wlinfo("+++++ %s +++++ \n", buff);
+  wlinfo("+++++ %s +++++\n", buff);
   return TYPE_UNMATCH;
 }
 
@@ -1145,7 +1156,7 @@ static void _parse_pkt_in_s1(FAR struct pkt_ctx_s *pkt_ctx,
       n = sscanf(msg, "DISCONNECT %c", &(pkt_dat->cid));
       ASSERT(1 == n);
 
-      wlinfo("+++++ msg=%s| cid=%c \n", msg, pkt_dat->cid);
+      wlinfo("+++++ msg=%s| cid=%c\n", msg, pkt_dat->cid);
     }
   else if (pkt_ctx->type == TYPE_CONNECT)
     {
@@ -1156,20 +1167,20 @@ static void _parse_pkt_in_s1(FAR struct pkt_ctx_s *pkt_ctx,
       n = sscanf(msg, "CONNECT %c", &(pkt_dat->cid));
       DEBUGASSERT(1 == n);
 
-      wlinfo("+++++ msg=%s| \n", msg);
+      wlinfo("+++++ msg=%s|\n", msg);
     }
 
   if (pkt_dat)
     {
       /* If specified, store the msg pointer to pkt_dat */
 
-      wlinfo("+++++ %d:(msize=%d, msg=%s|) \n", pkt_dat->n, msize, msg);
+      wlinfo("+++++ %d:(msize=%d, msg=%s|)\n", pkt_dat->n, msize, msg);
       ASSERT(pkt_dat->n < NRESPMSG);
       pkt_dat->msg[pkt_dat->n++] = msg;
     }
   else
     {
-      wlinfo("+++++ (msize=%d, msg=%s|) \n", msize, msg);
+      wlinfo("+++++ (msize=%d, msg=%s|)\n", msize, msg);
       kmm_free(msg);
     }
 
@@ -1194,7 +1205,7 @@ static void _parse_pkt_in_s2(FAR struct pkt_ctx_s *pkt_ctx,
 
   if ('Z' == c)
     {
-      wlinfo("** <ESC>Z \n");
+      wlinfo("** <ESC>Z\n");
 
       /* NOTE: See 7.5.3.2 Bulk Data Handling */
 
@@ -1202,7 +1213,7 @@ static void _parse_pkt_in_s2(FAR struct pkt_ctx_s *pkt_ctx,
     }
   else if ('y' == c)
     {
-      wlinfo("** <ESC>y \n");
+      wlinfo("** <ESC>y\n");
 
       /* NOTE: See 7.5.3.2 Bulk Data Handling */
 
@@ -1210,7 +1221,7 @@ static void _parse_pkt_in_s2(FAR struct pkt_ctx_s *pkt_ctx,
     }
   else if ('F' == c)
     {
-      wlwarn("** <ESC>F \n");
+      wlwarn("** <ESC>F\n");
 
       /* NOTE: See Table 6 Data Handling Responses at Completion */
 
@@ -1219,7 +1230,7 @@ static void _parse_pkt_in_s2(FAR struct pkt_ctx_s *pkt_ctx,
     }
   else
     {
-      wlerr("** <ESC>%c not supported \n", c);
+      wlerr("** <ESC>%c not supported\n", c);
       ASSERT(false);
     }
 }
@@ -1251,7 +1262,7 @@ static void _parse_pkt_in_s3(FAR struct pkt_ctx_s *pkt_ctx,
       pkt_ctx->dlen = _to_uint16((char *)pkt_ctx->ptr);
       pkt_ctx->ptr += 3;
 
-      wlinfo("dlen=%d \n", pkt_ctx->dlen);
+      wlinfo("dlen=%d\n", pkt_ctx->dlen);
 
       /* Allocate memory for the packet */
 
@@ -1303,10 +1314,10 @@ static void _parse_pkt_in_s4(FAR struct pkt_ctx_s *pkt_ctx,
       n = sscanf((char *)pkt_ctx->ptr, "%s %s\t", addr, port);
       ASSERT(2 == n);
 
-      wlinfo("from (%s:%s) \n", addr, port);
+      wlinfo("from (%s:%s)\n", addr, port);
 
       inet_aton(addr, &pkt_dat->addr.sin_addr);
-      pkt_dat->addr.sin_port = htons((uint16_t)atoi(port));
+      pkt_dat->addr.sin_port = HTONS((uint16_t)atoi(port));
 
       /* Skip until data length */
 
@@ -1318,7 +1329,7 @@ static void _parse_pkt_in_s4(FAR struct pkt_ctx_s *pkt_ctx,
       pkt_ctx->dlen = _to_uint16((char *)pkt_ctx->ptr);
       pkt_ctx->ptr += 3;
 
-      wlinfo("dlen=%d \n", pkt_ctx->dlen);
+      wlinfo("dlen=%d\n", pkt_ctx->dlen);
 
       /* Allocate memory for the packet */
 
@@ -1461,7 +1472,7 @@ static enum pkt_type_e gs2200m_recv_pkt(FAR struct gs2200m_dev_s *dev,
       goto errout;
     }
 
-  wlinfo("+++ len=%d pkt_dat=%p \n", len, pkt_dat);
+  wlinfo("+++ len=%d pkt_dat=%p\n", len, pkt_dat);
 
   /* Parse the received packet */
 
@@ -1530,7 +1541,7 @@ retry_recv:
 
   if ((TYPE_BULK_DATA_TCP == r || TYPE_BULK_DATA_UDP == r) && pkt_dat)
     {
-      wlwarn("*** Found bulk data \n");
+      wlwarn("*** Found bulk data\n");
 
       /* Bulk data found in the response,
        * duplicate the packet and notify
@@ -1541,7 +1552,7 @@ retry_recv:
       /* release & initialize pkt_dat before retry */
 
       _release_pkt_dat(dev, pkt_dat);
-      memset(pkt_dat, 0, sizeof(pkt_dat));
+      memset(pkt_dat, 0, sizeof(*pkt_dat));
 
       bulk = true;
       goto retry_recv;
@@ -1556,10 +1567,10 @@ retry_recv:
           /* release & initialize pkt_dat before retry */
 
           _release_pkt_dat(dev, pkt_dat);
-          memset(pkt_dat, 0, sizeof(pkt_dat));
+          memset(pkt_dat, 0, sizeof(*pkt_dat));
         }
 
-      wlwarn("*** retry cmd=%s (n=%d) \n", cmd, n);
+      wlwarn("*** retry cmd=%s (n=%d)\n", cmd, n);
       goto retry;
     }
 
@@ -1567,7 +1578,7 @@ errout:
 
   if (bulk)
     {
-      wlwarn("*** Normal response r=%d \n", r);
+      wlwarn("*** Normal response r=%d\n", r);
     }
 
   /* Enable gs2200m irq again */
@@ -1628,7 +1639,7 @@ static enum pkt_type_e gs2200m_set_opmode(FAR struct gs2200m_dev_s *dev,
 static enum pkt_type_e gs2200m_get_mac(FAR struct gs2200m_dev_s *dev)
 {
   struct pkt_dat_s pkt_dat;
-  enum pkt_type_e   r;
+  enum pkt_type_e  r;
   uint32_t mac[6];
   char cmd[16];
   int n;
@@ -1720,7 +1731,7 @@ static enum pkt_type_e gs2200m_join_network(FAR struct gs2200m_dev_s *dev,
                                             FAR char *ssid, uint8_t ch)
 {
   struct pkt_dat_s pkt_dat;
-  enum pkt_type_e   r;
+  enum pkt_type_e  r;
   char cmd[64];
   char addr[3][17];
   int n;
@@ -1853,7 +1864,7 @@ static enum pkt_type_e gs2200m_set_wpa2pf(FAR struct gs2200m_dev_s *dev,
 enum pkt_type_e gs2200m_get_wstatus(FAR struct gs2200m_dev_s *dev)
 {
   struct pkt_dat_s pkt_dat;
-  enum pkt_type_e   r;
+  enum pkt_type_e  r;
   int i;
 
   /* Initialize pkt_dat and send command */
@@ -1886,8 +1897,8 @@ gs2200m_create_clnt(FAR struct gs2200m_dev_s *dev,
                     FAR struct gs2200m_connect_msg *msg,
                     FAR char *cid)
 {
-  enum pkt_type_e  r;
   struct pkt_dat_s pkt_dat;
+  enum pkt_type_e  r;
   char cmd[40];
   char *p;
   int   n;
@@ -1925,7 +1936,7 @@ gs2200m_create_clnt(FAR struct gs2200m_dev_s *dev,
 
   if (r != TYPE_OK || pkt_dat.n == 0)
     {
-      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s \n",
+      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s\n",
             r, pkt_dat.msg[0]);
       goto errout;
     }
@@ -1934,7 +1945,7 @@ gs2200m_create_clnt(FAR struct gs2200m_dev_s *dev,
     {
       n = sscanf(p, "CONNECT %c", cid);
       ASSERT(1 == n);
-      wlinfo("+++ OK: p=%s| (n=%d) \n", p, n);
+      wlinfo("+++ OK: p=%s| (n=%d)\n", p, n);
     }
 
 errout:
@@ -1951,8 +1962,8 @@ static enum pkt_type_e gs2200m_start_server(FAR struct gs2200m_dev_s *dev,
                                             FAR char *port, bool is_tcp,
                                             FAR char *cid)
 {
-  enum pkt_type_e   r;
   struct pkt_dat_s pkt_dat;
+  enum pkt_type_e  r;
   char cmd[40];
   char *p;
   int   n;
@@ -1982,7 +1993,7 @@ static enum pkt_type_e gs2200m_start_server(FAR struct gs2200m_dev_s *dev,
     {
       n = sscanf(p, "CONNECT %c", cid);
       ASSERT(1 == n);
-      wlinfo("+++ OK: p=%s| (n=%d) \n", p, n);
+      wlinfo("+++ OK: p=%s| (n=%d)\n", p, n);
     }
 
 errout:
@@ -1998,10 +2009,10 @@ errout:
 static enum pkt_type_e gs2200m_send_bulk(FAR struct gs2200m_dev_s *dev,
                                          FAR struct gs2200m_send_msg *msg)
 {
-  enum pkt_type_e   r;
   enum spi_status_e s;
+  enum pkt_type_e   r;
   int  bulk_hdr_size;
-  char digits[5];
+  char digits[6];
   char cmd[32];
 
   memset(cmd, 0, sizeof(cmd));
@@ -2015,7 +2026,7 @@ static enum pkt_type_e gs2200m_send_bulk(FAR struct gs2200m_dev_s *dev,
 
   _to_ascii_char(msg->len, digits);
 
-  wlinfo("** cid=%c len=%d digits=%s \n", msg->cid, msg->len, digits);
+  wlinfo("** cid=%c len=%d digits=%s\n", msg->cid, msg->len, digits);
 
   if (msg->is_tcp)
     {
@@ -2027,8 +2038,8 @@ static enum pkt_type_e gs2200m_send_bulk(FAR struct gs2200m_dev_s *dev,
     }
   else
     {
-      wlinfo("** addr=%s port=%d \n", inet_ntoa(msg->addr.sin_addr),
-             ntohs(msg->addr.sin_port));
+      wlinfo("** addr=%s port=%d\n", inet_ntoa(msg->addr.sin_addr),
+             NTOHS(msg->addr.sin_port));
 
       /* NOTE: See 7.5.3.2 Bulk Data Handling for UDP
        * <ESC>Y<CID><IP address>:<port>:<Data Length xxxx 4 ascii char><data>
@@ -2036,7 +2047,7 @@ static enum pkt_type_e gs2200m_send_bulk(FAR struct gs2200m_dev_s *dev,
 
       snprintf(cmd, sizeof(cmd), "%cY%c%s:%d:%s",
                ASCII_ESC, msg->cid,
-               inet_ntoa(msg->addr.sin_addr), ntohs(msg->addr.sin_port),
+               inet_ntoa(msg->addr.sin_addr), NTOHS(msg->addr.sin_port),
                digits);
     }
 
@@ -2171,7 +2182,7 @@ static enum pkt_type_e gs2200m_get_cstatus(FAR struct gs2200m_dev_s *dev,
                                            FAR struct gs2200m_name_msg *msg)
 {
   struct pkt_dat_s pkt_dat;
-  enum pkt_type_e   r;
+  enum pkt_type_e  r;
   char cmd[16];
   int i;
 
@@ -2184,7 +2195,7 @@ static enum pkt_type_e gs2200m_get_cstatus(FAR struct gs2200m_dev_s *dev,
 
   if (r != TYPE_OK || pkt_dat.n <= 2)
     {
-      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s \n",
+      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s\n",
             r, pkt_dat.msg[0]);
 
       goto errout;
@@ -2207,7 +2218,7 @@ static enum pkt_type_e gs2200m_get_cstatus(FAR struct gs2200m_dev_s *dev,
                  &a[0], &a[1], &a[2], &a[3]);
       ASSERT(9 == n);
 
-      wlinfo("[%d]: %c %s %s %d %d %d.%d.%d.%d \n",
+      wlinfo("[%d]: %c %s %s %d %d %d.%d.%d.%d\n",
              i, c, type, mode, p[0], p[1],
              a[0], a[1], a[2], a[3]);
 
@@ -2219,12 +2230,12 @@ static enum pkt_type_e gs2200m_get_cstatus(FAR struct gs2200m_dev_s *dev,
 
           if (msg->local)
             {
-              msg->addr.sin_port = htons(p[0]);
+              msg->addr.sin_port = HTONS(p[0]);
             }
           else
             {
               char addr[20];
-              msg->addr.sin_port = htons(p[1]);
+              msg->addr.sin_port = HTONS(p[1]);
               snprintf(addr, sizeof(addr),
                        "%d.%d.%d.%d", a[0], a[1], a[2], a[3]);
               inet_aton(addr, &msg->addr.sin_addr);
@@ -2257,7 +2268,7 @@ static int gs2200m_ioctl_bind(FAR struct gs2200m_dev_s *dev,
   char cid = 'z';
   int ret = OK;
 
-  wlinfo("+++ start: (cid=%c, port=%s) \n", msg->cid, msg->port);
+  wlinfo("+++ start: (cid=%c, port=%s)\n", msg->cid, msg->port);
 
   port = (uint16_t)strtol(msg->port, NULL, 10);
 
@@ -2297,7 +2308,7 @@ errout:
   msg->type = type;
   msg->cid  = cid;
 
-  wlinfo("+++ end: type=%d (cid=%c) \n", type, cid);
+  wlinfo("+++ end: type=%d (cid=%c)\n", type, cid);
 
   return ret;
 }
@@ -2313,7 +2324,7 @@ static int gs2200m_ioctl_connect(FAR struct gs2200m_dev_s *dev,
   char cid = 'z';
   int ret = OK;
 
-  wlinfo("++ start: addr=%s port=%s \n", msg->addr, msg->port);
+  wlinfo("++ start: addr=%s port=%s\n", msg->addr, msg->port);
 
   /* Create TCP or UDP connection */
 
@@ -2344,12 +2355,12 @@ static int gs2200m_ioctl_connect(FAR struct gs2200m_dev_s *dev,
         break;
 
       default:
-        wlerr("+++ error: type=%d \n", type);
+        wlerr("+++ error: type=%d\n", type);
         ASSERT(false);
         ret = -EINVAL;
     }
 
-  wlinfo("++ end: cid=%c (type=%d,ret=%d) \n", cid, type, ret);
+  wlinfo("++ end: cid=%c (type=%d,ret=%d)\n", cid, type, ret);
 
   return ret;
 }
@@ -2365,7 +2376,7 @@ static int gs2200m_ioctl_send(FAR struct gs2200m_dev_s *dev,
   enum pkt_type_e type;
   int ret = OK;
 
-  wlinfo("+++ start: (cid=%c) \n", msg->cid);
+  wlinfo("+++ start: (cid=%c)\n", msg->cid);
 
 #ifdef USE_LED
   gs2200m_set_gpio(dev, LED_GPIO, 1);
@@ -2381,13 +2392,13 @@ static int gs2200m_ioctl_send(FAR struct gs2200m_dev_s *dev,
       ret = gs2200m_ioctl_bind(dev, &bmsg);
       ASSERT(0 == ret);
 
-      wlinfo("+++ cid is assigned for udp (cid=%c) \n", bmsg.cid);
+      wlinfo("+++ cid is assigned for udp (cid=%c)\n", bmsg.cid);
       msg->cid = bmsg.cid;
     }
 
   if (!_cid_is_set(&dev->valid_cid_bits, msg->cid))
     {
-      wlinfo("+++ already closed \n");
+      wlinfo("+++ already closed\n");
       type = TYPE_DISCONNECT;
       ret = -ENOTCONN;
       goto errout;
@@ -2408,7 +2419,7 @@ errout:
   gs2200m_set_gpio(dev, LED_GPIO, 0);
 #endif
 
-  wlinfo("+++ end: cid=%c len=%d type=%d \n",
+  wlinfo("+++ end: cid=%c len=%d type=%d\n",
          msg->cid, msg->len, type);
 
   return ret;
@@ -2425,7 +2436,7 @@ static int gs2200m_ioctl_recv(FAR struct gs2200m_dev_s *dev,
   int      ret  = OK;
   uint8_t  c    = _cid_to_uint8(msg->cid);
 
-  wlinfo("+++ start: cid=%c \n", msg->cid);
+  wlinfo("+++ start: cid=%c\n", msg->cid);
 
 #ifdef USE_LED
   gs2200m_set_gpio(dev, LED_GPIO, 1);
@@ -2435,7 +2446,7 @@ static int gs2200m_ioctl_recv(FAR struct gs2200m_dev_s *dev,
     {
       /* REVISIT */
 
-      wlwarn("**** no packet for cid=%c \n", msg->cid);
+      wlwarn("**** no packet for cid=%c\n", msg->cid);
       ret = -EAGAIN;
       goto errout;
     }
@@ -2454,7 +2465,7 @@ static int gs2200m_ioctl_recv(FAR struct gs2200m_dev_s *dev,
       cont = _copy_data_from_pkt(dev, msg);
     }
 
-  wlinfo("+++ pkt_q_cnt[%c]=%d \n", msg->cid, dev->pkt_q_cnt[c]);
+  wlinfo("+++ pkt_q_cnt[%c]=%d\n", msg->cid, dev->pkt_q_cnt[c]);
 
   if (dev->pkt_q_cnt[c])
     {
@@ -2471,7 +2482,7 @@ errout:
   gs2200m_set_gpio(dev, LED_GPIO, 0);
 #endif
 
-  wlinfo("+++ end: cid=%c len=%d type=%d ret=%d \n",
+  wlinfo("+++ end: cid=%c len=%d type=%d ret=%d\n",
          msg->cid, msg->len, msg->type, ret);
 
   return ret;
@@ -2487,11 +2498,11 @@ static int gs2200m_ioctl_close(FAR struct gs2200m_dev_s *dev,
   enum pkt_type_e type = TYPE_OK;
   int ret = OK;
 
-  wlinfo("++ start: (cid=%c) \n", msg->cid);
+  wlinfo("++ start: (cid=%c)\n", msg->cid);
 
   if (!_cid_is_set(&dev->valid_cid_bits, msg->cid))
     {
-      wlinfo("+++ already closed \n");
+      wlinfo("+++ already closed\n");
       goto errout;
     }
 
@@ -2516,7 +2527,7 @@ errout:
 
   _control_pkt_q(dev);
 
-  wlinfo("++ end: cid=%c type=%d \n", msg->cid, type);
+  wlinfo("++ end: cid=%c type=%d\n", msg->cid, type);
 
   return ret;
 }
@@ -2534,18 +2545,25 @@ static int gs2200m_ioctl_accept(FAR struct gs2200m_dev_s *dev,
   uint8_t c;
   char s_cid;
   char c_cid;
+  int ret = OK;
   int n;
 
-  wlinfo("+++ start: cid=%c \n", msg->cid);
+  wlinfo("+++ start: cid=%c\n", msg->cid);
 
   c = _cid_to_uint8(msg->cid);
   pkt_dat = (FAR struct pkt_dat_s *)dq_peek(&dev->pkt_q[c]);
-  ASSERT(pkt_dat);
+
+  if (NULL == pkt_dat)
+    {
+      wlerr("*** error: cid=%c not found\n", msg->cid);
+      ret = -EINVAL;
+      goto errout;
+    }
 
   n = sscanf(pkt_dat->msg[0], "CONNECT %c %c", &s_cid, &c_cid);
   ASSERT(2 == n);
 
-  wlinfo("+++ s_cid=%c c_cid=%c \n", s_cid, c_cid);
+  wlinfo("+++ s_cid=%c c_cid=%c\n", s_cid, c_cid);
 
   /* Remove the accept packet (actually CONNECT) from the queue */
 
@@ -2572,13 +2590,20 @@ static int gs2200m_ioctl_accept(FAR struct gs2200m_dev_s *dev,
   nmsg.local = 0;
   nmsg.cid = msg->cid;
   r = gs2200m_get_cstatus(dev, &nmsg);
-  ASSERT(TYPE_OK == r);
+
+  if (TYPE_OK != r)
+    {
+      wlerr("*** error: cid=%c not found\n", msg->cid);
+      ret = -EINVAL;
+      goto errout;
+    }
 
   msg->addr = nmsg.addr;
 
-  wlinfo("+++ end: type=%d (msg->cid=%c) \n", msg->type, msg->cid);
+errout:
+  wlinfo("+++ end: type=%d (msg->cid=%c)\n", msg->type, msg->cid);
 
-  return OK;
+  return ret;
 }
 
 /****************************************************************************
@@ -2634,7 +2659,7 @@ static int gs2200m_ioctl_assoc_sta(FAR struct gs2200m_dev_s *dev,
 
   if (TYPE_OK != gs2200m_calc_key(dev, msg->ssid, msg->key))
     {
-      wlerr("*** error: invalid wpa2 key (key:%s) \n", msg->key);
+      wlerr("*** error: invalid wpa2 key (key:%s)\n", msg->key);
       return -1;
     }
 
@@ -2642,7 +2667,7 @@ static int gs2200m_ioctl_assoc_sta(FAR struct gs2200m_dev_s *dev,
 
   if (TYPE_OK != gs2200m_join_network(dev, msg->ssid, 0))
     {
-      wlerr("*** error: failed to join (ssid:%s) \n", msg->ssid);
+      wlerr("*** error: failed to join (ssid:%s)\n", msg->ssid);
       return -1;
     }
 
@@ -2699,7 +2724,7 @@ static int gs2200m_ioctl_assoc_ap(FAR struct gs2200m_dev_s *dev,
 
   if (TYPE_OK != gs2200m_set_wepkey(dev, msg->key))
     {
-      wlerr("*** error: invalid wepkey: %s \n", msg->key);
+      wlerr("*** error: invalid wepkey: %s\n", msg->key);
       return -1;
     }
 #else
@@ -2712,7 +2737,7 @@ static int gs2200m_ioctl_assoc_ap(FAR struct gs2200m_dev_s *dev,
 
   if (TYPE_OK != gs2200m_set_wpa2pf(dev, msg->key))
     {
-      wlerr("*** error: invalid passphrase: %s \n", msg->key);
+      wlerr("*** error: invalid passphrase: %s\n", msg->key);
       return -1;
     }
 #endif
@@ -2726,7 +2751,7 @@ static int gs2200m_ioctl_assoc_ap(FAR struct gs2200m_dev_s *dev,
 
   if (TYPE_OK != gs2200m_join_network(dev, msg->ssid, msg->ch))
     {
-      wlerr("*** error: failed to join (ssid:%s, ch:%d) \n",
+      wlerr("*** error: failed to join (ssid:%s, ch:%d)\n",
             msg->ssid, msg->ch);
       return -1;
     }
@@ -2743,7 +2768,7 @@ static int gs2200m_ioctl_iwreq(FAR struct gs2200m_dev_s *dev,
 {
   struct iwreq *res = (struct iwreq *)&msg->ifr;
   struct pkt_dat_s pkt_dat;
-  enum pkt_type_e   r;
+  enum pkt_type_e  r;
   char cmd[64];
   char cmd2[64];
   int  n = 0;
@@ -2757,7 +2782,7 @@ static int gs2200m_ioctl_iwreq(FAR struct gs2200m_dev_s *dev,
 
   if (r != TYPE_OK || pkt_dat.n <= 7)
     {
-      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s \n",
+      wlerr("+++ error: r=%d pkt_dat.msg[0]=%s\n",
             r, pkt_dat.msg[0]);
 
       goto errout;
@@ -2769,7 +2794,7 @@ static int gs2200m_ioctl_iwreq(FAR struct gs2200m_dev_s *dev,
     {
       if (strstr(pkt_dat.msg[2], "BSSID=") == NULL)
         {
-          wlerr("+++ error: pkt_dat.msg[2]=%s \n", pkt_dat.msg[2]);
+          wlerr("+++ error: pkt_dat.msg[2]=%s\n", pkt_dat.msg[2]);
           goto errout;
         }
 
@@ -2788,7 +2813,7 @@ static int gs2200m_ioctl_iwreq(FAR struct gs2200m_dev_s *dev,
     {
       if (strstr(pkt_dat.msg[2], "CHANNEL=") == NULL)
         {
-          wlerr("+++ error: pkt_dat.msg[2]=%s \n", pkt_dat.msg[2]);
+          wlerr("+++ error: pkt_dat.msg[2]=%s\n", pkt_dat.msg[2]);
           goto errout;
         }
 
@@ -2801,7 +2826,7 @@ static int gs2200m_ioctl_iwreq(FAR struct gs2200m_dev_s *dev,
     {
       if (strstr(pkt_dat.msg[3], "RSSI=") == NULL)
         {
-          wlerr("+++ error: pkt_dat.msg[3]=%s \n", pkt_dat.msg[3]);
+          wlerr("+++ error: pkt_dat.msg[3]=%s\n", pkt_dat.msg[3]);
           goto errout;
         }
 
@@ -2834,7 +2859,7 @@ static int gs2200m_ioctl_ifreq(FAR struct gs2200m_dev_s *dev,
   bool getreq = false;
   int ret = OK;
 
-  wlinfo("+++ start: cmd=%" PRIx32 " \n", msg->cmd);
+  wlinfo("+++ start: cmd=%" PRIx32 "\n", msg->cmd);
 
   inaddr = (FAR struct sockaddr_in *)&msg->ifr.ifr_addr;
 
@@ -2895,7 +2920,7 @@ static int gs2200m_ioctl_ifreq(FAR struct gs2200m_dev_s *dev,
       gs2200m_set_addresses(dev, addr[0], addr[1], addr[2]);
     }
 
-  wlinfo("+++ end: \n");
+  wlinfo("+++ end:\n");
   return ret;
 }
 
@@ -3124,7 +3149,7 @@ static int gs2200m_poll(FAR struct file *filep, FAR struct pollfd *fds,
         {
           dev->pfd->revents |= POLLIN;
           nxsem_post(dev->pfd->sem);
-          wlinfo("==== _notif_q_count=%d \n", n);
+          wlinfo("==== _notif_q_count=%d\n", n);
         }
     }
   else
@@ -3173,7 +3198,7 @@ static void gs2200m_irq_worker(FAR void *arg)
 repeat:
 
   n = dev->lower->dready(&ec);
-  wlinfo("== start (dready=%d, ec=%d) \n", n, ec);
+  wlinfo("== start (dready=%d, ec=%d)\n", n, ec);
 
   /* Allocate a new pkt_dat and initialize it */
 
@@ -3215,7 +3240,7 @@ repeat:
     {
       /* An error event? */
 
-      wlerr("=== ignore (type=%d msg[0]=%s|) \n",
+      wlerr("=== ignore (type=%d msg[0]=%s|)\n",
             pkt_dat->type, pkt_dat->msg[0]);
 
       ignored = true;
@@ -3226,7 +3251,7 @@ repeat:
 
   if (!_cid_is_set(&dev->valid_cid_bits, pkt_dat->cid))
     {
-      wlinfo("=== already closed (type=%d msg[0]=%s|) \n",
+      wlinfo("=== already closed (type=%d msg[0]=%s|)\n",
              pkt_dat->type, pkt_dat->msg[0]);
 
       ignored = true;
@@ -3240,13 +3265,13 @@ repeat:
   dq_addlast((FAR dq_entry_t *)pkt_dat, &dev->pkt_q[c]);
   dev->pkt_q_cnt[c]++;
 
-  wlinfo("=== added to qkt_q[%d] t=%d \n", c, t);
+  wlinfo("=== added to qkt_q[%d] t=%d\n", c, t);
 
   /* When a DISCONNECT packet received, disable the cid */
 
   if (TYPE_DISCONNECT == t)
     {
-      wlinfo("=== received DISCONNECT for cid=%c \n", pkt_dat->cid);
+      wlinfo("=== received DISCONNECT for cid=%c\n", pkt_dat->cid);
       _enable_cid(&dev->valid_cid_bits, pkt_dat->cid, false);
     }
 
@@ -3268,7 +3293,7 @@ repeat:
       n = sscanf(pkt_dat->msg[0], "CONNECT %c %c", &s_cid, &c_cid);
       ASSERT(2 == n);
 
-      wlinfo("==== CONNECT requested (%c:%c) pfd=%p \n",
+      wlinfo("==== CONNECT requested (%c:%c) pfd=%p\n",
              s_cid, c_cid, dev->pfd);
 
       /* Check pkt_q for the new client is empty */
@@ -3299,7 +3324,7 @@ errout:
 
   n = dev->lower->dready(&ec);
 
-  wlinfo("== end: cid=%c (dready=%d, ec=%d) type=%d \n",
+  wlinfo("== end: cid=%c (dready=%d, ec=%d) type=%d\n",
          pkt_dat->cid, n, ec, t);
 
   if (1 == n && !over)
@@ -3325,11 +3350,11 @@ static int gs2200m_irq(int irq, FAR void *context, FAR void *arg)
   DEBUGASSERT(arg != NULL);
   dev = (FAR struct gs2200m_dev_s *)arg;
 
-  wlinfo(">>>> \n");
+  wlinfo(">>>>\n");
 
   if (!work_available(&dev->irq_work))
     {
-      wlwarn("*** warning: there is still pending work **** \n");
+      wlwarn("*** warning: there is still pending work ****\n");
       return 0;
     }
 
@@ -3353,7 +3378,7 @@ static int gs2200m_start(FAR struct gs2200m_dev_s *dev)
 
   /* Check boot msg */
 
-  wlinfo("*** wait for boot msg \n");
+  wlinfo("*** wait for boot msg\n");
 
   while (dev->lower->dready(NULL))
     {
