@@ -262,7 +262,7 @@ int bcmf_driver_download_clm(FAR struct bcmf_dev_s *priv)
                   O_RDONLY | O_BINARY);
   if (ret < 0)
     {
-      wlerr("ERROR: Failed to open the FILE MTD file \n", ret);
+      wlerr("ERROR: Failed to open the FILE MTD file\n", ret);
       return ret;
     }
 
@@ -351,7 +351,7 @@ int bcmf_driver_download_clm(FAR struct bcmf_dev_s *priv)
     }
   else
     {
-      wlinfo("Download %d bytes @ 0x%08x\n", datalen, srcbuff);
+      wlinfo("Download %d bytes @ %p\n", datalen, srcbuff);
     }
 
   /* Divide CLM blob into chunks */
