@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __DRIVERS_WIRELESS_IEEE80211_BCMF_SDIO_H
-#define __DRIVERS_WIRELESS_IEEE80211_BCMF_SDIO_H
+#ifndef __DRIVERS_WIRELESS_IEEE80211_BCM43XXX_BCMF_SDIO_H
+#define __DRIVERS_WIRELESS_IEEE80211_BCM43XXX_BCMF_SDIO_H
 
 /****************************************************************************
  * Included Files
@@ -53,6 +53,7 @@
 
 struct bcmf_sdio_chip
 {
+  uint32_t ram_base;
   uint32_t ram_size;
   uint32_t core_base[MAX_CORE_ID];
 
@@ -147,8 +148,8 @@ int bcmf_bus_sdio_initialize(FAR struct bcmf_dev_s *priv,
  */
 
 int bcmf_transfer_bytes(FAR struct bcmf_sdio_dev_s *sbus, bool write,
-                         uint8_t function, uint32_t address,
-                         uint8_t *buf, unsigned int len);
+                        uint8_t function, uint32_t address,
+                        uint8_t *buf, unsigned int len);
 
 int bcmf_read_reg(FAR struct bcmf_sdio_dev_s *sbus, uint8_t function,
                   uint32_t address, uint8_t *reg);
@@ -162,4 +163,4 @@ struct bcmf_sdio_frame *bcmf_sdio_allocate_frame(FAR struct bcmf_dev_s *priv,
 void bcmf_sdio_free_frame(FAR struct bcmf_dev_s *priv,
                           struct bcmf_sdio_frame *sframe);
 
-#endif /* __DRIVERS_WIRELESS_IEEE80211_BCMF_SDIO_H */
+#endif /* __DRIVERS_WIRELESS_IEEE80211_BCM43XXX_BCMF_SDIO_H */
