@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef __FS_INODE_H
-#define __FS_INODE_H
+#ifndef __FS_INODE_INODE_H
+#define __FS_INODE_INODE_H
 
 /****************************************************************************
  * Included Files
@@ -424,4 +424,4 @@ int files_allocate(FAR struct inode *inode, int oflags, off_t pos,
 }
 #endif
 
-#endif /* __FS_INODE_H */
+#endif /* __FS_INODE_INODE_H */
