@@ -28,8 +28,6 @@
 #include <sys/statfs.h>
 #include <sys/stat.h>
 
-#include <stdint.h>
-#include <stdbool.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
@@ -43,7 +41,6 @@
 #include <nuttx/fs/fs.h>
 #include <nuttx/fs/ioctl.h>
 #include <nuttx/fs/dirent.h>
-#include <nuttx/mtd/mtd.h>
 
 #include "fs_romfs.h"
 
@@ -137,7 +134,7 @@ const struct mountpt_operations romfs_operations =
 static int romfs_open(FAR struct file *filep, FAR const char *relpath,
                       int oflags, mode_t mode)
 {
-  struct romfs_dirinfo_s      dirinfo;
+  struct romfs_nodeinfo_s     nodeinfo;
   FAR struct romfs_mountpt_s *rm;
   FAR struct romfs_file_s    *rf;
   int                         ret;
@@ -182,13 +179,9 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
       goto errout_with_semaphore;
     }
 
-  /* Initialize the directory info structure */
-
-  memset(&dirinfo, 0, sizeof(struct romfs_dirinfo_s));
-
   /* Locate the directory entry for this path */
 
-  ret = romfs_finddirentry(rm, &dirinfo, relpath);
+  ret = romfs_finddirentry(rm, &nodeinfo, relpath);
   if (ret < 0)
     {
       ferr("ERROR: Failed to find directory directory entry for '%s': %d\n",
@@ -204,7 +197,7 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
    * types.  At present, it returns the ENXIO.
    */
 
-  if (IS_DIRECTORY(dirinfo.rd_next))
+  if (IS_DIRECTORY(nodeinfo.rn_next))
     {
       /* It is a directory */
 
@@ -212,7 +205,7 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
       ferr("ERROR: '%s' is a directory\n", relpath);
       goto errout_with_semaphore;
     }
-  else if (!IS_FILE(dirinfo.rd_next))
+  else if (!IS_FILE(nodeinfo.rn_next))
     {
       /* ENXIO indicates "The named file is a character special or
        * block special file, and the device associated with this
@@ -231,7 +224,7 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
    * file.
    */
 
-  rf = (FAR struct romfs_file_s *)kmm_zalloc(sizeof(struct romfs_file_s));
+  rf = kmm_zalloc(sizeof(struct romfs_file_s) + strlen(relpath));
   if (!rf)
     {
       ferr("ERROR: Failed to allocate private data\n");
@@ -243,13 +236,13 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
    * non-zero elements)
    */
 
-  rf->rf_size = dirinfo.rd_size;
-  rf->rf_type = (uint8_t)(dirinfo.rd_next & RFNEXT_ALLMODEMASK);
+  rf->rf_size = nodeinfo.rn_size;
+  rf->rf_type = (uint8_t)(nodeinfo.rn_next & RFNEXT_ALLMODEMASK);
+  strcpy(rf->rf_path, relpath);
 
   /* Get the start of the file data */
 
-  ret = romfs_datastart(rm, dirinfo.rd_dir.fr_curroffset,
-                        &rf->rf_startoffset);
+  ret = romfs_datastart(rm, &nodeinfo, &rf->rf_startoffset);
   if (ret < 0)
     {
       ferr("ERROR: Failed to locate start of file data: %d\n", ret);
@@ -271,19 +264,7 @@ static int romfs_open(FAR struct file *filep, FAR const char *relpath,
 
   filep->f_priv = rf;
 
-  /* Then insert the new instance into the mountpoint structure.
-   * It needs to be there (1) to handle error conditions that effect
-   * all files, and (2) to inform the umount logic that we are busy
-   * (but a simple reference count could have done that).
-   */
-
-  rf->rf_next = rm->rm_head;
-  rm->rm_head = rf->rf_next;
-
-  romfs_semgive(rm);
-  return OK;
-
-  /* Error exits */
+  rm->rm_refs++;
 
 errout_with_semaphore:
   romfs_semgive(rm);
@@ -298,7 +279,7 @@ static int romfs_close(FAR struct file *filep)
 {
   FAR struct romfs_mountpt_s *rm;
   FAR struct romfs_file_s    *rf;
-  int                         ret = OK;
+  int                         ret;
 
   finfo("Closing\n");
 
@@ -313,6 +294,15 @@ static int romfs_close(FAR struct file *filep)
 
   DEBUGASSERT(rm != NULL);
 
+  ret = romfs_semtake(rm);
+  if (ret < 0)
+    {
+      return ret;
+    }
+
+  rm->rm_refs--;
+  romfs_semgive(rm);
+
   /* Do not check if the mount is healthy.  We must support closing of
    * the file even when there is healthy mount.
    */
@@ -346,7 +336,7 @@ static ssize_t romfs_read(FAR struct file *filep, FAR char *buffer,
   FAR struct romfs_mountpt_s *rm;
   FAR struct romfs_file_s    *rf;
   unsigned int                bytesread;
-  unsigned int                readsize;
+  unsigned int                readsize = 0;
   unsigned int                nsectors;
   uint32_t                    offset;
   size_t                      bytesleft;
@@ -400,14 +390,13 @@ static ssize_t romfs_read(FAR struct file *filep, FAR char *buffer,
    * error occurs.
    */
 
-  readsize = 0;
   while (buflen > 0)
     {
       /* Get the first sector and index to read from. */
 
-      offset     = rf->rf_startoffset + filep->f_pos;
-      sector     = SEC_NSECTORS(rm, offset);
-      sectorndx  = offset & SEC_NDXMASK(rm);
+      offset    = rf->rf_startoffset + filep->f_pos;
+      sector    = SEC_NSECTORS(rm, offset);
+      sectorndx = offset & SEC_NDXMASK(rm);
 
       /* Check if the user has provided a buffer large enough to
        * hold one or more complete sectors -AND- the read is
@@ -432,7 +421,7 @@ static ssize_t romfs_read(FAR struct file *filep, FAR char *buffer,
               goto errout_with_semaphore;
             }
 
-          bytesread  = nsectors * rm->rm_hwsectorsize;
+          bytesread = nsectors * rm->rm_hwsectorsize;
         }
       else
         {
@@ -472,12 +461,9 @@ static ssize_t romfs_read(FAR struct file *filep, FAR char *buffer,
       buflen       -= bytesread;
     }
 
-  romfs_semgive(rm);
-  return readsize;
-
 errout_with_semaphore:
   romfs_semgive(rm);
-  return ret;
+  return ret < 0 ? ret : readsize;
 }
 
 /****************************************************************************
@@ -499,8 +485,8 @@ static off_t romfs_seek(FAR struct file *filep, off_t offset, int whence)
 
   /* Recover our private data from the struct file instance */
 
-  rf    = filep->f_priv;
-  rm    = filep->f_inode->i_private;
+  rf = filep->f_priv;
+  rm = filep->f_inode->i_private;
 
   DEBUGASSERT(rm != NULL);
 
@@ -558,9 +544,6 @@ static off_t romfs_seek(FAR struct file *filep, off_t offset, int whence)
   filep->f_pos = position;
   finfo("New file position: %jd\n", (intmax_t)filep->f_pos);
 
-  romfs_semgive(rm);
-  return OK;
-
 errout_with_semaphore:
   romfs_semgive(rm);
   return ret;
@@ -600,8 +583,15 @@ static int romfs_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
       *ppv = (FAR void *)(rm->rm_xipbase + rf->rf_startoffset);
       return OK;
     }
+  else if (cmd == FIOC_FILEPATH)
+    {
+      FAR char *ptr = (FAR char *)((uintptr_t)arg);
+      inode_getpath(filep->f_inode, ptr);
+      strcat(ptr, rf->rf_path);
+      return OK;
+    }
 
-  ferr("ERROR: Invalid cmd: %d \n", cmd);
+  ferr("ERROR: Invalid cmd: %d\n", cmd);
   return -ENOTTY;
 }
 
@@ -628,7 +618,7 @@ static int romfs_dup(FAR const struct file *oldp, FAR struct file *newp)
    * structure
    */
 
-  rm = (FAR struct romfs_mountpt_s *)newp->f_inode->i_private;
+  rm = newp->f_inode->i_private;
   DEBUGASSERT(rm != NULL);
 
   /* Check if the mount is still healthy */
@@ -654,7 +644,7 @@ static int romfs_dup(FAR const struct file *oldp, FAR struct file *newp)
    * dup'ed file.
    */
 
-  newrf = (FAR struct romfs_file_s *)kmm_malloc(sizeof(struct romfs_file_s));
+  newrf = kmm_malloc(sizeof(struct romfs_file_s));
   if (!newrf)
     {
       ferr("ERROR: Failed to allocate private data\n");
@@ -681,19 +671,7 @@ static int romfs_dup(FAR const struct file *oldp, FAR struct file *newp)
 
   newp->f_priv = newrf;
 
-  /* Then insert the new instance into the mountpoint structure.
-   * It needs to be there (1) to handle error conditions that effect
-   * all files, and (2) to inform the umount logic that we are busy
-   * (but a simple reference count could have done that).
-   */
-
-  newrf->rf_next = rm->rm_head;
-  rm->rm_head = newrf->rf_next;
-
-  romfs_semgive(rm);
-  return OK;
-
-  /* Error exits */
+  rm->rm_refs++;
 
 errout_with_semaphore:
   romfs_semgive(rm);
@@ -726,7 +704,7 @@ static int romfs_fstat(FAR const struct file *filep, FAR struct stat *buf)
    */
 
   rf = filep->f_priv;
-  rm = (FAR struct romfs_mountpt_s *)filep->f_inode->i_private;
+  rm = filep->f_inode->i_private;
   DEBUGASSERT(rm != NULL);
 
   /* Check if the mount is still healthy */
@@ -762,7 +740,7 @@ static int romfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
                          FAR struct fs_dirent_s *dir)
 {
   FAR struct romfs_mountpt_s *rm;
-  FAR struct romfs_dirinfo_s  dirinfo;
+  struct romfs_nodeinfo_s     nodeinfo;
   int                         ret;
 
   finfo("relpath: '%s'\n", relpath);
@@ -792,7 +770,7 @@ static int romfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
 
   /* Find the requested directory */
 
-  ret = romfs_finddirentry(rm, &dirinfo, relpath);
+  ret = romfs_finddirentry(rm, &nodeinfo, relpath);
   if (ret < 0)
     {
       ferr("ERROR: Failed to find directory '%s': %d\n", relpath, ret);
@@ -801,7 +779,7 @@ static int romfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
 
   /* Verify that it is some kind of directory */
 
-  if (!IS_DIRECTORY(dirinfo.rd_next))
+  if (!IS_DIRECTORY(nodeinfo.rn_next))
     {
       /* The entry is not a directory */
 
@@ -812,9 +790,13 @@ static int romfs_opendir(FAR struct inode *mountpt, FAR const char *relpath,
 
   /* The entry is a directory */
 
-  memcpy(&dir->u.romfs, &dirinfo.rd_dir, sizeof(struct fs_romfsdir_s));
-  romfs_semgive(rm);
-  return OK;
+#ifdef CONFIG_FS_ROMFS_CACHE_NODE
+  dir->u.romfs.fr_firstnode   = nodeinfo.rn_child;
+  dir->u.romfs.fr_currnode    = nodeinfo.rn_child;
+#else
+  dir->u.romfs.fr_firstoffset = nodeinfo.rn_offset;
+  dir->u.romfs.fr_curroffset  = nodeinfo.rn_offset;
+#endif
 
 errout_with_semaphore:
   romfs_semgive(rm);
@@ -832,10 +814,12 @@ static int romfs_readdir(FAR struct inode *mountpt,
                          FAR struct fs_dirent_s *dir)
 {
   FAR struct romfs_mountpt_s *rm;
+#ifndef CONFIG_FS_ROMFS_CACHE_NODE
   uint32_t                    linkoffset;
-  uint32_t                    next;
   uint32_t                    info;
   uint32_t                    size;
+#endif
+  uint32_t                    next;
   int                         ret;
 
   finfo("Entry\n");
@@ -869,7 +853,11 @@ static int romfs_readdir(FAR struct inode *mountpt,
     {
       /* Have we reached the end of the directory */
 
+#ifdef CONFIG_FS_ROMFS_CACHE_NODE
+      if (!dir->u.romfs.fr_currnode || !(*dir->u.romfs.fr_currnode))
+#else
       if (!dir->u.romfs.fr_curroffset)
+#endif
         {
           /* We signal the end of the directory by returning the
            * special error -ENOENT
@@ -880,6 +868,11 @@ static int romfs_readdir(FAR struct inode *mountpt,
           goto errout_with_semaphore;
         }
 
+#ifdef CONFIG_FS_ROMFS_CACHE_NODE
+      next = (*dir->u.romfs.fr_currnode)->rn_next;
+      strcpy(dir->fd_dir.d_name, (*dir->u.romfs.fr_currnode)->rn_name);
+      dir->u.romfs.fr_currnode++;
+#else
       /* Parse the directory entry */
 
       ret = romfs_parsedirentry(rm, dir->u.romfs.fr_curroffset, &linkoffset,
@@ -903,6 +896,7 @@ static int romfs_readdir(FAR struct inode *mountpt,
       /* Set up the next directory entry offset */
 
       dir->u.romfs.fr_curroffset = next & RFNEXT_OFFSETMASK;
+#endif
 
       /* Check the file type */
 
@@ -962,7 +956,11 @@ static int romfs_rewinddir(FAR struct inode *mountpt,
   ret = romfs_checkmount(rm);
   if (ret == OK)
     {
+#ifdef CONFIG_FS_ROMFS_CACHE_NODE
+      dir->u.romfs.fr_currnode = dir->u.romfs.fr_firstnode;
+#else
       dir->u.romfs.fr_curroffset = dir->u.romfs.fr_firstoffset;
+#endif
     }
 
   romfs_semgive(rm);
@@ -1006,8 +1004,7 @@ static int romfs_bind(FAR struct inode *blkdriver, FAR const void *data,
 
   /* Create an instance of the mountpt state structure */
 
-  rm = (FAR struct romfs_mountpt_s *)
-    kmm_zalloc(sizeof(struct romfs_mountpt_s));
+  rm = kmm_zalloc(sizeof(struct romfs_mountpt_s));
   if (!rm)
     {
       ferr("ERROR: Failed to allocate mountpoint structure\n");
@@ -1019,8 +1016,8 @@ static int romfs_bind(FAR struct inode *blkdriver, FAR const void *data,
    * have to addref() here (but does have to release in ubind().
    */
 
-  nxsem_init(&rm->rm_sem, 0, 0);   /* Initialize the semaphore that controls access */
-  rm->rm_blkdriver   = blkdriver;  /* Save the block driver reference */
+  nxsem_init(&rm->rm_sem, 0, 0); /* Initialize the semaphore that controls access */
+  rm->rm_blkdriver = blkdriver;  /* Save the block driver reference */
 
   /* Get the hardware configuration and setup buffering appropriately */
 
@@ -1071,7 +1068,7 @@ errout_with_sem:
 static int romfs_unbind(FAR void *handle, FAR struct inode **blkdriver,
                         unsigned int flags)
 {
-  FAR struct romfs_mountpt_s *rm = (FAR struct romfs_mountpt_s *)handle;
+  FAR struct romfs_mountpt_s *rm = handle;
   int ret;
 
   finfo("Entry\n");
@@ -1091,7 +1088,7 @@ static int romfs_unbind(FAR void *handle, FAR struct inode **blkdriver,
       return ret;
     }
 
-  if (rm->rm_head)
+  if (rm->rm_refs)
     {
       /* We cannot unmount now.. there are open files */
 
@@ -1109,7 +1106,7 @@ static int romfs_unbind(FAR void *handle, FAR struct inode **blkdriver,
 
       if (rm->rm_blkdriver)
         {
-          struct inode *inode = rm->rm_blkdriver;
+          FAR struct inode *inode = rm->rm_blkdriver;
           if (inode)
             {
               if (INODE_IS_BLOCK(inode) && inode->u.i_bops->close != NULL)
@@ -1137,6 +1134,9 @@ static int romfs_unbind(FAR void *handle, FAR struct inode **blkdriver,
           kmm_free(rm->rm_buffer);
         }
 
+#ifdef CONFIG_FS_ROMFS_CACHE_NODE
+      romfs_freenode(rm->rm_root);
+#endif
       nxsem_destroy(&rm->rm_sem);
       kmm_free(rm);
       return OK;
@@ -1199,9 +1199,6 @@ static int romfs_statfs(FAR struct inode *mountpt, FAR struct statfs *buf)
   buf->f_bavail  = 0;
   buf->f_namelen = NAME_MAX;
 
-  romfs_semgive(rm);
-  return OK;
-
 errout_with_semaphore:
   romfs_semgive(rm);
   return ret;
@@ -1274,7 +1271,7 @@ static int romfs_stat(FAR struct inode *mountpt, FAR const char *relpath,
                       FAR struct stat *buf)
 {
   FAR struct romfs_mountpt_s *rm;
-  FAR struct romfs_dirinfo_s dirinfo;
+  struct romfs_nodeinfo_s nodeinfo;
   uint8_t type;
   int ret;
 
@@ -1305,7 +1302,7 @@ static int romfs_stat(FAR struct inode *mountpt, FAR const char *relpath,
 
   /* Find the directory entry corresponding to relpath. */
 
-  ret = romfs_finddirentry(rm, &dirinfo, relpath);
+  ret = romfs_finddirentry(rm, &nodeinfo, relpath);
 
   /* If nothing was found, then we fail with EEXIST */
 
@@ -1317,8 +1314,8 @@ static int romfs_stat(FAR struct inode *mountpt, FAR const char *relpath,
 
   /* Return information about the directory entry */
 
-  type = (uint8_t)(dirinfo.rd_next & RFNEXT_ALLMODEMASK);
-  ret  = romfs_stat_common(type, dirinfo.rd_size, rm->rm_hwsectorsize, buf);
+  type = (uint8_t)(nodeinfo.rn_next & RFNEXT_ALLMODEMASK);
+  ret  = romfs_stat_common(type, nodeinfo.rn_size, rm->rm_hwsectorsize, buf);
 
 errout_with_semaphore:
   romfs_semgive(rm);
