@@ -64,9 +64,9 @@ static const struct file_operations g_sock_fileops =
   sock_file_write,  /* write */
   NULL,             /* seek */
   sock_file_ioctl,  /* ioctl */
-  sock_file_poll,   /* poll */
+  sock_file_poll    /* poll */
 #ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  NULL,               /* unlink */
+  , NULL            /* unlink */
 #endif
 };
 
