@@ -83,25 +83,25 @@ int file_vioctl(FAR struct file *filep, int req, va_list ap)
           FAR int *nonblock = (FAR int *)(uintptr_t)arg;
           if (nonblock && *nonblock)
             {
-              ret = file_fcntl(filep, F_SETFL,
-                              file_fcntl(filep, F_GETFL) | O_NONBLOCK);
+              filep->f_oflags |= O_NONBLOCK;
             }
           else
             {
-              ret = file_fcntl(filep, F_SETFL,
-                              file_fcntl(filep, F_GETFL) & ~O_NONBLOCK);
+              filep->f_oflags &= ~O_NONBLOCK;
             }
+
+          ret = OK;
         }
         break;
 
       case FIOCLEX:
-        ret = file_fcntl(filep, F_SETFD,
-                         file_fcntl(filep, F_GETFD) | FD_CLOEXEC);
+        filep->f_oflags |= O_CLOEXEC;
+        ret = OK;
         break;
 
       case FIONCLEX:
-        ret = file_fcntl(filep, F_SETFD,
-                         file_fcntl(filep, F_GETFD) & ~FD_CLOEXEC);
+        filep->f_oflags &= ~O_CLOEXEC;
+        ret = OK;
         break;
 
       case FIOC_FILEPATH:
