@@ -186,10 +186,12 @@
 #  endif
 #endif
 
-/* The unsued code or data */
+/* The unused code or data */
 
 #  define unused_code __attribute__((unused))
 #  define unused_data __attribute__((unused))
+#  define used_code __attribute__((used))
+#  define used_data __attribute__((used))
 
 /* Some versions of GCC have a separate __syslog__ format.
  * http://mail-index.netbsd.org/source-changes/2015/10/14/msg069435.html
@@ -452,6 +454,8 @@
 
 #  define unused_code
 #  define unused_data
+#  define used_code
+#  define used_data
 
 #  define formatlike(a)
 #  define printflike(a, b)
@@ -591,6 +595,8 @@
 #  define nostackprotect_function
 #  define unused_code
 #  define unused_data
+#  define used_code
+#  define used_data
 #  define formatlike(a)
 #  define printflike(a, b)
 #  define sysloglike(a, b)
@@ -702,6 +708,8 @@
 #  define nostackprotect_function
 #  define unused_code
 #  define unused_data
+#  define used_code
+#  define used_data
 #  define formatlike(a)
 #  define printflike(a, b)
 #  define sysloglike(a, b)
@@ -768,6 +776,8 @@
 #  define nostackprotect_function
 #  define unused_code
 #  define unused_data
+#  define used_code
+#  define used_data
 #  define formatlike(a)
 #  define printflike(a, b)
 #  define sysloglike(a, b)
