@@ -18,8 +18,8 @@
  *
  ****************************************************************************/
 
-#ifndef _INCLUDE_NUTTX_MM_IOB_H
-#define _INCLUDE_NUTTX_MM_IOB_H
+#ifndef __INCLUDE_NUTTX_MM_IOB_H
+#define __INCLUDE_NUTTX_MM_IOB_H
 
 /****************************************************************************
  * Included Files
@@ -233,6 +233,23 @@ struct iob_userstats_s
 
 void iob_initialize(void);
 
+/****************************************************************************
+ * Name: iob_timedalloc
+ *
+ * Description:
+ *  Allocate an I/O buffer by taking the buffer at the head of the free list.
+ *  This wait will be terminated when the specified timeout expires.
+ *
+ * Input Parameters:
+ *   throttled  - An indication of the IOB allocation is "throttled"
+ *   timeout    - Timeout value in milliseconds.
+ *   consumerid - id representing who is consuming the IOB
+ *
+ ****************************************************************************/
+
+FAR struct iob_s *iob_timedalloc(bool throttled, unsigned int timeout,
+                                 enum iob_user_e consumerid);
+
 /****************************************************************************
  * Name: iob_alloc
  *
@@ -630,4 +647,4 @@ FAR struct iob_userstats_s * iob_getuserstats(enum iob_user_e userid);
 #endif
 
 #endif /* CONFIG_MM_IOB */
-#endif /* _INCLUDE_NUTTX_MM_IOB_H */
+#endif /* __INCLUDE_NUTTX_MM_IOB_H */
