@@ -63,14 +63,20 @@
 /* Note filter mode flag definitions */
 
 #define NOTE_FILTER_MODE_FLAG_ENABLE       (1 << 0) /* Enable instrumentation */
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
+#define NOTE_FILTER_MODE_FLAG_SWITCH       (1 << 1) /* Enable syscall instrumentation */
+#endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_SYSCALL
-#define NOTE_FILTER_MODE_FLAG_SYSCALL      (1 << 1) /* Enable syscall instrumentation */
+#define NOTE_FILTER_MODE_FLAG_SYSCALL      (1 << 2) /* Enable syscall instrumentation */
 #endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_IRQHANDLER
-#define NOTE_FILTER_MODE_FLAG_IRQ          (1 << 2) /* Enable IRQ instrumentaiton */
+#define NOTE_FILTER_MODE_FLAG_IRQ          (1 << 3) /* Enable IRQ instrumentaiton */
+#endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+#define NOTE_FILTER_MODE_FLAG_DUMP         (1 << 4) /* Enable dump instrumentaiton */
 #endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_SYSCALL
-#define NOTE_FILTER_MODE_FLAG_SYSCALL_ARGS (1 << 3) /* Enable collecting syscall arguments */
+#define NOTE_FILTER_MODE_FLAG_SYSCALL_ARGS (1 << 5) /* Enable collecting syscall arguments */
 #endif
 
 /* Helper macros for syscall instrumentation filter */
@@ -99,6 +105,18 @@
   memset((s), 0, sizeof(struct note_filter_irq_s))
 #endif
 
+/* Note dump module tag definitions */
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+#  define NOTE_MODULE(a, b, c, d)  \
+  ((uint32_t)((a) & 0xff)        | \
+  ((uint32_t)((b) & 0xff) << 8)  | \
+  ((uint32_t)((c) & 0xff) << 16) | \
+  ((uint32_t)((d) & 0xff) << 24))
+#else
+#  define NOTE_MODULE(a,b,c,d)
+#endif
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
@@ -108,18 +126,24 @@
 enum note_type_e
 {
   NOTE_START           = 0,
-  NOTE_STOP            = 1,
+  NOTE_STOP            = 1
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
+  ,
   NOTE_SUSPEND         = 2,
   NOTE_RESUME          = 3
+#endif
 #ifdef CONFIG_SMP
   ,
   NOTE_CPU_START       = 4,
-  NOTE_CPU_STARTED     = 5,
+  NOTE_CPU_STARTED     = 5
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
+  ,
   NOTE_CPU_PAUSE       = 6,
   NOTE_CPU_PAUSED      = 7,
   NOTE_CPU_RESUME      = 8,
   NOTE_CPU_RESUMED     = 9
 #endif
+#endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_PREEMPTION
   ,
   NOTE_PREEMPT_LOCK    = 10,
@@ -147,6 +171,11 @@ enum note_type_e
   NOTE_IRQ_ENTER       = 20,
   NOTE_IRQ_LEAVE       = 21
 #endif
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+  ,
+  NOTE_DUMP_STRING     = 22,
+  NOTE_DUMP_BINARY     = 23
+#endif
 };
 
 /* This structure provides the common header of each note */
@@ -186,6 +215,7 @@ struct note_stop_s
   struct note_common_s nsp_cmn; /* Common note parameters */
 };
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
 /* This is the specific form of the NOTE_SUSPEND note */
 
 struct note_suspend_s
@@ -200,6 +230,7 @@ struct note_resume_s
 {
   struct note_common_s nre_cmn; /* Common note parameters */
 };
+#endif
 
 #ifdef CONFIG_SMP
 
@@ -218,6 +249,7 @@ struct note_cpu_started_s
   struct note_common_s ncs_cmn; /* Common note parameters */
 };
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
 /* This is the specific form of the NOTE_CPU_PAUSE note */
 
 struct note_cpu_pause_s
@@ -248,6 +280,7 @@ struct note_cpu_resumed_s
   struct note_common_s ncr_cmn; /* Common note parameters */
 };
 #endif
+#endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_PREEMPTION
 /* This is the specific form of the NOTE_PREEMPT_LOCK/UNLOCK note */
@@ -318,6 +351,29 @@ struct note_irqhandler_s
 };
 #endif /* CONFIG_SCHED_INSTRUMENTATION_IRQHANDLER */
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+struct note_string_s
+{
+  struct note_common_s nst_cmn; /* Common note parameters */
+  char nst_data[1];             /* String data terminated by '\0' */
+};
+
+#define SIZEOF_NOTE_STRING(n) (sizeof(struct note_string_s) + \
+                               (n) * sizeof(char))
+
+struct note_binary_s
+{
+  struct note_common_s nbi_cmn; /* Common note parameters */
+  uint8_t  nbi_module[4];       /* Module number */
+  uint8_t  nbi_event;           /* Event number */
+  uint8_t  nbi_data[1];         /* Binary data */
+};
+
+#define SIZEOF_NOTE_BINARY(n) (sizeof(struct note_binary_s) + \
+                               ((n) - 1) * sizeof(uint8_t))
+
+#endif /* CONFIG_SCHED_INSTRUMENTATION_DUMP */
+
 #ifdef CONFIG_SCHED_INSTRUMENTATION_FILTER
 
 /* This is the type of the argument passed to the NOTECTL_GETMODE and
@@ -378,24 +434,37 @@ struct note_filter_irq_s
 
 void sched_note_start(FAR struct tcb_s *tcb);
 void sched_note_stop(FAR struct tcb_s *tcb);
+
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
 void sched_note_suspend(FAR struct tcb_s *tcb);
 void sched_note_resume(FAR struct tcb_s *tcb);
+#else
+#  define sched_note_suspend(t)
+#  define sched_note_resume(t)
+#endif
 
 #ifdef CONFIG_SMP
 void sched_note_cpu_start(FAR struct tcb_s *tcb, int cpu);
 void sched_note_cpu_started(FAR struct tcb_s *tcb);
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
 void sched_note_cpu_pause(FAR struct tcb_s *tcb, int cpu);
 void sched_note_cpu_paused(FAR struct tcb_s *tcb);
 void sched_note_cpu_resume(FAR struct tcb_s *tcb, int cpu);
 void sched_note_cpu_resumed(FAR struct tcb_s *tcb);
 #else
-#  define sched_note_cpu_start(t,c)
-#  define sched_note_cpu_started(t)
 #  define sched_note_cpu_pause(t,c)
 #  define sched_note_cpu_paused(t)
 #  define sched_note_cpu_resume(t,c)
 #  define sched_note_cpu_resumed(t)
 #endif
+#else
+#  define sched_note_cpu_pause(t,c)
+#  define sched_note_cpu_paused(t)
+#  define sched_note_cpu_resume(t,c)
+#  define sched_note_cpu_resumed(t)
+#  define sched_note_cpu_start(t,c)
+#  define sched_note_cpu_started(t)
+#endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_PREEMPTION
 void sched_note_premption(FAR struct tcb_s *tcb, bool locked);
@@ -439,6 +508,25 @@ void sched_note_irqhandler(int irq, FAR void *handler, bool enter);
 #  define sched_note_irqhandler(i,h,e)
 #endif
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+void sched_note_string(FAR const char *buf);
+void sched_note_dump(uint32_t module, uint8_t event,
+                     FAR const void *buf, size_t len);
+void sched_note_vprintf(FAR const char *fmt, va_list va) printflike(1, 0);
+void sched_note_vbprintf(uint32_t module, uint8_t event,
+                         FAR const char *fmt, va_list va) printflike(3, 0);
+void sched_note_printf(FAR const char *fmt, ...) printflike(1, 2);
+void sched_note_bprintf(uint32_t module, uint8_t event,
+                        FAR const char *fmt, ...) printflike(3, 4);
+#else
+#  define sched_note_string(b)
+#  define sched_note_dump(m,e,b,l)
+#  define sched_note_vprintf(f,v)
+#  define sched_note_vbprintf(m,e,f,v)
+#  define sched_note_printf(f...)
+#  define sched_note_bprintf(m,e,f...)
+#endif /* CONFIG_SCHED_INSTRUMENTATION_DUMP */
+
 #if defined(__KERNEL__) || defined(CONFIG_BUILD_FLAT)
 
 /****************************************************************************
@@ -542,6 +630,7 @@ void sched_note_filter_irq(struct note_filter_irq_s *oldf,
 
 #else /* CONFIG_SCHED_INSTRUMENTATION */
 
+#  define NOTE_MODULE(a,b,c,d)
 #  define sched_note_start(t)
 #  define sched_note_stop(t)
 #  define sched_note_suspend(t)
@@ -561,6 +650,12 @@ void sched_note_filter_irq(struct note_filter_irq_s *oldf,
 #  define sched_note_syscall_enter(n,a...)
 #  define sched_note_syscall_leave(n,r)
 #  define sched_note_irqhandler(i,h,e)
+#  define sched_note_string(b)
+#  define sched_note_dump(m,e,b,l)
+#  define sched_note_vprintf(f,v)
+#  define sched_note_vbprintf(m,e,f,v)
+#  define sched_note_printf(f...)
+#  define sched_note_bprintf(m,e,f...)
 
 #endif /* CONFIG_SCHED_INSTRUMENTATION */
 #endif /* __INCLUDE_NUTTX_SCHED_NOTE_H */
