@@ -125,8 +125,9 @@
 #define SENSOR_TYPE_IR                              11
 
 /* GPS
- * A sensor of this type returns gps data. Include year, month, day,
- * hour, minutes, seconds, altitude, longitude, latitude.
+ * A sensor of this type returns gps data. Include latitude, longitude,
+ * altitude, horizontal position accuracy, vertical position accuracy,
+ * horizontal dilution of precision, vertical dilution of precision...
  */
 
 #define SENSOR_TYPE_GPS                             12
@@ -217,9 +218,62 @@
 
 #define SENSOR_TYPE_HEART_BEAT                      24
 
+/* ECG (Electrocardiogram)
+ * A sensor of this type returns the ECG voltage in μV. Sensors may amplify
+ * the input ECG signal. Here the ECG voltage is the un-amplified ECG
+ * voltage.
+ */
+
+#define SENSOR_TYPE_ECG                             25
+
+/* PPG Dual (2-channel photoplethysmography)
+ * A sensor of this type returns the 2 channels PPG measurements in ADC
+ * counts and their corresponding LED current and ADC gains. The PPG
+ * measurements come from photodiodes and following current amplifiers and
+ * ADCs, where a photodiode switches reflected light intensity to current.
+ * The LED current decides the lightness of LED, which is the input of PPG
+ * measurements. The ADC gains are multipled on the output and affect SNR.
+ */
+
+#define SENSOR_TYPE_PPGD                            26
+
+/* PPG Quad (4-channel photoplethysmography)
+ * A sensor of this type returns the 4 channels PPG measurements in ADC
+ * counts and their corresponding LED current and ADC gains. The PPG
+ * measurements come from photodiodes and following current amplifiers and
+ * ADCs, where a photodiode switches reflected light intensity to current.
+ * The LED current decides the lightness of LED, which is the input of PPG
+ * measurements. The ADC gains are multipled on the output and affect SNR.
+ */
+
+#define SENSOR_TYPE_PPGQ                            27
+
+/* Imdepance
+ * A sensor of this type returns the impedance measurements. An impedance
+ * is a complex number, which consists of a real part(resistance) and an
+ * imaginary part(reactance). Both of them are in uint Ohm(Ω).
+ */
+
+#define SENSOR_TYPE_IMPEDANCE                       28
+
+/* OTS (Optical tracking sensor)
+ * A sensor of this type returns the OTS measurements in counts. It
+ * integrates an optical chip and a LASER light source in a single miniature
+ * package. It provies wide depth of field range on glossy surface, and
+ * design flexibility into a compact device.
+ */
+
+#define SENSOR_TYPE_OTS                             29
+
+/* Sensor of gps satellite
+ * A sensor of this type returns the gps satellite information.
+ */
+
+#define SENSOR_TYPE_GPS_SATELLITE                   30
+
 /* The total number of sensor */
 
-#define SENSOR_TYPE_COUNT                           25
+#define SENSOR_TYPE_COUNT                           31
 
 /****************************************************************************
  * Inline Functions
@@ -229,12 +283,7 @@ static inline uint64_t sensor_get_timestamp(void)
 {
   struct timespec ts;
 
-#ifdef CONFIG_CLOCK_MONOTONIC
-  clock_gettime(CLOCK_MONOTONIC, &ts);
-#else
-  clock_gettime(CLOCK_REALTIME, &ts);
-#endif
-
+  clock_systime_timespec(&ts);
   return 1000000ull * ts.tv_sec + ts.tv_nsec / 1000;
 }
 
@@ -327,19 +376,35 @@ struct sensor_event_ir      /* Type: Infrared Ray */
 
 struct sensor_event_gps     /* Type: Gps */
 {
-  int year;                 /* Time */
-  int month;
-  int day;
-  int hour;
-  int min;
-  int sec;
-  int msec;
+  uint64_t timestamp;       /* Time since system start, Units is microseconds */
+
+  /* This is the timestamp which comes from the gps module. It might be
+   * unavailable right after cold start, indicated by a value of 0,
+   * Units is microseconds
+   */
+
+  uint64_t time_utc;
 
-  float yaw;                /* Unit is Si degrees */
-  float height;             /* Unit is SI m */
-  float speed;              /* Unit is m/s */
   float latitude;           /* Unit is degrees */
   float longitude;          /* Unit is degrees */
+  float altitude;           /* Altitude above MSL(mean seal level), Unit is SI m */
+  float altitude_ellipsoid; /* Altitude bove Ellipsoid, Unit is SI m */
+
+  float eph;                /* GPS horizontal position accuracy (metres) */
+  float epv;                /* GPS vertical position accuracy (metres) */
+
+  float hdop;               /* Horizontal dilution of precision */
+  float vdop;               /* Vertical dilution of precision */
+
+  float ground_speed;       /* GPS ground speed, Unit is m/s */
+
+  /* Course over ground (NOT heading, but direction of movement),
+   * Unit is Si degrees
+   */
+
+  float course;
+
+  uint32_t satellites_used; /* Number of satellites used */
 };
 
 struct sensor_event_uv      /* Type: Ultraviolet Light */
@@ -414,6 +479,71 @@ struct sensor_event_hbeat   /* Type: Heart Beat */
   float beat;               /* Units is times/minutes */
 };
 
+struct sensor_event_ecg     /* Type: ECG */
+{
+  uint64_t timestamp;       /* Unit is microseconds */
+  float ecg;                /* Unit is μV */
+};
+
+struct sensor_event_ppgd    /* Type: PPGD */
+{
+  uint64_t timestamp;       /* Unit is microseconds */
+  uint32_t ppg[2];          /* PPG from 2 channels. Units are ADC counts. */
+  uint32_t current;         /* LED current. Unit is uA. */
+  uint16_t gain[2];         /* ADC gains of channels. Units are V/V or V/A. */
+};
+
+struct sensor_event_ppgq    /* Type: PPDQ */
+{
+  uint64_t timestamp;       /* Unit is microseconds */
+  uint32_t ppg[4];          /* PPG from 4 channels. Units are ADC counts. */
+  uint32_t current;         /* LED current. Unit is uA. */
+  uint16_t gain[4];         /* ADC gains of channels. Units are V/V or V/A. */
+};
+
+struct sensor_event_impd    /* Type: Impedance */
+{
+  uint64_t timestamp;       /* Unit is microseconds */
+  float real;               /* Real part, unit is Ohm(Ω) */
+  float imag;               /* Imaginary part, unit is Ohm(Ω) */
+};
+
+struct sensor_event_ots     /* Type: OTS */
+{
+  uint64_t timestamp;       /* Unit is microseconds */
+  int32_t x;                /* Axis X in counts */
+  int32_t y;                /* Axis Y in counts */
+};
+
+struct sensor_event_gps_satellite
+{
+  uint64_t timestamp;       /* Time since system start, Units is microseconds */
+  uint32_t count;           /* Total number of messages of satellites visible */
+  uint32_t satellites;      /* Total number of satellites in view */
+
+  struct satellite
+  {
+    uint32_t svid;          /* Space vehicle ID */
+
+  /* Elevation (0: right on top of receiver,
+   * 90: on the horizon) of satellite
+   */
+
+    uint32_t elevation;
+
+    /* Direction of satellite, 0: 0 deg, 255: 360 deg. */
+
+    uint32_t azimuth;
+
+  /* dBHz, Signal to noise ratio of satellite C/N0, range 0..99,
+   * zero when not tracking this satellite
+   */
+
+    uint32_t snr;
+  }
+  info[4];
+};
+
 /* The sensor lower half driver interface */
 
 struct sensor_lowerhalf_s;
@@ -561,7 +691,27 @@ struct sensor_ops_s
    **************************************************************************/
 
   CODE int (*selftest)(FAR struct sensor_lowerhalf_s *lower,
-                        unsigned long arg);
+                       unsigned long arg);
+
+  /**************************************************************************
+   * Name: set_calibvalue
+   *
+   * The calibration value to be written in or the non-volatile memory of the
+   * sensor or dedicated registers. At each power-on, so that the values read
+   * from the sensor are already corrected. When the device is calibrated,
+   * the absolute accuracy will be better than before.
+   *
+   * Input Parameters:
+   *   lower      - The instance of lower half sensor driver.
+   *   arg        - The parameters associated with calibration value.
+   *
+   * Returned Value:
+   *   Zero (OK) on success; a negated errno value on failure.
+   *
+   **************************************************************************/
+
+  CODE int (*set_calibvalue)(FAR struct sensor_lowerhalf_s *lower,
+                             unsigned long arg);
 
   /**************************************************************************
    * Name: control
