@@ -34,6 +34,12 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
+#ifdef CONFIG_LIBC_PASSWD_LINESIZE
+# define NSS_BUFLEN_PASSWD CONFIG_LIBC_PASSWD_LINESIZE
+#else
+# define NSS_BUFLEN_PASSWD 256
+#endif
+
 /****************************************************************************
  * Public Type Definitions
  ****************************************************************************/
