@@ -26,15 +26,10 @@
  ****************************************************************************/
 
 #include <nuttx/config.h>
+#include <nuttx/compiler.h>
 
 #include <stddef.h>
 
-/* Non-standard support for cases where CHAR_BIT != 8 carried in strings.h
- * only for convenience.  See include/nuttx/b2c.h.
- */
-
-#include <nuttx/b2c.h>
-
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
@@ -63,6 +58,7 @@ int        strerror_r(int, FAR char *, size_t);
 size_t     strlen(FAR const char *);
 size_t     strnlen(FAR const char *, size_t);
 FAR char  *strcat(FAR char *, FAR const char *);
+size_t     strlcat(FAR char *, FAR const char *, size_t);
 FAR char  *strncat(FAR char *, FAR const char *, size_t);
 int        strcmp(FAR const char *, FAR const char *);
 int        strncmp(FAR const char *, FAR const char *, size_t);
