@@ -25,10 +25,14 @@
  * Included Files
  ****************************************************************************/
 
+#include <limits.h>
+
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
 
+#define MAXHOSTNAMELEN HOST_NAME_MAX
+
 /****************************************************************************
  * Public Type Definitions
  ****************************************************************************/
