@@ -27,6 +27,7 @@
 
 #include <sys/types.h>
 #include <nuttx/compiler.h>
+#include <limits.h>
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -256,8 +257,6 @@
 #define STDIN_FILENO                     0       /* File number of stdin */
 #define STDOUT_FILENO                    1       /* File number of stdout */
 
-#define HOST_NAME_MAX                    32
-
 /* Helpers and legacy compatibility definitions */
 
 #define link(p1, p2)                     symlink((p1), (p2))
@@ -303,9 +302,7 @@ extern "C"
 pid_t   vfork(void);
 pid_t   getpid(void);
 pid_t   gettid(void);
-#ifdef CONFIG_SCHED_HAVE_PARENT
 pid_t   getppid(void);
-#endif
 void    _exit(int status) noreturn_function;
 unsigned int sleep(unsigned int seconds);
 int     usleep(useconds_t usec);
@@ -328,14 +325,12 @@ ssize_t pwrite(int fd, FAR const void *buf, size_t nbytes, off_t offset);
 int     ftruncate(int fd, off_t length);
 int     fchown(int fd, uid_t owner, gid_t group);
 
-#ifdef CONFIG_SERIAL_TERMIOS
 /* Check if a file descriptor corresponds to a terminal I/O file */
 
 int     isatty(int fd);
 
 FAR char *ttyname(int fd);
 int       ttyname_r(int fd, FAR char *buf, size_t buflen);
-#endif
 
 /* Memory management */
 
@@ -391,8 +386,8 @@ FAR int   *getopterrp(void);  /* Print error message */
 FAR int   *getoptindp(void);  /* Index into argv */
 FAR int   *getoptoptp(void);  /* Unrecognized option character */
 
-int     gethostname(FAR char *name, size_t size);
-int     sethostname(FAR const char *name, size_t size);
+int     gethostname(FAR char *name, size_t namelen);
+int     sethostname(FAR const char *name, size_t namelen);
 
 /* Get configurable system variables */
 
