@@ -264,38 +264,11 @@ static int readstream(FAR struct lib_instream_s *instream,
 
   while (ch != EOF && nbytes < (MAXRECORD_ASCSIZE - 1))
     {
-#if defined(CONFIG_EOL_IS_LF)
-      if (ch == '\n')
-        {
-          *line = '\0';
-          return nbytes;
-        }
-
-#elif defined(CONFIG_EOL_IS_BOTH_CRLF)
-      if (ch == '\r')
-        {
-          continue;
-        }
-      else if (ch == '\n')
-        {
-          *line = '\0';
-          return nbytes;
-        }
-
-#elif defined(CONFIG_EOL_IS_CR)
-      if (ch == '\r')
-        {
-          *line = '\0';
-          return nbytes;
-        }
-
-#elif defined(CONFIG_EOL_IS_EITHER_CRLF)
       if (ch == '\n' || ch == '\r')
         {
           *line = '\0';
           return nbytes;
         }
-#endif
 
       /* Only hex data goes into the line buffer */
 
