@@ -181,7 +181,7 @@ static inline uint16_t dns_alloc_id(void)
 {
   struct timespec ts;
 
-  clock_gettime(CLOCK_REALTIME, &ts);
+  clock_gettime(CLOCK_MONOTONIC, &ts);
   return (uint32_t)ts.tv_nsec + ((uint32_t)ts.tv_nsec >> 16);
 }
 
@@ -219,7 +219,7 @@ static int dns_send_query(int sd, FAR const char *name,
 
   hdr               = (FAR struct dns_header_s *)buffer;
   memset(hdr, 0, sizeof(*hdr));
-  hdr->id           = htons(id);
+  hdr->id           = HTONS(id);
   hdr->flags1       = DNS_FLAG1_RD;
   hdr->numquestions = HTONS(1);
 
@@ -279,7 +279,7 @@ static int dns_send_query(int sd, FAR const char *name,
   *dest++ = (DNS_CLASS_IN >> 8);   /* DNS record class (big endian) */
   *dest++ = (DNS_CLASS_IN & 0xff);
 
-  qinfo->rectype = htons(rectype);
+  qinfo->rectype = HTONS(rectype);
   qinfo->id      = hdr->id;
 
   /* Send the request */
@@ -334,6 +334,7 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
   FAR struct dns_answer_s *ans;
   FAR struct dns_header_s *hdr;
   FAR struct dns_question_s *que;
+  struct dns_question_s bak;
   uint16_t nquestions;
   uint16_t nanswers;
   uint16_t temp;
@@ -366,12 +367,12 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
   hdr         = (FAR struct dns_header_s *)buffer;
   endofbuffer = (FAR uint8_t *)buffer + ret;
 
-  ninfo("ID %d\n", ntohs(hdr->id));
+  ninfo("ID %d\n", NTOHS(hdr->id));
   ninfo("Query %d\n", hdr->flags1 & DNS_FLAG1_RESPONSE);
   ninfo("Error %d\n", hdr->flags2 & DNS_FLAG2_ERR_MASK);
   ninfo("Num questions %d, answers %d, authrr %d, extrarr %d\n",
-        ntohs(hdr->numquestions), ntohs(hdr->numanswers),
-        ntohs(hdr->numauthrr), ntohs(hdr->numextrarr));
+        NTOHS(hdr->numquestions), NTOHS(hdr->numanswers),
+        NTOHS(hdr->numauthrr), NTOHS(hdr->numextrarr));
 
   /* Check for error */
 
@@ -386,7 +387,7 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
   if (hdr->id != qinfo->id)
     {
       nerr("ERROR: DNS wrong response ID (expected %d, got %d)\n",
-           ntohs(qinfo->id), ntohs(hdr->id));
+           NTOHS(qinfo->id), NTOHS(hdr->id));
       return -EBADMSG;
     }
 
@@ -394,8 +395,8 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
    * and the extrarr are simply discarded.
    */
 
-  nquestions = ntohs(hdr->numquestions);
-  nanswers   = ntohs(hdr->numanswers);
+  nquestions = NTOHS(hdr->numquestions);
+  nanswers   = NTOHS(hdr->numanswers);
 
   /* We only ever send queries with one question. */
 
@@ -437,12 +438,13 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
   /* Validate query type and class */
 
   que = (FAR struct dns_question_s *)nameptr;
+  memcpy(&bak, que, sizeof(struct dns_question_s));
 
   /* N.B. Unaligned access may occur here */
 
   temp = HTONS(DNS_CLASS_IN);
-  if (memcmp(&que->type, &qinfo->rectype, sizeof(uint16_t)) != 0 ||
-      memcmp(&que->class, &temp, sizeof(uint16_t)) != 0)
+  if (memcmp(&bak.type, &qinfo->rectype, sizeof(uint16_t)) != 0 ||
+      memcmp(&bak.class, &temp, sizeof(uint16_t)) != 0)
     {
       nerr("ERROR: DNS response with wrong question\n");
       return -EBADMSG;
@@ -469,10 +471,10 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
 
       ans = (FAR struct dns_answer_s *)nameptr;
 
-      ninfo("Answer: type=%04x, class=%04x, ttl=%06x, length=%04x \n",
-            ntohs(ans->type), ntohs(ans->class),
-            (ntohs(ans->ttl[0]) << 16) | ntohs(ans->ttl[1]),
-            ntohs(ans->len));
+      ninfo("Answer: type=%04x, class=%04x, ttl=%06x, length=%04x\n",
+            NTOHS(ans->type), NTOHS(ans->class),
+            (NTOHS(ans->ttl[0]) << 16) | NTOHS(ans->ttl[1]),
+            NTOHS(ans->len));
 
       /* Check for IPv4/6 address type and Internet class. Others are
        * discarded.
@@ -518,14 +520,14 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
           nameptr += 10 + 16;
 
           ninfo("IPv6 address: %04x:%04x:%04x:%04x:%04x:%04x:%04x:%04x\n",
-                ntohs(ans->u.ipv6.s6_addr16[0]),
-                ntohs(ans->u.ipv6.s6_addr16[1]),
-                ntohs(ans->u.ipv6.s6_addr16[2]),
-                ntohs(ans->u.ipv6.s6_addr16[3]),
-                ntohs(ans->u.ipv6.s6_addr16[4]),
-                ntohs(ans->u.ipv6.s6_addr16[5]),
-                ntohs(ans->u.ipv6.s6_addr16[6]),
-                ntohs(ans->u.ipv6.s6_addr16[7]));
+                NTOHS(ans->u.ipv6.s6_addr16[0]),
+                NTOHS(ans->u.ipv6.s6_addr16[1]),
+                NTOHS(ans->u.ipv6.s6_addr16[2]),
+                NTOHS(ans->u.ipv6.s6_addr16[3]),
+                NTOHS(ans->u.ipv6.s6_addr16[4]),
+                NTOHS(ans->u.ipv6.s6_addr16[5]),
+                NTOHS(ans->u.ipv6.s6_addr16[6]),
+                NTOHS(ans->u.ipv6.s6_addr16[7]));
 
           inaddr                  = &addr[naddr_read].ipv6;
           inaddr->sin6_family     = AF_INET6;
@@ -541,7 +543,7 @@ static int dns_recv_response(int sd, FAR union dns_addr_u *addr, int naddr,
       else
 #endif
         {
-          nameptr = nameptr + 10 + ntohs(ans->len);
+          nameptr = nameptr + 10 + NTOHS(ans->len);
         }
     }
 
