@@ -29,9 +29,8 @@
 
 #include <nuttx/arch.h>
 #include <nuttx/tls.h>
-#include <arch/tls.h>
 
-#ifndef CONFIG_TLS_ALIGNED
+#if !defined(CONFIG_TLS_ALIGNED) || defined(__KERNEL__)
 
 /****************************************************************************
  * Public Functions
@@ -43,7 +42,7 @@
  * Description:
  *   Return a reference to the tls_info_s structure.  This is used as part
  *   of the internal implementation of tls_get/set_elem() and ONLY for the
- *   where CONFIG_TLS_ALIGNED is *not* defined
+ *   where CONFIG_TLS_ALIGNED is *not* defined or __KERNEL__ is defined.
  *
  * Input Parameters:
  *   None
@@ -73,4 +72,4 @@ FAR struct tls_info_s *tls_get_info(void)
   return info;
 }
 
-#endif /* !CONFIG_TLS_ALIGNED */
+#endif /* !CONFIG_TLS_ALIGNED || __KERNEL__ */
