@@ -314,10 +314,10 @@ int icmpv6_autoconfig(FAR struct net_driver_s *dev)
   icmpv6_linkipaddr(dev, lladdr);
 
   ninfo("lladdr=%04x:%04x:%04x:%04x:%04x:%04x:%04x:%04x\n",
-        ntohs(lladdr[0]), ntohs(lladdr[1]),
-        ntohs(lladdr[2]), ntohs(lladdr[3]),
-        ntohs(lladdr[4]), ntohs(lladdr[5]),
-        ntohs(lladdr[6]), ntohs(lladdr[7]));
+        NTOHS(lladdr[0]), NTOHS(lladdr[1]),
+        NTOHS(lladdr[2]), NTOHS(lladdr[3]),
+        NTOHS(lladdr[4]), NTOHS(lladdr[5]),
+        NTOHS(lladdr[6]), NTOHS(lladdr[7]));
 
 #ifdef CONFIG_NET_ICMPv6_NEIGHBOR
   /* 2. Link-Local Address Uniqueness Test:  The node tests to ensure that
