@@ -31,6 +31,7 @@
 
 #include <arch/irq.h>
 
+#include <nuttx/kmalloc.h>
 #include <nuttx/semaphore.h>
 #include <nuttx/net/netconfig.h>
 #include <nuttx/net/net.h>
@@ -47,12 +48,14 @@
 
 /* The array containing all IPPROTO_ICMP socket connections */
 
+#ifndef CONFIG_NET_ALLOC_CONNS
 static struct icmpv6_conn_s g_icmpv6_connections[CONFIG_NET_ICMPv6_NCONNS];
+#endif
 
 /* A list of all free IPPROTO_ICMP socket connections */
 
 static dq_queue_t g_free_icmpv6_connections;
-static sem_t g_free_sem;
+static sem_t g_free_sem = SEM_INITIALIZER(1);
 
 /* A list of all allocated IPPROTO_ICMP socket connections */
 
@@ -73,20 +76,17 @@ static dq_queue_t g_active_icmpv6_connections;
 
 void icmpv6_sock_initialize(void)
 {
+#ifndef CONFIG_NET_ALLOC_CONNS
   int i;
 
-  /* Initialize the queues */
-
-  dq_init(&g_free_icmpv6_connections);
-  dq_init(&g_active_icmpv6_connections);
-  nxsem_init(&g_free_sem, 0, 1);
-
   for (i = 0; i < CONFIG_NET_ICMPv6_NCONNS; i++)
     {
       /* Move the connection structure to the free list */
 
-      dq_addlast(&g_icmpv6_connections[i].node, &g_free_icmpv6_connections);
+      dq_addlast(&g_icmpv6_connections[i].sconn.node,
+                 &g_free_icmpv6_connections);
     }
+#endif
 }
 
 /****************************************************************************
@@ -109,17 +109,28 @@ FAR struct icmpv6_conn_s *icmpv6_alloc(void)
   ret = net_lockedwait(&g_free_sem);
   if (ret >= 0)
     {
+#ifdef CONFIG_NET_ALLOC_CONNS
+      if (dq_peek(&g_active_icmpv6_connections) == NULL)
+        {
+          conn = kmm_zalloc(sizeof(*conn) * CONFIG_NET_ICMPv6_NCONNS);
+          if (conn != NULL)
+            {
+              for (ret = 0; ret < CONFIG_NET_ICMPv6_NCONNS; ret++)
+                {
+                  dq_addlast(&conn[ret].sconn.node,
+                             &g_free_icmpv6_connections);
+                }
+            }
+        }
+#endif
+
       conn = (FAR struct icmpv6_conn_s *)
              dq_remfirst(&g_free_icmpv6_connections);
       if (conn != NULL)
         {
-          /* Clear the connection structure */
-
-          memset(conn, 0, sizeof(struct icmpv6_conn_s));
-
           /* Enqueue the connection into the active list */
 
-          dq_addlast(&conn->node, &g_active_icmpv6_connections);
+          dq_addlast(&conn->sconn.node, &g_active_icmpv6_connections);
         }
 
       nxsem_post(&g_free_sem);
@@ -149,11 +160,15 @@ void icmpv6_free(FAR struct icmpv6_conn_s *conn)
 
   /* Remove the connection from the active list */
 
-  dq_rem(&conn->node, &g_active_icmpv6_connections);
+  dq_rem(&conn->sconn.node, &g_active_icmpv6_connections);
+
+  /* Clear the connection structure */
+
+  memset(conn, 0, sizeof(*conn));
 
   /* Free the connection */
 
-  dq_addlast(&conn->node, &g_free_icmpv6_connections);
+  dq_addlast(&conn->sconn.node, &g_free_icmpv6_connections);
   nxsem_post(&g_free_sem);
 }
 
@@ -187,7 +202,7 @@ FAR struct icmpv6_conn_s *icmpv6_active(uint16_t id)
 
       /* Look at the next active connection */
 
-      conn = (FAR struct icmpv6_conn_s *)conn->node.flink;
+      conn = (FAR struct icmpv6_conn_s *)conn->sconn.node.flink;
     }
 
   return conn;
@@ -212,7 +227,7 @@ FAR struct icmpv6_conn_s *icmpv6_nextconn(FAR struct icmpv6_conn_s *conn)
     }
   else
     {
-      return (FAR struct icmpv6_conn_s *)conn->node.flink;
+      return (FAR struct icmpv6_conn_s *)conn->sconn.node.flink;
     }
 }
 
