@@ -120,17 +120,6 @@
 #endif
 #endif /* CONFIG_NETDEV_IOCTL */
 
-/* This is really kind of bogus.. When asked for an IP address, this is
- * family that is returned in the ifr structure.  Probably could just skip
- * this since the address family has nothing to do with the Ethernet address.
- */
-
-#ifdef CONFIG_NET_IPv6
-#  define AF_INETX AF_INET6
-#else
-#  define AF_INETX AF_INET
-#endif
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -932,7 +921,7 @@ static int netdev_ifr_ioctl(FAR struct socket *psock, int cmd,
               if (dev->d_lltype == NET_LL_ETHERNET ||
                   dev->d_lltype == NET_LL_IEEE80211)
                 {
-                  req->ifr_hwaddr.sa_family = AF_INETX;
+                  req->ifr_hwaddr.sa_family = NET_SOCK_FAMILY;
                   memcpy(req->ifr_hwaddr.sa_data,
                          dev->d_mac.ether.ether_addr_octet, IFHWADDRLEN);
                   ret = OK;
@@ -944,7 +933,7 @@ static int netdev_ifr_ioctl(FAR struct socket *psock, int cmd,
               if (dev->d_lltype == NET_LL_IEEE802154 ||
                   dev->d_lltype == NET_LL_PKTRADIO)
                 {
-                  req->ifr_hwaddr.sa_family = AF_INETX;
+                  req->ifr_hwaddr.sa_family = NET_SOCK_FAMILY;
                   memcpy(req->ifr_hwaddr.sa_data,
                          dev->d_mac.radio.nv_addr,
                          dev->d_mac.radio.nv_addrlen);
@@ -1222,6 +1211,40 @@ static int netdev_imsf_ioctl(FAR struct socket *psock, int cmd,
 }
 #endif
 
+/****************************************************************************
+ * Name: netdev_arp_callback
+ *
+ * Description:
+ *   This is a callback that checks if the Ethernet network device has the
+ *   indicated name
+ *
+ * Input Parameters:
+ *   dev    Ethernet driver device structure
+ *   req    The argument of the ioctl cmd
+ *
+ * Returned Value:
+ *   1 on success
+ *   0 on error
+ ****************************************************************************/
+
+#ifdef CONFIG_NET_ARP
+static int netdev_arp_callback(FAR struct net_driver_s *dev, FAR void *arg)
+{
+  FAR struct arpreq *req = arg;
+  FAR struct sockaddr_in *addr = (FAR struct sockaddr_in *)&req->arp_pa;
+
+  if (strncmp(dev->d_ifname, (FAR const char *)req->arp_dev,
+              sizeof(dev->d_ifname)))
+    {
+      return 0;
+    }
+
+  arp_update(dev, addr->sin_addr.s_addr,
+             (FAR uint8_t *)req->arp_ha.sa_data);
+  return 1;
+}
+#endif
+
 /****************************************************************************
  * Name: netdev_arp_ioctl
  *
@@ -1256,15 +1279,11 @@ static int netdev_arp_ioctl(FAR struct socket *psock, int cmd,
               req->arp_pa.sa_family == AF_INET &&
               req->arp_ha.sa_family == ARPHRD_ETHER)
             {
-              FAR struct sockaddr_in *addr =
-                (FAR struct sockaddr_in *)&req->arp_pa;
-
               /* Update any existing ARP table entry for this protocol
                * address -OR- add a new ARP table entry if there is not.
                */
 
-              ret = arp_update(addr->sin_addr.s_addr,
-                               (FAR uint8_t *)req->arp_ha.sa_data);
+              ret = netdev_foreach(netdev_arp_callback, req) ? OK : -EINVAL;
             }
           else
             {
@@ -1453,6 +1472,73 @@ static int netdev_rt_ioctl(FAR struct socket *psock, int cmd,
 }
 #endif
 
+/****************************************************************************
+ * Name: netdev_file_ioctl
+ *
+ * Description:
+ *   Perform file ioctl operations.
+ *
+ * Parameters:
+ *   psock    Socket structure
+ *   cmd      The ioctl command
+ *   arg      The argument of the ioctl cmd
+ *
+ * Return:
+ *   >=0 on success (positive non-zero values are cmd-specific)
+ *   Negated errno returned on failure.
+ *
+ ****************************************************************************/
+
+static int netdev_file_ioctl(FAR struct socket *psock, int cmd,
+                             unsigned long arg)
+{
+  int ret;
+
+  switch (cmd)
+    {
+      case FIONBIO:
+        {
+          FAR struct socket_conn_s *conn = psock->s_conn;
+          FAR int *nonblock = (FAR int *)(uintptr_t)arg;
+          sockcaps_t sockcaps;
+
+           /* Non-blocking is the only configurable option.  And it applies
+            * only Unix domain sockets and to read operations on TCP/IP
+            * and UDP/IP sockets when read-ahead is enabled.
+            */
+
+          DEBUGASSERT(psock->s_sockif != NULL &&
+                      psock->s_sockif->si_sockcaps != NULL);
+          sockcaps = psock->s_sockif->si_sockcaps(psock);
+
+          if ((sockcaps & SOCKCAP_NONBLOCKING) != 0)
+            {
+               if (nonblock && *nonblock)
+                 {
+                   conn->s_flags |= _SF_NONBLOCK;
+                 }
+               else
+                 {
+                   conn->s_flags &= ~_SF_NONBLOCK;
+                 }
+
+               ret = OK;
+            }
+          else
+            {
+              nerr("ERROR: Non-blocking not supported for this socket\n");
+              ret = -ENOSYS;
+            }
+        }
+
+      default:
+        ret = -ENOTTY;
+        break;
+    }
+
+  return ret;
+}
+
 /****************************************************************************
  * Name: netdev_ioctl
  *
@@ -1514,6 +1600,7 @@ ssize_t net_ioctl_arglen(int cmd)
 {
   switch (cmd)
     {
+      case FIONSPACE:
       case FIONREAD:
         return sizeof(int);
 
@@ -1653,13 +1740,21 @@ int psock_vioctl(FAR struct socket *psock, int cmd, va_list ap)
 
   arg = va_arg(ap, unsigned long);
 
-  /* Check for a USRSOCK ioctl command */
+  /* Check for socket specific ioctl command */
 
   ret = netdev_ioctl(psock, cmd, arg);
+
+  /* Check for file ioctl command */
+
   if (ret == -ENOTTY)
     {
-      /* Check for a standard network IOCTL command. */
+      ret = netdev_file_ioctl(psock, cmd, arg);
+    }
 
+  /* Check for a standard network IOCTL command. */
+
+  if (ret == -ENOTTY)
+    {
       ret = netdev_ifr_ioctl(psock, cmd, (FAR struct ifreq *)(uintptr_t)arg);
     }
 
