@@ -115,16 +115,6 @@ int netdev_lladdrsize(FAR struct net_driver_s *dev)
 #endif
 
 #ifdef CONFIG_NET_6LOWPAN
-#ifdef CONFIG_WIRELESS_BLUETOOTH
-      case NET_LL_BLUETOOTH:
-        {
-          /* 6LoWPAN can be configured to use either extended or short
-           * addressing.
-           */
-
-          return BLUETOOTH_HDRLEN;
-        }
-#endif /* CONFIG_WIRELESS_BLUETOOTH */
 
 #ifdef CONFIG_WIRELESS_IEEE802154
       case NET_LL_IEEE802154:
@@ -141,11 +131,11 @@ int netdev_lladdrsize(FAR struct net_driver_s *dev)
         }
 #endif /* CONFIG_WIRELESS_IEEE802154 */
 
-#if defined(CONFIG_WIRELESS_PKTRADIO) || defined(CONFIG_NET_BLUETOOTH)
+#if defined(CONFIG_WIRELESS_PKTRADIO) || defined(CONFIG_WIRELESS_BLUETOOTH)
 #ifdef CONFIG_WIRELESS_PKTRADIO
       case NET_LL_PKTRADIO:
 #endif
-#ifdef CONFIG_NET_BLUETOOTH
+#ifdef CONFIG_WIRELESS_BLUETOOTH
       case NET_LL_BLUETOOTH:
 #endif
         {
@@ -153,7 +143,7 @@ int netdev_lladdrsize(FAR struct net_driver_s *dev)
 
            return netdev_pktradio_addrlen(dev);
         }
-#endif /* CONFIG_WIRELESS_PKTRADIO || CONFIG_NET_BLUETOOTH */
+#endif /* CONFIG_WIRELESS_PKTRADIO || CONFIG_WIRELESS_BLUETOOTH */
 #endif /* CONFIG_NET_6LOWPAN */
 
        default:
