@@ -34,6 +34,7 @@
 #include <nuttx/mm/circbuf.h>
 #include <nuttx/rptun/openamp.h>
 #include <nuttx/semaphore.h>
+#include <nuttx/fs/ioctl.h>
 
 #include <netinet/in.h>
 #include <netpacket/rpmsg.h>
@@ -48,9 +49,13 @@
 #  define MIN(a, b) ((a) < (b) ? (a) : (b))
 #endif
 
-#define RPMSG_SOCKET_CMD_SYNC       1
-#define RPMSG_SOCKET_CMD_DATA       2
-#define RPMSG_SOCKET_NAME_PREFIX    "rpmsg-socket"
+#define RPMSG_SOCKET_CMD_SYNC           1
+#define RPMSG_SOCKET_CMD_DATA           2
+#define RPMSG_SOCKET_NAME_PREFIX        "rpmsg-socket:"
+#define RPMSG_SOCKET_NAME_PREFIX_LEN    13
+
+static_assert(RPMSG_SOCKET_NAME_SIZE + RPMSG_SOCKET_NAME_PREFIX_LEN
+              <= RPMSG_NAME_SIZE, "socket name size config error");
 
 /****************************************************************************
  * Private Types
@@ -75,6 +80,10 @@ begin_packed_struct struct rpmsg_socket_data_s
 
 struct rpmsg_socket_conn_s
 {
+  /* Common prologue of all connection structures. */
+
+  struct socket_conn_s           sconn;
+
   struct rpmsg_endpoint          ept;
 
   struct sockaddr_rpmsg          rpaddr;
@@ -140,6 +149,8 @@ static ssize_t    rpmsg_socket_sendmsg(FAR struct socket *psock,
 static ssize_t    rpmsg_socket_recvmsg(FAR struct socket *psock,
                     FAR struct msghdr *msg, int flags);
 static int        rpmsg_socket_close(FAR struct socket *psock);
+static int        rpmsg_socket_ioctl(FAR struct socket *psock, int cmd,
+                                     FAR void *arg, size_t arglen);
 
 /****************************************************************************
  * Public Data
@@ -159,7 +170,8 @@ const struct sock_intf_s g_rpmsg_sockif =
   rpmsg_socket_poll,        /* si_poll */
   rpmsg_socket_sendmsg,     /* si_sendmsg */
   rpmsg_socket_recvmsg,     /* si_recvmsg */
-  rpmsg_socket_close        /* si_close */
+  rpmsg_socket_close,       /* si_close */
+  rpmsg_socket_ioctl,       /* si_ioctl */
 };
 
 /****************************************************************************
@@ -260,21 +272,21 @@ static int rpmsg_socket_wakeup(FAR struct rpmsg_socket_conn_s *conn)
       return ret;
     }
 
+  rpmsg_socket_lock(&conn->recvlock);
   space = conn->recvpos - conn->lastpos;
 
   if (space > circbuf_size(&conn->recvbuf) / 2)
     {
+      conn->lastpos = conn->recvpos;
       msg.cmd = RPMSG_SOCKET_CMD_DATA;
       msg.pos = conn->recvpos;
       msg.len = 0;
-      ret = rpmsg_send(&conn->ept, &msg, sizeof(msg));
-      if (ret >= 0)
-        {
-          conn->lastpos = conn->recvpos;
-        }
+      ret = 1;
     }
 
-  return ret;
+  rpmsg_socket_unlock(&conn->recvlock);
+
+  return ret ? rpmsg_send(&conn->ept, &msg, sizeof(msg)) : 0;
 }
 
 static inline uint32_t rpmsg_socket_get_space(
@@ -292,9 +304,16 @@ static int rpmsg_socket_ept_cb(FAR struct rpmsg_endpoint *ept,
 
   if (head->cmd == RPMSG_SOCKET_CMD_SYNC)
     {
+      rpmsg_socket_lock(&conn->recvlock);
       conn->sendsize = head->size;
-      conn->psock->s_flags |= _SF_CONNECTED;
-      _SO_SETERRNO(conn->psock, OK);
+
+      if (conn->psock)
+        {
+          conn->sconn.s_flags |= _SF_CONNECTED;
+          _SO_SETERRNO(conn->psock, OK);
+        }
+
+      rpmsg_socket_unlock(&conn->recvlock);
       rpmsg_socket_post(&conn->sendsem);
       rpmsg_socket_pollnotify(conn, POLLOUT);
     }
@@ -398,6 +417,17 @@ static inline void rpmsg_socket_destroy_ept(
   rpmsg_socket_unlock(&conn->recvlock);
 }
 
+static void rpmsg_socket_ns_bound(struct rpmsg_endpoint *ept)
+{
+  FAR struct rpmsg_socket_conn_s *conn = ept->priv;
+  struct rpmsg_socket_sync_s msg;
+
+  msg.cmd  = RPMSG_SOCKET_CMD_SYNC;
+  msg.size = circbuf_size(&conn->recvbuf);
+
+  rpmsg_send(&conn->ept, &msg, sizeof(msg));
+}
+
 static void rpmsg_socket_ns_unbind(FAR struct rpmsg_endpoint *ept)
 {
   rpmsg_socket_destroy_ept(ept->priv);
@@ -407,7 +437,7 @@ static void rpmsg_socket_device_created(FAR struct rpmsg_device *rdev,
                                         FAR void *priv)
 {
   FAR struct rpmsg_socket_conn_s *conn = priv;
-  char buf[RPMSG_SOCKET_NAME_SIZE];
+  char buf[RPMSG_NAME_SIZE];
 
   if (conn->ept.rdev)
     {
@@ -417,7 +447,8 @@ static void rpmsg_socket_device_created(FAR struct rpmsg_device *rdev,
   if (strcmp(conn->rpaddr.rp_cpu, rpmsg_get_cpuname(rdev)) == 0)
     {
       conn->ept.priv = conn;
-      snprintf(buf, sizeof(buf), "%s:%s", RPMSG_SOCKET_NAME_PREFIX,
+      conn->ept.ns_bound_cb = rpmsg_socket_ns_bound;
+      snprintf(buf, sizeof(buf), "%s%s", RPMSG_SOCKET_NAME_PREFIX,
                conn->rpaddr.rp_name);
 
       rpmsg_create_ept(&conn->ept, rdev, buf,
@@ -437,19 +468,6 @@ static void rpmsg_socket_device_destroy(FAR struct rpmsg_device *rdev,
     }
 }
 
-static void rpmsg_socket_device_connect(FAR struct rpmsg_device *rdev,
-                                        FAR void *priv, FAR const char *name,
-                                        uint32_t dest)
-{
-  FAR struct rpmsg_socket_conn_s *conn = priv;
-  struct rpmsg_socket_sync_s msg;
-
-  msg.cmd  = RPMSG_SOCKET_CMD_SYNC;
-  msg.size = circbuf_size(&conn->recvbuf);
-
-  rpmsg_send(&conn->ept, &msg, sizeof(msg));
-}
-
 static void rpmsg_socket_ns_bind(FAR struct rpmsg_device *rdev,
                                  FAR void *priv, FAR const char *name,
                                  uint32_t dest)
@@ -457,11 +475,11 @@ static void rpmsg_socket_ns_bind(FAR struct rpmsg_device *rdev,
   FAR struct rpmsg_socket_conn_s *server = priv;
   FAR struct rpmsg_socket_conn_s *tmp;
   FAR struct rpmsg_socket_conn_s *new;
-  char buf[RPMSG_SOCKET_NAME_SIZE];
+  char buf[RPMSG_NAME_SIZE];
   int cnt = 0;
   int ret;
 
-  snprintf(buf, sizeof(buf), "%s:%s", RPMSG_SOCKET_NAME_PREFIX,
+  snprintf(buf, sizeof(buf), "%s%s", RPMSG_SOCKET_NAME_PREFIX,
            server->rpaddr.rp_name);
   if (strncmp(name, buf, strlen(buf)))
     {
@@ -500,7 +518,7 @@ static void rpmsg_socket_ns_bind(FAR struct rpmsg_device *rdev,
     }
 
   strcpy(new->rpaddr.rp_cpu, rpmsg_get_cpuname(rdev));
-  strcpy(new->rpaddr.rp_name, name);
+  strcpy(new->rpaddr.rp_name, name + RPMSG_SOCKET_NAME_PREFIX_LEN);
 
   rpmsg_socket_lock(&server->recvlock);
 
@@ -518,10 +536,11 @@ static void rpmsg_socket_ns_bind(FAR struct rpmsg_device *rdev,
     }
 
   tmp->next = new;
-  new->psock = server->psock;
 
   rpmsg_socket_unlock(&server->recvlock);
 
+  rpmsg_socket_ns_bound(&new->ept);
+
   rpmsg_socket_post(&server->recvsem);
   rpmsg_socket_pollnotify(server, POLLIN);
 }
@@ -603,17 +622,26 @@ static int rpmsg_socket_bind(FAR struct socket *psock,
 }
 
 static int rpmsg_socket_getsockname(FAR struct socket *psock,
-                                   FAR struct sockaddr *addr,
-                                   FAR socklen_t *addrlen)
+                                    FAR struct sockaddr *addr,
+                                    FAR socklen_t *addrlen)
 {
-  return rpmsg_socket_getaddr(psock->s_conn, addr, addrlen);
+  int ret;
+
+  ret = rpmsg_socket_getaddr(psock->s_conn, addr, addrlen);
+  if (ret >= 0)
+    {
+      strncpy(((struct sockaddr_rpmsg *)addr)->rp_cpu,
+              CONFIG_RPTUN_LOCAL_CPUNAME, RPMSG_SOCKET_CPU_SIZE);
+    }
+
+  return ret;
 }
 
 static int rpmsg_socket_getconnname(FAR struct socket *psock,
                                     FAR struct sockaddr *addr,
                                     FAR socklen_t *addrlen)
 {
-  return rpmsg_socket_getsockname(psock, addr, addrlen);
+  return rpmsg_socket_getaddr(psock->s_conn, addr, addrlen);
 }
 
 static int rpmsg_socket_listen(FAR struct socket *psock, int backlog)
@@ -625,7 +653,7 @@ static int rpmsg_socket_listen(FAR struct socket *psock, int backlog)
       return -ENOSYS;
     }
 
-  if (!_SS_ISBOUND(psock->s_flags) || backlog <= 0)
+  if (!_SS_ISBOUND(server->sconn.s_flags) || backlog <= 0)
     {
       return -EINVAL;
     }
@@ -651,7 +679,7 @@ static int rpmsg_socket_connect_internal(FAR struct socket *psock)
   ret = rpmsg_register_callback(conn,
                                 rpmsg_socket_device_created,
                                 rpmsg_socket_device_destroy,
-                                rpmsg_socket_device_connect);
+                                NULL);
   if (ret < 0)
     {
       return ret;
@@ -659,20 +687,20 @@ static int rpmsg_socket_connect_internal(FAR struct socket *psock)
 
   if (conn->sendsize == 0)
     {
-      if (_SS_ISNONBLOCK(psock->s_flags))
+      if (_SS_ISNONBLOCK(conn->sconn.s_flags))
         {
           return -EINPROGRESS;
         }
 
       ret = net_timedwait(&conn->sendsem,
-                          _SO_TIMEOUT(psock->s_rcvtimeo));
+                          _SO_TIMEOUT(conn->sconn.s_rcvtimeo));
 
       if (ret < 0)
         {
           rpmsg_unregister_callback(conn,
                                     rpmsg_socket_device_created,
                                     rpmsg_socket_device_destroy,
-                                    rpmsg_socket_device_connect);
+                                    NULL);
         }
     }
 
@@ -686,7 +714,7 @@ static int rpmsg_socket_connect(FAR struct socket *psock,
   FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
   int ret;
 
-  if (_SS_ISCONNECTED(psock->s_flags))
+  if (_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       return -EISCONN;
     }
@@ -714,7 +742,7 @@ static int rpmsg_socket_accept(FAR struct socket *psock,
       return -ECONNRESET;
     }
 
-  if (!_SS_ISLISTENING(psock->s_flags))
+  if (!_SS_ISLISTENING(server->sconn.s_flags))
     {
       return -EINVAL;
     }
@@ -739,7 +767,7 @@ static int rpmsg_socket_accept(FAR struct socket *psock,
           rpmsg_register_callback(conn,
                                   rpmsg_socket_device_created,
                                   rpmsg_socket_device_destroy,
-                                  rpmsg_socket_device_connect);
+                                  NULL);
 
           if (conn->sendsize == 0)
             {
@@ -750,6 +778,7 @@ static int rpmsg_socket_accept(FAR struct socket *psock,
           newsock->s_sockif = psock->s_sockif;
           newsock->s_type   = SOCK_STREAM;
           newsock->s_conn   = conn;
+          conn->psock       = newsock;
 
           rpmsg_socket_getaddr(conn, addr, addrlen);
 
@@ -757,7 +786,7 @@ static int rpmsg_socket_accept(FAR struct socket *psock,
         }
       else
         {
-          if (_SS_ISNONBLOCK(psock->s_flags))
+          if (_SS_ISNONBLOCK(server->sconn.s_flags))
             {
               ret = -EAGAIN;
               break;
@@ -814,7 +843,7 @@ static int rpmsg_socket_poll(FAR struct socket *psock,
 
       /* Immediately notify on any of the requested events */
 
-      if (_SS_ISLISTENING(psock->s_flags))
+      if (_SS_ISLISTENING(conn->sconn.s_flags))
         {
           if (conn->backlog == -1)
             {
@@ -827,7 +856,7 @@ static int rpmsg_socket_poll(FAR struct socket *psock,
               eventset |= (fds->events & POLLIN);
             }
         }
-      else if (_SS_ISCONNECTED(psock->s_flags))
+      else if (_SS_ISCONNECTED(conn->sconn.s_flags))
         {
           if (!conn->ept.rdev)
             {
@@ -853,8 +882,8 @@ static int rpmsg_socket_poll(FAR struct socket *psock,
 
           rpmsg_socket_unlock(&conn->recvlock);
         }
-      else if (!_SS_ISCONNECTED(psock->s_flags) &&
-               _SS_ISNONBLOCK(psock->s_flags))
+      else if (!_SS_ISCONNECTED(conn->sconn.s_flags) &&
+               _SS_ISNONBLOCK(conn->sconn.s_flags))
         {
           ret = OK;
         }
@@ -900,7 +929,7 @@ static uint32_t rpmsg_socket_get_iovlen(FAR const struct iovec *buf,
 
 static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
                                             FAR const struct iovec *buf,
-                                            size_t iovcnt)
+                                            size_t iovcnt, bool nonblock)
 {
   FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
   uint32_t len = rpmsg_socket_get_iovlen(buf, iovcnt);
@@ -908,30 +937,28 @@ static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
   uint32_t offset = 0;
   int ret = 0;
 
-  rpmsg_socket_lock(&conn->sendlock);
-
   while (written < len)
     {
-      uint32_t block = MIN(len - written, rpmsg_socket_get_space(conn));
       FAR struct rpmsg_socket_data_s *msg;
       uint32_t block_written = 0;
       uint32_t ipcsize;
+      uint32_t block;
+
+      rpmsg_socket_lock(&conn->sendlock);
+      block = MIN(len - written, rpmsg_socket_get_space(conn));
+      rpmsg_socket_unlock(&conn->sendlock);
 
       if (block == 0)
         {
-          if (!_SS_ISNONBLOCK(psock->s_flags))
+          if (!nonblock)
             {
-              rpmsg_socket_unlock(&conn->sendlock);
-
               ret = net_timedwait(&conn->sendsem,
-                                  _SO_TIMEOUT(psock->s_sndtimeo));
+                                  _SO_TIMEOUT(conn->sconn.s_sndtimeo));
               if (!conn->ept.rdev)
                 {
                   ret = -ECONNRESET;
                 }
 
-              rpmsg_socket_lock(&conn->sendlock);
-
               if (ret < 0)
                 {
                   break;
@@ -942,6 +969,8 @@ static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
               ret = -EAGAIN;
               break;
             }
+
+          continue;
         }
 
       msg = rpmsg_get_tx_payload_buffer(&conn->ept, &ipcsize, true);
@@ -951,6 +980,9 @@ static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
           break;
         }
 
+      rpmsg_socket_lock(&conn->sendlock);
+
+      block = MIN(len - written, rpmsg_socket_get_space(conn));
       block = MIN(block, ipcsize - sizeof(*msg));
 
       msg->cmd = RPMSG_SOCKET_CMD_DATA;
@@ -974,6 +1006,8 @@ static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
       conn->lastpos  = conn->recvpos;
       conn->sendpos += msg->len;
 
+      rpmsg_socket_unlock(&conn->sendlock);
+
       ret = rpmsg_send_nocopy(&conn->ept, msg, block + sizeof(*msg));
       if (ret < 0)
         {
@@ -983,14 +1017,12 @@ static ssize_t rpmsg_socket_send_continuous(FAR struct socket *psock,
       written += block;
     }
 
-  rpmsg_socket_unlock(&conn->sendlock);
-
   return written ? written : ret;
 }
 
 static ssize_t rpmsg_socket_send_single(FAR struct socket *psock,
                                         FAR const struct iovec *buf,
-                                        size_t iovcnt)
+                                        size_t iovcnt, bool nonblock)
 {
   FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
   FAR struct rpmsg_socket_data_s *msg;
@@ -998,6 +1030,7 @@ static ssize_t rpmsg_socket_send_single(FAR struct socket *psock,
   uint32_t total = len + sizeof(*msg) + sizeof(uint32_t);
   uint32_t written = 0;
   uint32_t ipcsize;
+  uint32_t space;
   char *msgpos;
   int ret;
 
@@ -1006,47 +1039,47 @@ static ssize_t rpmsg_socket_send_single(FAR struct socket *psock,
       return -EFBIG;
     }
 
-  rpmsg_socket_lock(&conn->sendlock);
-
-  while (total - sizeof(*msg) > rpmsg_socket_get_space(conn))
+  while (1)
     {
-      if (!_SS_ISNONBLOCK(psock->s_flags))
-        {
-          rpmsg_socket_unlock(&conn->sendlock);
+      rpmsg_socket_lock(&conn->sendlock);
+      space = rpmsg_socket_get_space(conn);
+      rpmsg_socket_unlock(&conn->sendlock);
 
+      if (space >= total - sizeof(*msg))
+          break;
+
+      if (!nonblock)
+        {
           ret = net_timedwait(&conn->sendsem,
-                              _SO_TIMEOUT(psock->s_sndtimeo));
+                              _SO_TIMEOUT(conn->sconn.s_sndtimeo));
           if (!conn->ept.rdev)
             {
               ret = -ECONNRESET;
             }
 
-          rpmsg_socket_lock(&conn->sendlock);
-
           if (ret < 0)
             {
-              goto out;
+              return ret;
             }
         }
       else
         {
-          ret = -EAGAIN;
-          goto out;
+          return -EAGAIN;
         }
     }
 
   msg = rpmsg_get_tx_payload_buffer(&conn->ept, &ipcsize, true);
   if (!msg)
     {
-      ret = -EINVAL;
-      goto out;
+      return -EINVAL;
     }
 
-  if (total > ipcsize)
-    {
-      total = ipcsize;
-      len   = ipcsize - sizeof(*msg) - sizeof(uint32_t);
-    }
+  rpmsg_socket_lock(&conn->sendlock);
+
+  space = rpmsg_socket_get_space(conn);
+  total = MIN(total, space + sizeof(*msg));
+  total = MIN(total, ipcsize);
+  len = total - sizeof(*msg) - sizeof(uint32_t);
 
   /* SOCK_DGRAM need write len to buffer */
 
@@ -1074,45 +1107,25 @@ static ssize_t rpmsg_socket_send_single(FAR struct socket *psock,
   conn->lastpos  = conn->recvpos;
   conn->sendpos += len + sizeof(uint32_t);
 
-  ret = rpmsg_send_nocopy(&conn->ept, msg, total);
-out:
   rpmsg_socket_unlock(&conn->sendlock);
+
+  ret = rpmsg_send_nocopy(&conn->ept, msg, total);
+
   return ret > 0 ? len : ret;
 }
 
-static ssize_t rpmsg_socket_send_internal(FAR struct socket *psock,
-                                          FAR const void *buf,
-                                          size_t len, int flags)
-{
-  FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
-
-  if (!conn->ept.rdev)
-    {
-      /* return ECONNRESET if lower IPC closed */
-
-      return -ECONNRESET;
-    }
-
-  if (psock->s_type == SOCK_STREAM)
-    {
-      return rpmsg_socket_send_continuous(psock, buf, len);
-    }
-  else
-    {
-      return rpmsg_socket_send_single(psock, buf, len);
-    }
-}
-
 static ssize_t rpmsg_socket_sendmsg(FAR struct socket *psock,
                                     FAR struct msghdr *msg, int flags)
 {
+  FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
   FAR const struct iovec *buf = msg->msg_iov;
   size_t len = msg->msg_iovlen;
   FAR const struct sockaddr *to = msg->msg_name;
   socklen_t tolen = msg->msg_namelen;
+  bool nonblock;
   ssize_t ret;
 
-  if (!_SS_ISCONNECTED(psock->s_flags))
+  if (!_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       if (to == NULL)
         {
@@ -1126,7 +1139,24 @@ static ssize_t rpmsg_socket_sendmsg(FAR struct socket *psock,
         }
     }
 
-  return rpmsg_socket_send_internal(psock, buf, len, flags);
+  if (!conn->ept.rdev)
+    {
+      /* return ECONNRESET if lower IPC closed */
+
+      return -ECONNRESET;
+    }
+
+  nonblock = _SS_ISNONBLOCK(conn->sconn.s_flags) ||
+                            (flags & MSG_DONTWAIT) != 0;
+
+  if (psock->s_type == SOCK_STREAM)
+    {
+      return rpmsg_socket_send_continuous(psock, buf, len, nonblock);
+    }
+  else
+    {
+      return rpmsg_socket_send_single(psock, buf, len, nonblock);
+    }
 }
 
 static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
@@ -1139,8 +1169,8 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
   FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
   ssize_t ret;
 
-  if (psock->s_type == SOCK_DGRAM && _SS_ISBOUND(psock->s_flags)
-          && !_SS_ISCONNECTED(psock->s_flags))
+  if (psock->s_type != SOCK_STREAM && _SS_ISBOUND(conn->sconn.s_flags)
+          && !_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       ret = rpmsg_socket_connect_internal(psock);
       if (ret < 0)
@@ -1149,14 +1179,14 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
         }
     }
 
-  if (!_SS_ISCONNECTED(psock->s_flags))
+  if (!_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       return -EISCONN;
     }
 
   rpmsg_socket_lock(&conn->recvlock);
 
-  if (psock->s_type == SOCK_DGRAM)
+  if (psock->s_type != SOCK_STREAM)
     {
       uint32_t datalen;
 
@@ -1180,7 +1210,6 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
 
   if (ret > 0)
     {
-      rpmsg_socket_wakeup(conn);
       goto out;
     }
 
@@ -1192,7 +1221,7 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
       goto out;
     }
 
-  if (_SS_ISNONBLOCK(psock->s_flags))
+  if (_SS_ISNONBLOCK(conn->sconn.s_flags) || (flags & MSG_DONTWAIT) != 0)
     {
       ret = -EAGAIN;
       goto out;
@@ -1204,7 +1233,7 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
   rpmsg_socket_unlock(&conn->recvlock);
 
   ret = net_timedwait(&conn->recvsem,
-                      _SO_TIMEOUT(psock->s_rcvtimeo));
+                      _SO_TIMEOUT(conn->sconn.s_rcvtimeo));
   if (!conn->ept.rdev)
     {
       ret = -ECONNRESET;
@@ -1215,7 +1244,6 @@ static ssize_t rpmsg_socket_recvmsg(FAR struct socket *psock,
   if (!conn->recvdata)
     {
       ret = conn->recvlen;
-      rpmsg_socket_wakeup(conn);
     }
   else
     {
@@ -1227,6 +1255,7 @@ out:
 
   if (ret > 0)
     {
+      rpmsg_socket_wakeup(conn);
       rpmsg_socket_getaddr(conn, from, fromlen);
     }
 
@@ -1255,10 +1284,46 @@ static int rpmsg_socket_close(FAR struct socket *psock)
       rpmsg_unregister_callback(conn,
                                 rpmsg_socket_device_created,
                                 rpmsg_socket_device_destroy,
-                                rpmsg_socket_device_connect);
+                                NULL);
     }
 
   rpmsg_socket_destroy_ept(conn);
   rpmsg_socket_free(conn);
   return 0;
 }
+
+static int rpmsg_socket_ioctl(FAR struct socket *psock, int cmd,
+                              FAR void *arg, size_t arglen)
+{
+  FAR struct rpmsg_socket_conn_s *conn = psock->s_conn;
+  int ret = OK;
+
+  switch (cmd)
+    {
+      case FIONREAD:
+        if (arglen != sizeof(int))
+          {
+            ret = -EINVAL;
+            break;
+          }
+
+        *(FAR int *)((uintptr_t)arg) = circbuf_used(&conn->recvbuf);
+
+        break;
+      case FIONSPACE:
+        if (arglen != sizeof(int))
+          {
+            ret = -EINVAL;
+            break;
+          }
+
+        *(FAR int *)((uintptr_t)arg) = rpmsg_socket_get_space(conn);
+
+        break;
+      default:
+        ret = -ENOTTY;
+        break;
+    }
+
+  return ret;
+}
