@@ -92,16 +92,16 @@ int psock_bind(FAR struct socket *psock, const struct sockaddr *addr,
 
   /* Was the bind successful */
 
-  if (ret < 0)
+  if (ret >= 0)
     {
-      return ret;
+      FAR struct socket_conn_s *conn = psock->s_conn;
+
+      /* Mark the socket bound */
+
+      conn->s_flags |= _SF_BOUND;
     }
 
-  /* Mark the socket bound */
-
-  psock->s_flags |= _SF_BOUND;
-
-  return OK;
+  return ret;
 }
 
 /****************************************************************************
