@@ -55,6 +55,7 @@
 #include <arch/irq.h>
 
 #include <nuttx/clock.h>
+#include <nuttx/kmalloc.h>
 #include <nuttx/net/netconfig.h>
 #include <nuttx/net/net.h>
 #include <nuttx/net/netdev.h>
@@ -71,8 +72,8 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define IPv4BUF ((struct ipv4_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev)])
-#define IPv6BUF ((struct ipv6_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev)])
+#define IPv4BUF ((FAR struct ipv4_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev)])
+#define IPv6BUF ((FAR struct ipv6_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev)])
 
 /****************************************************************************
  * Private Data
@@ -80,7 +81,9 @@
 
 /* The array containing all TCP connections. */
 
+#ifndef CONFIG_NET_ALLOC_CONNS
 static struct tcp_conn_s g_tcp_connections[CONFIG_NET_TCP_CONNS];
+#endif
 
 /* A list of all free TCP connections */
 
@@ -110,15 +113,12 @@ static FAR struct tcp_conn_s *
   tcp_listener(uint8_t domain, FAR const union ip_addr_u *ipaddr,
                uint16_t portno)
 {
-  FAR struct tcp_conn_s *conn;
-  int i;
+  FAR struct tcp_conn_s *conn = NULL;
 
   /* Check if this port number is in use by any active UIP TCP connection */
 
-  for (i = 0; i < CONFIG_NET_TCP_CONNS; i++)
+  while ((conn = tcp_nextconn(conn)) != NULL)
     {
-      conn = &g_tcp_connections[i];
-
       /* Check if this connection is open and the local port assignment
        * matches the requested port number.
        */
@@ -234,7 +234,7 @@ static int tcp_selectport(uint8_t domain,
               g_last_tcp_port = 4096;
             }
 
-          portno = htons(g_last_tcp_port);
+          portno = HTONS(g_last_tcp_port);
         }
       while (tcp_listener(domain, ipaddr, portno));
     }
@@ -317,7 +317,7 @@ static inline FAR struct tcp_conn_s *
 
       /* Look at the next active connection */
 
-      conn = (FAR struct tcp_conn_s *)conn->node.flink;
+      conn = (FAR struct tcp_conn_s *)conn->sconn.node.flink;
     }
 
   return conn;
@@ -384,7 +384,7 @@ static inline FAR struct tcp_conn_s *
 
       /* Look at the next active connection */
 
-      conn = (FAR struct tcp_conn_s *)conn->node.flink;
+      conn = (FAR struct tcp_conn_s *)conn->sconn.node.flink;
     }
 
   return conn;
@@ -425,6 +425,7 @@ static inline int tcp_ipv4_bind(FAR struct tcp_conn_s *conn,
   if (port < 0)
     {
       nerr("ERROR: tcp_selectport failed: %d\n", port);
+      net_unlock();
       return port;
     }
 
@@ -448,11 +449,10 @@ static inline int tcp_ipv4_bind(FAR struct tcp_conn_s *conn,
 
       conn->lport = 0;
       net_ipv4addr_copy(conn->u.ipv4.laddr, INADDR_ANY);
-      return ret;
     }
 
   net_unlock();
-  return OK;
+  return ret;
 }
 #endif /* CONFIG_NET_IPv4 */
 
@@ -492,6 +492,7 @@ static inline int tcp_ipv6_bind(FAR struct tcp_conn_s *conn,
   if (port < 0)
     {
       nerr("ERROR: tcp_selectport failed: %d\n", port);
+      net_unlock();
       return port;
     }
 
@@ -515,14 +516,53 @@ static inline int tcp_ipv6_bind(FAR struct tcp_conn_s *conn,
 
       conn->lport = 0;
       net_ipv6addr_copy(conn->u.ipv6.laddr, g_ipv6_unspecaddr);
-      return ret;
     }
 
   net_unlock();
-  return OK;
+  return ret;
 }
 #endif /* CONFIG_NET_IPv6 */
 
+/****************************************************************************
+ * Name: tcp_alloc_conn
+ *
+ * Description:
+ *   Find or allocate a free TCP/IP connection structure for use.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_NET_ALLOC_CONNS
+FAR struct tcp_conn_s *tcp_alloc_conn(void)
+{
+  FAR struct tcp_conn_s *conn;
+  int i;
+
+  /* Return the entry from the head of the free list */
+
+  if (dq_peek(&g_free_tcp_connections) == NULL)
+    {
+      conn = kmm_zalloc(sizeof(struct tcp_conn_s) *
+                        CONFIG_NET_TCP_CONNS);
+      if (conn == NULL)
+        {
+          return conn;
+        }
+
+      /* Now initialize each connection structure */
+
+      for (i = 0; i < CONFIG_NET_TCP_CONNS; i++)
+        {
+          /* Mark the connection closed and move it to the free list */
+
+          conn[i].tcpstateflags = TCP_CLOSED;
+          dq_addlast(&conn[i].sconn.node, &g_free_tcp_connections);
+        }
+    }
+
+  return (FAR struct tcp_conn_s *)dq_remfirst(&g_free_tcp_connections);
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -538,22 +578,17 @@ static inline int tcp_ipv6_bind(FAR struct tcp_conn_s *conn,
 
 void tcp_initialize(void)
 {
+#ifndef CONFIG_NET_ALLOC_CONNS
   int i;
 
-  /* Initialize the queues */
-
-  dq_init(&g_free_tcp_connections);
-  dq_init(&g_active_tcp_connections);
-
-  /* Now initialize each connection structure */
-
   for (i = 0; i < CONFIG_NET_TCP_CONNS; i++)
     {
       /* Mark the connection closed and move it to the free list */
 
       g_tcp_connections[i].tcpstateflags = TCP_CLOSED;
-      dq_addlast(&g_tcp_connections[i].node, &g_free_tcp_connections);
+      dq_addlast(&g_tcp_connections[i].sconn.node, &g_free_tcp_connections);
     }
+#endif
 }
 
 /****************************************************************************
@@ -624,7 +659,7 @@ FAR struct tcp_conn_s *tcp_alloc(uint8_t domain)
 
           /* Look at the next active connection */
 
-          tmp = (FAR struct tcp_conn_s *)tmp->node.flink;
+          tmp = (FAR struct tcp_conn_s *)tmp->sconn.node.flink;
         }
 
       /* Did we find a connection that we can re-use? */
@@ -656,6 +691,15 @@ FAR struct tcp_conn_s *tcp_alloc(uint8_t domain)
     }
 #endif
 
+  /* Allocate the connect entry from heap */
+
+#ifdef CONFIG_NET_ALLOC_CONNS
+  if (conn == NULL)
+    {
+      conn = tcp_alloc_conn();
+    }
+#endif
+
   net_unlock();
 
   /* Mark the connection allocated */
@@ -716,7 +760,7 @@ void tcp_free(FAR struct tcp_conn_s *conn)
    * callback for CONFIG_NET_TCP_WRITE_BUFFERS is left.
    */
 
-  for (cb = conn->list; cb; cb = next)
+  for (cb = conn->sconn.list; cb; cb = next)
     {
       next = cb->nxtconn;
       tcp_callback_free(conn, cb);
@@ -730,7 +774,7 @@ void tcp_free(FAR struct tcp_conn_s *conn)
     {
       /* Remove the connection from the active list */
 
-      dq_rem(&conn->node, &g_active_tcp_connections);
+      dq_rem(&conn->sconn.node, &g_active_tcp_connections);
     }
 
   /* Release any read-ahead buffers attached to the connection */
@@ -782,7 +826,7 @@ void tcp_free(FAR struct tcp_conn_s *conn)
   /* Mark the connection available and put it into the free list */
 
   conn->tcpstateflags = TCP_CLOSED;
-  dq_addlast(&conn->node, &g_free_tcp_connections);
+  dq_addlast(&conn->sconn.node, &g_free_tcp_connections);
   net_unlock();
 }
 
@@ -839,7 +883,7 @@ FAR struct tcp_conn_s *tcp_nextconn(FAR struct tcp_conn_s *conn)
     }
   else
     {
-      return (FAR struct tcp_conn_s *)conn->node.flink;
+      return (FAR struct tcp_conn_s *)conn->sconn.node.flink;
     }
 }
 
@@ -1000,7 +1044,7 @@ FAR struct tcp_conn_s *tcp_alloc_accept(FAR struct net_driver_s *dev,
        * Interrupts should already be disabled in this context.
        */
 
-      dq_addlast(&conn->node, &g_active_tcp_connections);
+      dq_addlast(&conn->sconn.node, &g_active_tcp_connections);
     }
 
   return conn;
@@ -1272,7 +1316,7 @@ int tcp_connect(FAR struct tcp_conn_s *conn, FAR const struct sockaddr *addr)
 
   /* And, finally, put the connection structure into the active list. */
 
-  dq_addlast(&conn->node, &g_active_tcp_connections);
+  dq_addlast(&conn->sconn.node, &g_active_tcp_connections);
   ret = OK;
 
 errout_with_lock:
