@@ -67,12 +67,8 @@
 #  define NEED_IPDOMAIN_SUPPORT 1
 #endif
 
-#if defined(CONFIG_NET_TCP_SPLIT) && !defined(CONFIG_NET_TCP_SPLIT_SIZE)
-#  define CONFIG_NET_TCP_SPLIT_SIZE 40
-#endif
-
-#define TCPIPv4BUF ((struct tcp_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev) + IPv4_HDRLEN])
-#define TCPIPv6BUF ((struct tcp_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev) + IPv6_HDRLEN])
+#define TCPIPv4BUF ((FAR struct tcp_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev) + IPv4_HDRLEN])
+#define TCPIPv6BUF ((FAR struct tcp_hdr_s *)&dev->d_buf[NET_LL_HDRLEN(dev) + IPv6_HDRLEN])
 
 /****************************************************************************
  * Private Types
@@ -84,16 +80,24 @@
 
 struct send_s
 {
-  FAR struct socket      *snd_sock;    /* Points to the parent socket structure */
-  FAR struct devif_callback_s *snd_cb; /* Reference to callback instance */
-  sem_t                   snd_sem;     /* Used to wake up the waiting thread */
-  FAR const uint8_t      *snd_buffer;  /* Points to the buffer of data to send */
-  size_t                  snd_buflen;  /* Number of bytes in the buffer to send */
-  ssize_t                 snd_sent;    /* The number of bytes sent */
-  uint32_t                snd_isn;     /* Initial sequence number */
-  uint32_t                snd_acked;   /* The number of bytes acked */
-#if defined(CONFIG_NET_TCP_SPLIT)
-  bool                    snd_odd;     /* True: Odd packet in pair transaction */
+  FAR struct socket      *snd_sock;     /* Points to the parent socket structure */
+  FAR struct devif_callback_s *snd_cb;  /* Reference to callback instance */
+  sem_t                   snd_sem;      /* Used to wake up the waiting thread */
+  FAR const uint8_t      *snd_buffer;   /* Points to the buffer of data to send */
+  size_t                  snd_buflen;   /* Number of bytes in the buffer to send */
+  ssize_t                 snd_sent;     /* The number of bytes sent */
+  uint32_t                snd_isn;      /* Initial sequence number */
+  uint32_t                snd_acked;    /* The number of bytes acked */
+#ifdef CONFIG_NET_TCP_FAST_RETRANSMIT
+  uint32_t                snd_prev_ack; /* The previous ACKed seq number */
+#ifdef CONFIG_NET_TCP_WINDOW_SCALE
+  uint32_t                snd_prev_wnd; /* The advertised window in the last
+                                         * incoming acknowledgment
+                                         */
+#else
+  uint16_t                snd_prev_wnd;
+#endif
+  int                     snd_dup_acks; /* Duplicate ACK counter */
 #endif
 };
 
@@ -168,8 +172,42 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
                                      FAR void *pvconn,
                                      FAR void *pvpriv, uint16_t flags)
 {
-  FAR struct tcp_conn_s *conn = (FAR struct tcp_conn_s *)pvconn;
+  /* FAR struct tcp_conn_s *conn = (FAR struct tcp_conn_s *)pvconn;
+   *
+   * Do not use pvconn argument to get the TCP connection pointer (the above
+   * commented line) because pvconn is normally NULL for some events like
+   * NETDEV_DOWN. Instead, the TCP connection pointer can be reliably
+   * obtained from the corresponding TCP socket.
+   */
+
   FAR struct send_s *pstate = (FAR struct send_s *)pvpriv;
+  FAR struct socket *psock;
+  FAR struct tcp_conn_s *conn;
+
+  DEBUGASSERT(pstate != NULL);
+
+  psock = pstate->snd_sock;
+  DEBUGASSERT(psock != NULL);
+
+  /* Get the TCP connection pointer reliably from
+   * the corresponding TCP socket.
+   */
+
+  conn = psock->s_conn;
+  DEBUGASSERT(conn != NULL);
+
+#ifdef CONFIG_DEBUG_NET_ERROR
+  if (conn->dev == NULL || (pvconn != conn && pvconn != NULL))
+    {
+      tcp_event_handler_dump(dev, pvconn, pvpriv, flags, conn);
+    }
+#endif
+
+  /* If pvconn is not NULL, make sure that pvconn refers to the same
+   * connection as the socket is bound to.
+   */
+
+  DEBUGASSERT(pvconn == conn || pvconn == NULL);
 
   /* The TCP socket is connected and, hence, should be bound to a device.
    * Make sure that the polling device is the one that we are bound to.
@@ -184,12 +222,24 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
   ninfo("flags: %04x acked: %" PRId32 " sent: %zd\n",
         flags, pstate->snd_acked, pstate->snd_sent);
 
+  /* The TCP_ACKDATA, TCP_REXMIT and TCP_DISCONN_EVENTS flags are expected to
+   * appear here strictly one at a time, except for the FIN + ACK case.
+   */
+
+  DEBUGASSERT((flags & TCP_ACKDATA) == 0 ||
+              (flags & TCP_REXMIT) == 0);
+  DEBUGASSERT((flags & TCP_DISCONN_EVENTS) == 0 ||
+              (flags & TCP_REXMIT) == 0);
+
   /* If this packet contains an acknowledgement, then update the count of
    * acknowledged bytes.
+   * This condition is located here for performance reasons
+   * (TCP_ACKDATA is the most frequent event).
    */
 
   if ((flags & TCP_ACKDATA) != 0)
     {
+      uint32_t ackno;
       FAR struct tcp_hdr_s *tcp;
 
       /* Get the offset address of the TCP header */
@@ -220,9 +270,10 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
        * of bytes to be acknowledged.
        */
 
-      pstate->snd_acked = TCP_SEQ_SUB(tcp_getsequence(tcp->ackno),
+      ackno = tcp_getsequence(tcp->ackno);
+      pstate->snd_acked = TCP_SEQ_SUB(ackno,
                                       pstate->snd_isn);
-      ninfo("ACK: acked=%" PRId32 " sent=%zd buflen=%zd\n",
+      ninfo("ACK: acked=%" PRId32 " sent=%zd buflen=%zu\n",
             pstate->snd_acked, pstate->snd_sent, pstate->snd_buflen);
 
       /* Have all of the bytes in the buffer been sent and acknowledged? */
@@ -236,36 +287,93 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
           goto end_wait;
         }
 
-      /* No.. fall through to send more data if necessary */
-    }
-
-  /* Check if we are being asked to retransmit data */
-
-  else if ((flags & TCP_REXMIT) != 0)
-    {
-      /* Yes.. in this case, reset the number of bytes that have been sent
-       * to the number of bytes that have been ACKed.
+#ifdef CONFIG_NET_TCP_FAST_RETRANSMIT
+      /* Fast Retransmit (RFC 5681): an acknowledgment is considered a
+       * "duplicate" when (a) the receiver of the ACK has outstanding data,
+       * (b) the incoming acknowledgment carries no data, (c) the SYN and
+       * FIN bits are both off, (d) the acknowledgment number is equal to
+       * the greatest acknowledgment received on the given connection
+       * and (e) the advertised window in the incoming acknowledgment equals
+       * the advertised window in the last incoming acknowledgment.
        */
 
-      pstate->snd_sent = pstate->snd_acked;
+      if (pstate->snd_acked < pstate->snd_sent &&
+          (flags & TCP_NEWDATA) == 0 &&
+          (tcp->flags & (TCP_SYN | TCP_FIN)) == 0 &&
+          ackno == pstate->snd_prev_ack &&
+          conn->snd_wnd == pstate->snd_prev_wnd)
+        {
+          if (++pstate->snd_dup_acks >= TCP_FAST_RETRANSMISSION_THRESH)
+            {
+              flags |= TCP_REXMIT;
+              pstate->snd_dup_acks = 0;
+            }
+        }
+      else
+        {
+          pstate->snd_dup_acks = 0;
+        }
 
-#if defined(CONFIG_NET_TCP_SPLIT)
-      /* Reset the even/odd indicator to even since we need to
-       * retransmit.
-       */
-
-      pstate->snd_odd = false;
+      pstate->snd_prev_ack = ackno;
+      pstate->snd_prev_wnd = conn->snd_wnd;
 #endif
-
-      /* Fall through to re-send data from the last that was ACKed */
     }
 
-  /* Check for a loss of connection */
+  /* Check if we are being asked to retransmit data.
+   * This condition is located here after TCP_ACKDATA for performance reasons
+   * (TCP_REXMIT is less frequent than TCP_ACKDATA).
+   */
+
+  if ((flags & TCP_REXMIT) != 0)
+    {
+      uint32_t sndlen;
+
+      nwarn("WARNING: TCP_REXMIT\n");
+
+      /* According to RFC 6298 (5.4), retransmit the earliest segment
+       * that has not been acknowledged by the TCP receiver.
+       */
+
+      /* Reconstruct the length of the earliest segment to be retransmitted */
+
+      sndlen = pstate->snd_buflen - pstate->snd_acked;
+
+      if (sndlen > conn->mss)
+        {
+          sndlen = conn->mss;
+        }
+
+      conn->rexmit_seq = pstate->snd_isn + pstate->snd_acked;
+
+#ifdef NEED_IPDOMAIN_SUPPORT
+      /* If both IPv4 and IPv6 support are enabled, then we will need to
+       * select which one to use when generating the outgoing packet.
+       * If only one domain is selected, then the setup is already in
+       * place and we need do nothing.
+       */
+
+      tcpsend_ipselect(dev, conn);
+#endif
+      /* Then set-up to send that amount of data. (this won't actually
+       * happen until the polling cycle completes).
+       */
+
+      devif_send(dev,
+                 &pstate->snd_buffer[pstate->snd_acked],
+                 sndlen);
+
+      /* Continue waiting */
+
+      return flags;
+    }
+
+  /* Check for a loss of connection.
+   * This condition is located here after both the TCP_ACKDATA and TCP_REXMIT
+   * because TCP_DISCONN_EVENTS is the least frequent event.
+   */
 
   else if ((flags & TCP_DISCONN_EVENTS) != 0)
     {
-      FAR struct socket *psock = pstate->snd_sock;
-
       ninfo("Lost connection\n");
 
       /* We could get here recursively through the callback actions of
@@ -273,12 +381,11 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
        * already been disconnected.
        */
 
-      DEBUGASSERT(psock != NULL);
-      if (_SS_ISCONNECTED(psock->s_flags))
+      if (_SS_ISCONNECTED(conn->sconn.s_flags))
         {
           /* Report not connected */
 
-          tcp_lost_connection(psock, pstate->snd_cb, flags);
+          tcp_lost_connection(conn, pstate->snd_cb, flags);
         }
 
       pstate->snd_sent = -ENOTCONN;
@@ -308,93 +415,10 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
 
   if ((flags & TCP_NEWDATA) == 0 && pstate->snd_sent < pstate->snd_buflen)
     {
-      uint32_t seqno;
-
       /* Get the amount of data that we can send in the next packet */
 
       uint32_t sndlen = pstate->snd_buflen - pstate->snd_sent;
 
-#if defined(CONFIG_NET_TCP_SPLIT)
-
-      /* RFC 1122 states that a host may delay ACKing for up to 500ms but
-       * must respond to every second  segment).  This logic here will trick
-       * the RFC 1122 recipient into responding sooner.  This logic will be
-       * activated if:
-       *
-       *   1. An even number of packets has been send (where zero is an even
-       *      number),
-       *   2. There is more data be sent (more than or equal to
-       *      CONFIG_NET_TCP_SPLIT_SIZE), but
-       *   3. Not enough data for two packets.
-       *
-       * Then we will split the remaining, single packet into two partial
-       * packets.  This will stimulate the RFC 1122 peer to ACK sooner.
-       *
-       * Don't try to split very small packets (less than
-       * CONFIG_NET_TCP_SPLIT_SIZE).  Only the first even packet and the
-       * last odd packets could have sndlen less than
-       * CONFIG_NET_TCP_SPLIT_SIZE.  The value of sndlen on the last even
-       * packet is guaranteed to be at least MSS / 2 by the logic below.
-       */
-
-      if (sndlen >= CONFIG_NET_TCP_SPLIT_SIZE)
-        {
-          /* sndlen is the number of bytes remaining to be sent.
-           * conn->mss will provide the number of bytes that can sent
-           * in one packet.  The difference, then, is the number of bytes
-           * that would be sent in the next packet after this one.
-           */
-
-          int32_t next_sndlen = sndlen - conn->mss;
-
-          /*  Is this the even packet in the packet pair transaction? */
-
-          if (!pstate->snd_odd)
-            {
-              /* next_sndlen <= 0 means that the entire remaining data
-               * could fit into this single packet.  This is condition
-               * in which we must do the split.
-               */
-
-              if (next_sndlen <= 0)
-                {
-                  /* Split so that there will be an odd packet.  Here
-                   * we know that 0 < sndlen <= MSS
-                   */
-
-                  sndlen = (sndlen / 2) + 1;
-                }
-            }
-
-          /* No... this is the odd packet in the packet pair transaction */
-
-          else
-            {
-              /* Will there be another (even) packet after this one?
-               * (next_sndlen > 0)  Will the split condition occur on that
-               * next, even packet? ((next_sndlen - conn->mss) < 0) If
-               * so, then perform the split now to avoid the case where the
-               * byte count is less than CONFIG_NET_TCP_SPLIT_SIZE on the
-               * next pair.
-               */
-
-              if (next_sndlen > 0 && (next_sndlen - conn->mss) < 0)
-                {
-                  /* Here, we know that sndlen must be MSS < sndlen <= 2*MSS
-                   * and so (sndlen / 2) is <= MSS.
-                   */
-
-                  sndlen /= 2;
-                }
-            }
-        }
-
-      /* Toggle the even/odd indicator */
-
-      pstate->snd_odd ^= true;
-
-#endif /* CONFIG_NET_TCP_SPLIT */
-
       if (sndlen > conn->mss)
         {
           sndlen = conn->mss;
@@ -404,19 +428,6 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
 
       if ((pstate->snd_sent - pstate->snd_acked + sndlen) < conn->snd_wnd)
         {
-          /* Set the sequence number for this packet.  NOTE:  The network
-           * updates sndseq on receipt of ACK *before* this function is
-           * called.  In that case sndseq will point to the next
-           * unacknowledged byte (which might have already been sent).  We
-           * will overwrite the value of sndseq here before the packet is
-           * sent.
-           */
-
-          seqno = pstate->snd_sent + pstate->snd_isn;
-          ninfo("SEND: sndseq %08" PRIx32 "->%08" PRIx32 "\n",
-                tcp_getsequence(conn->sndseq), seqno);
-          tcp_setsequence(conn->sndseq, seqno);
-
 #ifdef NEED_IPDOMAIN_SUPPORT
           /* If both IPv4 and IPv6 support are enabled, then we will need to
            * select which one to use when generating the outgoing packet.
@@ -435,9 +446,13 @@ static uint16_t tcpsend_eventhandler(FAR struct net_driver_s *dev,
           /* Update the amount of data sent (but not necessarily ACKed) */
 
           pstate->snd_sent += sndlen;
-          ninfo("SEND: acked=%" PRId32 " sent=%zd buflen=%zd\n",
+          ninfo("SEND: acked=%" PRId32 " sent=%zd buflen=%zu\n",
                 pstate->snd_acked, pstate->snd_sent, pstate->snd_buflen);
         }
+      else
+        {
+          nwarn("WARNING: Window full, wait for ack\n");
+        }
     }
 
   /* Continue waiting */
@@ -448,6 +463,8 @@ end_wait:
 
   /* Do not allow any further callbacks */
 
+  DEBUGASSERT(pstate->snd_cb != NULL);
+
   pstate->snd_cb->flags   = 0;
   pstate->snd_cb->priv    = NULL;
   pstate->snd_cb->event   = NULL;
@@ -531,19 +548,22 @@ ssize_t psock_tcp_send(FAR struct socket *psock,
 
   /* Verify that the sockfd corresponds to valid, allocated socket */
 
-  if (psock == NULL || psock->s_conn == NULL)
+  if (psock == NULL || psock->s_type != SOCK_STREAM ||
+      psock->s_conn == NULL)
     {
       nerr("ERROR: Invalid socket\n");
       ret = -EBADF;
       goto errout;
     }
 
+  conn = (FAR struct tcp_conn_s *)psock->s_conn;
+
   /* Check early if this is an un-connected socket, if so, then
    * return -ENOTCONN. Note, we will have to check this again, as we can't
    * guarantee the state won't change until we have the network locked.
    */
 
-  if (psock->s_type != SOCK_STREAM)
+  if (!_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       nerr("ERROR: Not connected\n");
       ret = -ENOTCONN;
@@ -552,9 +572,6 @@ ssize_t psock_tcp_send(FAR struct socket *psock,
 
   /* Make sure that we have the IP address mapping */
 
-  conn = (FAR struct tcp_conn_s *)psock->s_conn;
-  DEBUGASSERT(conn);
-
 #if defined(CONFIG_NET_ARP_SEND) || defined(CONFIG_NET_ICMPv6_NEIGHBOR)
 #ifdef CONFIG_NET_ARP_SEND
 #ifdef CONFIG_NET_ICMPv6_NEIGHBOR
@@ -601,7 +618,7 @@ ssize_t psock_tcp_send(FAR struct socket *psock,
    * state again to ensure the connection is still valid.
    */
 
-  if (!_SS_ISCONNECTED(psock->s_flags))
+  if (!_SS_ISCONNECTED(conn->sconn.s_flags))
     {
       nerr("ERROR: No longer connected\n");
       net_unlock();
@@ -660,7 +677,7 @@ ssize_t psock_tcp_send(FAR struct socket *psock,
               uint32_t acked = state.snd_acked;
 
               ret = net_timedwait(&state.snd_sem,
-                                  _SO_TIMEOUT(psock->s_sndtimeo));
+                                  _SO_TIMEOUT(conn->sconn.s_sndtimeo));
               if (ret != -ETIMEDOUT || acked == state.snd_acked)
                 {
                   break; /* Timeout without any progress */
@@ -713,7 +730,7 @@ errout:
  *   write occurs first.
  *
  * Input Parameters:
- *   psock    An instance of the internal socket structure.
+ *   conn     The TCP connection of interest
  *
  * Returned Value:
  *   OK (Always can send).
@@ -723,7 +740,7 @@ errout:
  *
  ****************************************************************************/
 
-int psock_tcp_cansend(FAR struct socket *psock)
+int psock_tcp_cansend(FAR struct tcp_conn_s *conn)
 {
   return OK;
 }
