@@ -269,7 +269,12 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
 
               else if (
 #ifdef CONFIG_NET_TCP_WRITE_BUFFERS
+#  ifdef CONFIG_NET_SENDFILE
+                  (!conn->sendfile && conn->expired > 0) ||
+                  (conn->sendfile && conn->nrtx >= TCP_MAXRTX) ||
+#  else
                   conn->expired > 0 ||
+#  endif
 #else
                   conn->nrtx >= TCP_MAXRTX ||
 #endif
@@ -317,6 +322,11 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
                      * SYNACK.
                      */
 
+#if !defined(CONFIG_NET_TCP_WRITE_BUFFERS)
+                    tcp_setsequence(conn->sndseq, conn->rexmit_seq);
+#else
+                    /* REVISIT for the buffered mode */
+#endif
                     tcp_synack(dev, conn, TCP_ACK | TCP_SYN);
                     goto done;
 
@@ -324,6 +334,11 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
 
                     /* In the SYN_SENT state, we retransmit out SYN. */
 
+#if !defined(CONFIG_NET_TCP_WRITE_BUFFERS)
+                    tcp_setsequence(conn->sndseq, conn->rexmit_seq);
+#else
+                    /* REVISIT for the buffered mode */
+#endif
                     tcp_synack(dev, conn, TCP_SYN);
                     goto done;
 
@@ -344,6 +359,11 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
 
                     /* In all these states we should retransmit a FINACK. */
 
+#if !defined(CONFIG_NET_TCP_WRITE_BUFFERS)
+                    tcp_setsequence(conn->sndseq, conn->rexmit_seq);
+#else
+                    /* REVISIT for the buffered mode */
+#endif
                     tcp_send(dev, conn, TCP_FIN | TCP_ACK, hdrlen);
                     goto done;
                 }
