@@ -184,7 +184,9 @@ FAR struct net_driver_s *udp_find_laddr_device(FAR struct udp_conn_s *conn)
  *
  ****************************************************************************/
 
-FAR struct net_driver_s *udp_find_raddr_device(FAR struct udp_conn_s *conn)
+FAR struct net_driver_s *
+udp_find_raddr_device(FAR struct udp_conn_s *conn,
+                      FAR struct sockaddr_storage *remote)
 {
   /* We need to select the device that is going to route the UDP packet
    * based on the provided IP address.
@@ -195,13 +197,25 @@ FAR struct net_driver_s *udp_find_raddr_device(FAR struct udp_conn_s *conn)
       if (conn->domain == PF_INET)
 #endif
         {
+          in_addr_t raddr;
+
+          if (remote)
+            {
+              FAR const struct sockaddr_in *inaddr =
+                (FAR const struct sockaddr_in *)remote;
+              net_ipv4addr_copy(raddr, inaddr->sin_addr.s_addr);
+            }
+          else
+            {
+              net_ipv4addr_copy(raddr, conn->u.ipv4.raddr);
+            }
+
           /* Check if the remote, destination address is the broadcast
            * or multicast address.  If this is the case, select the device
            * using the locally bound address (assuming that there is one).
            */
 
-          if (conn->u.ipv4.raddr == INADDR_BROADCAST ||
-              IN_MULTICAST(NTOHL(conn->u.ipv4.raddr)))
+          if (raddr == INADDR_BROADCAST || IN_MULTICAST(NTOHL(raddr)))
             {
               /* Make sure that the socket is bound to some non-zero, local
                * address.  Zero is used as an indication that the laddr is
@@ -225,12 +239,12 @@ FAR struct net_driver_s *udp_find_raddr_device(FAR struct udp_conn_s *conn)
            * address.
            */
 
-          else if (conn->u.ipv4.raddr != INADDR_ANY)
+          else if (raddr != INADDR_ANY)
             {
               /* Normal lookup using the verified remote address */
 
               return netdev_findby_ripv4addr(conn->u.ipv4.laddr,
-                                             conn->u.ipv4.raddr);
+                                             raddr);
             }
           else
             {
@@ -248,12 +262,25 @@ FAR struct net_driver_s *udp_find_raddr_device(FAR struct udp_conn_s *conn)
       else
 #endif
         {
+          net_ipv6addr_t raddr;
+
+          if (remote)
+            {
+              FAR const struct sockaddr_in6 *inaddr =
+                (FAR const struct sockaddr_in6 *)remote;
+              net_ipv6addr_copy(raddr, inaddr->sin6_addr.s6_addr16);
+            }
+          else
+            {
+              net_ipv6addr_copy(raddr, conn->u.ipv6.raddr);
+            }
+
           /* Check if the remote, destination address is a multicast
            * address.  If this is the case, select the device
            * using the locally bound address (assuming that there is one).
            */
 
-          if (net_is_addr_mcast(conn->u.ipv6.raddr))
+          if (net_is_addr_mcast(raddr))
             {
               /* Make sure that the socket is bound to some non-zero, local
                * address.  The IPv6 unspecified address is used as an
@@ -278,12 +305,12 @@ FAR struct net_driver_s *udp_find_raddr_device(FAR struct udp_conn_s *conn)
            * address.
            */
 
-          else if (!net_ipv6addr_cmp(conn->u.ipv6.raddr, g_ipv6_unspecaddr))
+          else if (!net_ipv6addr_cmp(raddr, g_ipv6_unspecaddr))
             {
               /* Normal lookup using the verified remote address */
 
               return netdev_findby_ripv6addr(conn->u.ipv6.laddr,
-                                             conn->u.ipv6.raddr);
+                                             raddr);
             }
           else
             {
