@@ -57,10 +57,8 @@ int clock_getres(clockid_t clock_id, struct timespec *res)
         ret = ERROR;
         break;
 
-#ifdef CONFIG_CLOCK_MONOTONIC
       case CLOCK_MONOTONIC:
       case CLOCK_BOOTTIME:
-#endif
       case CLOCK_REALTIME:
 
         /* Form the timspec using clock resolution in nanoseconds */
