@@ -41,6 +41,6 @@ int clock_timekeeping_set_wall_time(FAR struct timespec *ts);
 
 void clock_update_wall_time(void);
 
-void clock_inittimekeeping(void);
+void clock_inittimekeeping(FAR const struct timespec *tp);
 
 #endif /* __SCHED_CLOCK_CLOCK_TIMEKEEPING_H */
