@@ -25,6 +25,7 @@
 #include <nuttx/config.h>
 
 #include <sched.h>
+#include <assert.h>
 #include <errno.h>
 #include <debug.h>
 
@@ -37,19 +38,9 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-/* Note that there cannot be more that CONFIG_MAX_TASKS tasks in total.
- * However, the number of child status structures may need to be
- * significantly larger because this number includes the maximum number of
- * tasks that are running PLUS the number of tasks that have exit'ed without
- * having their exit status reaped (via wait(), waitid(), or waitpid()).
- *
- * Obviously, if tasks spawn children indefinitely and never have the exit
- * status reaped, then you have a memory leak!
- */
-
 #if !defined(CONFIG_PREALLOC_CHILDSTATUS) || CONFIG_PREALLOC_CHILDSTATUS == 0
 #  undef  CONFIG_PREALLOC_CHILDSTATUS
-#  define CONFIG_PREALLOC_CHILDSTATUS (2*CONFIG_MAX_TASKS)
+#  define CONFIG_PREALLOC_CHILDSTATUS 16
 #endif
 
 #ifndef CONFIG_DEBUG_INFO
@@ -165,8 +156,7 @@ void task_initialize(void)
  *
  * Returned Value:
  *   On success, a non-NULL pointer to a child status structure.  NULL is
- *   returned if there are no remaining, pre-allocated child status
- *   structures.
+ *   returned when memory allocation fails.
  *
  * Assumptions:
  *   Called during task creation in a safe context.  No special precautions
@@ -186,6 +176,10 @@ FAR struct child_status_s *group_alloc_child(void)
       g_child_pool.freelist = ret->flink;
       ret->flink            = NULL;
     }
+  else
+    {
+      ret = kmm_zalloc(sizeof(*ret));
+    }
 
   return ret;
 }
