@@ -66,7 +66,8 @@ static FAR struct semholder_s *g_freeholders;
  * Name: nxsem_allocholder
  ****************************************************************************/
 
-static inline FAR struct semholder_s *nxsem_allocholder(sem_t *sem)
+static inline FAR struct semholder_s *
+nxsem_allocholder(FAR sem_t *sem, FAR struct tcb_s *htcb)
 {
   FAR struct semholder_s *pholder;
 
@@ -79,37 +80,43 @@ static inline FAR struct semholder_s *nxsem_allocholder(sem_t *sem)
   pholder = g_freeholders;
   if (pholder != NULL)
     {
-      /* Remove the holder from the free list an put it into the semaphore's
-       * holder list
+      /* Remove the holder from the free list and
+       * put it into the semaphore's holder list
        */
 
       g_freeholders    = pholder->flink;
       pholder->flink   = sem->hhead;
       sem->hhead       = pholder;
-
-      /* Make sure the initial count is zero */
-
-      pholder->counts  = 0;
     }
 #else
   if (sem->holder[0].htcb == NULL)
     {
       pholder          = &sem->holder[0];
-      pholder->counts  = 0;
     }
   else if (sem->holder[1].htcb == NULL)
     {
       pholder          = &sem->holder[1];
-      pholder->counts  = 0;
     }
 #endif
   else
     {
       serr("ERROR: Insufficient pre-allocated holders\n");
       pholder          = NULL;
+      DEBUGASSERT(0);
+    }
+
+  if (pholder != NULL)
+    {
+      pholder->sem    = sem;
+      pholder->htcb   = htcb;
+      pholder->counts = 0;
+
+      /* Put it into the task's list */
+
+      pholder->tlink  = htcb->holdsem;
+      htcb->holdsem   = pholder;
     }
 
-  DEBUGASSERT(pholder != NULL);
   return pholder;
 }
 
@@ -122,8 +129,8 @@ static inline FAR struct semholder_s *nxsem_allocholder(sem_t *sem)
  *
  ****************************************************************************/
 
-static FAR struct semholder_s *nxsem_findholder(sem_t *sem,
-                                                FAR struct tcb_s *htcb)
+static FAR struct semholder_s *
+nxsem_findholder(FAR sem_t *sem, FAR struct tcb_s *htcb)
 {
   FAR struct semholder_s *pholder;
 
@@ -143,7 +150,6 @@ static FAR struct semholder_s *nxsem_findholder(sem_t *sem,
     }
 #else
   int i;
-  pholder = NULL;
 
   /* We have two hard-allocated holder structures in sem_t */
 
@@ -169,12 +175,12 @@ static FAR struct semholder_s *nxsem_findholder(sem_t *sem,
  ****************************************************************************/
 
 static inline FAR struct semholder_s *
-nxsem_findorallocateholder(sem_t *sem, FAR struct tcb_s *htcb)
+nxsem_findorallocateholder(FAR sem_t *sem, FAR struct tcb_s *htcb)
 {
   FAR struct semholder_s *pholder = nxsem_findholder(sem, htcb);
   if (!pholder)
     {
-      pholder = nxsem_allocholder(sem);
+      pholder = nxsem_allocholder(sem, htcb);
     }
 
   return pholder;
@@ -184,64 +190,70 @@ nxsem_findorallocateholder(sem_t *sem, FAR struct tcb_s *htcb)
  * Name: nxsem_freeholder
  ****************************************************************************/
 
-static inline void nxsem_freeholder(sem_t *sem,
+static inline void nxsem_freeholder(FAR sem_t *sem,
                                     FAR struct semholder_s *pholder)
 {
-#if CONFIG_SEM_PREALLOCHOLDERS > 0
-  FAR struct semholder_s *curr;
-  FAR struct semholder_s *prev;
-#endif
+  FAR struct semholder_s * FAR *curr;
+
+  /* Remove the holder from the task's list */
+
+  for (curr = &pholder->htcb->holdsem;
+       *curr != NULL;
+       curr = &(*curr)->tlink)
+    {
+      if (*curr == pholder)
+        {
+          *curr = pholder->tlink;
+          break;
+        }
+    }
 
   /* Release the holder and counts */
 
+  pholder->tlink  = NULL;
+  pholder->sem    = NULL;
   pholder->htcb   = NULL;
   pholder->counts = 0;
 
 #if CONFIG_SEM_PREALLOCHOLDERS > 0
-  /* Search the list for the matching holder */
+  /* Remove the holder from the semaphore's list */
 
-  for (prev = NULL, curr = sem->hhead;
-       curr && curr != pholder;
-       prev = curr, curr = curr->flink);
-
-  if (curr != NULL)
+  for (curr = &sem->hhead;
+       *curr != NULL;
+       curr = &(*curr)->flink)
     {
-      /* Remove the holder from the list */
-
-      if (prev != NULL)
+      if (*curr == pholder)
         {
-          prev->flink = pholder->flink;
+          *curr = pholder->flink;
+          break;
         }
-      else
-        {
-          sem->hhead = pholder->flink;
-        }
-
-      /* And put it in the free list */
-
-      pholder->flink = g_freeholders;
-      g_freeholders  = pholder;
     }
+
+  /* And put it in the free list */
+
+  pholder->flink = g_freeholders;
+  g_freeholders  = pholder;
 #endif
 }
 
 /****************************************************************************
- * Name: nxsem_findandfreeholder
+ * Name: nxsem_freecount0holder
  ****************************************************************************/
 
-static inline void nxsem_findandfreeholder(sem_t *sem,
-                                           FAR struct tcb_s *htcb)
+static int nxsem_freecount0holder(FAR struct semholder_s *pholder,
+                                  FAR sem_t *sem, FAR void *arg)
 {
-  FAR struct semholder_s *pholder = nxsem_findholder(sem, htcb);
-
   /* When no more counts are held, remove the holder from the list.  The
    * count was decremented in nxsem_release_holder.
    */
 
-  if (pholder != NULL && pholder->counts <= 0)
+  if (pholder->counts <= 0)
     {
       nxsem_freeholder(sem, pholder);
+      return 1;
     }
+
+  return 0;
 }
 
 /****************************************************************************
@@ -263,23 +275,18 @@ static int nxsem_foreachholder(FAR sem_t *sem, holderhandler_t handler,
 
       next = pholder->flink;
 
-      /* Check if there is a handler... there should always be one
-       * in this configuration.
-       */
+      DEBUGASSERT(pholder->htcb != NULL);
 
-      if (pholder->htcb != NULL)
-        {
-          /* Call the handler */
+      /* Call the handler */
 
-          ret = handler(pholder, sem, arg);
-        }
+      ret = handler(pholder, sem, arg);
     }
 #else
   int i;
 
   /* We have two hard-allocated holder structures in sem_t */
 
-  for (i = 0; i < 2; i++)
+  for (i = 0; i < 2 && ret == 0; i++)
     {
       pholder = &sem->holder[i];
 
@@ -301,14 +308,12 @@ static int nxsem_foreachholder(FAR sem_t *sem, holderhandler_t handler,
  * Name: nxsem_recoverholders
  ****************************************************************************/
 
-#if CONFIG_SEM_PREALLOCHOLDERS > 0
 static int nxsem_recoverholders(FAR struct semholder_s *pholder,
                                 FAR sem_t *sem, FAR void *arg)
 {
   nxsem_freeholder(sem, pholder);
   return 0;
 }
-#endif
 
 /****************************************************************************
  * Name: nxsem_boostholderprio
@@ -320,25 +325,13 @@ static int nxsem_boostholderprio(FAR struct semholder_s *pholder,
   FAR struct tcb_s *htcb = (FAR struct tcb_s *)pholder->htcb;
   FAR struct tcb_s *rtcb = (FAR struct tcb_s *)arg;
 
-  /* Make sure that the holder thread is still active.  If it exited without
-   * releasing its counts, then that would be a bad thing.  But we can take
-   * no real action because we don't know what the program is doing.
-   * Perhaps its plan is to kill a thread, then destroy the semaphore.
-   */
-
-  if (!nxsched_verify_tcb(htcb))
-    {
-      swarn("WARNING: TCB %p is a stale handle, counts lost\n", htcb);
-      nxsem_freeholder(sem, pholder);
-    }
-
 #if CONFIG_SEM_NNESTPRIO > 0
   /* If the priority of the thread that is waiting for a count is greater
    * than the base priority of the thread holding a count, then we may need
    * to adjust the holder's priority now or later to that priority.
    */
 
-  else if (rtcb->sched_priority > htcb->base_priority)
+  if (rtcb->sched_priority > htcb->base_priority)
     {
       /* If the new priority is greater than the current, possibly already
        * boosted priority of the holder thread, then we will have to raise
@@ -407,7 +400,7 @@ static int nxsem_boostholderprio(FAR struct semholder_s *pholder,
    * because the thread is already running at a sufficient priority.
    */
 
-  else if (rtcb->sched_priority > htcb->sched_priority)
+  if (rtcb->sched_priority > htcb->sched_priority)
     {
       /* Raise the priority of the holder of the semaphore.  This
        * cannot cause a context switch because we have preemption
@@ -447,6 +440,7 @@ static int nxsem_verifyholder(FAR struct semholder_s *pholder,
 #endif
   DEBUGASSERT(htcb->sched_priority == htcb->base_priority);
 #endif
+
   return 0;
 }
 #endif
@@ -460,11 +454,13 @@ static int nxsem_dumpholder(FAR struct semholder_s *pholder, FAR sem_t *sem,
                             FAR void *arg)
 {
 #if CONFIG_SEM_PREALLOCHOLDERS > 0
-  _info("  %08x: %08x %08x %04x\n",
-        pholder, pholder->flink, pholder->htcb, pholder->counts);
+  _info("  %08x: %08x %08x %08x %08x %04x\n",
+        pholder, pholder->flink,
 #else
-  _info("  %08x: %08x %04x\n", pholder, pholder->htcb, pholder->counts);
+  _info("  %08x: %08x %08x %08x %04x\n",
+        pholder,
 #endif
+        pholder->tlink, pholder->sem, pholder->htcb, pholder->counts);
   return 0;
 }
 #endif
@@ -473,10 +469,10 @@ static int nxsem_dumpholder(FAR struct semholder_s *pholder, FAR sem_t *sem,
  * Name: nxsem_restoreholderprio
  ****************************************************************************/
 
-static int nxsem_restoreholderprio(FAR struct tcb_s *htcb,
+static int nxsem_restoreholderprio(FAR struct semholder_s *pholder,
                                    FAR sem_t *sem, FAR void *arg)
 {
-  FAR struct semholder_s *pholder = 0;
+  FAR struct tcb_s *htcb = pholder->htcb;
 #if CONFIG_SEM_NNESTPRIO > 0
   FAR struct tcb_s *stcb = (FAR struct tcb_s *)arg;
   int rpriority;
@@ -484,28 +480,20 @@ static int nxsem_restoreholderprio(FAR struct tcb_s *htcb,
   int j;
 #endif
 
-  /* Make sure that the holder thread is still active.  If it exited without
-   * releasing its counts, then that would be a bad thing.  But we can take
-   * no real action because we don't know what the program is doing.
-   * Perhaps its plan is to kill a thread, then destroy the semaphore.
+  /* Release the holder if all counts have been given up
+   * before reprioritizing causes a context switch.
    */
 
-  if (!nxsched_verify_tcb(htcb))
+  if (pholder->counts <= 0)
     {
-      swarn("WARNING: TCB %p is a stale handle, counts lost\n", htcb);
-
-      pholder = nxsem_findholder(sem, htcb);
-      if (pholder != NULL)
-        {
-          nxsem_freeholder(sem, pholder);
-        }
+      nxsem_freeholder(sem, pholder);
     }
 
   /* Was the priority of the holder thread boosted? If so, then drop its
    * priority back to the correct level.  What is the correct level?
    */
 
-  else if (htcb->sched_priority != htcb->base_priority)
+  if (htcb->sched_priority != htcb->base_priority)
     {
 #if CONFIG_SEM_NNESTPRIO > 0
       /* Are there other, pending priority levels to revert to? */
@@ -617,20 +605,6 @@ static int nxsem_restoreholderprio(FAR struct tcb_s *htcb,
   return 0;
 }
 
-/****************************************************************************
- * Name: nxsem_restoreholderprioall
- *
- * Description:
- *   Reprioritize all holders
- *
- ****************************************************************************/
-
-static int nxsem_restoreholderprioall(FAR struct semholder_s *pholder,
-                                      FAR sem_t *sem, FAR void *arg)
-{
-  return nxsem_restoreholderprio(pholder->htcb, sem, arg);
-}
-
 /****************************************************************************
  * Name: nxsem_restoreholderprio_others
  *
@@ -645,7 +619,7 @@ static int nxsem_restoreholderprio_others(FAR struct semholder_s *pholder,
   FAR struct tcb_s *rtcb = this_task();
   if (pholder->htcb != rtcb)
     {
-      return nxsem_restoreholderprio(pholder->htcb, sem, arg);
+      return nxsem_restoreholderprio(pholder, sem, arg);
     }
 
   return 0;
@@ -668,16 +642,7 @@ static int nxsem_restoreholderprio_self(FAR struct semholder_s *pholder,
     {
       /* The running task has given up a count on the semaphore */
 
-#if CONFIG_SEM_PREALLOCHOLDERS == 0
-      /* In the case where there are only 2 holders. This step
-       * is necessary to ensure we have space. Release the holder
-       * if all counts have been given up before reprioritizing
-       * causes a context switch.
-       */
-
-      nxsem_findandfreeholder(sem, rtcb);
-#endif
-      nxsem_restoreholderprio(rtcb, sem, arg);
+      nxsem_restoreholderprio(pholder, sem, arg);
       return 1;
     }
 
@@ -719,30 +684,9 @@ static int nxsem_restoreholderprio_self(FAR struct semholder_s *pholder,
 static inline void nxsem_restore_baseprio_irq(FAR struct tcb_s *stcb,
                                               FAR sem_t *sem)
 {
-  /* Perform the following actions only if a new thread was given a count.
-   * The thread that received the count should be the highest priority
-   * of all threads waiting for a count from the semaphore.  So in that
-   * case, the priority of all holder threads should be dropped to the
-   * next highest pending priority.
-   */
+  /* Drop the priority of all holder threads */
 
-  if (stcb != NULL)
-    {
-      /* Drop the priority of all holder threads */
-
-      nxsem_foreachholder(sem, nxsem_restoreholderprioall, stcb);
-    }
-
-  /* If there are no tasks waiting for available counts, then all holders
-   * should be at their base priority.
-   */
-
-#ifdef CONFIG_DEBUG_ASSERTIONS
-  else
-    {
-      nxsem_foreachholder(sem, nxsem_verifyholder, NULL);
-    }
-#endif
+  nxsem_foreachholder(sem, nxsem_restoreholderprio, stcb);
 }
 
 /****************************************************************************
@@ -780,50 +724,20 @@ static inline void nxsem_restore_baseprio_irq(FAR struct tcb_s *stcb,
 static inline void nxsem_restore_baseprio_task(FAR struct tcb_s *stcb,
                                                FAR sem_t *sem)
 {
-  FAR struct tcb_s *rtcb = this_task();
-
-  /* Perform the following actions only if a new thread was given a count.
-   * The thread that received the count should be the highest priority
-   * of all threads waiting for a count from the semaphore.  So in that
-   * case, the priority of all holder threads should be dropped to the
-   * next highest pending priority.
+  /* The currently executed thread should be the lower priority
+   * thread that just posted the count and caused this action.
+   * However, we cannot drop the priority of the currently running
+   * thread -- because that will cause it to be suspended.
+   *
+   * So, do this in two passes.  First, reprioritizing all holders
+   * except for the running thread.
    */
 
-  if (stcb != NULL)
-    {
-      /* The currently executed thread should be the lower priority
-       * thread that just posted the count and caused this action.
-       * However, we cannot drop the priority of the currently running
-       * thread -- because that will cause it to be suspended.
-       *
-       * So, do this in two passes.  First, reprioritizing all holders
-       * except for the running thread.
-       */
+  nxsem_foreachholder(sem, nxsem_restoreholderprio_others, stcb);
 
-      nxsem_foreachholder(sem, nxsem_restoreholderprio_others, stcb);
+  /* Now, find an reprioritize only the ready to run task */
 
-      /* Now, find an reprioritize only the ready to run task */
-
-      nxsem_foreachholder(sem, nxsem_restoreholderprio_self, stcb);
-    }
-
-  /* If there are no tasks waiting for available counts, then all holders
-   * should be at their base priority.
-   */
-
-#ifdef CONFIG_DEBUG_ASSERTIONS
-  else
-    {
-      nxsem_foreachholder(sem, nxsem_verifyholder, NULL);
-    }
-#endif
-
-  /* In any case, the currently executing task should have an entry in the
-   * list.  Its counts were previously decremented; if it now holds no
-   * counts, then we need to remove it from the list of holders.
-   */
-
-  nxsem_findandfreeholder(sem, rtcb);
+  nxsem_foreachholder(sem, nxsem_restoreholderprio_self, stcb);
 }
 
 /****************************************************************************
@@ -906,7 +820,6 @@ void nxsem_destroyholder(FAR sem_t *sem)
        */
 
       DEBUGASSERT(sem->hhead->flink == NULL);
-      nxsem_foreachholder(sem, nxsem_recoverholders, NULL);
     }
 
 #else
@@ -914,9 +827,9 @@ void nxsem_destroyholder(FAR sem_t *sem)
 
   DEBUGASSERT(sem->holder[0].htcb == NULL || sem->holder[1].htcb == NULL);
 
-  sem->holder[0].htcb = NULL;
-  sem->holder[1].htcb = NULL;
 #endif
+
+  nxsem_foreachholder(sem, nxsem_recoverholders, NULL);
 }
 
 /****************************************************************************
@@ -942,23 +855,21 @@ void nxsem_add_holder_tcb(FAR struct tcb_s *htcb, FAR sem_t *sem)
 {
   FAR struct semholder_s *pholder;
 
-  /* If priority inheritance is disabled for this thread, then do not add
-   * the holder.  If there are never holders of the semaphore, the priority
+  /* If priority inheritance is disabled for this thread or it is IDLE
+   * thread, then do not add the holder.
+   * If there are never holders of the semaphore, the priority
    * inheritance is effectively disabled.
    */
 
-  if ((sem->flags & PRIOINHERIT_FLAGS_DISABLE) == 0)
+  if (htcb->flink != NULL && (sem->flags & PRIOINHERIT_FLAGS_DISABLE) == 0)
     {
       /* Find or allocate a container for this new holder */
 
       pholder = nxsem_findorallocateholder(sem, htcb);
-      if (pholder != NULL)
+      if (pholder != NULL && pholder->counts < SEM_VALUE_MAX)
         {
-          /* Then set the holder and increment the number of counts held by
-           * this holder
-           */
+          /* Increment the number of counts held by this holder */
 
-          pholder->htcb = htcb;
           pholder->counts++;
         }
     }
@@ -1035,18 +946,60 @@ void nxsem_release_holder(FAR sem_t *sem)
 {
   FAR struct tcb_s *rtcb = this_task();
   FAR struct semholder_s *pholder;
+  FAR struct semholder_s *candidate = NULL;
+  unsigned int total = 0;
 
   /* Find the container for this holder */
 
-  pholder = nxsem_findholder(sem, rtcb);
-  if (pholder != NULL && pholder->counts > 0)
+#if CONFIG_SEM_PREALLOCHOLDERS > 0
+  for (pholder = sem->hhead; pholder; pholder = pholder->flink)
+#else
+  int i;
+
+  /* We have two hard-allocated holder structures in sem_t */
+
+  for (i = 0; i < 2; i++)
+#endif
     {
-      /* Decrement the counts on this holder -- the holder will be freed
-       * later in nxsem_restore_baseprio.
+#if CONFIG_SEM_PREALLOCHOLDERS == 0
+      pholder = &sem->holder[i];
+      if (pholder->htcb == NULL)
+        {
+          continue;
+        }
+#endif
+
+      DEBUGASSERT(pholder->counts > 0);
+
+      if (pholder->htcb == rtcb)
+        {
+          /* Decrement the counts on this holder -- the holder will be freed
+           * later in nxsem_restore_baseprio.
+           */
+
+          pholder->counts--;
+          return;
+        }
+
+      total++;
+      candidate = pholder;
+    }
+
+  /* The current task is not a holder */
+
+  if (total == 1)
+    {
+      /* If the sempahore has only one holder, we can decrement the counts
+       * simply.
        */
 
-      pholder->counts--;
+      candidate->counts--;
+      return;
     }
+
+  /* TODO:
+   *   How do we choose the holder to decrement it's counts?
+   */
 }
 
 /****************************************************************************
@@ -1091,21 +1044,45 @@ void nxsem_restore_baseprio(FAR struct tcb_s *stcb, FAR sem_t *sem)
               (sem->semcount <= 0 && stcb != NULL));
 #endif
 
-  /* Handler semaphore counts posed from an interrupt handler differently
-   * from interrupts posted from threads.  The primary difference is that
-   * if the semaphore is posted from a thread, then the poster thread is
-   * a player in the priority inheritance scheme.  The interrupt handler
-   * externally injects the new count without otherwise participating
-   * itself.
+  /* Perform the following actions only if a new thread was given a count.
+   * The thread that received the count should be the highest priority
+   * of all threads waiting for a count from the semaphore.  So in that
+   * case, the priority of all holder threads should be dropped to the
+   * next highest pending priority.
    */
 
-  if (up_interrupt_context())
+  if (stcb != NULL)
     {
-      nxsem_restore_baseprio_irq(stcb, sem);
+      /* Handler semaphore counts posed from an interrupt handler differently
+       * from interrupts posted from threads.  The primary difference is that
+       * if the semaphore is posted from a thread, then the poster thread is
+       * a player in the priority inheritance scheme.  The interrupt handler
+       * externally injects the new count without otherwise participating
+       * itself.
+       */
+
+      if (up_interrupt_context())
+        {
+          nxsem_restore_baseprio_irq(stcb, sem);
+        }
+      else
+        {
+          nxsem_restore_baseprio_task(stcb, sem);
+        }
     }
   else
     {
-      nxsem_restore_baseprio_task(stcb, sem);
+      /* Remove the holder from the list if it's counts is zero. */
+
+      nxsem_foreachholder(sem, nxsem_freecount0holder, NULL);
+
+      /* If there are no tasks waiting for available counts, then all holders
+       * should be at their base priority.
+       */
+
+#ifdef CONFIG_DEBUG_ASSERTIONS
+      nxsem_foreachholder(sem, nxsem_verifyholder, NULL);
+#endif
     }
 }
 
@@ -1136,7 +1113,7 @@ void nxsem_canceled(FAR struct tcb_s *stcb, FAR sem_t *sem)
 
   /* Adjust the priority of every holder as necessary */
 
-  nxsem_foreachholder(sem, nxsem_restoreholderprioall, stcb);
+  nxsem_foreachholder(sem, nxsem_restoreholderprio, stcb);
 }
 
 /****************************************************************************
@@ -1200,4 +1177,32 @@ int nxsem_nfreeholders(void)
 }
 #endif
 
+/****************************************************************************
+ * Name: nxsem_release_all
+ *
+ * Description:
+ *   Release all semaphore holders for the task.
+ *
+ * Input Parameters:
+ *   htcb - TCB of the task
+ *
+ * Returned Value:
+ *   None
+ *
+ * Assumptions:
+ *
+ ****************************************************************************/
+
+void nxsem_release_all(FAR struct tcb_s *htcb)
+{
+  FAR struct semholder_s *pholder;
+
+  while ((pholder = htcb->holdsem) != NULL)
+    {
+      FAR sem_t *sem = pholder->sem;
+
+      nxsem_freeholder(sem, pholder);
+    }
+}
+
 #endif /* CONFIG_PRIORITY_INHERITANCE */
