@@ -25,6 +25,8 @@
 #include <nuttx/config.h>
 
 #include <sched.h>
+#include <assert.h>
+#include <debug.h>
 
 #include <nuttx/irq.h>
 #include <nuttx/wqueue.h>
