@@ -37,7 +37,7 @@ EXTRA_PATH=
 
 case ${os} in
   Darwin)
-    install="python-tools u-boot-tools elf-toolchain gen-romfs kconfig-frontends arm-gcc-toolchain riscv-gcc-toolchain xtensa-esp32-gcc-toolchain avr-gcc-toolchain c-cache binutils"
+    install="python-tools u-boot-tools elf-toolchain gen-romfs kconfig-frontends rust arm-gcc-toolchain riscv-gcc-toolchain xtensa-esp32-gcc-toolchain avr-gcc-toolchain c-cache binutils"
     mkdir -p "${prebuilt}"/homebrew
     export HOMEBREW_CACHE=${prebuilt}/homebrew
     # https://github.com/actions/virtual-environments/issues/2322#issuecomment-749211076
@@ -46,7 +46,7 @@ case ${os} in
     brew update --quiet
     ;;
   Linux)
-    install="python-tools gen-romfs gperf kconfig-frontends arm-gcc-toolchain mips-gcc-toolchain riscv-gcc-toolchain xtensa-esp32-gcc-toolchain rx-gcc-toolchain c-cache"
+    install="python-tools gen-romfs gperf kconfig-frontends rust arm-gcc-toolchain mips-gcc-toolchain riscv-gcc-toolchain xtensa-esp32-gcc-toolchain rx-gcc-toolchain sparc-gcc-toolchain c-cache"
     ;;
 esac
 
@@ -164,10 +164,10 @@ function arm-gcc-toolchain {
         ;;
     esac
     cd "${prebuilt}"
-    wget --quiet https://developer.arm.com/-/media/Files/downloads/gnu-rm/9-2019q4/RC2.1/gcc-arm-none-eabi-9-2019-q4-major-${flavor}.tar.bz2
-    tar jxf gcc-arm-none-eabi-9-2019-q4-major-${flavor}.tar.bz2
-    mv gcc-arm-none-eabi-9-2019-q4-major gcc-arm-none-eabi
-    rm gcc-arm-none-eabi-9-2019-q4-major-${flavor}.tar.bz2
+    wget --quiet https://developer.arm.com/-/media/Files/downloads/gnu-rm/10.3-2021.10/gcc-arm-none-eabi-10.3-2021.10-${flavor}.tar.bz2
+    tar jxf gcc-arm-none-eabi-10.3-2021.10-${flavor}.tar.bz2
+    mv gcc-arm-none-eabi-10.3-2021.10 gcc-arm-none-eabi
+    rm gcc-arm-none-eabi-10.3-2021.10-${flavor}.tar.bz2
   fi
   arm-none-eabi-gcc --version
 }
@@ -288,6 +288,24 @@ function rx-gcc-toolchain {
   rx-elf-gcc --version
 }
 
+function sparc-gcc-toolchain {
+  add_path "${prebuilt}"/sparc-gaisler-elf-gcc/bin
+
+  if [ ! -f "${prebuilt}/sparc-gaisler-elf-gcc/bin/sparc-gaisler-elf-gcc" ]; then
+    case ${os} in
+      Linux)
+        cd "${prebuilt}"
+        wget --quiet https://www.gaisler.com/anonftp/bcc2/bin/bcc-2.1.0-gcc-linux64.tar.xz
+        xz -d bcc-2.1.0-gcc-linux64.tar.xz
+        tar xf bcc-2.1.0-gcc-linux64.tar
+        mv bcc-2.1.0-gcc sparc-gaisler-elf-gcc
+        rm bcc-2.1.0-gcc-linux64.tar
+        ;;
+    esac
+  fi
+  sparc-gaisler-elf-gcc --version
+}
+
 function c-cache {
   add_path "${prebuilt}"/ccache/bin
 
@@ -324,6 +342,8 @@ function c-cache {
   ln -sf "$(which ccache)" "${prebuilt}"/ccache/bin/xtensa-esp32-elf-gcc
   ln -sf "$(which ccache)" "${prebuilt}"/ccache/bin/avr-gcc
   ln -sf "$(which ccache)" "${prebuilt}"/ccache/bin/avr-g++
+  ln -sf "$(which ccache)" "${prebuilt}"/ccache/bin/sparc-gaisler-elf-gcc
+  ln -sf "$(which ccache)" "${prebuilt}"/ccache/bin/sparc-gaisler-elf-g++
 }
 
 function binutils {
@@ -335,7 +355,7 @@ function binutils {
       Darwin)
         brew install binutils
         # It is possible we cached prebuilt but did brew install so recreate
-        # simlink if it exists
+        # symlink if it exists
         rm -f "${prebuilt}"/bintools/bin/objcopy
         ln -s /usr/local/opt/binutils/bin/objcopy "${prebuilt}"/bintools/bin/objcopy
         ;;
@@ -343,6 +363,24 @@ function binutils {
   fi
 }
 
+function rust {
+  mkdir -p "${prebuilt}"/rust/bin
+  add_path "${prebuilt}"/rust/bin
+
+  if ! type rustc &> /dev/null; then
+    case ${os} in
+      Darwin)
+        brew install rust
+        ;;
+      Linux)
+        # Currently Debian installed rustc doesn't support 2021 edition.
+        export CARGO_HOME=${prebuilt}/rust
+        curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh -s -- -y
+        ;;
+    esac
+  fi
+}
+
 function usage {
   echo ""
   echo "USAGE: $0 [-i] [-s] [-c] [-*] <testlist>"
