@@ -199,12 +199,6 @@ static void generate_proxy(int nfixed, int nparms)
           g_parm[NAME_INDEX]);
   fprintf(stream, "#include <nuttx/config.h>\n");
 
-  /* Suppress "'noreturn' function does return" warnings. */
-
-  fprintf(stream, "#include <nuttx/compiler.h>\n");
-  fprintf(stream, "#undef noreturn_function\n");
-  fprintf(stream, "#define noreturn_function\n");
-
   /* Does this function have a variable number of parameters?  If so then the
    * final parameter type will be encoded as "..."
    */
@@ -230,7 +224,16 @@ static void generate_proxy(int nfixed, int nparms)
    * prototype
    */
 
-  fprintf(stream, "%s %s(", g_parm[RETTYPE_INDEX], g_parm[NAME_INDEX]);
+  if (strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
+    {
+      fprintf(stream, "void ");
+    }
+  else
+    {
+      fprintf(stream, "%s ", g_parm[RETTYPE_INDEX]);
+    }
+
+  fprintf(stream, "%s(", g_parm[NAME_INDEX]);
 
   /* Generate the formal parameter list */
 
@@ -307,7 +310,8 @@ static void generate_proxy(int nfixed, int nparms)
    * are special cases.
    */
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0 ||
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
     {
       fprintf(stream, "  (void)sys_call%d(", nparms);
     }
@@ -345,7 +349,14 @@ static void generate_proxy(int nfixed, int nparms)
 
   /* Handle the tail end of the function. */
 
-  fprintf(stream, ");\n}\n");
+  fprintf(stream, ");\n");
+  if (strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
+    {
+        fprintf(stream, "  while(1);\n");
+    }
+
+  fprintf(stream, "}\n");
+
   if (g_parm[COND_INDEX][0] != '\0')
     {
       fprintf(stream, "\n#endif /* %s */\n", g_parm[COND_INDEX]);
@@ -454,7 +465,8 @@ static void generate_stub(int nfixed, int nparms)
    * a special case.
    */
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0 ||
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
     {
       fprintf(stream, "  %s(", g_parm[NAME_INDEX]);
     }
@@ -600,8 +612,16 @@ static void generate_wrapper(int nfixed, int nparms)
    * prototype
    */
 
-  fprintf(stream, "%s UP_WRAPSYM(%s)(", g_parm[RETTYPE_INDEX],
-          g_parm[NAME_INDEX]);
+  if (strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
+    {
+      fprintf(stream, "void ");
+    }
+  else
+    {
+      fprintf(stream, "%s ", g_parm[RETTYPE_INDEX]);
+    }
+
+  fprintf(stream, "UP_WRAPSYM(%s)(", g_parm[NAME_INDEX]);
 
   /* Generate the formal parameter list */
 
@@ -643,15 +663,24 @@ static void generate_wrapper(int nfixed, int nparms)
 
   /* Generate the result variable definition for non-void function */
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") != 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") != 0 &&
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") != 0)
     {
       fprintf(stream, "  %s result;\n", g_parm[RETTYPE_INDEX]);
     }
 
   /* Generate the wrapped (real) function prototype definition */
 
-  fprintf(stream, "  %s UP_REALSYM(%s)(", g_parm[RETTYPE_INDEX],
-          g_parm[NAME_INDEX]);
+  if (strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
+    {
+      fprintf(stream, "  void ");
+    }
+  else
+    {
+      fprintf(stream, "  %s ", g_parm[RETTYPE_INDEX]);
+    }
+
+  fprintf(stream, "UP_REALSYM(%s)(", g_parm[NAME_INDEX]);
 
   /* Generate the formal parameter list */
 
@@ -755,7 +784,8 @@ static void generate_wrapper(int nfixed, int nparms)
    * value are a special case.
    */
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0 ||
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
     {
       fprintf(stream, "  UP_REALSYM(%s)(", g_parm[NAME_INDEX]);
     }
@@ -786,7 +816,8 @@ static void generate_wrapper(int nfixed, int nparms)
 
   fprintf(stream, "  sched_note_syscall_leave(SYS_%s, ", g_parm[NAME_INDEX]);
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0 ||
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
     {
       fprintf(stream, "0");
     }
@@ -801,7 +832,8 @@ static void generate_wrapper(int nfixed, int nparms)
    * value, do nothing.
    */
 
-  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0)
+  if (strcmp(g_parm[RETTYPE_INDEX], "void") == 0 ||
+      strcmp(g_parm[RETTYPE_INDEX], "noreturn") == 0)
     {
       fprintf(stream, "}\n");
     }
