@@ -248,9 +248,44 @@ static const char *g_white_list[] =
   "_Far",
   "_Erom",
 
+  /* Ref:
+   * arch/sim/src/sim/up_wpcap.c
+   */
+
+  "Address",
+  "Description",
+  "FirstUnicastAddress",
+  "GetAdaptersAddresses",
+  "GetProcAddress",
+  "LoadLibrary",
+  "lpSockaddr",
+  "Next",
+  "PhysicalAddressLength",
+  "PhysicalAddress",
+  "WideCharToMultiByte",
+
+  /* Ref:
+   * drivers/segger/note_sysview.c
+   */
+
+  "SEGGER_SYSVIEW",
+  "TaskID",
+  "sName",
+  "Prio",
+  "StackBase",
+  "StackSize",
+
+  /* Ref:
+   * drivers/segger/syslog_rtt.c
+   */
+
+  "SEGGER_RTT",
+
   /* Ref:
    * fs/nfs/rpc.h
    * fs/nfs/nfs_proto.h
+   * fs/nfs/nfs_mount.h
+   * fs/nfs/nfs_vfsops.c
    */
 
   "CREATE3args",
@@ -275,6 +310,37 @@ static const char *g_white_list[] =
   "SETATTR3args",
   "SETATTR3resok",
   "FS3args",
+  "SIZEOF_rpc_reply_read",
+  "SIZEOF_rpc_call_write",
+  "SIZEOF_rpc_reply_readdir",
+  "SIZEOF_nfsmount",
+
+  /* Ref:
+   * mm/kasan/kasan.c
+   */
+
+  "__asan_loadN",
+  "__asan_storeN",
+  "__asan_loadN_noabort",
+  "__asan_storeN_noabort",
+
+  /* Ref:
+   * tools/jlink-nuttx.c
+   */
+
+  "RTOS_Init",
+  "RTOS_GetVersion",
+  "RTOS_GetSymbols",
+  "RTOS_GetNumThreads",
+  "RTOS_GetCurrentThreadId",
+  "RTOS_GetThreadId",
+  "RTOS_GetThreadDisplay",
+  "RTOS_GetThreadReg",
+  "RTOS_GetThreadRegList",
+  "RTOS_GetThreadRegList",
+  "RTOS_SetThreadReg",
+  "RTOS_SetThreadRegList",
+  "RTOS_UpdateThreads",
 
   NULL
 };
@@ -1904,7 +1970,7 @@ int main(int argc, char **argv, char **envp)
                        */
 
                       ncomment = 0;
-                       ERROR("Closing without opening comment", lineno, n);
+                      ERROR("Closing without opening comment", lineno, n);
                     }
 
                   n++;
@@ -1917,7 +1983,8 @@ int main(int argc, char **argv, char **envp)
                 {
                   /* Check for URI schemes, e.g. "http://" or "https://" */
 
-                  if (n == 0 || strncmp(&line[n - 1], "://", 3) != 0)
+                  if ((ncomment == 0) &&
+                      (n == 0 || strncmp(&line[n - 1], "://", 3) != 0))
                     {
                       ERROR("C++ style comment", lineno, n);
                       n++;
@@ -2270,7 +2337,7 @@ int main(int argc, char **argv, char **envp)
                                  endndx++);
                           }
 
-                        n = endndx + 1;
+                        n = endndx;
                       }
                   }
                   break;
@@ -2460,7 +2527,7 @@ int main(int argc, char **argv, char **envp)
                     {
                       /* REVISIT: This gives false alarms on syntax like *--ptr */
 
-                      if (line[n - 1] != ' ')
+                      if (line[n - 1] != ' ' && line[n - 1] != '(')
                         {
                            ERROR("Operator/assignment must be preceded "
                                   "with whitespace", lineno, n);
